#!/usr/bin/env python
#
# parses the min jsonline file from OPUS
# Author: Thamme Gowda [tg (at) isi (dot) edu]
# Created: 5/9/20

data="""EUconst_v1	EUconst/v1/moses/%s-%s.txt.zip	cs-da cs-de da-de cs-el da-el de-el cs-en da-en de-en el-en cs-es da-es de-es el-es en-es cs-et da-et de-et el-et en-et es-et cs-fi da-fi de-fi el-fi en-fi es-fi et-fi cs-fr da-fr de-fr el-fr en-fr es-fr et-fr fi-fr cs-ga da-ga de-ga el-ga en-ga es-ga et-ga fi-ga fr-ga cs-hu da-hu de-hu el-hu en-hu es-hu et-hu fi-hu fr-hu ga-hu cs-it da-it de-it el-it en-it es-it et-it fi-it fr-it ga-it hu-it cs-lt da-lt de-lt el-lt en-lt es-lt et-lt fi-lt fr-lt ga-lt hu-lt it-lt cs-lv da-lv de-lv el-lv en-lv es-lv et-lv fi-lv fr-lv ga-lv hu-lv it-lv lt-lv cs-mt da-mt de-mt el-mt en-mt es-mt et-mt fi-mt fr-mt ga-mt hu-mt it-mt lt-mt lv-mt cs-nl da-nl de-nl el-nl en-nl es-nl et-nl fi-nl fr-nl ga-nl hu-nl it-nl lt-nl lv-nl mt-nl cs-pl da-pl de-pl el-pl en-pl es-pl et-pl fi-pl fr-pl ga-pl hu-pl it-pl lt-pl lv-pl mt-pl nl-pl cs-pt da-pt de-pt el-pt en-pt es-pt et-pt fi-pt fr-pt ga-pt hu-pt it-pt lt-pt lv-pt mt-pt nl-pt pl-pt cs-sk da-sk de-sk el-sk en-sk es-sk et-sk fi-sk fr-sk ga-sk hu-sk it-sk lt-sk lv-sk mt-sk nl-sk pl-sk pt-sk cs-sl da-sl de-sl el-sl en-sl es-sl et-sl fi-sl fr-sl ga-sl hu-sl it-sl lt-sl lv-sl mt-sl nl-sl pl-sl pt-sl sk-sl cs-sv da-sv de-sv el-sv en-sv es-sv et-sv fi-sv fr-sv ga-sv hu-sv it-sv lt-sv lv-sv mt-sv nl-sv pl-sv pt-sv sk-sv sl-sv
EUbookshop_v2	EUbookshop/v2/moses/%s-%s.txt.zip	ar-bg bg-bs bg-ca ar-cs bg-cs bs-cs ca-cs cs-cy ar-da bg-da ca-da cs-da cy-da ar-de bg-de bs-de ca-de cs-de cy-de da-de ar-el bg-el bs-el ca-el cs-el cy-el da-el de-el ar-en be-en bg-en bs-en ca-en cs-en cy-en da-en de-en el-en ar-es bg-es bs-es ca-es cs-es cy-es da-es de-es el-es en-es ar-et bg-et bs-et ca-et cs-et cy-et da-et de-et el-et en-et es-et ar-fi bg-fi bs-fi ca-fi cs-fi cy-fi da-fi de-fi el-fi en-fi es-fi et-fi ar-fr bg-fr bs-fr ca-fr cs-fr cy-fr da-fr de-fr el-fr en-fr es-fr et-fr fi-fr ar-ga bg-ga ca-ga cs-ga cy-ga da-ga de-ga el-ga en-ga es-ga et-ga fi-ga fr-ga bg-gd ca-gd cs-gd da-gd de-gd el-gd en-gd es-gd et-gd fi-gd fr-gd ga-gd bg-hr bs-hr ca-hr cs-hr cy-hr da-hr de-hr el-hr en-hr es-hr et-hr fi-hr fr-hr ga-hr ar-hu bg-hu bs-hu ca-hu cs-hu cy-hu da-hu de-hu el-hu en-hu es-hu et-hu fi-hu fr-hu ga-hu gd-hu hr-hu bg-is cs-is da-is de-is el-is en-is es-is et-is fi-is fr-is ga-is hu-is ar-it bg-it bs-it ca-it cs-it cy-it da-it de-it el-it en-it es-it et-it fi-it fr-it ga-it gd-it hr-it hu-it is-it cs-ja da-ja de-ja el-ja en-ja es-ja et-ja fi-ja fr-ja hu-ja it-ja ar-lt bg-lt bs-lt ca-lt cs-lt cy-lt da-lt de-lt el-lt en-lt es-lt et-lt fi-lt fr-lt ga-lt gd-lt hr-lt hu-lt is-lt it-lt ja-lt ar-lv bg-lv bs-lv ca-lv cs-lv cy-lv da-lv de-lv el-lv en-lv es-lv et-lv fi-lv fr-lv ga-lv gd-lv hr-lv hu-lv is-lv it-lv ja-lv lt-lv bg-mk bs-mk cs-mk da-mk de-mk el-mk en-mk es-mk et-mk fi-mk fr-mk ga-mk hr-mk hu-mk is-mk it-mk lt-mk lv-mk ar-mt bg-mt ca-mt cs-mt da-mt de-mt el-mt en-mt es-mt et-mt fi-mt fr-mt ga-mt gd-mt hr-mt hu-mt is-mt it-mt lt-mt lv-mt mk-mt bg-nb bs-nb cs-nb da-nb de-nb el-nb en-nb es-nb et-nb fi-nb fr-nb ga-nb hr-nb hu-nb is-nb it-nb lt-nb lv-nb mk-nb mt-nb ar-nl bg-nl bs-nl ca-nl cs-nl cy-nl da-nl de-nl el-nl en-nl es-nl et-nl fi-nl fr-nl ga-nl gd-nl hr-nl hu-nl is-nl it-nl ja-nl lt-nl lv-nl mk-nl mt-nl nb-nl ar-pl bg-pl bs-pl ca-pl cs-pl cy-pl da-pl de-pl el-pl en-pl es-pl et-pl fi-pl fr-pl ga-pl gd-pl hr-pl hu-pl is-pl it-pl ja-pl lt-pl lv-pl mk-pl mt-pl nb-pl nl-pl ar-pt bg-pt ca-pt cs-pt cy-pt da-pt de-pt el-pt en-pt es-pt et-pt fi-pt fr-pt ga-pt gd-pt hr-pt hu-pt is-pt it-pt ja-pt lt-pt lv-pt mk-pt mt-pt nb-pt nl-pt pl-pt ar-ro bg-ro bs-ro ca-ro cs-ro da-ro de-ro el-ro en-ro es-ro et-ro fi-ro fr-ro ga-ro gd-ro hr-ro hu-ro is-ro it-ro lt-ro lv-ro mk-ro mt-ro nb-ro nl-ro pl-ro pt-ro ar-ru bg-ru cs-ru da-ru de-ru el-ru en-ru es-ru et-ru fi-ru fr-ru ga-ru hr-ru hu-ru is-ru it-ru ja-ru lt-ru lv-ru mk-ru mt-ru nb-ru nl-ru pl-ru pt-ru ro-ru bs-sh en-sh hr-sh ar-sk bg-sk bs-sk ca-sk cs-sk cy-sk da-sk de-sk el-sk en-sk es-sk et-sk fi-sk fr-sk ga-sk gd-sk hr-sk hu-sk is-sk it-sk ja-sk lt-sk lv-sk mk-sk mt-sk nb-sk nl-sk pl-sk pt-sk ro-sk ru-sk ar-sl bg-sl bs-sl ca-sl cs-sl cy-sl da-sl de-sl el-sl en-sl es-sl et-sl fi-sl fr-sl ga-sl gd-sl hr-sl hu-sl is-sl it-sl ja-sl lt-sl lv-sl mk-sl mt-sl nb-sl nl-sl pl-sl pt-sl ro-sl ru-sl sk-sl bg-sq bs-sq cs-sq da-sq de-sq el-sq en-sq es-sq et-sq fi-sq fr-sq ga-sq hr-sq hu-sq it-sq lt-sq lv-sq mk-sq mt-sq nb-sq nl-sq pl-sq pt-sq ro-sq ru-sq sh-sq sk-sq sl-sq bg-sr bs-sr cs-sr da-sr de-sr el-sr en-sr es-sr et-sr fi-sr fr-sr hr-sr hu-sr it-sr lt-sr lv-sr mk-sr mt-sr nb-sr nl-sr pl-sr pt-sr ro-sr ru-sr sh-sr sk-sr sl-sr sq-sr ar-sv bg-sv bs-sv ca-sv cs-sv cy-sv da-sv de-sv el-sv en-sv es-sv et-sv fi-sv fr-sv ga-sv gd-sv hr-sv hu-sv is-sv it-sv ja-sv lt-sv lv-sv mk-sv mt-sv nb-sv nl-sv pl-sv pt-sv ro-sv ru-sv sk-sv sl-sv sq-sv sr-sv bg-sw cs-sw da-sw de-sw el-sw en-sw es-sw et-sw fi-sw fr-sw ga-sw hr-sw hu-sw it-sw lt-sw lv-sw mk-sw mt-sw nb-sw nl-sw pl-sw pt-sw ro-sw ru-sw sk-sw sl-sw sq-sw sr-sw sv-sw da-tc de-tc en-tc es-tc fr-tc hu-tc it-tc nl-tc bg-tr bs-tr cs-tr da-tr de-tr el-tr en-tr es-tr et-tr fi-tr fr-tr ga-tr hr-tr hu-tr is-tr it-tr lt-tr lv-tr mk-tr mt-tr nb-tr nl-tr pl-tr pt-tr ro-tr ru-tr sk-tr sl-tr sq-tr sr-tr sv-tr sw-tr cs-uk cy-uk da-uk de-uk el-uk en-uk es-uk et-uk fi-uk fr-uk hr-uk hu-uk it-uk lt-uk lv-uk mt-uk nl-uk pl-uk pt-uk ru-uk sk-uk sl-uk sv-uk
EMEA_v3	EMEA/v3/moses/%s-%s.txt.zip	bg-cs bg-da cs-da bg-de cs-de da-de bg-el cs-el da-el de-el bg-en cs-en da-en de-en el-en bg-es cs-es da-es de-es el-es en-es bg-et cs-et da-et de-et el-et en-et es-et bg-fi cs-fi da-fi de-fi el-fi en-fi es-fi et-fi bg-fr cs-fr da-fr de-fr el-fr en-fr es-fr et-fr fi-fr bg-hu cs-hu da-hu de-hu el-hu en-hu es-hu et-hu fi-hu fr-hu bg-it cs-it da-it de-it el-it en-it es-it et-it fi-it fr-it hu-it bg-lt cs-lt da-lt de-lt el-lt en-lt es-lt et-lt fi-lt fr-lt hu-lt it-lt bg-lv cs-lv da-lv de-lv el-lv en-lv es-lv et-lv fi-lv fr-lv hu-lv it-lv lt-lv bg-mt cs-mt da-mt de-mt el-mt en-mt es-mt et-mt fi-mt fr-mt hu-mt it-mt lt-mt lv-mt bg-nl cs-nl da-nl de-nl el-nl en-nl es-nl et-nl fi-nl fr-nl hu-nl it-nl lt-nl lv-nl mt-nl bg-pl cs-pl da-pl de-pl el-pl en-pl es-pl et-pl fi-pl fr-pl hu-pl it-pl lt-pl lv-pl mt-pl nl-pl bg-pt cs-pt da-pt de-pt el-pt en-pt es-pt et-pt fi-pt fr-pt hu-pt it-pt lt-pt lv-pt mt-pt nl-pt pl-pt bg-ro cs-ro da-ro de-ro el-ro en-ro es-ro et-ro fi-ro fr-ro hu-ro it-ro lt-ro lv-ro mt-ro nl-ro pl-ro pt-ro bg-sk cs-sk da-sk de-sk el-sk en-sk es-sk et-sk fi-sk fr-sk hu-sk it-sk lt-sk lv-sk mt-sk nl-sk pl-sk pt-sk ro-sk bg-sl cs-sl da-sl de-sl el-sl en-sl es-sl et-sl fi-sl fr-sl hu-sl it-sl lt-sl lv-sl mt-sl nl-sl pl-sl pt-sl ro-sl sk-sl bg-sv cs-sv da-sv de-sv el-sv en-sv es-sv et-sv fi-sv fr-sv hu-sv it-sv lt-sv lv-sv mt-sv nl-sv pl-sv pt-sv ro-sv sk-sv sl-sv
Elhuyar_v1	Elhuyar/v1/moses/%s-%s.txt.zip	es-eu
EhuHac_v1	EhuHac/v1/moses/%s-%s.txt.zip	en-eu es-eu eu-fr
ECB_v1	ECB/v1/moses/%s-%s.txt.zip	cs-da cs-de da-de cs-el da-el de-el cs-en da-en de-en el-en cs-es da-es de-es el-es en-es cs-et da-et de-et el-et en-et es-et cs-fi da-fi de-fi el-fi en-fi es-fi et-fi cs-fr da-fr de-fr el-fr en-fr es-fr et-fr fi-fr cs-hu da-hu de-hu el-hu en-hu es-hu et-hu fi-hu fr-hu cs-it da-it de-it el-it en-it es-it et-it fi-it fr-it hu-it cs-lt da-lt de-lt el-lt en-lt es-lt fi-lt fr-lt hu-lt it-lt cs-lv da-lv de-lv el-lv en-lv es-lv et-lv fi-lv fr-lv hu-lv it-lv lt-lv cs-mt da-mt de-mt el-mt en-mt es-mt et-mt fi-mt fr-mt hu-mt it-mt lt-mt lv-mt cs-nl da-nl de-nl el-nl en-nl es-nl et-nl fi-nl fr-nl hu-nl it-nl lt-nl lv-nl mt-nl cs-pl da-pl de-pl el-pl en-pl es-pl et-pl fi-pl fr-pl hu-pl it-pl lt-pl lv-pl mt-pl nl-pl cs-pt da-pt de-pt el-pt en-pt es-pt et-pt fi-pt fr-pt hu-pt it-pt lt-pt lv-pt mt-pt nl-pt pl-pt cs-sk da-sk de-sk el-sk en-sk es-sk et-sk fi-sk fr-sk hu-sk it-sk lt-sk lv-sk mt-sk nl-sk pl-sk pt-sk cs-sl da-sl de-sl el-sl en-sl es-sl et-sl fi-sl fr-sl hu-sl it-sl lt-sl lv-sl mt-sl nl-sl pl-sl pt-sl sk-sl
DOGC_v2	DOGC/v2/moses/%s-%s.txt.zip	ca-es
DGT_v2019	DGT/v2019/moses/%s-%s.txt.zip	bg-cs bg-da cs-da bg-de cs-de da-de bg-el cs-el da-el de-el bg-en cs-en da-en de-en el-en bg-es cs-es da-es de-es el-es en-es bg-et cs-et da-et de-et el-et en-et es-et bg-fi cs-fi da-fi de-fi el-fi en-fi es-fi et-fi bg-fr cs-fr da-fr de-fr el-fr en-fr es-fr et-fr fi-fr bg-ga cs-ga da-ga de-ga el-ga en-ga es-ga et-ga fi-ga fr-ga bg-hr cs-hr da-hr de-hr el-hr en-hr es-hr et-hr fi-hr fr-hr ga-hr bg-hu cs-hu da-hu de-hu el-hu en-hu es-hu et-hu fi-hu fr-hu ga-hu hr-hu bg-it cs-it da-it de-it el-it en-it es-it et-it fi-it fr-it ga-it hr-it hu-it bg-lt cs-lt da-lt de-lt el-lt en-lt es-lt et-lt fi-lt fr-lt ga-lt hr-lt hu-lt it-lt bg-lv cs-lv da-lv de-lv el-lv en-lv es-lv et-lv fi-lv fr-lv ga-lv hr-lv hu-lv it-lv lt-lv bg-mt cs-mt da-mt de-mt el-mt en-mt es-mt et-mt fi-mt fr-mt ga-mt hr-mt hu-mt it-mt lt-mt lv-mt bg-nl cs-nl da-nl de-nl el-nl en-nl es-nl et-nl fi-nl fr-nl ga-nl hr-nl hu-nl it-nl lt-nl lv-nl mt-nl bg-pl cs-pl da-pl de-pl el-pl en-pl es-pl et-pl fi-pl fr-pl ga-pl hr-pl hu-pl it-pl lt-pl lv-pl mt-pl nl-pl bg-pt cs-pt da-pt de-pt el-pt en-pt es-pt et-pt fi-pt fr-pt ga-pt hr-pt hu-pt it-pt lt-pt lv-pt mt-pt nl-pt pl-pt bg-ro cs-ro da-ro de-ro el-ro en-ro es-ro et-ro fi-ro fr-ro ga-ro hr-ro hu-ro it-ro lt-ro lv-ro mt-ro nl-ro pl-ro pt-ro bg-sh cs-sh da-sh de-sh el-sh en-sh es-sh et-sh fi-sh fr-sh ga-sh hu-sh it-sh lt-sh lv-sh mt-sh nl-sh pl-sh pt-sh ro-sh bg-sk cs-sk da-sk de-sk el-sk en-sk es-sk et-sk fi-sk fr-sk ga-sk hr-sk hu-sk it-sk lt-sk lv-sk mt-sk nl-sk pl-sk pt-sk ro-sk sh-sk bg-sl cs-sl da-sl de-sl el-sl en-sl es-sl et-sl fi-sl fr-sl ga-sl hr-sl hu-sl it-sl lt-sl lv-sl mt-sl nl-sl pl-sl pt-sl ro-sl sh-sl sk-sl bg-sv cs-sv da-sv de-sv el-sv en-sv es-sv et-sv fi-sv fr-sv ga-sv hr-sv hu-sv it-sv lt-sv lv-sv mt-sv nl-sv pl-sv pt-sv ro-sv sh-sv sk-sv sl-sv
CAPES_v1	CAPES/v1/moses/%s-%s.txt.zip	en-pt
Books_v1	Books/v1/moses/%s-%s.txt.zip	ca-de ca-en de-en el-en de-eo en-eo de-es el-es en-es eo-es en-fi es-fi de-fr el-fr en-fr eo-fr es-fr fi-fr ca-hu de-hu el-hu en-hu eo-hu es-hu fi-hu fr-hu de-it en-it eo-it es-it fr-it hu-it ca-nl de-nl en-nl es-nl fr-nl hu-nl it-nl en-no es-no fi-no fr-no hu-no en-pl fi-pl fr-pl hu-pl de-pt en-pt eo-pt es-pt fr-pt hu-pt it-pt de-ru en-ru es-ru fr-ru hu-ru it-ru en-sv fr-sv it-sv
Bianet_v1	Bianet/v1/moses/%s-%s.txt.zip	en-ku en-tr ku-tr
bible_uedin_v1	bible-uedin/v1/moses/%s-%s.txt.zip	acu-af acu-agr af-agr acu-ake af-ake agr-ake acu-am af-am agr-am ake-am acu-amu af-amu agr-amu ake-amu am-amu acu-ar af-ar agr-ar ake-ar am-ar amu-ar acu-bg af-bg agr-bg ake-bg am-bg amu-bg ar-bg acu-bsn af-bsn agr-bsn ake-bsn am-bsn amu-bsn ar-bsn bg-bsn acu-cak af-cak agr-cak ake-cak am-cak amu-cak ar-cak bg-cak bsn-cak acu-ceb af-ceb agr-ceb ake-ceb am-ceb amu-ceb ar-ceb bg-ceb bsn-ceb cak-ceb acu-ch af-ch agr-ch ake-ch am-ch amu-ch ar-ch bg-ch bsn-ch cak-ch ceb-ch acu-chq af-chq agr-chq ake-chq am-chq amu-chq ar-chq bg-chq bsn-chq cak-chq ceb-chq ch-chq acu-chr af-chr agr-chr ake-chr am-chr amu-chr ar-chr bg-chr bsn-chr cak-chr ceb-chr ch-chr chq-chr acu-cjp af-cjp agr-cjp ake-cjp am-cjp amu-cjp ar-cjp bg-cjp bsn-cjp cak-cjp ceb-cjp ch-cjp chq-cjp chr-cjp acu-cni af-cni agr-cni ake-cni am-cni amu-cni ar-cni bg-cni bsn-cni cak-cni ceb-cni ch-cni chq-cni chr-cni cjp-cni acu-cop af-cop agr-cop ake-cop am-cop amu-cop ar-cop bg-cop bsn-cop cak-cop ceb-cop ch-cop chq-cop chr-cop cjp-cop cni-cop acu-crp af-crp agr-crp ake-crp am-crp amu-crp ar-crp bg-crp bsn-crp cak-crp ceb-crp ch-crp chq-crp chr-crp cjp-crp cni-crp cop-crp acu-cs af-cs agr-cs ake-cs am-cs amu-cs ar-cs bg-cs bsn-cs cak-cs ceb-cs ch-cs chq-cs chr-cs cjp-cs cni-cs cop-cs crp-cs acu-da af-da agr-da ake-da am-da amu-da ar-da bg-da bsn-da cak-da ceb-da ch-da chq-da chr-da cjp-da cni-da cop-da crp-da cs-da acu-de af-de agr-de ake-de am-de amu-de ar-de bg-de bsn-de cak-de ceb-de ch-de chq-de chr-de cjp-de cni-de cop-de crp-de cs-de da-de acu-dik af-dik agr-dik ake-dik am-dik amu-dik ar-dik bg-dik bsn-dik cak-dik ceb-dik ch-dik chq-dik chr-dik cjp-dik cni-dik cop-dik crp-dik cs-dik da-dik de-dik acu-dje af-dje agr-dje ake-dje am-dje amu-dje ar-dje bg-dje bsn-dje cak-dje ceb-dje ch-dje chq-dje chr-dje cjp-dje cni-dje cop-dje crp-dje cs-dje da-dje de-dje dik-dje acu-djk af-djk agr-djk ake-djk am-djk amu-djk ar-djk bg-djk bsn-djk cak-djk ceb-djk ch-djk chq-djk chr-djk cjp-djk cni-djk cop-djk crp-djk cs-djk da-djk de-djk dik-djk dje-djk acu-dop af-dop agr-dop ake-dop am-dop amu-dop ar-dop bg-dop bsn-dop cak-dop ceb-dop ch-dop chq-dop chr-dop cjp-dop cni-dop cop-dop crp-dop cs-dop da-dop de-dop dik-dop dje-dop djk-dop acu-ee af-ee agr-ee ake-ee am-ee amu-ee ar-ee bg-ee bsn-ee cak-ee ceb-ee ch-ee chq-ee chr-ee cjp-ee cni-ee cop-ee crp-ee cs-ee da-ee de-ee dik-ee dje-ee djk-ee dop-ee acu-el af-el agr-el ake-el am-el amu-el ar-el bg-el bsn-el cak-el ceb-el ch-el chq-el chr-el cjp-el cni-el cop-el crp-el cs-el da-el de-el dik-el dje-el djk-el dop-el ee-el acu-en af-en agr-en ake-en am-en amu-en ar-en bg-en bsn-en cak-en ceb-en ch-en chq-en chr-en cjp-en cni-en cop-en crp-en cs-en da-en de-en dik-en dje-en djk-en dop-en ee-en el-en acu-eo af-eo agr-eo ake-eo am-eo amu-eo ar-eo bg-eo bsn-eo cak-eo ceb-eo ch-eo chq-eo chr-eo cjp-eo cni-eo cop-eo crp-eo cs-eo da-eo de-eo dik-eo dje-eo djk-eo dop-eo ee-eo el-eo en-eo acu-es af-es agr-es ake-es am-es amu-es ar-es bg-es bsn-es cak-es ceb-es ch-es chq-es chr-es cjp-es cni-es cop-es crp-es cs-es da-es de-es dik-es dje-es djk-es dop-es ee-es el-es en-es eo-es acu-et af-et agr-et ake-et am-et amu-et ar-et bg-et bsn-et cak-et ceb-et ch-et chq-et chr-et cjp-et cni-et cop-et crp-et cs-et da-et de-et dik-et dje-et djk-et dop-et ee-et el-et en-et eo-et es-et acu-eu af-eu agr-eu ake-eu am-eu amu-eu ar-eu bg-eu bsn-eu cak-eu ceb-eu ch-eu chq-eu chr-eu cjp-eu cni-eu cop-eu crp-eu cs-eu da-eu de-eu dik-eu dje-eu djk-eu dop-eu ee-eu el-eu en-eu eo-eu es-eu et-eu acu-fi af-fi agr-fi ake-fi am-fi amu-fi ar-fi bg-fi bsn-fi cak-fi ceb-fi ch-fi chq-fi chr-fi cjp-fi cni-fi cop-fi crp-fi cs-fi da-fi de-fi dik-fi dje-fi djk-fi dop-fi ee-fi el-fi en-fi eo-fi es-fi et-fi eu-fi acu-fr af-fr agr-fr ake-fr am-fr amu-fr ar-fr bg-fr bsn-fr cak-fr ceb-fr ch-fr chq-fr chr-fr cjp-fr cni-fr cop-fr crp-fr cs-fr da-fr de-fr dik-fr dje-fr djk-fr dop-fr ee-fr el-fr en-fr eo-fr es-fr et-fr eu-fr fi-fr acu-gbi af-gbi agr-gbi ake-gbi am-gbi amu-gbi ar-gbi bg-gbi bsn-gbi cak-gbi ceb-gbi ch-gbi chq-gbi chr-gbi cjp-gbi cni-gbi cop-gbi crp-gbi cs-gbi da-gbi de-gbi dik-gbi dje-gbi djk-gbi dop-gbi ee-gbi el-gbi en-gbi eo-gbi es-gbi et-gbi eu-gbi fi-gbi fr-gbi acu-gd af-gd agr-gd ake-gd am-gd amu-gd ar-gd bg-gd bsn-gd cak-gd ceb-gd ch-gd chq-gd chr-gd cjp-gd cni-gd cop-gd crp-gd cs-gd da-gd de-gd dik-gd dje-gd djk-gd dop-gd ee-gd el-gd en-gd eo-gd es-gd et-gd eu-gd fi-gd fr-gd gbi-gd acu-gu af-gu agr-gu ake-gu am-gu amu-gu ar-gu bg-gu bsn-gu cak-gu ceb-gu ch-gu chq-gu chr-gu cjp-gu cni-gu cop-gu crp-gu cs-gu da-gu de-gu dik-gu dje-gu djk-gu dop-gu ee-gu el-gu en-gu eo-gu es-gu et-gu eu-gu fi-gu fr-gu gbi-gu gd-gu acu-gv af-gv agr-gv ake-gv am-gv amu-gv ar-gv bg-gv bsn-gv cak-gv ceb-gv ch-gv chq-gv chr-gv cjp-gv cni-gv cop-gv crp-gv cs-gv da-gv de-gv dik-gv dje-gv djk-gv dop-gv ee-gv el-gv en-gv eo-gv es-gv et-gv eu-gv fi-gv fr-gv gbi-gv gd-gv gu-gv acu-he af-he agr-he ake-he am-he amu-he ar-he bg-he bsn-he cak-he ceb-he ch-he chq-he chr-he cjp-he cni-he cop-he crp-he cs-he da-he de-he dik-he dje-he djk-he dop-he ee-he el-he en-he eo-he es-he et-he eu-he fi-he fr-he gbi-he gd-he gu-he gv-he acu-hi af-hi agr-hi ake-hi am-hi amu-hi ar-hi bg-hi bsn-hi cak-hi ceb-hi ch-hi chq-hi chr-hi cjp-hi cni-hi cop-hi crp-hi cs-hi da-hi de-hi dik-hi dje-hi djk-hi dop-hi ee-hi el-hi en-hi eo-hi es-hi et-hi eu-hi fi-hi fr-hi gbi-hi gd-hi gu-hi gv-hi he-hi acu-hr af-hr agr-hr ake-hr am-hr amu-hr ar-hr bg-hr bsn-hr cak-hr ceb-hr ch-hr chq-hr chr-hr cjp-hr cni-hr cop-hr crp-hr cs-hr da-hr de-hr dik-hr dje-hr djk-hr dop-hr ee-hr el-hr en-hr eo-hr es-hr et-hr eu-hr fi-hr fr-hr gbi-hr gd-hr gu-hr gv-hr he-hr hi-hr acu-hu af-hu agr-hu ake-hu am-hu amu-hu ar-hu bg-hu bsn-hu cak-hu ceb-hu ch-hu chq-hu chr-hu cjp-hu cni-hu cop-hu crp-hu cs-hu da-hu de-hu dik-hu dje-hu djk-hu dop-hu ee-hu el-hu en-hu eo-hu es-hu et-hu eu-hu fi-hu fr-hu gbi-hu gd-hu gu-hu gv-hu he-hu hi-hu hr-hu acu-hy af-hy agr-hy ake-hy am-hy amu-hy ar-hy bg-hy bsn-hy cak-hy ceb-hy ch-hy chq-hy chr-hy cjp-hy cni-hy cop-hy crp-hy cs-hy da-hy de-hy dik-hy dje-hy djk-hy dop-hy ee-hy el-hy en-hy eo-hy es-hy et-hy eu-hy fi-hy fr-hy gbi-hy gd-hy gu-hy gv-hy he-hy hi-hy hr-hy hu-hy acu-id af-id agr-id ake-id am-id amu-id ar-id bg-id bsn-id cak-id ceb-id ch-id chq-id chr-id cjp-id cni-id cop-id crp-id cs-id da-id de-id dik-id dje-id djk-id dop-id ee-id el-id en-id eo-id es-id et-id eu-id fi-id fr-id gbi-id gd-id gu-id gv-id he-id hi-id hr-id hu-id hy-id acu-is af-is agr-is ake-is am-is amu-is ar-is bg-is bsn-is cak-is ceb-is ch-is chq-is chr-is cjp-is cni-is cop-is crp-is cs-is da-is de-is dik-is dje-is djk-is dop-is ee-is el-is en-is eo-is es-is et-is eu-is fi-is fr-is gbi-is gd-is gu-is gv-is he-is hi-is hr-is hu-is hy-is id-is acu-it af-it agr-it ake-it am-it amu-it ar-it bg-it bsn-it cak-it ceb-it ch-it chq-it chr-it cjp-it cni-it cop-it crp-it cs-it da-it de-it dik-it dje-it djk-it dop-it ee-it el-it en-it eo-it es-it et-it eu-it fi-it fr-it gbi-it gd-it gu-it gv-it he-it hi-it hr-it hu-it hy-it id-it is-it acu-jak af-jak agr-jak ake-jak am-jak amu-jak ar-jak bg-jak bsn-jak cak-jak ceb-jak ch-jak chq-jak chr-jak cjp-jak cni-jak cop-jak crp-jak cs-jak da-jak de-jak dik-jak dje-jak djk-jak dop-jak ee-jak el-jak en-jak eo-jak es-jak et-jak eu-jak fi-jak fr-jak gbi-jak gd-jak gu-jak gv-jak he-jak hi-jak hr-jak hu-jak hy-jak id-jak is-jak it-jak acu-jap af-jap agr-jap ake-jap am-jap amu-jap ar-jap bg-jap bsn-jap cak-jap ceb-jap ch-jap chq-jap chr-jap cjp-jap cni-jap cop-jap crp-jap cs-jap da-jap de-jap dik-jap dje-jap djk-jap dop-jap ee-jap el-jap en-jap eo-jap es-jap et-jap eu-jap fi-jap fr-jap gbi-jap gd-jap gu-jap gv-jap he-jap hi-jap hr-jap hu-jap hy-jap id-jap is-jap it-jap jak-jap acu-jiv af-jiv agr-jiv ake-jiv am-jiv amu-jiv ar-jiv bg-jiv bsn-jiv cak-jiv ceb-jiv ch-jiv chq-jiv chr-jiv cjp-jiv cni-jiv cop-jiv crp-jiv cs-jiv da-jiv de-jiv dik-jiv dje-jiv djk-jiv dop-jiv ee-jiv el-jiv en-jiv eo-jiv es-jiv et-jiv eu-jiv fi-jiv fr-jiv gbi-jiv gd-jiv gu-jiv gv-jiv he-jiv hi-jiv hr-jiv hu-jiv hy-jiv id-jiv is-jiv it-jiv jak-jiv jap-jiv acu-kab af-kab agr-kab ake-kab am-kab amu-kab ar-kab bg-kab bsn-kab cak-kab ceb-kab ch-kab chq-kab chr-kab cjp-kab cni-kab cop-kab crp-kab cs-kab da-kab de-kab dik-kab dje-kab djk-kab dop-kab ee-kab el-kab en-kab eo-kab es-kab et-kab eu-kab fi-kab fr-kab gbi-kab gd-kab gu-kab gv-kab he-kab hi-kab hr-kab hu-kab hy-kab id-kab is-kab it-kab jak-kab jap-kab jiv-kab acu-kbh af-kbh agr-kbh ake-kbh am-kbh amu-kbh ar-kbh bg-kbh bsn-kbh cak-kbh ceb-kbh ch-kbh chq-kbh chr-kbh cjp-kbh cni-kbh cop-kbh crp-kbh cs-kbh da-kbh de-kbh dik-kbh dje-kbh djk-kbh dop-kbh ee-kbh el-kbh en-kbh eo-kbh es-kbh et-kbh eu-kbh fi-kbh fr-kbh gbi-kbh gd-kbh gu-kbh gv-kbh he-kbh hi-kbh hr-kbh hu-kbh hy-kbh id-kbh is-kbh it-kbh jak-kbh jap-kbh jiv-kbh kab-kbh acu-kek af-kek agr-kek ake-kek am-kek amu-kek ar-kek bg-kek bsn-kek cak-kek ceb-kek ch-kek chq-kek chr-kek cjp-kek cni-kek cop-kek crp-kek cs-kek da-kek de-kek dik-kek dje-kek djk-kek dop-kek ee-kek el-kek en-kek eo-kek es-kek et-kek eu-kek fi-kek fr-kek gbi-kek gd-kek gu-kek gv-kek he-kek hi-kek hr-kek hu-kek hy-kek id-kek is-kek it-kek jak-kek jap-kek jiv-kek kab-kek kbh-kek acu-kn af-kn agr-kn ake-kn am-kn amu-kn ar-kn bg-kn bsn-kn cak-kn ceb-kn ch-kn chq-kn chr-kn cjp-kn cni-kn cop-kn crp-kn cs-kn da-kn de-kn dik-kn dje-kn djk-kn dop-kn ee-kn el-kn en-kn eo-kn es-kn et-kn eu-kn fi-kn fr-kn gbi-kn gd-kn gu-kn gv-kn he-kn hi-kn hr-kn hu-kn hy-kn id-kn is-kn it-kn jak-kn jap-kn jiv-kn kab-kn kbh-kn kek-kn acu-ko af-ko agr-ko ake-ko am-ko amu-ko ar-ko bg-ko bsn-ko cak-ko ceb-ko ch-ko chq-ko chr-ko cjp-ko cni-ko cop-ko crp-ko cs-ko da-ko de-ko dik-ko dje-ko djk-ko dop-ko ee-ko el-ko en-ko eo-ko es-ko et-ko eu-ko fi-ko fr-ko gbi-ko gd-ko gu-ko gv-ko he-ko hi-ko hr-ko hu-ko hy-ko id-ko is-ko it-ko jak-ko jap-ko jiv-ko kab-ko kbh-ko kek-ko kn-ko acu-la af-la agr-la ake-la am-la amu-la ar-la bg-la bsn-la cak-la ceb-la ch-la chq-la chr-la cjp-la cni-la cop-la crp-la cs-la da-la de-la dik-la dje-la djk-la dop-la ee-la el-la en-la eo-la es-la et-la eu-la fi-la fr-la gbi-la gd-la gu-la gv-la he-la hi-la hr-la hu-la hy-la id-la is-la it-la jak-la jap-la jiv-la kab-la kbh-la kek-la kn-la ko-la acu-lt af-lt agr-lt ake-lt am-lt amu-lt ar-lt bg-lt bsn-lt cak-lt ceb-lt ch-lt chq-lt chr-lt cjp-lt cni-lt cop-lt crp-lt cs-lt da-lt de-lt dik-lt dje-lt djk-lt dop-lt ee-lt el-lt en-lt eo-lt es-lt et-lt eu-lt fi-lt fr-lt gbi-lt gd-lt gu-lt gv-lt he-lt hi-lt hr-lt hu-lt hy-lt id-lt is-lt it-lt jak-lt jap-lt jiv-lt kab-lt kbh-lt kek-lt kn-lt ko-lt la-lt acu-lv af-lv agr-lv ake-lv am-lv amu-lv ar-lv bg-lv bsn-lv cak-lv ceb-lv ch-lv chq-lv chr-lv cjp-lv cni-lv cop-lv crp-lv cs-lv da-lv de-lv dik-lv dje-lv djk-lv dop-lv ee-lv el-lv en-lv eo-lv es-lv et-lv eu-lv fi-lv fr-lv gbi-lv gd-lv gu-lv gv-lv he-lv hi-lv hr-lv hu-lv hy-lv id-lv is-lv it-lv jak-lv jap-lv jiv-lv kab-lv kbh-lv kek-lv kn-lv ko-lv la-lv lt-lv acu-mam af-mam agr-mam ake-mam am-mam amu-mam ar-mam bg-mam bsn-mam cak-mam ceb-mam ch-mam chq-mam chr-mam cjp-mam cni-mam cop-mam crp-mam cs-mam da-mam de-mam dik-mam dje-mam djk-mam dop-mam ee-mam el-mam en-mam eo-mam es-mam et-mam eu-mam fi-mam fr-mam gbi-mam gd-mam gu-mam gv-mam he-mam hi-mam hr-mam hu-mam hy-mam id-mam is-mam it-mam jak-mam jap-mam jiv-mam kab-mam kbh-mam kek-mam kn-mam ko-mam la-mam lt-mam lv-mam acu-mi af-mi agr-mi ake-mi am-mi amu-mi ar-mi bg-mi bsn-mi cak-mi ceb-mi ch-mi chq-mi chr-mi cjp-mi cni-mi cop-mi crp-mi cs-mi da-mi de-mi dik-mi dje-mi djk-mi dop-mi ee-mi el-mi en-mi eo-mi es-mi et-mi eu-mi fi-mi fr-mi gbi-mi gd-mi gu-mi gv-mi he-mi hi-mi hr-mi hu-mi hy-mi id-mi is-mi it-mi jak-mi jap-mi jiv-mi kab-mi kbh-mi kek-mi kn-mi ko-mi la-mi lt-mi lv-mi mam-mi acu-ml af-ml agr-ml ake-ml am-ml amu-ml ar-ml bg-ml bsn-ml cak-ml ceb-ml ch-ml chq-ml chr-ml cjp-ml cni-ml cop-ml crp-ml cs-ml da-ml de-ml dik-ml dje-ml djk-ml dop-ml ee-ml el-ml en-ml eo-ml es-ml et-ml eu-ml fi-ml fr-ml gbi-ml gd-ml gu-ml gv-ml he-ml hi-ml hr-ml hu-ml hy-ml id-ml is-ml it-ml jak-ml jap-ml jiv-ml kab-ml kbh-ml kek-ml kn-ml ko-ml la-ml lt-ml lv-ml mam-ml mi-ml acu-mr af-mr agr-mr ake-mr am-mr amu-mr ar-mr bg-mr bsn-mr cak-mr ceb-mr ch-mr chq-mr chr-mr cjp-mr cni-mr cop-mr crp-mr cs-mr da-mr de-mr dik-mr dje-mr djk-mr dop-mr ee-mr el-mr en-mr eo-mr es-mr et-mr eu-mr fi-mr fr-mr gbi-mr gd-mr gu-mr gv-mr he-mr hi-mr hr-mr hu-mr hy-mr id-mr is-mr it-mr jak-mr jap-mr jiv-mr kab-mr kbh-mr kek-mr kn-mr ko-mr la-mr lt-mr lv-mr mam-mr mi-mr ml-mr acu-my af-my agr-my ake-my am-my amu-my ar-my bg-my bsn-my cak-my ceb-my ch-my chq-my chr-my cjp-my cni-my cop-my crp-my cs-my da-my de-my dik-my dje-my djk-my dop-my ee-my el-my en-my eo-my es-my et-my eu-my fi-my fr-my gbi-my gd-my gu-my gv-my he-my hi-my hr-my hu-my hy-my id-my is-my it-my jak-my jap-my jiv-my kab-my kbh-my kek-my kn-my ko-my la-my lt-my lv-my mam-my mi-my ml-my mr-my acu-ne af-ne agr-ne ake-ne am-ne amu-ne ar-ne bg-ne bsn-ne cak-ne ceb-ne ch-ne chq-ne chr-ne cjp-ne cni-ne cop-ne crp-ne cs-ne da-ne de-ne dik-ne dje-ne djk-ne dop-ne ee-ne el-ne en-ne eo-ne es-ne et-ne eu-ne fi-ne fr-ne gbi-ne gd-ne gu-ne gv-ne he-ne hi-ne hr-ne hu-ne hy-ne id-ne is-ne it-ne jak-ne jap-ne jiv-ne kab-ne kbh-ne kek-ne kn-ne ko-ne la-ne lt-ne lv-ne mam-ne mi-ne ml-ne mr-ne my-ne acu-nhg af-nhg agr-nhg ake-nhg am-nhg amu-nhg ar-nhg bg-nhg bsn-nhg cak-nhg ceb-nhg ch-nhg chq-nhg chr-nhg cjp-nhg cni-nhg cop-nhg crp-nhg cs-nhg da-nhg de-nhg dik-nhg dje-nhg djk-nhg dop-nhg ee-nhg el-nhg en-nhg eo-nhg es-nhg et-nhg eu-nhg fi-nhg fr-nhg gbi-nhg gd-nhg gu-nhg gv-nhg he-nhg hi-nhg hr-nhg hu-nhg hy-nhg id-nhg is-nhg it-nhg jak-nhg jap-nhg jiv-nhg kab-nhg kbh-nhg kek-nhg kn-nhg ko-nhg la-nhg lt-nhg lv-nhg mam-nhg mi-nhg ml-nhg mr-nhg my-nhg ne-nhg acu-nl af-nl agr-nl ake-nl am-nl amu-nl ar-nl bg-nl bsn-nl cak-nl ceb-nl ch-nl chq-nl chr-nl cjp-nl cni-nl cop-nl crp-nl cs-nl da-nl de-nl dik-nl dje-nl djk-nl dop-nl ee-nl el-nl en-nl eo-nl es-nl et-nl eu-nl fi-nl fr-nl gbi-nl gd-nl gu-nl gv-nl he-nl hi-nl hr-nl hu-nl hy-nl id-nl is-nl it-nl jak-nl jap-nl jiv-nl kab-nl kbh-nl kek-nl kn-nl ko-nl la-nl lt-nl lv-nl mam-nl mi-nl ml-nl mr-nl my-nl ne-nl nhg-nl acu-no af-no agr-no ake-no am-no amu-no ar-no bg-no bsn-no cak-no ceb-no ch-no chq-no chr-no cjp-no cni-no cop-no crp-no cs-no da-no de-no dik-no dje-no djk-no dop-no ee-no el-no en-no eo-no es-no et-no eu-no fi-no fr-no gbi-no gd-no gu-no gv-no he-no hi-no hr-no hu-no hy-no id-no is-no it-no jak-no jap-no jiv-no kab-no kbh-no kek-no kn-no ko-no la-no lt-no lv-no mam-no mi-no ml-no mr-no my-no ne-no nhg-no nl-no acu-ojb af-ojb agr-ojb ake-ojb am-ojb amu-ojb ar-ojb bg-ojb bsn-ojb cak-ojb ceb-ojb ch-ojb chq-ojb chr-ojb cjp-ojb cni-ojb cop-ojb crp-ojb cs-ojb da-ojb de-ojb dik-ojb dje-ojb djk-ojb dop-ojb ee-ojb el-ojb en-ojb eo-ojb es-ojb et-ojb eu-ojb fi-ojb fr-ojb gbi-ojb gd-ojb gu-ojb gv-ojb he-ojb hi-ojb hr-ojb hu-ojb hy-ojb id-ojb is-ojb it-ojb jak-ojb jap-ojb jiv-ojb kab-ojb kbh-ojb kek-ojb kn-ojb ko-ojb la-ojb lt-ojb lv-ojb mam-ojb mi-ojb ml-ojb mr-ojb my-ojb ne-ojb nhg-ojb nl-ojb no-ojb acu-pck af-pck agr-pck ake-pck am-pck amu-pck ar-pck bg-pck bsn-pck cak-pck ceb-pck ch-pck chq-pck chr-pck cjp-pck cni-pck cop-pck crp-pck cs-pck da-pck de-pck dik-pck dje-pck djk-pck dop-pck ee-pck el-pck en-pck eo-pck es-pck et-pck eu-pck fi-pck fr-pck gbi-pck gd-pck gu-pck gv-pck he-pck hi-pck hr-pck hu-pck hy-pck id-pck is-pck it-pck jak-pck jap-pck jiv-pck kab-pck kbh-pck kek-pck kn-pck ko-pck la-pck lt-pck lv-pck mam-pck mi-pck ml-pck mr-pck my-pck ne-pck nhg-pck nl-pck no-pck ojb-pck acu-pes af-pes agr-pes ake-pes am-pes amu-pes ar-pes bg-pes bsn-pes cak-pes ceb-pes ch-pes chq-pes chr-pes cjp-pes cni-pes cop-pes crp-pes cs-pes da-pes de-pes dik-pes dje-pes djk-pes dop-pes ee-pes el-pes en-pes eo-pes es-pes et-pes eu-pes fi-pes fr-pes gbi-pes gd-pes gu-pes gv-pes he-pes hi-pes hr-pes hu-pes hy-pes id-pes is-pes it-pes jak-pes jap-pes jiv-pes kab-pes kbh-pes kek-pes kn-pes ko-pes la-pes lt-pes lv-pes mam-pes mi-pes ml-pes mr-pes my-pes ne-pes nhg-pes nl-pes no-pes ojb-pes pck-pes acu-pl af-pl agr-pl ake-pl am-pl amu-pl ar-pl bg-pl bsn-pl cak-pl ceb-pl ch-pl chq-pl chr-pl cjp-pl cni-pl cop-pl crp-pl cs-pl da-pl de-pl dik-pl dje-pl djk-pl dop-pl ee-pl el-pl en-pl eo-pl es-pl et-pl eu-pl fi-pl fr-pl gbi-pl gd-pl gu-pl gv-pl he-pl hi-pl hr-pl hu-pl hy-pl id-pl is-pl it-pl jak-pl jap-pl jiv-pl kab-pl kbh-pl kek-pl kn-pl ko-pl la-pl lt-pl lv-pl mam-pl mi-pl ml-pl mr-pl my-pl ne-pl nhg-pl nl-pl no-pl ojb-pl pck-pl pes-pl acu-plt af-plt agr-plt ake-plt am-plt amu-plt ar-plt bg-plt bsn-plt cak-plt ceb-plt ch-plt chq-plt chr-plt cjp-plt cni-plt cop-plt crp-plt cs-plt da-plt de-plt dik-plt dje-plt djk-plt dop-plt ee-plt el-plt en-plt eo-plt es-plt et-plt eu-plt fi-plt fr-plt gbi-plt gd-plt gu-plt gv-plt he-plt hi-plt hr-plt hu-plt hy-plt id-plt is-plt it-plt jak-plt jap-plt jiv-plt kab-plt kbh-plt kek-plt kn-plt ko-plt la-plt lt-plt lv-plt mam-plt mi-plt ml-plt mr-plt my-plt ne-plt nhg-plt nl-plt no-plt ojb-plt pck-plt pes-plt pl-plt acu-pot af-pot agr-pot ake-pot am-pot amu-pot ar-pot bg-pot bsn-pot cak-pot ceb-pot ch-pot chq-pot chr-pot cjp-pot cni-pot cop-pot crp-pot cs-pot da-pot de-pot dik-pot dje-pot djk-pot dop-pot ee-pot el-pot en-pot eo-pot es-pot et-pot eu-pot fi-pot fr-pot gbi-pot gu-pot gv-pot he-pot hi-pot hr-pot hu-pot hy-pot id-pot is-pot it-pot jak-pot jap-pot jiv-pot kab-pot kbh-pot kek-pot kn-pot ko-pot la-pot lt-pot lv-pot mam-pot mi-pot ml-pot mr-pot my-pot ne-pot nhg-pot nl-pot no-pot ojb-pot pck-pot pes-pot pl-pot plt-pot acu-ppk af-ppk agr-ppk ake-ppk am-ppk amu-ppk ar-ppk bg-ppk bsn-ppk cak-ppk ceb-ppk ch-ppk chq-ppk chr-ppk cjp-ppk cni-ppk cop-ppk crp-ppk cs-ppk da-ppk de-ppk dik-ppk dje-ppk djk-ppk dop-ppk ee-ppk el-ppk en-ppk eo-ppk es-ppk et-ppk eu-ppk fi-ppk fr-ppk gbi-ppk gd-ppk gu-ppk gv-ppk he-ppk hi-ppk hr-ppk hu-ppk hy-ppk id-ppk is-ppk it-ppk jak-ppk jap-ppk jiv-ppk kab-ppk kbh-ppk kek-ppk kn-ppk ko-ppk la-ppk lt-ppk lv-ppk mam-ppk mi-ppk ml-ppk mr-ppk my-ppk ne-ppk nhg-ppk nl-ppk no-ppk ojb-ppk pck-ppk pes-ppk pl-ppk plt-ppk pot-ppk acu-pt af-pt agr-pt ake-pt am-pt amu-pt ar-pt bg-pt bsn-pt cak-pt ceb-pt ch-pt chq-pt chr-pt cjp-pt cni-pt cop-pt crp-pt cs-pt da-pt de-pt dik-pt dje-pt djk-pt dop-pt ee-pt el-pt en-pt eo-pt es-pt et-pt eu-pt fi-pt fr-pt gbi-pt gd-pt gu-pt gv-pt he-pt hi-pt hr-pt hu-pt hy-pt id-pt is-pt it-pt jak-pt jap-pt jiv-pt kab-pt kbh-pt kek-pt kn-pt ko-pt la-pt lt-pt lv-pt mam-pt mi-pt ml-pt mr-pt my-pt ne-pt nhg-pt nl-pt no-pt ojb-pt pck-pt pes-pt pl-pt plt-pt pot-pt ppk-pt acu-quc af-quc agr-quc ake-quc am-quc amu-quc ar-quc bg-quc bsn-quc cak-quc ceb-quc ch-quc chq-quc chr-quc cjp-quc cni-quc cop-quc crp-quc cs-quc da-quc de-quc dik-quc dje-quc djk-quc dop-quc ee-quc el-quc en-quc eo-quc es-quc et-quc eu-quc fi-quc fr-quc gbi-quc gd-quc gu-quc gv-quc he-quc hi-quc hr-quc hu-quc hy-quc id-quc is-quc it-quc jak-quc jap-quc jiv-quc kab-quc kbh-quc kek-quc kn-quc ko-quc la-quc lt-quc lv-quc mam-quc mi-quc ml-quc mr-quc my-quc ne-quc nhg-quc nl-quc no-quc ojb-quc pck-quc pes-quc pl-quc plt-quc pot-quc ppk-quc pt-quc acu-quw af-quw agr-quw ake-quw am-quw amu-quw ar-quw bg-quw bsn-quw cak-quw ceb-quw ch-quw chq-quw chr-quw cjp-quw cni-quw cop-quw crp-quw cs-quw da-quw de-quw dik-quw dje-quw djk-quw dop-quw ee-quw el-quw en-quw eo-quw es-quw et-quw eu-quw fi-quw fr-quw gbi-quw gd-quw gu-quw gv-quw he-quw hi-quw hr-quw hu-quw hy-quw id-quw is-quw it-quw jak-quw jap-quw jiv-quw kab-quw kbh-quw kek-quw kn-quw ko-quw la-quw lt-quw lv-quw mam-quw mi-quw ml-quw mr-quw my-quw ne-quw nhg-quw nl-quw no-quw ojb-quw pck-quw pes-quw pl-quw plt-quw pot-quw ppk-quw pt-quw quc-quw acu-ro af-ro agr-ro ake-ro am-ro amu-ro ar-ro bg-ro bsn-ro cak-ro ceb-ro ch-ro chq-ro chr-ro cjp-ro cni-ro cop-ro crp-ro cs-ro da-ro de-ro dik-ro dje-ro djk-ro dop-ro ee-ro el-ro en-ro eo-ro es-ro et-ro eu-ro fi-ro fr-ro gbi-ro gd-ro gu-ro gv-ro he-ro hi-ro hr-ro hu-ro hy-ro id-ro is-ro it-ro jak-ro jap-ro jiv-ro kab-ro kbh-ro kek-ro kn-ro ko-ro la-ro lt-ro lv-ro mam-ro mi-ro ml-ro mr-ro my-ro ne-ro nhg-ro nl-ro no-ro ojb-ro pck-ro pes-ro pl-ro plt-ro pot-ro ppk-ro pt-ro quc-ro quw-ro acu-rom af-rom agr-rom ake-rom am-rom amu-rom ar-rom bg-rom bsn-rom cak-rom ceb-rom ch-rom chq-rom chr-rom cjp-rom cni-rom cop-rom crp-rom cs-rom da-rom de-rom dik-rom dje-rom djk-rom dop-rom ee-rom el-rom en-rom eo-rom es-rom et-rom eu-rom fi-rom fr-rom gbi-rom gd-rom gu-rom gv-rom he-rom hi-rom hr-rom hu-rom hy-rom id-rom is-rom it-rom jak-rom jap-rom jiv-rom kab-rom kbh-rom kek-rom kn-rom ko-rom la-rom lt-rom lv-rom mam-rom mi-rom ml-rom mr-rom my-rom ne-rom nhg-rom nl-rom no-rom ojb-rom pck-rom pes-rom pl-rom plt-rom pot-rom ppk-rom pt-rom quc-rom quw-rom ro-rom acu-ru af-ru agr-ru ake-ru am-ru amu-ru ar-ru bg-ru bsn-ru cak-ru ceb-ru ch-ru chq-ru chr-ru cjp-ru cni-ru cop-ru crp-ru cs-ru da-ru de-ru dik-ru dje-ru djk-ru dop-ru ee-ru el-ru en-ru eo-ru es-ru et-ru eu-ru fi-ru fr-ru gbi-ru gd-ru gu-ru gv-ru he-ru hi-ru hr-ru hu-ru hy-ru id-ru is-ru it-ru jak-ru jap-ru jiv-ru kab-ru kbh-ru kek-ru kn-ru ko-ru la-ru lt-ru lv-ru mam-ru mi-ru ml-ru mr-ru my-ru ne-ru nhg-ru nl-ru no-ru ojb-ru pck-ru pes-ru pl-ru plt-ru pot-ru ppk-ru pt-ru quc-ru quw-ru ro-ru rom-ru acu-shi af-shi agr-shi ake-shi am-shi amu-shi ar-shi bg-shi bsn-shi cak-shi ceb-shi ch-shi chq-shi chr-shi cjp-shi cni-shi cop-shi crp-shi cs-shi da-shi de-shi dik-shi dje-shi djk-shi dop-shi ee-shi el-shi en-shi eo-shi es-shi et-shi eu-shi fi-shi fr-shi gbi-shi gd-shi gu-shi gv-shi he-shi hi-shi hr-shi hu-shi hy-shi id-shi is-shi it-shi jak-shi jap-shi jiv-shi kab-shi kbh-shi kek-shi kn-shi ko-shi la-shi lt-shi lv-shi mam-shi mi-shi ml-shi mr-shi my-shi ne-shi nhg-shi nl-shi no-shi ojb-shi pck-shi pes-shi pl-shi plt-shi pot-shi ppk-shi pt-shi quc-shi quw-shi ro-shi rom-shi ru-shi acu-sk af-sk agr-sk ake-sk am-sk amu-sk ar-sk bg-sk bsn-sk cak-sk ceb-sk ch-sk chq-sk chr-sk cjp-sk cni-sk cop-sk crp-sk cs-sk da-sk de-sk dik-sk dje-sk djk-sk dop-sk ee-sk el-sk en-sk eo-sk es-sk et-sk eu-sk fi-sk fr-sk gbi-sk gd-sk gu-sk gv-sk he-sk hi-sk hr-sk hu-sk hy-sk id-sk is-sk it-sk jak-sk jap-sk jiv-sk kab-sk kbh-sk kek-sk kn-sk ko-sk la-sk lt-sk lv-sk mam-sk mi-sk ml-sk mr-sk my-sk ne-sk nhg-sk nl-sk no-sk ojb-sk pck-sk pes-sk pl-sk plt-sk pot-sk ppk-sk pt-sk quc-sk quw-sk ro-sk rom-sk ru-sk shi-sk acu-sl af-sl agr-sl ake-sl am-sl amu-sl ar-sl bg-sl bsn-sl cak-sl ceb-sl ch-sl chq-sl chr-sl cjp-sl cni-sl cop-sl crp-sl cs-sl da-sl de-sl dik-sl dje-sl djk-sl dop-sl ee-sl el-sl en-sl eo-sl es-sl et-sl eu-sl fi-sl fr-sl gbi-sl gd-sl gu-sl gv-sl he-sl hi-sl hr-sl hu-sl hy-sl id-sl is-sl it-sl jak-sl jap-sl jiv-sl kab-sl kbh-sl kek-sl kn-sl ko-sl la-sl lt-sl lv-sl mam-sl mi-sl ml-sl mr-sl my-sl ne-sl nhg-sl nl-sl no-sl ojb-sl pck-sl pes-sl pl-sl plt-sl pot-sl ppk-sl pt-sl quc-sl quw-sl ro-sl rom-sl ru-sl shi-sl sk-sl acu-sn af-sn agr-sn ake-sn am-sn amu-sn ar-sn bg-sn bsn-sn cak-sn ceb-sn ch-sn chq-sn chr-sn cjp-sn cni-sn cop-sn crp-sn cs-sn da-sn de-sn dik-sn dje-sn djk-sn dop-sn ee-sn el-sn en-sn eo-sn es-sn et-sn eu-sn fi-sn fr-sn gbi-sn gd-sn gu-sn gv-sn he-sn hi-sn hr-sn hu-sn hy-sn id-sn is-sn it-sn jak-sn jap-sn jiv-sn kab-sn kbh-sn kek-sn kn-sn ko-sn la-sn lt-sn lv-sn mam-sn mi-sn ml-sn mr-sn my-sn ne-sn nhg-sn nl-sn no-sn ojb-sn pck-sn pes-sn pl-sn plt-sn pot-sn ppk-sn pt-sn quc-sn quw-sn ro-sn rom-sn ru-sn shi-sn sk-sn sl-sn acu-so af-so agr-so ake-so am-so amu-so ar-so bg-so bsn-so cak-so ceb-so ch-so chq-so chr-so cjp-so cni-so cop-so crp-so cs-so da-so de-so dik-so dje-so djk-so dop-so ee-so el-so en-so eo-so es-so et-so eu-so fi-so fr-so gbi-so gd-so gu-so gv-so he-so hi-so hr-so hu-so hy-so id-so is-so it-so jak-so jap-so jiv-so kab-so kbh-so kek-so kn-so ko-so la-so lt-so lv-so mam-so mi-so ml-so mr-so my-so ne-so nhg-so nl-so no-so ojb-so pck-so pes-so pl-so plt-so pot-so ppk-so pt-so quc-so quw-so ro-so rom-so ru-so shi-so sk-so sl-so sn-so acu-sq af-sq agr-sq ake-sq am-sq amu-sq ar-sq bg-sq bsn-sq cak-sq ceb-sq ch-sq chq-sq chr-sq cjp-sq cni-sq cop-sq crp-sq cs-sq da-sq de-sq dik-sq dje-sq djk-sq dop-sq ee-sq el-sq en-sq eo-sq es-sq et-sq eu-sq fi-sq fr-sq gbi-sq gd-sq gu-sq gv-sq he-sq hi-sq hr-sq hu-sq hy-sq id-sq is-sq it-sq jak-sq jap-sq jiv-sq kab-sq kbh-sq kek-sq kn-sq ko-sq la-sq lt-sq lv-sq mam-sq mi-sq ml-sq mr-sq my-sq ne-sq nhg-sq nl-sq no-sq ojb-sq pck-sq pes-sq pl-sq plt-sq pot-sq ppk-sq pt-sq quc-sq quw-sq ro-sq rom-sq ru-sq shi-sq sk-sq sl-sq sn-sq so-sq acu-sr af-sr agr-sr ake-sr am-sr amu-sr ar-sr bg-sr bsn-sr cak-sr ceb-sr ch-sr chq-sr chr-sr cjp-sr cni-sr cop-sr crp-sr cs-sr da-sr de-sr dik-sr dje-sr djk-sr dop-sr ee-sr el-sr en-sr eo-sr es-sr et-sr eu-sr fi-sr fr-sr gbi-sr gd-sr gu-sr gv-sr he-sr hi-sr hr-sr hu-sr hy-sr id-sr is-sr it-sr jak-sr jap-sr jiv-sr kab-sr kbh-sr kek-sr kn-sr ko-sr la-sr lt-sr lv-sr mam-sr mi-sr ml-sr mr-sr my-sr ne-sr nhg-sr nl-sr no-sr ojb-sr pck-sr pes-sr pl-sr plt-sr pot-sr ppk-sr pt-sr quc-sr quw-sr ro-sr rom-sr ru-sr shi-sr sk-sr sl-sr sn-sr so-sr sq-sr acu-ss af-ss agr-ss ake-ss am-ss amu-ss ar-ss bg-ss bsn-ss cak-ss ceb-ss ch-ss chq-ss chr-ss cjp-ss cni-ss cop-ss crp-ss cs-ss da-ss de-ss dik-ss dje-ss djk-ss dop-ss ee-ss el-ss en-ss eo-ss es-ss et-ss eu-ss fi-ss fr-ss gbi-ss gd-ss gu-ss gv-ss he-ss hi-ss hr-ss hu-ss hy-ss id-ss is-ss it-ss jak-ss jap-ss jiv-ss kab-ss kbh-ss kek-ss kn-ss ko-ss la-ss lt-ss lv-ss mam-ss mi-ss ml-ss mr-ss my-ss ne-ss nhg-ss nl-ss no-ss ojb-ss pck-ss pes-ss pl-ss plt-ss pot-ss ppk-ss pt-ss quc-ss quw-ss ro-ss rom-ss ru-ss shi-ss sk-ss sl-ss sn-ss so-ss sq-ss sr-ss acu-sv af-sv agr-sv ake-sv am-sv amu-sv ar-sv bg-sv bsn-sv cak-sv ceb-sv ch-sv chq-sv chr-sv cjp-sv cni-sv cop-sv crp-sv cs-sv da-sv de-sv dik-sv dje-sv djk-sv dop-sv ee-sv el-sv en-sv eo-sv es-sv et-sv eu-sv fi-sv fr-sv gbi-sv gd-sv gu-sv gv-sv he-sv hi-sv hr-sv hu-sv hy-sv id-sv is-sv it-sv jak-sv jap-sv jiv-sv kab-sv kbh-sv kek-sv kn-sv ko-sv la-sv lt-sv lv-sv mam-sv mi-sv ml-sv mr-sv my-sv ne-sv nhg-sv nl-sv no-sv ojb-sv pck-sv pes-sv pl-sv plt-sv pot-sv ppk-sv pt-sv quc-sv quw-sv ro-sv rom-sv ru-sv shi-sv sk-sv sl-sv sn-sv so-sv sq-sv sr-sv ss-sv acu-syr af-syr agr-syr ake-syr am-syr amu-syr ar-syr bg-syr bsn-syr cak-syr ceb-syr ch-syr chq-syr chr-syr cjp-syr cni-syr cop-syr crp-syr cs-syr da-syr de-syr dik-syr dje-syr djk-syr dop-syr ee-syr el-syr en-syr eo-syr es-syr et-syr eu-syr fi-syr fr-syr gbi-syr gd-syr gu-syr gv-syr he-syr hi-syr hr-syr hu-syr hy-syr id-syr is-syr it-syr jak-syr jap-syr jiv-syr kab-syr kbh-syr kek-syr kn-syr ko-syr la-syr lt-syr lv-syr mam-syr mi-syr ml-syr mr-syr my-syr ne-syr nhg-syr nl-syr no-syr ojb-syr pck-syr pes-syr pl-syr plt-syr pot-syr ppk-syr pt-syr quc-syr quw-syr ro-syr rom-syr ru-syr shi-syr sk-syr sl-syr sn-syr so-syr sq-syr sr-syr ss-syr sv-syr acu-te af-te agr-te ake-te am-te amu-te ar-te bg-te bsn-te cak-te ceb-te ch-te chq-te chr-te cjp-te cni-te cop-te crp-te cs-te da-te de-te dik-te dje-te djk-te dop-te ee-te el-te en-te eo-te es-te et-te eu-te fi-te fr-te gbi-te gd-te gu-te gv-te he-te hi-te hr-te hu-te hy-te id-te is-te it-te jak-te jap-te jiv-te kab-te kbh-te kek-te kn-te ko-te la-te lt-te lv-te mam-te mi-te ml-te mr-te my-te ne-te nhg-te nl-te no-te ojb-te pck-te pes-te pl-te plt-te pot-te ppk-te pt-te quc-te quw-te ro-te rom-te ru-te shi-te sk-te sl-te sn-te so-te sq-te sr-te ss-te sv-te syr-te acu-th af-th agr-th ake-th am-th amu-th ar-th bg-th bsn-th cak-th ceb-th ch-th chq-th chr-th cjp-th cni-th cop-th crp-th cs-th da-th de-th dik-th dje-th djk-th dop-th ee-th el-th en-th eo-th es-th et-th eu-th fi-th fr-th gbi-th gd-th gu-th gv-th he-th hi-th hr-th hu-th hy-th id-th is-th it-th jak-th jap-th jiv-th kab-th kbh-th kek-th kn-th ko-th la-th lt-th lv-th mam-th mi-th ml-th mr-th my-th ne-th nhg-th nl-th no-th ojb-th pck-th pes-th pl-th plt-th pot-th ppk-th pt-th quc-th quw-th ro-th rom-th ru-th shi-th sk-th sl-th sn-th so-th sq-th sr-th ss-th sv-th syr-th te-th acu-tl af-tl agr-tl ake-tl am-tl amu-tl ar-tl bg-tl bsn-tl cak-tl ceb-tl ch-tl chq-tl chr-tl cjp-tl cni-tl cop-tl crp-tl cs-tl da-tl de-tl dik-tl dje-tl djk-tl dop-tl ee-tl el-tl en-tl eo-tl es-tl et-tl eu-tl fi-tl fr-tl gbi-tl gd-tl gu-tl gv-tl he-tl hi-tl hr-tl hu-tl hy-tl id-tl is-tl it-tl jak-tl jap-tl jiv-tl kab-tl kbh-tl kek-tl kn-tl ko-tl la-tl lt-tl lv-tl mam-tl mi-tl ml-tl mr-tl my-tl ne-tl nhg-tl nl-tl no-tl ojb-tl pck-tl pes-tl pl-tl plt-tl pot-tl ppk-tl pt-tl quc-tl quw-tl ro-tl rom-tl ru-tl shi-tl sk-tl sl-tl sn-tl so-tl sq-tl sr-tl ss-tl sv-tl syr-tl te-tl th-tl acu-tmh af-tmh agr-tmh ake-tmh am-tmh amu-tmh ar-tmh bg-tmh bsn-tmh cak-tmh ceb-tmh ch-tmh chq-tmh chr-tmh cjp-tmh cni-tmh cop-tmh crp-tmh cs-tmh da-tmh de-tmh dik-tmh dje-tmh djk-tmh dop-tmh ee-tmh el-tmh en-tmh eo-tmh es-tmh et-tmh eu-tmh fi-tmh fr-tmh gbi-tmh gu-tmh gv-tmh he-tmh hi-tmh hr-tmh hu-tmh hy-tmh id-tmh is-tmh it-tmh jak-tmh jap-tmh jiv-tmh kab-tmh kbh-tmh kek-tmh kn-tmh ko-tmh la-tmh lt-tmh lv-tmh mam-tmh mi-tmh ml-tmh mr-tmh my-tmh ne-tmh nhg-tmh nl-tmh no-tmh ojb-tmh pck-tmh pes-tmh pl-tmh plt-tmh ppk-tmh pt-tmh quc-tmh quw-tmh ro-tmh rom-tmh ru-tmh shi-tmh sk-tmh sl-tmh sn-tmh so-tmh sq-tmh sr-tmh ss-tmh sv-tmh syr-tmh te-tmh th-tmh tl-tmh acu-tr af-tr agr-tr ake-tr am-tr amu-tr ar-tr bg-tr bsn-tr cak-tr ceb-tr ch-tr chq-tr chr-tr cjp-tr cni-tr cop-tr crp-tr cs-tr da-tr de-tr dik-tr dje-tr djk-tr dop-tr ee-tr el-tr en-tr eo-tr es-tr et-tr eu-tr fi-tr fr-tr gbi-tr gd-tr gu-tr gv-tr he-tr hi-tr hr-tr hu-tr hy-tr id-tr is-tr it-tr jak-tr jap-tr jiv-tr kab-tr kbh-tr kek-tr kn-tr ko-tr la-tr lt-tr lv-tr mam-tr mi-tr ml-tr mr-tr my-tr ne-tr nhg-tr nl-tr no-tr ojb-tr pck-tr pes-tr pl-tr plt-tr pot-tr ppk-tr pt-tr quc-tr quw-tr ro-tr rom-tr ru-tr shi-tr sk-tr sl-tr sn-tr so-tr sq-tr sr-tr ss-tr sv-tr syr-tr te-tr th-tr tl-tr tmh-tr acu-uk af-uk agr-uk ake-uk am-uk amu-uk ar-uk bg-uk bsn-uk cak-uk ceb-uk ch-uk chq-uk chr-uk cjp-uk cni-uk cop-uk crp-uk cs-uk da-uk de-uk dik-uk dje-uk djk-uk dop-uk ee-uk el-uk en-uk eo-uk es-uk et-uk eu-uk fi-uk fr-uk gbi-uk gd-uk gu-uk gv-uk he-uk hi-uk hr-uk hu-uk hy-uk id-uk is-uk it-uk jak-uk jap-uk jiv-uk kab-uk kbh-uk kek-uk kn-uk ko-uk la-uk lt-uk lv-uk mam-uk mi-uk ml-uk mr-uk my-uk ne-uk nhg-uk nl-uk no-uk ojb-uk pck-uk pes-uk pl-uk plt-uk pot-uk ppk-uk pt-uk quc-uk quw-uk ro-uk rom-uk ru-uk shi-uk sk-uk sl-uk sn-uk so-uk sq-uk sr-uk ss-uk sv-uk syr-uk te-uk th-uk tl-uk tmh-uk tr-uk acu-usp af-usp agr-usp ake-usp am-usp amu-usp ar-usp bg-usp bsn-usp cak-usp ceb-usp ch-usp chq-usp chr-usp cjp-usp cni-usp cop-usp crp-usp cs-usp da-usp de-usp dik-usp dje-usp djk-usp dop-usp ee-usp el-usp en-usp eo-usp es-usp et-usp eu-usp fi-usp fr-usp gbi-usp gd-usp gu-usp gv-usp he-usp hi-usp hr-usp hu-usp hy-usp id-usp is-usp it-usp jak-usp jap-usp jiv-usp kab-usp kbh-usp kek-usp kn-usp ko-usp la-usp lt-usp lv-usp mam-usp mi-usp ml-usp mr-usp my-usp ne-usp nhg-usp nl-usp no-usp ojb-usp pck-usp pes-usp pl-usp plt-usp pot-usp ppk-usp pt-usp quc-usp quw-usp ro-usp rom-usp ru-usp shi-usp sk-usp sl-usp sn-usp so-usp sq-usp sr-usp ss-usp sv-usp syr-usp te-usp th-usp tl-usp tmh-usp tr-usp uk-usp acu-vi af-vi agr-vi ake-vi am-vi amu-vi ar-vi bg-vi bsn-vi cak-vi ceb-vi ch-vi chq-vi chr-vi cjp-vi cni-vi cop-vi crp-vi cs-vi da-vi de-vi dik-vi dje-vi djk-vi dop-vi ee-vi el-vi en-vi eo-vi es-vi et-vi eu-vi fi-vi fr-vi gbi-vi gd-vi gu-vi gv-vi he-vi hi-vi hr-vi hu-vi hy-vi id-vi is-vi it-vi jak-vi jap-vi jiv-vi kab-vi kbh-vi kek-vi kn-vi ko-vi la-vi lt-vi lv-vi mam-vi mi-vi ml-vi mr-vi my-vi ne-vi nhg-vi nl-vi no-vi ojb-vi pck-vi pes-vi pl-vi plt-vi pot-vi ppk-vi pt-vi quc-vi quw-vi ro-vi rom-vi ru-vi shi-vi sk-vi sl-vi sn-vi so-vi sq-vi sr-vi ss-vi sv-vi syr-vi te-vi th-vi tl-vi tmh-vi tr-vi uk-vi usp-vi acu-wal af-wal agr-wal ake-wal am-wal amu-wal ar-wal bg-wal bsn-wal cak-wal ceb-wal ch-wal chq-wal chr-wal cjp-wal cni-wal cop-wal crp-wal cs-wal da-wal de-wal dik-wal dje-wal djk-wal dop-wal ee-wal el-wal en-wal eo-wal es-wal et-wal eu-wal fi-wal fr-wal gbi-wal gd-wal gu-wal gv-wal he-wal hi-wal hr-wal hu-wal hy-wal id-wal is-wal it-wal jak-wal jap-wal jiv-wal kab-wal kbh-wal kek-wal kn-wal ko-wal la-wal lt-wal lv-wal mam-wal mi-wal ml-wal mr-wal my-wal ne-wal nhg-wal nl-wal no-wal ojb-wal pck-wal pes-wal pl-wal plt-wal pot-wal ppk-wal pt-wal quc-wal quw-wal ro-wal rom-wal ru-wal shi-wal sk-wal sl-wal sn-wal so-wal sq-wal sr-wal ss-wal sv-wal syr-wal te-wal th-wal tl-wal tmh-wal tr-wal uk-wal usp-wal vi-wal acu-wo af-wo agr-wo ake-wo am-wo amu-wo ar-wo bg-wo bsn-wo cak-wo ceb-wo ch-wo chq-wo chr-wo cjp-wo cni-wo cop-wo crp-wo cs-wo da-wo de-wo dik-wo dje-wo djk-wo dop-wo ee-wo el-wo en-wo eo-wo es-wo et-wo eu-wo fi-wo fr-wo gbi-wo gd-wo gu-wo gv-wo he-wo hi-wo hr-wo hu-wo hy-wo id-wo is-wo it-wo jak-wo jap-wo jiv-wo kab-wo kbh-wo kek-wo kn-wo ko-wo la-wo lt-wo lv-wo mam-wo mi-wo ml-wo mr-wo my-wo ne-wo nhg-wo nl-wo no-wo ojb-wo pck-wo pes-wo pl-wo plt-wo pot-wo ppk-wo pt-wo quc-wo quw-wo ro-wo rom-wo ru-wo shi-wo sk-wo sl-wo sn-wo so-wo sq-wo sr-wo ss-wo sv-wo syr-wo te-wo th-wo tl-wo tmh-wo tr-wo uk-wo usp-wo vi-wo wal-wo acu-xh af-xh agr-xh ake-xh am-xh amu-xh ar-xh bg-xh bsn-xh cak-xh ceb-xh ch-xh chq-xh chr-xh cjp-xh cni-xh cop-xh crp-xh cs-xh da-xh de-xh dik-xh dje-xh djk-xh dop-xh ee-xh el-xh en-xh eo-xh es-xh et-xh eu-xh fi-xh fr-xh gbi-xh gd-xh gu-xh gv-xh he-xh hi-xh hr-xh hu-xh hy-xh id-xh is-xh it-xh jak-xh jap-xh jiv-xh kab-xh kbh-xh kek-xh kn-xh ko-xh la-xh lt-xh lv-xh mam-xh mi-xh ml-xh mr-xh my-xh ne-xh nhg-xh nl-xh no-xh ojb-xh pck-xh pes-xh pl-xh plt-xh pot-xh ppk-xh pt-xh quc-xh quw-xh ro-xh rom-xh ru-xh shi-xh sk-xh sl-xh sn-xh so-xh sq-xh sr-xh ss-xh sv-xh syr-xh te-xh th-xh tl-xh tmh-xh tr-xh uk-xh usp-xh vi-xh wal-xh wo-xh acu-zh af-zh agr-zh ake-zh am-zh amu-zh ar-zh bg-zh bsn-zh cak-zh ceb-zh ch-zh chq-zh chr-zh cjp-zh cni-zh cop-zh crp-zh cs-zh da-zh de-zh dik-zh dje-zh djk-zh dop-zh ee-zh el-zh en-zh eo-zh es-zh et-zh eu-zh fi-zh fr-zh gbi-zh gd-zh gu-zh gv-zh he-zh hi-zh hr-zh hu-zh hy-zh id-zh is-zh it-zh jak-zh jap-zh jiv-zh kab-zh kbh-zh kek-zh kn-zh ko-zh la-zh lt-zh lv-zh mam-zh mi-zh ml-zh mr-zh my-zh ne-zh nhg-zh nl-zh no-zh ojb-zh pck-zh pes-zh pl-zh plt-zh pot-zh ppk-zh pt-zh quc-zh quw-zh ro-zh rom-zh ru-zh shi-zh sk-zh sl-zh sn-zh so-zh sq-zh sr-zh ss-zh sv-zh syr-zh te-zh th-zh tl-zh tmh-zh tr-zh uk-zh usp-zh vi-zh wal-zh wo-zh xh-zh acu-zu af-zu agr-zu ake-zu am-zu amu-zu ar-zu bg-zu bsn-zu cak-zu ceb-zu ch-zu chq-zu chr-zu cjp-zu cni-zu cop-zu crp-zu cs-zu da-zu de-zu dik-zu dje-zu djk-zu dop-zu ee-zu el-zu en-zu eo-zu es-zu et-zu eu-zu fi-zu fr-zu gbi-zu gd-zu gu-zu gv-zu he-zu hi-zu hr-zu hu-zu hy-zu id-zu is-zu it-zu jak-zu jap-zu jiv-zu kab-zu kbh-zu kek-zu kn-zu ko-zu la-zu lt-zu lv-zu mam-zu mi-zu ml-zu mr-zu my-zu ne-zu nhg-zu nl-zu no-zu ojb-zu pck-zu pes-zu pl-zu plt-zu pot-zu ppk-zu pt-zu quc-zu quw-zu ro-zu rom-zu ru-zu shi-zu sk-zu sl-zu sn-zu so-zu sq-zu sr-zu ss-zu sv-zu syr-zu te-zu th-zu tl-zu tmh-zu tr-zu uk-zu usp-zu vi-zu wal-zu wo-zu xh-zu zh-zu
ada83_v1	ada83/v1/moses/%s-%s.txt.zip	en-ru
XhosaNavy_v1	XhosaNavy/v1/moses/%s-%s.txt.zip	en-xh
WMT_News_v2019	WMT-News/v2019/moses/%s-%s.txt.zip	cs-de cs-en de-en cs-es de-es en-es en-et en-fi cs-fr de-fr en-fr es-fr en-gu en-hi cs-hu de-hu en-hu es-hu fr-hu cs-it de-it en-it es-it fr-it hu-it en-kk en-lt en-lv en-ro cs-ru de-ru en-ru es-ru fr-ru en-tr en-zh
WikiSource_v1	WikiSource/v1/moses/%s-%s.txt.zip	en-sv
Wikipedia_v1.0	Wikipedia/v1.0/moses/%s-%s.txt.zip	ar-en bg-en cs-en de-en el-en en-es en-fa en-fr en-he en-hu en-it en-nl ar-pl cs-pl de-pl el-pl en-pl es-pl fa-pl fr-pl he-pl hu-pl it-pl nl-pl en-pt pl-pt en-ro pl-ro en-ru pl-ru en-sl pl-sl en-tr pl-tr en-vi pl-vi
wikimedia_v20190628	wikimedia/v20190628/moses/%s-%s.txt.zip	af-ar an-ast az-ba be-be_tarask ba-bg be-bg ar-bn as-bn bho-bn bn-bpy bg-bs bn-bug an-ca ast-ca be-ce ar-ckb ar-cr bs-cr be_tarask-cs bg-cs bg-cu ca-cy ang-da bg-da af-de ak-de am-de ast-de ba-de bar-de be_tarask-de bg-de bn-de cy-de cr-din az-diq de-diq de-dsb ar-dz bg-el ab-en ace-en ak-en am-en an-en ang-en arc-en as-en ast-en atj-en ay-en ba-en bar-en bcl-en be_tarask-en bho-en bo-en bpy-en br-en bug-en bxr-en cbk_zam-en cdo-en ch-en chr-en chy-en co-en crh_latn-en din-en diq-en dsb-en dty-en dv-en dz-en ee-en eml-en ast-eo bg-eo ady-es af-es an-es ang-es ay-es bg-es bho-es bn-es bpy-es cbk_zam-es chr-es co-es cy-es diq-es de-et ee-et es-et bn-eu ca-eu de-eu eo-eu et-eu ast-ext en-ext es-ext ar-fa arz-fa az-fa azb-fa ckb-fa da-fa de-fa eo-fa es-fa ar-ff en-ff bg-fi cs-fi da-fi de-fi es-fi et-fi fa-fi en-fj da-fo en-fo af-fr am-fr as-fr ast-fr ba-fr bg-fr br-fr ch-fr co-fr cy-fr diq-fr dty-fr eu-fr fa-fr ff-fr fi-fr es-frr en-fur en-fy es-fy es-gag ar-gan en-gd eo-gd fr-gd ga-gd af-gl ast-gl bn-gl chr-gl cy-gl eu-gl en-glk fa-glk en-gn es-gn fr-gn en-gom en-gor de-got en-got bar-gsw de-gsw en-gsw es-gsw fr-gsw af-gu bho-gu bn-gu bpy-gu ca-gu dty-gu es-gu fi-gu fr-gu en-ha ff-ha cdo-hak af-haw en-haw es-haw fr-haw ar-he ca-he ceb-he da-he de-he eo-he es-he fa-he fr-he gu-he as-hi bho-hi bn-hi dty-hi es-hi fa-hi fi-hi gu-hi he-hi ak-hif bn-hif en-hif bg-hr bs-hr de-hr en-hr es-hr eu-hr fa-hr fi-hr fr-hr he-hr de-hsb ar-ht en-ht es-ht fr-ht ba-hu be-hu bg-hu cs-hu de-hu eo-hu es-hu fi-hu fr-hu haw-hu he-hu hr-hu ar-hy az-hy ba-hy be-hy bg-hy de-hy es-hy fr-hy hu-hy hy-hyw en-ia es-ia fr-ia ace-id af-id ar-id bjn-id bug-id ca-id ceb-id de-id es-id fa-id fr-id gor-id he-id hi-id de-ie en-ie id-ie en-ig de-ik en-ik en-ilo en-io fr-io af-is da-is de-is en-is es-is fa-is fi-is fr-is af-it bg-it bm-it bn-it br-it co-it cy-it eml-it et-it eu-it fa-it ff-it fi-it fur-it glk-it he-it hr-it hu-it hy-it ia-it id-it is-it ar-iu bn-ja bo-ja fa-ja fi-ja gd-ja hi-ja hu-ja id-ja en-jam es-jam fr-jam en-jbo id-jbo hif-jv id-jv ady-ka az-ka de-ka es-ka fr-ka hy-ka it-ka ar-kab de-kab en-kab fr-kab fr-kg en-ki az-kk ba-kk bxr-kk el-kk en-kk es-kk en-kl fr-kl is-kl en-km fr-km ja-km gu-kn hi-kn ba-ko bxr-ko cy-ko de-ko es-ko fa-ko fr-ko he-ko hi-ko id-ko it-ko en-ks hi-ks en-ksh ckb-ku de-ku diq-ku en-ku es-ku fa-ku ka-ku en-kv en-kw it-kw ba-ky en-ky fa-ky kk-ky bg-la ca-la cs-la de-la el-la en-la eo-la es-la fr-la haw-la he-la hr-la hu-la ia-la it-la ja-la en-lad es-lad de-lb en-lb es-lb fr-lb en-lbe en-lez fr-lez en-lfn it-lfn la-lfn en-lg fr-lg es-li de-lij en-lij es-lij fr-lij it-lij de-lmo en-lmo fr-lmo it-lmo fr-ln kg-ln ceb-lo de-lo en-lo fr-lo ko-lo en-lrc be-lt da-lt de-lt en-lt es-lt et-lt eu-lt fi-lt fr-lt hr-lt is-lt ko-lt bg-lv da-lv de-lv en-lv eo-lv es-lv et-lv fi-lv it-lv ka-lv lt-lv ltg-lv cdo-lzh en-lzh fr-lzh ja-lzh ko-lzh en-mai gom-mai hi-mai id-mai en-map_bms en-mdf ka-mg el-mhr en-mi be-min de-min en-min id-min jv-min bg-mk bs-mk de-mk es-mk fr-mk he-mk hr-mk hu-mk it-mk ar-ml ceb-ml es-ml fr-ml gu-ml he-ml hi-ml ja-ml kn-ml bxr-mn en-mn ja-mn ko-mn bho-mr bn-mr en-mr es-mr gu-mr hi-mr en-mrj fr-mrj kk-mrj ar-ms bn-ms es-ms fi-ms fr-ms id-ms it-ms ja-ms jv-ms ko-ms lo-ms ar-mt ca-mt en-mt es-mt fr-mt it-mt es-mwl fa-my ja-my km-my ba-myv de-myv en-myv arz-mzn en-mzn fa-mzn de-na en-na en-nah es-nah hu-nah en-nan id-nan ja-nan en-nap it-nap af-nb ar-nb az-nb bg-nb bn-nb cs-nb de-nb eo-nb es-nb fa-nb fi-nb fr-nb he-nb hr-nb hu-nb hy-nb id-nb is-nb it-nb ja-nb lv-nb nan-nb de-nds de-nds_nl en-nds_nl ia-nds_nl nds-nds_nl as-ne bn-ne dty-ne en-ne gu-ne hi-ne mai-ne en-new fi-new hi-new ne-new af-nl bg-nl diq-nl fa-nl fi-nl fy-nl he-nl hr-nl hu-nl hy-nl ia-nl id-nl jv-nl ka-nl ko-nl ku-nl la-nl li-nl mk-nl nb-nl nds-nl nds_nl-nl bg-nn da-nn de-nn en-nn fi-nn ko-nn bg-no da-no de-no en-no hu-no nn-no en-nov frp-nrm af-nso en-nso en-nv de-ny en-ny ast-oc bg-oc cs-oc de-oc en-oc es-oc gl-oc hu-oc it-oc en-om fr-om hi-or bg-os en-os eo-os af-pa bn-pa gu-pa hi-pa en-pam en-pap es-pap fr-pap nl-pap fr-pcd nrm-pcd da-pdc en-pdc it-pdc nds-pdc de-pfl en-pfl fr-pfl gu-pi hi-pi mai-pi mr-pi en-pih ba-pl be-pl be_tarask-pl bg-pl bs-pl crh_latn-pl cs-pl cy-pl da-pl de-pl eo-pl es-pl et-pl fa-pl fi-pl fr-pl he-pl hu-pl hy-pl id-pl it-pl ja-pl ka-pl la-pl lt-pl lv-pl mk-pl nb-pl nl-pl nv-pl pdc-pl en-pms es-pms en-pnb pa-pnb el-pnt en-pnt en-ps fa-ps fr-ps hi-ps it-ps nb-ps nl-ps af-pt ast-pt bg-pt bn-pt cy-pt et-pt eu-pt fa-pt fi-pt fy-pt gag-pt ha-pt haw-pt he-pt hif-pt hr-pt ht-pt ia-pt id-pt ig-pt io-pt jbo-pt ko-pt la-pt ln-pt lv-pt ms-pt mwl-pt nb-pt nov-pt oc-pt pap-pt pdc-pt pl-pt en-qu es-qu gl-qu de-rm it-rm ee-rmy en-rmy es-rmy fi-rmy hif-rmy mai-rmy af-ro be_tarask-ro bg-ro eu-ro he-ro hu-ro nb-ro ab-ru ace-ru af-ru av-ru ay-ru be_tarask-ru bn-ru bo-ru bxr-ru ce-ru cv-ru cy-ru dz-ru et-ru eu-ru fa-ru fi-ru frp-ru gag-ru gn-ru gv-ru hi-ru hr-ru hu-ru id-ru inh-ru is-ru jv-ru ka-ru kbd-ru km-ru ko-ru krc-ru ky-ru la-ru lo-ru lt-ru lv-ru mk-ru mn-ru ms-ru my-ru myv-ru nah-ru nb-ru nn-ru ny-ru oc-ru olo-ru os-ru pa-ru pl-ru pt-rup en-rw fr-rw en-sa gu-sa hi-sa kn-sa mr-sa bg-sah en-sah ru-sah ar-sat en-sat hi-sat or-sat ar-sc ca-sc en-sc es-sc it-sc pt-sc co-scn en-scn it-scn en-sco es-sco fr-sco fy-sco it-sco ar-sd en-sd gu-sd pnb-sd en-se fi-se nb-se nn-se qu-se en-sgs it-sgs lt-sgs ba-sh bs-sh de-sh en-sh es-sh fr-sh hi-sh hr-sh hu-sh mk-sh ru-sh af-si bn-si ca-si en-si fr-si af-simple am-simple ast-simple ba-simple bho-simple bn-simple ch-simple ckb-simple co-simple cy-simple dv-simple eu-simple fa-simple ff-simple fi-simple fy-simple gd-simple gu-simple he-simple hi-simple hif-simple ht-simple jv-simple ka-simple ko-simple ku-simple la-simple lmo-simple ln-simple lt-simple lv-simple lzh-simple mi-simple mk-simple ms-simple nb-simple ny-simple os-simple pa-simple pap-simple pcd-simple pih-simple pl-simple pms-simple sah-simple sat-simple sco-simple bg-sk hu-sk pl-sk bs-sl ce-sl cs-sl de-sl es-sl fr-sl hr-sl hu-sl it-sl ja-sl mk-sl nb-sl sh-sl simple-sl sk-sl en-sm fr-sm pt-sm en-sn ar-so de-so en-so ja-so bs-sq ca-sq ceb-sq cs-sq de-sq es-sq fr-sq hr-sq it-sq ja-sq mk-sq nn-sq pl-sq ro-sq ru-sq sh-sq simple-sq sk-sq sl-sq so-sq be-sr bg-sr bs-sr da-sr de-sr el-sr eo-sr es-sr fa-sr fr-sr hr-sr hu-sr hy-sr it-sr mk-sr nl-sr pl-sr pt-sr ru-sr sh-sr simple-sr sk-sr sl-sr sq-sr en-srn nl-srn ru-srn en-ss af-st de-st en-st nso-st ar-su bn-su de-su en-su id-su it-su ms-su nl-su ar-sv ba-sv bg-sv bn-sv ckb-sv da-sv de-sv es-sv et-sv fa-sv fi-sv fo-sv fr-sv gor-sv he-sv hu-sv id-sv is-sv it-sv ja-sv jv-sv ko-sv kv-sv lad-sv lo-sv lt-sv ml-sv nb-sv nl-sv nn-sv no-sv pdc-sv pl-sv ro-sv ru-sv se-sv simple-sv sq-sv bg-sw de-sw en-sw es-sw fr-sw hr-sw ja-sw nl-sw ru-sw simple-sw en-szl pl-szl bn-ta fr-ta gu-ta hi-ta pl-ta ru-ta si-ta simple-ta en-tcy kn-tcy kn-te nb-te pt-te en-tet fr-tet id-tet ko-tet simple-tet en-tg fa-tg nb-tg ru-tg sq-tg ab-th ace-th ak-th am-th an-th ang-th ar-th ast-th ay-th bi-th ca-th cbk_zam-th cdo-th ceb-th crh_latn-th de-th dsb-th dz-th eml-th eo-th es-th et-th fa-th fi-th fr-th frp-th frr-th fur-th gd-th gn-th hif-th hsb-th ht-th id-th ie-th ig-th io-th ja-th jv-th ka-th kaa-th kab-th km-th ko-th lij-th lmo-th lo-th ltg-th mi-th ms-th mt-th mwl-th my-th na-th nah-th nan-th nb-th nl-th nov-th nso-th oc-th olo-th pih-th pms-th pt-th rm-th ro-th ru-th rw-th sc-th scn-th sco-th se-th simple-th so-th stq-th sv-th tet-th en-ti en-tk ru-tk bcl-tl cs-tl eo-tl es-tl fr-tl hu-tl id-tl ja-tl ko-tl lo-tl ms-tl nl-tl ru-tl simple-tl th-tl af-tn en-tn simple-tn en-to en-tpi ru-tpi th-tpi ba-tr bg-tr bn-tr bxr-tr diq-tr fa-tr gag-tr he-tr hu-tr id-tr inh-tr jv-tr ka-tr kbd-tr kk-tr ku-tr ky-tr mdf-tr mk-tr ms-tr nb-tr ny-tr pl-tr rm-tr so-tr sq-tr sv-tr tg-tr th-tr tk-tr en-ts az-tt ba-tt bg-tt de-tt el-tt en-tt fa-tt fr-tt kk-tt ru-tt tr-tt en-tum en-tw th-tw fr-ty haw-ty ie-ty it-ty pt-ty ta-ty th-ty en-tyv ru-tyv de-udm en-udm fi-udm ru-udm en-ug th-ug ba-uk be_tarask-uk bxr-uk fi-uk he-uk hr-uk hu-uk kk-uk myv-uk new-uk pl-uk rue-uk sr-uk sv-uk af-ur ar-ur arz-ur bn-ur es-ur fa-ur gu-ur hi-ur pa-ur pnb-ur sd-ur be-uz en-uz fa-uz ky-uz ny-uz pt-uz ru-uz th-uz tr-uz en-ve en-vec it-vec cs-vi da-vi de-vi es-vi fr-vi hi-vi hr-vi id-vi it-vi ja-vi km-vi ko-vi ml-vi pl-vi pt-vi ru-vi simple-vi sr-vi th-vi tr-vi uk-vi fr-vls nl-vls cs-vo de-vo en-vo es-vo fr-vo gn-vo it-vo ko-vo th-vo ty-vo et-vro th-vro en-wa ko-wa ceb-war en-war fr-war id-war lo-war pag-war pt-war th-war tl-war uk-war bn-wuu en-wuu fr-wuu ja-wuu lzh-wuu af-xh en-xh fr-xh gv-xh pt-xh simple-xh st-xh th-xh tr-xh en-xmf ka-xmf ru-xmf en-yi fr-yi he-yi it-yi pt-yi simple-yi az-yue ca-yue de-yue en-yue fi-yue fr-yue gan-yue ja-yue ko-yue lzh-yue ms-yue nan-yue nb-yue nl-yue pt-yue sv-yue th-yue wuu-yue en-za yue-za es-zea ab-zh ace-zh am-zh ba-zh bi-zh bo-zh cbk_zam-zh cdo-zh chy-zh co-zh crh_latn-zh diq-zh eu-zh fi-zh frp-zh frr-zh gan-zh gn-zh got-zh he-zh ht-zh hy-zh id-zh io-zh iu-zh jbo-zh kab-zh kl-zh km-zh ko-zh lo-zh lv-zh lzh-zh mi-zh min-zh ms-zh na-zh nan-zh nds_nl-zh nov-zh om-zh pap-zh pms-zh sc-zh scn-zh sco-zh se-zh so-zh srn-zh stq-zh th-zh tl-zh tpi-zh vep-zh vi-zh vo-zh war-zh xal-zh en-zh_tw zh-zh_tw wuu-zh_yue af-zu en-zu pa-zu th-zu
UNPC_v1.0	UNPC/v1.0/moses/%s-%s.txt.zip	ar-en ar-es en-es ar-fr en-fr es-fr ar-ru en-ru es-ru fr-ru ar-zh en-zh es-zh fr-zh ru-zh
UN_v20090831	UN/v20090831/moses/%s-%s.txt.zip	ar-en ar-es en-es ar-fr en-fr es-fr ar-ru en-ru es-ru fr-ru ar-zh en-zh es-zh fr-zh ru-zh
Ubuntu_v14.10	Ubuntu/v14.10/moses/%s-%s.txt.zip	ace-af ace-ak af-ak ace-am af-am ak-am ace-an af-an ak-an am-an ace-ang af-ang am-ang ace-ar af-ar ak-ar am-ar an-ar ang-ar af-ar_SY ar-ar_SY ace-ary af-ary am-ary an-ary ar-ary ace-as af-as ak-as am-as an-as ang-as ar-as ary-as ace-ast af-ast ak-ast am-ast an-ast ang-ast ar-ast ar_SY-ast ary-ast as-ast ace-az af-az ak-az am-az an-az ang-az ar-az ar_SY-az ary-az as-az ast-az af-ba am-ba ar-ba ast-ba az-ba af-bal am-bal ar-bal as-bal ast-bal az-bal ace-be af-be ak-be am-be an-be ang-be ar-be ar_SY-be ary-be as-be ast-be az-be ba-be bal-be ace-bem af-bem am-bem an-bem ar-bem ary-bem as-bem ast-bem az-bem be-bem ace-ber af-ber ak-ber am-ber an-ber ar-ber as-ber ast-ber az-ber be-ber bem-ber ace-bg af-bg ak-bg am-bg an-bg ang-bg ar-bg ar_SY-bg ary-bg as-bg ast-bg az-bg ba-bg bal-bg be-bg bem-bg ber-bg af-bho am-bho ar-bho as-bho ast-bho az-bho be-bho bg-bho ace-bn af-bn ak-bn am-bn an-bn ang-bn ar-bn ary-bn as-bn ast-bn az-bn ba-bn bal-bn be-bn bem-bn ber-bn bg-bn bho-bn ace-bn_IN af-bn_IN am-bn_IN ang-bn_IN ar-bn_IN as-bn_IN ast-bn_IN az-bn_IN be-bn_IN bg-bn_IN bn-bn_IN ace-bo af-bo ak-bo am-bo an-bo ang-bo ar-bo ary-bo as-bo ast-bo az-bo be-bo bem-bo ber-bo bg-bo bn-bo bn_IN-bo ace-br af-br ak-br am-br an-br ang-br ar-br ary-br as-br ast-br az-br ba-br bal-br be-br bem-br ber-br bg-br bho-br bn-br bn_IN-br bo-br ace-brx af-brx am-brx an-brx ar-brx as-brx ast-brx az-brx be-brx bem-brx bg-brx bn-brx bo-brx br-brx ace-bs af-bs ak-bs am-bs an-bs ang-bs ar-bs ar_SY-bs ary-bs as-bs ast-bs az-bs ba-bs bal-bs be-bs bem-bs ber-bs bg-bs bho-bs bn-bs bn_IN-bs bo-bs br-bs brx-bs af-bua am-bua ar-bua ast-bua az-bua ba-bua be-bua bg-bua bn-bua br-bua bs-bua ace-byn af-byn am-byn an-byn ar-byn ary-byn as-byn ast-byn az-byn be-byn bem-byn bg-byn bn-byn bo-byn br-byn brx-byn bs-byn ace-ca af-ca ak-ca am-ca an-ca ang-ca ar-ca ar_SY-ca ary-ca as-ca ast-ca az-ca ba-ca bal-ca be-ca bem-ca ber-ca bg-ca bho-ca bn-ca bn_IN-ca bo-ca br-ca brx-ca bs-ca bua-ca byn-ca ace-ce af-ce ak-ce am-ce an-ce ar-ce ary-ce as-ce ast-ce az-ce be-ce bem-ce bg-ce bn-ce bo-ce br-ce brx-ce bs-ce byn-ce ca-ce af-ceb ak-ceb am-ceb an-ceb ar-ceb as-ceb ast-ceb az-ceb be-ceb ber-ceb bg-ceb bn-ceb bo-ceb br-ceb brx-ceb bs-ceb ca-ceb ace-chr af-chr am-chr an-chr ar-chr as-chr ast-chr az-chr be-chr bg-chr bn-chr bo-chr br-chr bs-chr ca-chr ace-ckb af-ckb ak-ckb am-ckb an-ckb ang-ckb ar-ckb ary-ckb as-ckb ast-ckb az-ckb ba-ckb bal-ckb be-ckb bem-ckb ber-ckb bg-ckb bn-ckb bn_IN-ckb bo-ckb br-ckb brx-ckb bs-ckb bua-ckb byn-ckb ca-ckb ce-ckb ceb-ckb chr-ckb ace-co af-co ak-co am-co an-co ar-co as-co ast-co az-co be-co bg-co bn-co bo-co br-co bs-co ca-co ce-co ckb-co ace-crh af-crh ak-crh am-crh an-crh ang-crh ar-crh ary-crh as-crh ast-crh az-crh bal-crh be-crh bem-crh ber-crh bg-crh bn-crh bn_IN-crh bo-crh br-crh brx-crh bs-crh byn-crh ca-crh ce-crh ceb-crh chr-crh ckb-crh co-crh ace-cs af-cs ak-cs am-cs an-cs ang-cs ar-cs ar_SY-cs ary-cs as-cs ast-cs az-cs ba-cs bal-cs be-cs bem-cs ber-cs bg-cs bho-cs bn-cs bn_IN-cs bo-cs br-cs brx-cs bs-cs bua-cs byn-cs ca-cs ce-cs ceb-cs chr-cs ckb-cs co-cs crh-cs ace-csb af-csb ak-csb am-csb an-csb ang-csb ar-csb ary-csb as-csb ast-csb az-csb bal-csb be-csb bem-csb bg-csb bn-csb bo-csb br-csb brx-csb bs-csb byn-csb ca-csb ce-csb chr-csb ckb-csb co-csb crh-csb cs-csb ace-cv af-cv ak-cv am-cv an-cv ar-cv ary-cv as-cv ast-cv az-cv bal-cv be-cv bem-cv ber-cv bg-cv bn-cv bn_IN-cv bo-cv br-cv brx-cv bs-cv byn-cv ca-cv ce-cv ceb-cv chr-cv ckb-cv co-cv crh-cv cs-cv csb-cv ace-cy af-cy ak-cy am-cy an-cy ang-cy ar-cy ary-cy as-cy ast-cy az-cy ba-cy bal-cy be-cy bem-cy ber-cy bg-cy bho-cy bn-cy bn_IN-cy bo-cy br-cy brx-cy bs-cy bua-cy byn-cy ca-cy ce-cy ceb-cy chr-cy ckb-cy co-cy crh-cy cs-cy csb-cy cv-cy ace-da af-da ak-da am-da an-da ang-da ar-da ar_SY-da ary-da as-da ast-da az-da ba-da bal-da be-da bem-da ber-da bg-da bho-da bn-da bn_IN-da bo-da br-da brx-da bs-da bua-da byn-da ca-da ce-da ceb-da chr-da ckb-da co-da crh-da cs-da csb-da cv-da cy-da ace-de af-de ak-de am-de an-de ang-de ar-de ar_SY-de ary-de as-de ast-de az-de ba-de bal-de be-de bem-de ber-de bg-de bho-de bn-de bn_IN-de bo-de br-de brx-de bs-de bua-de byn-de ca-de ce-de ceb-de chr-de ckb-de co-de crh-de cs-de csb-de cv-de cy-de da-de ace-de_AT af-de_AT ak-de_AT am-de_AT an-de_AT ar-de_AT as-de_AT ast-de_AT az-de_AT be-de_AT bg-de_AT bn-de_AT bo-de_AT br-de_AT bs-de_AT ca-de_AT ce-de_AT ckb-de_AT co-de_AT crh-de_AT cs-de_AT csb-de_AT cv-de_AT cy-de_AT da-de_AT de-de_AT ace-de_DE af-de_DE ak-de_DE am-de_DE an-de_DE ang-de_DE ar-de_DE as-de_DE ast-de_DE az-de_DE ba-de_DE be-de_DE bg-de_DE bn-de_DE bo-de_DE br-de_DE bs-de_DE bua-de_DE ca-de_DE ce-de_DE ckb-de_DE co-de_DE crh-de_DE cs-de_DE csb-de_DE cv-de_DE cy-de_DE da-de_DE de-de_DE de_AT-de_DE ace-dsb af-dsb ak-dsb am-dsb an-dsb ar-dsb as-dsb ast-dsb az-dsb be-dsb bg-dsb bn-dsb bo-dsb br-dsb bs-dsb ca-dsb ce-dsb ckb-dsb co-dsb crh-dsb cs-dsb csb-dsb cv-dsb cy-dsb da-dsb de-dsb de_AT-dsb de_DE-dsb ace-dv af-dv ak-dv am-dv an-dv ang-dv ar-dv ary-dv as-dv ast-dv az-dv ba-dv bal-dv be-dv bem-dv ber-dv bg-dv bho-dv bn-dv bn_IN-dv bo-dv br-dv brx-dv bs-dv bua-dv byn-dv ca-dv ce-dv ceb-dv chr-dv ckb-dv co-dv crh-dv cs-dv csb-dv cv-dv cy-dv da-dv de-dv de_AT-dv de_DE-dv dsb-dv ace-dz af-dz ak-dz am-dz an-dz ang-dz ar-dz as-dz ast-dz az-dz ba-dz bal-dz be-dz ber-dz bg-dz bho-dz bn-dz bn_IN-dz bo-dz br-dz bs-dz bua-dz ca-dz ce-dz ceb-dz chr-dz ckb-dz co-dz crh-dz cs-dz csb-dz cv-dz cy-dz da-dz de-dz de_AT-dz de_DE-dz dsb-dz dv-dz ace-el af-el ak-el am-el an-el ang-el ar-el ar_SY-el ary-el as-el ast-el az-el ba-el bal-el be-el bem-el ber-el bg-el bho-el bn-el bn_IN-el bo-el br-el brx-el bs-el bua-el byn-el ca-el ce-el ceb-el chr-el ckb-el co-el crh-el cs-el csb-el cv-el cy-el da-el de-el de_AT-el de_DE-el dsb-el dv-el dz-el ace-en af-en ak-en am-en an-en ang-en ar-en ar_SY-en ary-en as-en ast-en az-en ba-en bal-en be-en bem-en ber-en bg-en bho-en bn-en bn_IN-en bo-en br-en brx-en bs-en bua-en byn-en ca-en ce-en ceb-en chr-en ckb-en co-en crh-en cs-en csb-en cv-en cy-en da-en de-en de_AT-en de_DE-en dsb-en dv-en dz-en el-en ace-en_AU af-en_AU ak-en_AU am-en_AU an-en_AU ang-en_AU ar-en_AU ar_SY-en_AU ary-en_AU as-en_AU ast-en_AU az-en_AU ba-en_AU bal-en_AU be-en_AU bem-en_AU ber-en_AU bg-en_AU bho-en_AU bn-en_AU bn_IN-en_AU bo-en_AU br-en_AU brx-en_AU bs-en_AU bua-en_AU byn-en_AU ca-en_AU ce-en_AU ceb-en_AU chr-en_AU ckb-en_AU co-en_AU crh-en_AU cs-en_AU csb-en_AU cv-en_AU cy-en_AU da-en_AU de-en_AU de_AT-en_AU de_DE-en_AU dsb-en_AU dv-en_AU dz-en_AU el-en_AU en-en_AU ace-en_CA af-en_CA ak-en_CA am-en_CA an-en_CA ang-en_CA ar-en_CA ary-en_CA as-en_CA ast-en_CA az-en_CA ba-en_CA bal-en_CA be-en_CA bem-en_CA ber-en_CA bg-en_CA bho-en_CA bn-en_CA bn_IN-en_CA bo-en_CA br-en_CA brx-en_CA bs-en_CA bua-en_CA byn-en_CA ca-en_CA ce-en_CA ceb-en_CA chr-en_CA ckb-en_CA co-en_CA crh-en_CA cs-en_CA csb-en_CA cv-en_CA cy-en_CA da-en_CA de-en_CA de_AT-en_CA de_DE-en_CA dsb-en_CA dv-en_CA dz-en_CA el-en_CA en-en_CA en_AU-en_CA ace-en_GB af-en_GB ak-en_GB am-en_GB an-en_GB ang-en_GB ar-en_GB ar_SY-en_GB ary-en_GB as-en_GB ast-en_GB az-en_GB ba-en_GB bal-en_GB be-en_GB bem-en_GB ber-en_GB bg-en_GB bho-en_GB bn-en_GB bn_IN-en_GB bo-en_GB br-en_GB brx-en_GB bs-en_GB bua-en_GB byn-en_GB ca-en_GB ce-en_GB ceb-en_GB chr-en_GB ckb-en_GB co-en_GB crh-en_GB cs-en_GB csb-en_GB cv-en_GB cy-en_GB da-en_GB de-en_GB de_AT-en_GB de_DE-en_GB dsb-en_GB dv-en_GB dz-en_GB el-en_GB en-en_GB en_AU-en_GB en_CA-en_GB af-en_NZ am-en_NZ ar-en_NZ ast-en_NZ az-en_NZ ba-en_NZ be-en_NZ bg-en_NZ bn-en_NZ br-en_NZ bs-en_NZ bua-en_NZ ca-en_NZ ckb-en_NZ cs-en_NZ cy-en_NZ da-en_NZ de-en_NZ de_DE-en_NZ dv-en_NZ dz-en_NZ el-en_NZ en-en_NZ en_AU-en_NZ en_CA-en_NZ en_GB-en_NZ af-en_US am-en_US an-en_US ar-en_US as-en_US ast-en_US az-en_US be-en_US bg-en_US bn-en_US bn_IN-en_US bo-en_US br-en_US bs-en_US ca-en_US ceb-en_US ckb-en_US crh-en_US cs-en_US cy-en_US da-en_US de-en_US de_DE-en_US dsb-en_US dv-en_US dz-en_US el-en_US en-en_US en_AU-en_US en_CA-en_US en_GB-en_US ace-eo af-eo ak-eo am-eo an-eo ang-eo ar-eo ar_SY-eo ary-eo as-eo ast-eo az-eo ba-eo bal-eo be-eo bem-eo ber-eo bg-eo bho-eo bn-eo bn_IN-eo bo-eo br-eo brx-eo bs-eo bua-eo byn-eo ca-eo ce-eo ceb-eo chr-eo ckb-eo co-eo crh-eo cs-eo csb-eo cv-eo cy-eo da-eo de-eo de_AT-eo de_DE-eo dsb-eo dv-eo dz-eo el-eo en-eo en_AU-eo en_CA-eo en_GB-eo en_NZ-eo en_US-eo ace-es af-es ak-es am-es an-es ang-es ar-es ar_SY-es ary-es as-es ast-es az-es ba-es bal-es be-es bem-es ber-es bg-es bho-es bn-es bn_IN-es bo-es br-es brx-es bs-es bua-es byn-es ca-es ce-es ceb-es chr-es ckb-es co-es crh-es cs-es csb-es cv-es cy-es da-es de-es de_AT-es de_DE-es dsb-es dv-es dz-es el-es en-es en_AU-es en_CA-es en_GB-es en_NZ-es en_US-es eo-es af-es_AR am-es_AR ar-es_AR as-es_AR ast-es_AR az-es_AR be-es_AR bg-es_AR bn-es_AR bn_IN-es_AR br-es_AR bs-es_AR ca-es_AR crh-es_AR cs-es_AR cy-es_AR da-es_AR de-es_AR de_DE-es_AR dz-es_AR el-es_AR en-es_AR en_AU-es_AR en_CA-es_AR en_GB-es_AR eo-es_AR es-es_AR af-es_CL am-es_CL ar-es_CL as-es_CL ast-es_CL az-es_CL be-es_CL bg-es_CL bn-es_CL bn_IN-es_CL br-es_CL bs-es_CL ca-es_CL crh-es_CL cs-es_CL cy-es_CL da-es_CL de-es_CL dz-es_CL el-es_CL en-es_CL en_AU-es_CL en_CA-es_CL en_GB-es_CL eo-es_CL es-es_CL es_AR-es_CL ace-es_CO af-es_CO am-es_CO an-es_CO ar-es_CO as-es_CO ast-es_CO az-es_CO be-es_CO bem-es_CO ber-es_CO bg-es_CO bn-es_CO bn_IN-es_CO bo-es_CO br-es_CO bs-es_CO ca-es_CO ckb-es_CO crh-es_CO cs-es_CO cv-es_CO cy-es_CO da-es_CO de-es_CO dv-es_CO dz-es_CO el-es_CO en-es_CO en_AU-es_CO en_CA-es_CO en_GB-es_CO eo-es_CO es-es_CO es_AR-es_CO es_CL-es_CO af-es_CR am-es_CR ar-es_CR as-es_CR ast-es_CR az-es_CR be-es_CR bg-es_CR bn-es_CR bn_IN-es_CR br-es_CR bs-es_CR ca-es_CR crh-es_CR cs-es_CR cy-es_CR da-es_CR de-es_CR dz-es_CR el-es_CR en-es_CR en_AU-es_CR en_CA-es_CR en_GB-es_CR eo-es_CR es-es_CR es_AR-es_CR es_CL-es_CR es_CO-es_CR af-es_DO am-es_DO ar-es_DO as-es_DO ast-es_DO az-es_DO be-es_DO bg-es_DO bn-es_DO bn_IN-es_DO br-es_DO bs-es_DO ca-es_DO crh-es_DO cs-es_DO cy-es_DO da-es_DO de-es_DO dz-es_DO el-es_DO en-es_DO en_AU-es_DO en_CA-es_DO en_GB-es_DO eo-es_DO es-es_DO es_AR-es_DO es_CL-es_DO es_CO-es_DO es_CR-es_DO af-es_EC am-es_EC ar-es_EC as-es_EC ast-es_EC az-es_EC be-es_EC bg-es_EC bn-es_EC bn_IN-es_EC br-es_EC bs-es_EC ca-es_EC crh-es_EC cs-es_EC cy-es_EC da-es_EC de-es_EC dz-es_EC el-es_EC en-es_EC en_AU-es_EC en_CA-es_EC en_GB-es_EC eo-es_EC es-es_EC es_AR-es_EC es_CL-es_EC es_CO-es_EC es_CR-es_EC es_DO-es_EC ace-es_ES af-es_ES ak-es_ES am-es_ES an-es_ES ar-es_ES as-es_ES ast-es_ES az-es_ES be-es_ES bg-es_ES bn-es_ES bn_IN-es_ES bo-es_ES br-es_ES bs-es_ES ca-es_ES ce-es_ES ckb-es_ES co-es_ES crh-es_ES cs-es_ES csb-es_ES cv-es_ES cy-es_ES da-es_ES de-es_ES de_AT-es_ES de_DE-es_ES dsb-es_ES dv-es_ES dz-es_ES el-es_ES en-es_ES en_AU-es_ES en_CA-es_ES en_GB-es_ES en_US-es_ES eo-es_ES es-es_ES es_AR-es_ES es_CL-es_ES es_CO-es_ES es_CR-es_ES es_DO-es_ES es_EC-es_ES af-es_GT am-es_GT ar-es_GT as-es_GT ast-es_GT az-es_GT be-es_GT bg-es_GT bn-es_GT bn_IN-es_GT br-es_GT bs-es_GT ca-es_GT crh-es_GT cs-es_GT cy-es_GT da-es_GT de-es_GT dz-es_GT el-es_GT en-es_GT en_AU-es_GT en_CA-es_GT en_GB-es_GT eo-es_GT es-es_GT es_AR-es_GT es_CL-es_GT es_CO-es_GT es_CR-es_GT es_DO-es_GT es_EC-es_GT es_ES-es_GT af-es_HN am-es_HN ar-es_HN as-es_HN ast-es_HN az-es_HN be-es_HN bg-es_HN bn-es_HN bn_IN-es_HN br-es_HN bs-es_HN ca-es_HN crh-es_HN cs-es_HN cy-es_HN da-es_HN de-es_HN dz-es_HN el-es_HN en-es_HN en_AU-es_HN en_CA-es_HN en_GB-es_HN eo-es_HN es-es_HN es_AR-es_HN es_CL-es_HN es_CO-es_HN es_CR-es_HN es_DO-es_HN es_EC-es_HN es_ES-es_HN es_GT-es_HN af-es_MX am-es_MX ar-es_MX as-es_MX ast-es_MX az-es_MX be-es_MX bg-es_MX bn-es_MX bn_IN-es_MX br-es_MX bs-es_MX ca-es_MX crh-es_MX cs-es_MX cy-es_MX da-es_MX de-es_MX dz-es_MX el-es_MX en-es_MX en_AU-es_MX en_CA-es_MX en_GB-es_MX eo-es_MX es-es_MX es_AR-es_MX es_CL-es_MX es_CO-es_MX es_CR-es_MX es_DO-es_MX es_EC-es_MX es_ES-es_MX es_GT-es_MX es_HN-es_MX af-es_NI am-es_NI ar-es_NI as-es_NI ast-es_NI az-es_NI be-es_NI bg-es_NI bn-es_NI bn_IN-es_NI br-es_NI bs-es_NI ca-es_NI crh-es_NI cs-es_NI cy-es_NI da-es_NI de-es_NI dz-es_NI el-es_NI en-es_NI en_AU-es_NI en_CA-es_NI en_GB-es_NI eo-es_NI es-es_NI es_AR-es_NI es_CL-es_NI es_CO-es_NI es_CR-es_NI es_DO-es_NI es_EC-es_NI es_ES-es_NI es_GT-es_NI es_HN-es_NI es_MX-es_NI af-es_PA am-es_PA ar-es_PA as-es_PA ast-es_PA az-es_PA be-es_PA bg-es_PA bn-es_PA bn_IN-es_PA br-es_PA bs-es_PA ca-es_PA crh-es_PA cs-es_PA cy-es_PA da-es_PA de-es_PA dz-es_PA el-es_PA en-es_PA en_AU-es_PA en_CA-es_PA en_GB-es_PA eo-es_PA es-es_PA es_AR-es_PA es_CL-es_PA es_CO-es_PA es_CR-es_PA es_DO-es_PA es_EC-es_PA es_ES-es_PA es_GT-es_PA es_HN-es_PA es_MX-es_PA es_NI-es_PA af-es_PE am-es_PE ar-es_PE as-es_PE ast-es_PE az-es_PE be-es_PE bg-es_PE bn-es_PE bn_IN-es_PE br-es_PE bs-es_PE ca-es_PE crh-es_PE cs-es_PE cy-es_PE da-es_PE de-es_PE dz-es_PE el-es_PE en-es_PE en_AU-es_PE en_CA-es_PE en_GB-es_PE eo-es_PE es-es_PE es_AR-es_PE es_CL-es_PE es_CO-es_PE es_CR-es_PE es_DO-es_PE es_EC-es_PE es_ES-es_PE es_GT-es_PE es_HN-es_PE es_MX-es_PE es_NI-es_PE es_PA-es_PE ace-es_PR af-es_PR ak-es_PR am-es_PR an-es_PR ar-es_PR as-es_PR ast-es_PR az-es_PR be-es_PR bg-es_PR bn-es_PR bn_IN-es_PR bo-es_PR br-es_PR bs-es_PR ca-es_PR ce-es_PR ckb-es_PR co-es_PR crh-es_PR cs-es_PR csb-es_PR cv-es_PR cy-es_PR da-es_PR de-es_PR de_AT-es_PR de_DE-es_PR dsb-es_PR dv-es_PR dz-es_PR el-es_PR en-es_PR en_AU-es_PR en_CA-es_PR en_GB-es_PR eo-es_PR es-es_PR es_AR-es_PR es_CL-es_PR es_CO-es_PR es_CR-es_PR es_DO-es_PR es_EC-es_PR es_ES-es_PR es_GT-es_PR es_HN-es_PR es_MX-es_PR es_NI-es_PR es_PA-es_PR es_PE-es_PR af-es_SV am-es_SV ar-es_SV as-es_SV ast-es_SV az-es_SV be-es_SV bg-es_SV bn-es_SV bn_IN-es_SV br-es_SV bs-es_SV ca-es_SV crh-es_SV cs-es_SV cy-es_SV da-es_SV de-es_SV dz-es_SV el-es_SV en-es_SV en_AU-es_SV en_CA-es_SV en_GB-es_SV eo-es_SV es-es_SV es_AR-es_SV es_CL-es_SV es_CO-es_SV es_CR-es_SV es_DO-es_SV es_EC-es_SV es_ES-es_SV es_GT-es_SV es_HN-es_SV es_MX-es_SV es_NI-es_SV es_PA-es_SV es_PE-es_SV es_PR-es_SV af-es_UY am-es_UY ar-es_UY as-es_UY ast-es_UY az-es_UY be-es_UY bg-es_UY bho-es_UY bn-es_UY bn_IN-es_UY br-es_UY bs-es_UY ca-es_UY crh-es_UY cs-es_UY cy-es_UY da-es_UY de-es_UY dv-es_UY dz-es_UY el-es_UY en-es_UY en_AU-es_UY en_CA-es_UY en_GB-es_UY eo-es_UY es-es_UY es_AR-es_UY es_CL-es_UY es_CO-es_UY es_CR-es_UY es_DO-es_UY es_EC-es_UY es_ES-es_UY es_GT-es_UY es_HN-es_UY es_MX-es_UY es_NI-es_UY es_PA-es_UY es_PE-es_UY es_PR-es_UY es_SV-es_UY af-es_VE am-es_VE ar-es_VE as-es_VE ast-es_VE az-es_VE be-es_VE bg-es_VE bn-es_VE bn_IN-es_VE br-es_VE bs-es_VE ca-es_VE crh-es_VE cs-es_VE cy-es_VE da-es_VE de-es_VE dz-es_VE el-es_VE en-es_VE en_AU-es_VE en_CA-es_VE en_GB-es_VE eo-es_VE es-es_VE es_AR-es_VE es_CL-es_VE es_CO-es_VE es_CR-es_VE es_DO-es_VE es_EC-es_VE es_ES-es_VE es_GT-es_VE es_HN-es_VE es_MX-es_VE es_NI-es_VE es_PA-es_VE es_PE-es_VE es_PR-es_VE es_SV-es_VE es_UY-es_VE ace-et af-et ak-et am-et an-et ang-et ar-et ar_SY-et ary-et as-et ast-et az-et ba-et bal-et be-et bem-et ber-et bg-et bho-et bn-et bn_IN-et bo-et br-et brx-et bs-et bua-et byn-et ca-et ce-et ceb-et chr-et ckb-et co-et crh-et cs-et csb-et cv-et cy-et da-et de-et de_AT-et de_DE-et dsb-et dv-et dz-et el-et en-et en_AU-et en_CA-et en_GB-et en_NZ-et en_US-et eo-et es-et es_AR-et es_CL-et es_CO-et es_CR-et es_DO-et es_EC-et es_ES-et es_GT-et es_HN-et es_MX-et es_NI-et es_PA-et es_PE-et es_PR-et es_SV-et es_UY-et es_VE-et ace-eu af-eu ak-eu am-eu an-eu ang-eu ar-eu ar_SY-eu ary-eu as-eu ast-eu az-eu ba-eu bal-eu be-eu bem-eu ber-eu bg-eu bho-eu bn-eu bn_IN-eu bo-eu br-eu brx-eu bs-eu bua-eu byn-eu ca-eu ce-eu ceb-eu chr-eu ckb-eu co-eu crh-eu cs-eu csb-eu cv-eu cy-eu da-eu de-eu de_AT-eu de_DE-eu dsb-eu dv-eu dz-eu el-eu en-eu en_AU-eu en_CA-eu en_GB-eu en_NZ-eu en_US-eu eo-eu es-eu es_AR-eu es_CL-eu es_CO-eu es_CR-eu es_DO-eu es_EC-eu es_ES-eu es_GT-eu es_HN-eu es_MX-eu es_NI-eu es_PA-eu es_PE-eu es_PR-eu es_SV-eu es_UY-eu es_VE-eu et-eu ace-fa af-fa ak-fa am-fa an-fa ang-fa ar-fa ary-fa as-fa ast-fa az-fa ba-fa bal-fa be-fa bem-fa ber-fa bg-fa bho-fa bn-fa bn_IN-fa bo-fa br-fa brx-fa bs-fa bua-fa byn-fa ca-fa ce-fa ceb-fa chr-fa ckb-fa co-fa crh-fa cs-fa csb-fa cv-fa cy-fa da-fa de-fa de_AT-fa de_DE-fa dsb-fa dv-fa dz-fa el-fa en-fa en_AU-fa en_CA-fa en_GB-fa en_NZ-fa en_US-fa eo-fa es-fa es_AR-fa es_CL-fa es_CO-fa es_CR-fa es_DO-fa es_EC-fa es_ES-fa es_GT-fa es_HN-fa es_MX-fa es_NI-fa es_PA-fa es_PE-fa es_PR-fa es_SV-fa es_UY-fa es_VE-fa et-fa eu-fa ace-fa_AF af-fa_AF ak-fa_AF am-fa_AF an-fa_AF ar-fa_AF ary-fa_AF as-fa_AF az-fa_AF be-fa_AF bg-fa_AF bn-fa_AF bo-fa_AF br-fa_AF bs-fa_AF ca-fa_AF ce-fa_AF ceb-fa_AF ckb-fa_AF co-fa_AF crh-fa_AF cs-fa_AF csb-fa_AF cv-fa_AF cy-fa_AF da-fa_AF de-fa_AF de_AT-fa_AF de_DE-fa_AF dsb-fa_AF dv-fa_AF dz-fa_AF el-fa_AF en-fa_AF en_AU-fa_AF en_CA-fa_AF en_GB-fa_AF en_US-fa_AF eo-fa_AF es_ES-fa_AF es_PR-fa_AF et-fa_AF eu-fa_AF fa-fa_AF ace-ff af-ff ak-ff am-ff an-ff ar-ff ary-ff as-ff ast-ff az-ff be-ff bem-ff bg-ff bn-ff bo-ff br-ff brx-ff bs-ff byn-ff ca-ff ce-ff ckb-ff crh-ff cs-ff csb-ff cv-ff cy-ff da-ff de-ff dv-ff dz-ff el-ff en-ff en_AU-ff en_CA-ff en_GB-ff eo-ff es-ff et-ff eu-ff fa-ff ace-fi af-fi ak-fi am-fi an-fi ang-fi ar-fi ar_SY-fi ary-fi as-fi ast-fi az-fi ba-fi bal-fi be-fi bem-fi ber-fi bg-fi bho-fi bn-fi bn_IN-fi bo-fi br-fi brx-fi bs-fi bua-fi byn-fi ca-fi ce-fi ceb-fi chr-fi ckb-fi co-fi crh-fi cs-fi csb-fi cv-fi cy-fi da-fi de-fi de_AT-fi de_DE-fi dsb-fi dv-fi dz-fi el-fi en-fi en_AU-fi en_CA-fi en_GB-fi en_NZ-fi en_US-fi eo-fi es-fi es_AR-fi es_CL-fi es_CO-fi es_CR-fi es_DO-fi es_EC-fi es_ES-fi es_GT-fi es_HN-fi es_MX-fi es_NI-fi es_PA-fi es_PE-fi es_PR-fi es_SV-fi es_UY-fi es_VE-fi et-fi eu-fi fa-fi fa_AF-fi ff-fi ace-fil af-fil ak-fil am-fil an-fil ang-fil ar-fil ary-fil as-fil ast-fil az-fil bal-fil be-fil bem-fil ber-fil bg-fil bn-fil bo-fil br-fil brx-fil bs-fil byn-fil ca-fil ce-fil ceb-fil ckb-fil co-fil crh-fil cs-fil csb-fil cv-fil cy-fil da-fil de-fil de_AT-fil de_DE-fil dsb-fil dv-fil dz-fil el-fil en-fil en_AU-fil en_CA-fil en_GB-fil eo-fil es-fil es_CO-fil es_ES-fil es_PR-fil et-fil eu-fil fa-fil fa_AF-fil ff-fil fi-fil ace-fo af-fo ak-fo am-fo an-fo ang-fo ar-fo ary-fo as-fo ast-fo az-fo ba-fo be-fo bem-fo ber-fo bg-fo bho-fo bn-fo bn_IN-fo bo-fo br-fo brx-fo bs-fo bua-fo byn-fo ca-fo ce-fo ceb-fo chr-fo ckb-fo co-fo crh-fo cs-fo csb-fo cv-fo cy-fo da-fo de-fo de_AT-fo de_DE-fo dsb-fo dv-fo dz-fo el-fo en-fo en_AU-fo en_CA-fo en_GB-fo en_NZ-fo eo-fo es-fo es_CO-fo es_ES-fo es_PR-fo es_UY-fo et-fo eu-fo fa-fo fa_AF-fo ff-fo fi-fo fil-fo ace-fr af-fr ak-fr am-fr an-fr ang-fr ar-fr ar_SY-fr ary-fr as-fr ast-fr az-fr ba-fr bal-fr be-fr bem-fr ber-fr bg-fr bho-fr bn-fr bn_IN-fr bo-fr br-fr brx-fr bs-fr bua-fr byn-fr ca-fr ce-fr ceb-fr chr-fr ckb-fr co-fr crh-fr cs-fr csb-fr cv-fr cy-fr da-fr de-fr de_AT-fr de_DE-fr dsb-fr dv-fr dz-fr el-fr en-fr en_AU-fr en_CA-fr en_GB-fr en_NZ-fr en_US-fr eo-fr es-fr es_AR-fr es_CL-fr es_CO-fr es_CR-fr es_DO-fr es_EC-fr es_ES-fr es_GT-fr es_HN-fr es_MX-fr es_NI-fr es_PA-fr es_PE-fr es_PR-fr es_SV-fr es_UY-fr es_VE-fr et-fr eu-fr fa-fr ff-fr fi-fr fil-fr fo-fr ace-fr_CA af-fr_CA ak-fr_CA am-fr_CA an-fr_CA ar-fr_CA ary-fr_CA as-fr_CA ast-fr_CA az-fr_CA be-fr_CA bem-fr_CA ber-fr_CA bg-fr_CA bn-fr_CA bo-fr_CA br-fr_CA brx-fr_CA bs-fr_CA byn-fr_CA ca-fr_CA ce-fr_CA ceb-fr_CA chr-fr_CA ckb-fr_CA co-fr_CA crh-fr_CA cs-fr_CA csb-fr_CA cv-fr_CA cy-fr_CA da-fr_CA de-fr_CA de_AT-fr_CA de_DE-fr_CA dsb-fr_CA dv-fr_CA dz-fr_CA el-fr_CA en-fr_CA en_AU-fr_CA en_CA-fr_CA en_GB-fr_CA eo-fr_CA es-fr_CA es_CO-fr_CA es_ES-fr_CA es_PR-fr_CA et-fr_CA eu-fr_CA fa-fr_CA fa_AF-fr_CA ff-fr_CA fi-fr_CA fil-fr_CA fo-fr_CA fr-fr_CA ace-fr_FR af-fr_FR ak-fr_FR am-fr_FR an-fr_FR ang-fr_FR ar-fr_FR as-fr_FR ast-fr_FR az-fr_FR be-fr_FR bg-fr_FR bn-fr_FR bo-fr_FR br-fr_FR bs-fr_FR ca-fr_FR ce-fr_FR ckb-fr_FR co-fr_FR crh-fr_FR cs-fr_FR csb-fr_FR cv-fr_FR cy-fr_FR da-fr_FR de-fr_FR de_AT-fr_FR de_DE-fr_FR dsb-fr_FR dv-fr_FR dz-fr_FR el-fr_FR en-fr_FR en_AU-fr_FR en_CA-fr_FR en_GB-fr_FR eo-fr_FR es-fr_FR es_ES-fr_FR es_PR-fr_FR et-fr_FR eu-fr_FR fa-fr_FR fa_AF-fr_FR fi-fr_FR fil-fr_FR fo-fr_FR fr-fr_FR fr_CA-fr_FR ace-frm af-frm ak-frm am-frm an-frm ar-frm as-frm ast-frm az-frm be-frm bg-frm bn-frm bo-frm br-frm bs-frm ca-frm ce-frm ckb-frm co-frm crh-frm cs-frm csb-frm cy-frm da-frm de-frm de_AT-frm de_DE-frm dsb-frm dv-frm dz-frm el-frm en-frm en_AU-frm en_CA-frm en_GB-frm eo-frm es-frm es_ES-frm es_PR-frm et-frm eu-frm fa-frm fa_AF-frm fi-frm fil-frm fo-frm fr-frm fr_CA-frm fr_FR-frm ace-frp af-frp ak-frp am-frp an-frp ang-frp ar-frp ary-frp as-frp ast-frp az-frp ba-frp be-frp bem-frp ber-frp bg-frp bho-frp bn-frp bn_IN-frp bo-frp br-frp brx-frp bs-frp bua-frp byn-frp ca-frp ce-frp ceb-frp ckb-frp co-frp crh-frp cs-frp csb-frp cv-frp cy-frp da-frp de-frp de_AT-frp de_DE-frp dsb-frp dv-frp dz-frp el-frp en-frp en_AU-frp en_CA-frp en_GB-frp en_NZ-frp en_US-frp eo-frp es-frp es_ES-frp es_PR-frp es_UY-frp et-frp eu-frp fa-frp fa_AF-frp ff-frp fi-frp fil-frp fo-frp fr-frp fr_CA-frp fr_FR-frp frm-frp ace-fur af-fur ak-fur am-fur an-fur ar-fur ary-fur as-fur ast-fur az-fur ba-fur be-fur bem-fur ber-fur bg-fur bho-fur bn-fur bn_IN-fur bo-fur br-fur brx-fur bs-fur bua-fur byn-fur ca-fur ce-fur ceb-fur ckb-fur co-fur crh-fur cs-fur csb-fur cv-fur cy-fur da-fur de-fur de_AT-fur de_DE-fur dsb-fur dv-fur dz-fur el-fur en-fur en_AU-fur en_CA-fur en_GB-fur en_NZ-fur en_US-fur eo-fur es-fur es_CO-fur es_ES-fur es_PR-fur es_UY-fur et-fur eu-fur fa-fur fa_AF-fur ff-fur fi-fur fil-fur fo-fur fr-fur fr_CA-fur fr_FR-fur frm-fur frp-fur ace-fy af-fy ak-fy am-fy an-fy ang-fy ar-fy ary-fy as-fy ast-fy az-fy ba-fy bal-fy be-fy bem-fy ber-fy bg-fy bho-fy bn-fy bn_IN-fy bo-fy br-fy brx-fy bs-fy bua-fy byn-fy ca-fy ce-fy ceb-fy chr-fy ckb-fy co-fy crh-fy cs-fy csb-fy cv-fy cy-fy da-fy de-fy de_AT-fy de_DE-fy dsb-fy dv-fy dz-fy el-fy en-fy en_AU-fy en_CA-fy en_GB-fy en_NZ-fy en_US-fy eo-fy es-fy es_AR-fy es_CL-fy es_CO-fy es_CR-fy es_DO-fy es_EC-fy es_ES-fy es_GT-fy es_HN-fy es_MX-fy es_NI-fy es_PA-fy es_PE-fy es_PR-fy es_SV-fy es_UY-fy es_VE-fy et-fy eu-fy fa-fy fa_AF-fy ff-fy fi-fy fil-fy fo-fy fr-fy fr_CA-fy fr_FR-fy frm-fy frp-fy fur-fy ace-ga af-ga ak-ga am-ga an-ga ang-ga ar-ga ar_SY-ga ary-ga as-ga ast-ga az-ga ba-ga bal-ga be-ga bem-ga ber-ga bg-ga bho-ga bn-ga bn_IN-ga bo-ga br-ga brx-ga bs-ga bua-ga byn-ga ca-ga ce-ga ceb-ga chr-ga ckb-ga co-ga crh-ga cs-ga csb-ga cv-ga cy-ga da-ga de-ga de_AT-ga de_DE-ga dsb-ga dv-ga dz-ga el-ga en-ga en_AU-ga en_CA-ga en_GB-ga en_NZ-ga en_US-ga eo-ga es-ga es_AR-ga es_CL-ga es_CO-ga es_CR-ga es_DO-ga es_EC-ga es_ES-ga es_GT-ga es_HN-ga es_MX-ga es_NI-ga es_PA-ga es_PE-ga es_PR-ga es_SV-ga es_UY-ga es_VE-ga et-ga eu-ga fa-ga fa_AF-ga ff-ga fi-ga fil-ga fo-ga fr-ga fr_CA-ga fr_FR-ga frm-ga frp-ga fur-ga fy-ga ace-gd af-gd ak-gd am-gd an-gd ang-gd ar-gd ary-gd as-gd ast-gd az-gd be-gd bem-gd ber-gd bg-gd bn-gd bn_IN-gd bo-gd br-gd brx-gd bs-gd byn-gd ca-gd ce-gd ceb-gd chr-gd ckb-gd co-gd crh-gd cs-gd csb-gd cv-gd cy-gd da-gd de-gd de_AT-gd de_DE-gd dsb-gd dv-gd dz-gd el-gd en-gd en_AU-gd en_CA-gd en_GB-gd en_US-gd eo-gd es-gd es_AR-gd es_CL-gd es_CO-gd es_CR-gd es_DO-gd es_EC-gd es_ES-gd es_GT-gd es_HN-gd es_MX-gd es_NI-gd es_PA-gd es_PE-gd es_PR-gd es_SV-gd es_UY-gd es_VE-gd et-gd eu-gd fa-gd fa_AF-gd ff-gd fi-gd fil-gd fo-gd fr-gd fr_CA-gd fr_FR-gd frm-gd frp-gd fur-gd fy-gd ga-gd ace-gl af-gl ak-gl am-gl an-gl ang-gl ar-gl ar_SY-gl ary-gl as-gl ast-gl az-gl ba-gl bal-gl be-gl bem-gl ber-gl bg-gl bho-gl bn-gl bn_IN-gl bo-gl br-gl brx-gl bs-gl bua-gl byn-gl ca-gl ce-gl ceb-gl chr-gl ckb-gl co-gl crh-gl cs-gl csb-gl cv-gl cy-gl da-gl de-gl de_AT-gl de_DE-gl dsb-gl dv-gl dz-gl el-gl en-gl en_AU-gl en_CA-gl en_GB-gl en_NZ-gl en_US-gl eo-gl es-gl es_AR-gl es_CL-gl es_CO-gl es_CR-gl es_DO-gl es_EC-gl es_ES-gl es_GT-gl es_HN-gl es_MX-gl es_NI-gl es_PA-gl es_PE-gl es_PR-gl es_SV-gl es_UY-gl es_VE-gl et-gl eu-gl fa-gl fa_AF-gl ff-gl fi-gl fil-gl fo-gl fr-gl fr_CA-gl fr_FR-gl frm-gl frp-gl fur-gl fy-gl ga-gl gd-gl ace-gn af-gn ak-gn am-gn an-gn ar-gn ary-gn as-gn ast-gn az-gn be-gn bem-gn bg-gn bn-gn bo-gn br-gn brx-gn bs-gn byn-gn ca-gn ce-gn ckb-gn co-gn crh-gn cs-gn csb-gn cv-gn cy-gn da-gn de-gn de_AT-gn de_DE-gn dsb-gn dv-gn dz-gn el-gn en-gn en_AU-gn en_CA-gn en_GB-gn eo-gn es-gn es_ES-gn es_PR-gn et-gn eu-gn fa-gn fa_AF-gn ff-gn fi-gn fil-gn fo-gn fr-gn fr_CA-gn fr_FR-gn frm-gn frp-gn fur-gn fy-gn ga-gn gd-gn gl-gn ast-grc be-grc bn-grc br-grc bs-grc ca-grc cs-grc da-grc de-grc el-grc en-grc en_AU-grc en_CA-grc en_GB-grc es-grc et-grc fi-grc fr-grc gl-grc ace-gu af-gu ak-gu am-gu an-gu ang-gu ar-gu ary-gu as-gu ast-gu az-gu ba-gu bal-gu be-gu bem-gu ber-gu bg-gu bho-gu bn-gu bn_IN-gu bo-gu br-gu brx-gu bs-gu bua-gu byn-gu ca-gu ce-gu ceb-gu chr-gu ckb-gu co-gu crh-gu cs-gu csb-gu cv-gu cy-gu da-gu de-gu de_AT-gu de_DE-gu dsb-gu dv-gu dz-gu el-gu en-gu en_AU-gu en_CA-gu en_GB-gu en_NZ-gu en_US-gu eo-gu es-gu es_AR-gu es_CL-gu es_CO-gu es_CR-gu es_DO-gu es_EC-gu es_ES-gu es_GT-gu es_HN-gu es_MX-gu es_NI-gu es_PA-gu es_PE-gu es_PR-gu es_SV-gu es_UY-gu es_VE-gu et-gu eu-gu fa-gu fa_AF-gu ff-gu fi-gu fil-gu fo-gu fr-gu fr_CA-gu fr_FR-gu frm-gu frp-gu fur-gu fy-gu ga-gu gd-gu gl-gu gn-gu ace-guc af-guc am-guc an-guc ar-guc as-guc ast-guc az-guc be-guc bem-guc bg-guc bn-guc bo-guc br-guc brx-guc bs-guc byn-guc ca-guc ce-guc ckb-guc crh-guc cs-guc csb-guc cv-guc cy-guc da-guc de-guc dv-guc el-guc en-guc en_AU-guc en_CA-guc en_GB-guc eo-guc es-guc et-guc eu-guc fa-guc ff-guc fi-guc fil-guc fo-guc fr-guc fr_CA-guc frp-guc fur-guc fy-guc ga-guc gd-guc gl-guc gn-guc gu-guc ace-gv af-gv ak-gv am-gv an-gv ar-gv ary-gv as-gv ast-gv az-gv be-gv bem-gv ber-gv bg-gv bho-gv bn-gv bn_IN-gv bo-gv br-gv brx-gv bs-gv byn-gv ca-gv ce-gv ceb-gv ckb-gv co-gv crh-gv cs-gv csb-gv cv-gv cy-gv da-gv de-gv de_AT-gv de_DE-gv dsb-gv dv-gv dz-gv el-gv en-gv en_AU-gv en_CA-gv en_GB-gv eo-gv es-gv es_CO-gv es_ES-gv es_PR-gv es_UY-gv et-gv eu-gv fa-gv fa_AF-gv ff-gv fi-gv fil-gv fo-gv fr-gv fr_CA-gv fr_FR-gv frm-gv frp-gv fur-gv fy-gv ga-gv gd-gv gl-gv gn-gv gu-gv guc-gv ace-ha af-ha ak-ha am-ha an-ha ar-ha as-ha ast-ha az-ha be-ha bg-ha bn-ha bo-ha br-ha bs-ha ca-ha ce-ha ckb-ha co-ha crh-ha cs-ha csb-ha cy-ha da-ha de-ha de_AT-ha de_DE-ha dsb-ha dv-ha dz-ha el-ha en-ha en_AU-ha en_CA-ha en_GB-ha eo-ha es-ha es_ES-ha es_PR-ha et-ha eu-ha fa-ha fa_AF-ha ff-ha fi-ha fil-ha fo-ha fr-ha fr_CA-ha fr_FR-ha frm-ha frp-ha fur-ha fy-ha ga-ha gd-ha gl-ha gn-ha gu-ha gv-ha af-haw an-haw ar-haw as-haw ast-haw az-haw be-haw bg-haw bn-haw bo-haw br-haw bs-haw ca-haw ckb-haw cs-haw cy-haw da-haw de-haw dv-haw dz-haw el-haw en-haw en_AU-haw en_CA-haw en_GB-haw eo-haw es-haw et-haw eu-haw fa-haw fi-haw fil-haw fo-haw fr-haw fy-haw ga-haw gd-haw gl-haw gu-haw ace-he af-he ak-he am-he an-he ang-he ar-he ar_SY-he ary-he as-he ast-he az-he ba-he bal-he be-he bem-he ber-he bg-he bho-he bn-he bn_IN-he bo-he br-he brx-he bs-he bua-he byn-he ca-he ce-he ceb-he chr-he ckb-he co-he crh-he cs-he csb-he cv-he cy-he da-he de-he de_AT-he de_DE-he dsb-he dv-he dz-he el-he en-he en_AU-he en_CA-he en_GB-he en_NZ-he en_US-he eo-he es-he es_AR-he es_CL-he es_CO-he es_CR-he es_DO-he es_EC-he es_ES-he es_GT-he es_HN-he es_MX-he es_NI-he es_PA-he es_PE-he es_PR-he es_SV-he es_UY-he es_VE-he et-he eu-he fa-he fa_AF-he ff-he fi-he fil-he fo-he fr-he fr_CA-he fr_FR-he frm-he frp-he fur-he fy-he ga-he gd-he gl-he gn-he gu-he guc-he gv-he ha-he haw-he ace-hi af-hi ak-hi am-hi an-hi ang-hi ar-hi ary-hi as-hi ast-hi az-hi ba-hi bal-hi be-hi bem-hi ber-hi bg-hi bho-hi bn-hi bn_IN-hi bo-hi br-hi brx-hi bs-hi bua-hi byn-hi ca-hi ce-hi ceb-hi chr-hi ckb-hi co-hi crh-hi cs-hi csb-hi cv-hi cy-hi da-hi de-hi de_AT-hi de_DE-hi dsb-hi dv-hi dz-hi el-hi en-hi en_AU-hi en_CA-hi en_GB-hi en_NZ-hi en_US-hi eo-hi es-hi es_AR-hi es_CL-hi es_CO-hi es_CR-hi es_DO-hi es_EC-hi es_ES-hi es_GT-hi es_HN-hi es_MX-hi es_NI-hi es_PA-hi es_PE-hi es_PR-hi es_SV-hi es_UY-hi es_VE-hi et-hi eu-hi fa-hi fa_AF-hi ff-hi fi-hi fil-hi fo-hi fr-hi fr_CA-hi fr_FR-hi frm-hi frp-hi fur-hi fy-hi ga-hi gd-hi gl-hi gn-hi gu-hi guc-hi gv-hi ha-hi haw-hi he-hi ace-hil af-hil ak-hil am-hil an-hil ar-hil as-hil ast-hil az-hil be-hil bg-hil bho-hil bn-hil bo-hil br-hil bs-hil ca-hil ckb-hil co-hil crh-hil cs-hil csb-hil cv-hil cy-hil da-hil de-hil de_AT-hil de_DE-hil dsb-hil dv-hil dz-hil el-hil en-hil en_AU-hil en_CA-hil en_GB-hil eo-hil es-hil es_ES-hil es_PR-hil es_UY-hil et-hil eu-hil fa-hil fa_AF-hil fi-hil fil-hil fo-hil fr-hil fr_FR-hil frp-hil fur-hil fy-hil ga-hil gd-hil gl-hil gu-hil gv-hil he-hil hi-hil af-hne am-hne an-hne ar-hne ast-hne az-hne be-hne bg-hne bn-hne bo-hne br-hne bs-hne ca-hne ckb-hne cs-hne csb-hne cy-hne da-hne de-hne dv-hne el-hne en-hne en_AU-hne en_CA-hne en_GB-hne eo-hne es-hne et-hne eu-hne fa-hne fa_AF-hne fi-hne fil-hne fr-hne fr_CA-hne fur-hne ga-hne gd-hne gl-hne gu-hne he-hne hi-hne ace-hr af-hr ak-hr am-hr an-hr ang-hr ar-hr ar_SY-hr ary-hr as-hr ast-hr az-hr ba-hr bal-hr be-hr bem-hr ber-hr bg-hr bho-hr bn-hr bn_IN-hr bo-hr br-hr brx-hr bs-hr bua-hr byn-hr ca-hr ce-hr ceb-hr chr-hr ckb-hr co-hr crh-hr cs-hr csb-hr cv-hr cy-hr da-hr de-hr de_AT-hr de_DE-hr dsb-hr dv-hr dz-hr el-hr en-hr en_AU-hr en_CA-hr en_GB-hr en_NZ-hr en_US-hr eo-hr es-hr es_AR-hr es_CL-hr es_CO-hr es_CR-hr es_DO-hr es_EC-hr es_ES-hr es_GT-hr es_HN-hr es_MX-hr es_NI-hr es_PA-hr es_PE-hr es_PR-hr es_SV-hr es_UY-hr es_VE-hr et-hr eu-hr fa-hr fa_AF-hr ff-hr fi-hr fil-hr fo-hr fr-hr fr_CA-hr fr_FR-hr frm-hr frp-hr fur-hr fy-hr ga-hr gd-hr gl-hr gn-hr gu-hr guc-hr gv-hr ha-hr haw-hr he-hr hi-hr hil-hr hne-hr ar-hsb bg-hsb bs-hsb ca-hsb cs-hsb da-hsb de-hsb el-hsb en-hsb en_AU-hsb en_CA-hsb en_GB-hsb es-hsb et-hsb eu-hsb fi-hsb fo-hsb fr-hsb ga-hsb gl-hsb he-hsb ace-ht af-ht ak-ht am-ht an-ht ar-ht ary-ht as-ht ast-ht az-ht bal-ht be-ht bem-ht ber-ht bg-ht bn-ht bo-ht br-ht brx-ht bs-ht byn-ht ca-ht ce-ht chr-ht ckb-ht co-ht crh-ht cs-ht csb-ht cv-ht cy-ht da-ht de-ht de_AT-ht de_DE-ht dsb-ht dv-ht dz-ht el-ht en-ht en_AU-ht en_CA-ht en_GB-ht eo-ht es-ht es_CO-ht es_ES-ht es_PR-ht et-ht eu-ht fa-ht fa_AF-ht ff-ht fi-ht fil-ht fo-ht fr-ht fr_CA-ht fr_FR-ht frm-ht frp-ht fur-ht fy-ht ga-ht gd-ht gl-ht gn-ht gu-ht guc-ht gv-ht ha-ht he-ht hi-ht hil-ht hr-ht ace-hu af-hu ak-hu am-hu an-hu ang-hu ar-hu ar_SY-hu ary-hu as-hu ast-hu az-hu ba-hu bal-hu be-hu bem-hu ber-hu bg-hu bho-hu bn-hu bn_IN-hu bo-hu br-hu brx-hu bs-hu bua-hu byn-hu ca-hu ce-hu ceb-hu chr-hu ckb-hu co-hu crh-hu cs-hu csb-hu cv-hu cy-hu da-hu de-hu de_AT-hu de_DE-hu dsb-hu dv-hu dz-hu el-hu en-hu en_AU-hu en_CA-hu en_GB-hu en_NZ-hu en_US-hu eo-hu es-hu es_AR-hu es_CL-hu es_CO-hu es_CR-hu es_DO-hu es_EC-hu es_ES-hu es_GT-hu es_HN-hu es_MX-hu es_NI-hu es_PA-hu es_PE-hu es_PR-hu es_SV-hu es_UY-hu es_VE-hu et-hu eu-hu fa-hu fa_AF-hu ff-hu fi-hu fil-hu fo-hu fr-hu fr_CA-hu fr_FR-hu frm-hu frp-hu fur-hu fy-hu ga-hu gd-hu gl-hu gn-hu grc-hu gu-hu guc-hu gv-hu ha-hu haw-hu he-hu hi-hu hil-hu hne-hu hr-hu hsb-hu ht-hu ace-hy af-hy ak-hy am-hy an-hy ang-hy ar-hy ary-hy as-hy ast-hy az-hy ba-hy be-hy bem-hy ber-hy bg-hy bho-hy bn-hy bn_IN-hy bo-hy br-hy brx-hy bs-hy bua-hy byn-hy ca-hy ce-hy ceb-hy chr-hy ckb-hy co-hy crh-hy cs-hy csb-hy cv-hy cy-hy da-hy de-hy de_AT-hy de_DE-hy dsb-hy dv-hy dz-hy el-hy en-hy en_AU-hy en_CA-hy en_GB-hy en_NZ-hy en_US-hy eo-hy es-hy es_AR-hy es_CL-hy es_CO-hy es_CR-hy es_DO-hy es_EC-hy es_ES-hy es_GT-hy es_HN-hy es_MX-hy es_NI-hy es_PA-hy es_PE-hy es_PR-hy es_SV-hy es_UY-hy es_VE-hy et-hy eu-hy fa-hy fa_AF-hy ff-hy fi-hy fil-hy fo-hy fr-hy fr_CA-hy fr_FR-hy frm-hy frp-hy fur-hy fy-hy ga-hy gd-hy gl-hy gn-hy gu-hy guc-hy gv-hy ha-hy haw-hy he-hy hi-hy hil-hy hne-hy hr-hy ht-hy hu-hy ace-ia af-ia ak-ia am-ia an-ia ang-ia ar-ia as-ia ast-ia az-ia bal-ia be-ia bg-ia bn-ia bn_IN-ia bo-ia br-ia bs-ia ca-ia ce-ia ceb-ia ckb-ia co-ia crh-ia cs-ia csb-ia cv-ia cy-ia da-ia de-ia de_AT-ia de_DE-ia dsb-ia dv-ia dz-ia el-ia en-ia en_AU-ia en_CA-ia en_GB-ia eo-ia es-ia es_ES-ia es_PR-ia et-ia eu-ia fa-ia fa_AF-ia fi-ia fil-ia fo-ia fr-ia fr_CA-ia fr_FR-ia frm-ia frp-ia fur-ia fy-ia ga-ia gd-ia gl-ia gn-ia gu-ia gv-ia ha-ia he-ia hi-ia hr-ia ht-ia hu-ia hy-ia ace-id af-id ak-id am-id an-id ang-id ar-id ar_SY-id ary-id as-id ast-id az-id ba-id bal-id be-id bem-id ber-id bg-id bho-id bn-id bn_IN-id bo-id br-id brx-id bs-id bua-id byn-id ca-id ce-id ceb-id chr-id ckb-id co-id crh-id cs-id csb-id cv-id cy-id da-id de-id de_AT-id de_DE-id dsb-id dv-id dz-id el-id en-id en_AU-id en_CA-id en_GB-id en_NZ-id en_US-id eo-id es-id es_AR-id es_CL-id es_CO-id es_CR-id es_DO-id es_EC-id es_ES-id es_GT-id es_HN-id es_MX-id es_NI-id es_PA-id es_PE-id es_PR-id es_SV-id es_UY-id es_VE-id et-id eu-id fa-id fa_AF-id ff-id fi-id fil-id fo-id fr-id fr_CA-id fr_FR-id frm-id frp-id fur-id fy-id ga-id gd-id gl-id gn-id grc-id gu-id guc-id gv-id ha-id haw-id he-id hi-id hil-id hne-id hr-id hsb-id ht-id hu-id hy-id ia-id ace-ig af-ig ak-ig am-ig an-ig ar-ig as-ig ast-ig az-ig be-ig bg-ig bn-ig bo-ig br-ig bs-ig ca-ig ce-ig ckb-ig co-ig crh-ig cs-ig csb-ig cv-ig cy-ig da-ig de-ig de_AT-ig de_DE-ig dsb-ig dv-ig dz-ig el-ig en-ig en_AU-ig en_CA-ig en_GB-ig eo-ig es-ig es_ES-ig es_PR-ig et-ig eu-ig fa-ig fa_AF-ig ff-ig fi-ig fil-ig fo-ig fr-ig fr_CA-ig fr_FR-ig frm-ig frp-ig fur-ig fy-ig ga-ig gd-ig gl-ig gn-ig gu-ig gv-ig ha-ig he-ig hi-ig hil-ig hr-ig ht-ig hu-ig hy-ig ia-ig id-ig ace-io af-io ak-io am-io an-io ang-io ar-io as-io az-io be-io bg-io bn-io bo-io br-io bs-io ca-io ce-io ckb-io co-io crh-io cs-io csb-io cy-io da-io de-io de_AT-io de_DE-io dsb-io dv-io dz-io el-io en-io en_AU-io en_CA-io en_GB-io eo-io es-io es_ES-io es_PR-io et-io eu-io fa-io fa_AF-io ff-io fi-io fil-io fo-io fr-io fr_CA-io fr_FR-io frm-io frp-io fur-io fy-io ga-io gd-io gl-io gn-io gu-io gv-io ha-io he-io hi-io hr-io ht-io hu-io hy-io ia-io id-io ig-io ace-is af-is ak-is am-is an-is ang-is ar-is ar_SY-is ary-is as-is ast-is az-is ba-is bal-is be-is bem-is ber-is bg-is bho-is bn-is bn_IN-is bo-is br-is brx-is bs-is bua-is byn-is ca-is ce-is ceb-is chr-is ckb-is co-is crh-is cs-is csb-is cv-is cy-is da-is de-is de_AT-is de_DE-is dsb-is dv-is dz-is el-is en-is en_AU-is en_CA-is en_GB-is en_NZ-is en_US-is eo-is es-is es_AR-is es_CL-is es_CO-is es_CR-is es_DO-is es_EC-is es_ES-is es_GT-is es_HN-is es_MX-is es_NI-is es_PA-is es_PE-is es_PR-is es_SV-is es_UY-is es_VE-is et-is eu-is fa-is fa_AF-is ff-is fi-is fil-is fo-is fr-is fr_CA-is fr_FR-is frm-is frp-is fur-is fy-is ga-is gd-is gl-is gn-is grc-is gu-is guc-is gv-is ha-is haw-is he-is hi-is hil-is hne-is hr-is hsb-is ht-is hu-is hy-is ia-is id-is ig-is io-is ace-it af-it ak-it am-it an-it ang-it ar-it ar_SY-it ary-it as-it ast-it az-it ba-it bal-it be-it bem-it ber-it bg-it bho-it bn-it bn_IN-it bo-it br-it brx-it bs-it bua-it byn-it ca-it ce-it ceb-it chr-it ckb-it co-it crh-it cs-it csb-it cv-it cy-it da-it de-it de_AT-it de_DE-it dsb-it dv-it dz-it el-it en-it en_AU-it en_CA-it en_GB-it en_NZ-it en_US-it eo-it es-it es_AR-it es_CL-it es_CO-it es_CR-it es_DO-it es_EC-it es_ES-it es_GT-it es_HN-it es_MX-it es_NI-it es_PA-it es_PE-it es_PR-it es_SV-it es_UY-it es_VE-it et-it eu-it fa-it fa_AF-it ff-it fi-it fil-it fo-it fr-it fr_CA-it fr_FR-it frm-it frp-it fur-it fy-it ga-it gd-it gl-it gn-it grc-it gu-it guc-it gv-it ha-it haw-it he-it hi-it hil-it hne-it hr-it hsb-it ht-it hu-it hy-it ia-it id-it ig-it io-it is-it ace-iu af-iu am-iu an-iu ar-iu ary-iu as-iu ast-iu az-iu be-iu bem-iu bg-iu bn-iu bo-iu br-iu brx-iu bs-iu byn-iu ca-iu ce-iu ckb-iu crh-iu cs-iu csb-iu cv-iu cy-iu da-iu de-iu dv-iu el-iu en-iu en_AU-iu en_CA-iu en_GB-iu eo-iu es-iu et-iu eu-iu fa-iu ff-iu fi-iu fil-iu fo-iu fr-iu fr_CA-iu frp-iu fur-iu fy-iu ga-iu gd-iu gl-iu gn-iu gu-iu guc-iu gv-iu he-iu hi-iu hr-iu ht-iu hu-iu hy-iu id-iu is-iu it-iu ace-ja af-ja ak-ja am-ja an-ja ang-ja ar-ja ar_SY-ja ary-ja as-ja ast-ja az-ja ba-ja bal-ja be-ja bem-ja ber-ja bg-ja bho-ja bn-ja bn_IN-ja bo-ja br-ja brx-ja bs-ja bua-ja byn-ja ca-ja ce-ja ceb-ja chr-ja ckb-ja co-ja crh-ja cs-ja csb-ja cv-ja cy-ja da-ja de-ja de_AT-ja de_DE-ja dsb-ja dv-ja dz-ja el-ja en-ja en_AU-ja en_CA-ja en_GB-ja en_NZ-ja en_US-ja eo-ja es-ja es_AR-ja es_CL-ja es_CO-ja es_CR-ja es_DO-ja es_EC-ja es_ES-ja es_GT-ja es_HN-ja es_MX-ja es_NI-ja es_PA-ja es_PE-ja es_PR-ja es_SV-ja es_UY-ja es_VE-ja et-ja eu-ja fa-ja fa_AF-ja ff-ja fi-ja fil-ja fo-ja fr-ja fr_CA-ja fr_FR-ja frm-ja frp-ja fur-ja fy-ja ga-ja gd-ja gl-ja gn-ja grc-ja gu-ja guc-ja gv-ja ha-ja haw-ja he-ja hi-ja hil-ja hne-ja hr-ja hsb-ja ht-ja hu-ja hy-ja ia-ja id-ja ig-ja io-ja is-ja it-ja iu-ja ace-jbo af-jbo ak-jbo am-jbo an-jbo ar-jbo ary-jbo as-jbo ast-jbo az-jbo be-jbo bem-jbo ber-jbo bg-jbo bn-jbo bo-jbo br-jbo brx-jbo bs-jbo byn-jbo ca-jbo ce-jbo ceb-jbo ckb-jbo co-jbo crh-jbo cs-jbo csb-jbo cv-jbo cy-jbo da-jbo de-jbo de_AT-jbo de_DE-jbo dsb-jbo dv-jbo dz-jbo el-jbo en-jbo en_AU-jbo en_CA-jbo en_GB-jbo en_US-jbo eo-jbo es-jbo es_CO-jbo es_ES-jbo es_PR-jbo et-jbo eu-jbo fa-jbo fa_AF-jbo ff-jbo fi-jbo fil-jbo fo-jbo fr-jbo fr_CA-jbo fr_FR-jbo frm-jbo frp-jbo fur-jbo fy-jbo ga-jbo gd-jbo gl-jbo gn-jbo gu-jbo guc-jbo gv-jbo ha-jbo he-jbo hi-jbo hr-jbo ht-jbo hu-jbo hy-jbo ia-jbo id-jbo ig-jbo io-jbo is-jbo it-jbo iu-jbo ja-jbo ace-jv af-jv ak-jv am-jv an-jv ang-jv ar-jv ary-jv as-jv ast-jv az-jv ba-jv be-jv bem-jv ber-jv bg-jv bho-jv bn-jv bn_IN-jv bo-jv br-jv brx-jv bs-jv bua-jv byn-jv ca-jv ce-jv ceb-jv chr-jv ckb-jv co-jv crh-jv cs-jv csb-jv cv-jv cy-jv da-jv de-jv de_AT-jv de_DE-jv dsb-jv dv-jv dz-jv el-jv en-jv en_AU-jv en_CA-jv en_GB-jv en_NZ-jv en_US-jv eo-jv es-jv es_CO-jv es_ES-jv es_MX-jv es_PR-jv es_UY-jv et-jv eu-jv fa-jv fa_AF-jv ff-jv fi-jv fil-jv fo-jv fr-jv fr_CA-jv fr_FR-jv frm-jv frp-jv fur-jv fy-jv ga-jv gd-jv gl-jv gn-jv gu-jv guc-jv gv-jv ha-jv haw-jv he-jv hi-jv hil-jv hne-jv hr-jv ht-jv hu-jv hy-jv ia-jv id-jv ig-jv io-jv is-jv it-jv iu-jv ja-jv jbo-jv ace-ka af-ka ak-ka am-ka an-ka ang-ka ar-ka ary-ka as-ka ast-ka az-ka ba-ka bal-ka be-ka bem-ka ber-ka bg-ka bho-ka bn-ka bn_IN-ka bo-ka br-ka brx-ka bs-ka bua-ka byn-ka ca-ka ce-ka ceb-ka chr-ka ckb-ka co-ka crh-ka cs-ka csb-ka cv-ka cy-ka da-ka de-ka de_AT-ka de_DE-ka dsb-ka dv-ka dz-ka el-ka en-ka en_AU-ka en_CA-ka en_GB-ka en_NZ-ka en_US-ka eo-ka es-ka es_AR-ka es_CL-ka es_CO-ka es_CR-ka es_DO-ka es_EC-ka es_ES-ka es_GT-ka es_HN-ka es_MX-ka es_NI-ka es_PA-ka es_PE-ka es_PR-ka es_SV-ka es_UY-ka es_VE-ka et-ka eu-ka fa-ka fa_AF-ka ff-ka fi-ka fil-ka fo-ka fr-ka fr_CA-ka fr_FR-ka frm-ka frp-ka fur-ka fy-ka ga-ka gd-ka gl-ka gn-ka grc-ka gu-ka guc-ka gv-ka ha-ka haw-ka he-ka hi-ka hil-ka hne-ka hr-ka ht-ka hu-ka hy-ka ia-ka id-ka ig-ka io-ka is-ka it-ka iu-ka ja-ka jbo-ka jv-ka ace-kab af-kab ak-kab am-kab an-kab ar-kab as-kab ast-kab az-kab be-kab bem-kab bg-kab bho-kab bn-kab bo-kab br-kab brx-kab bs-kab byn-kab ca-kab ce-kab ckb-kab co-kab crh-kab cs-kab csb-kab cv-kab cy-kab da-kab de-kab de_AT-kab de_DE-kab dsb-kab dv-kab dz-kab el-kab en-kab en_AU-kab en_CA-kab en_GB-kab eo-kab es-kab es_ES-kab es_PR-kab es_UY-kab et-kab eu-kab fa-kab fa_AF-kab ff-kab fi-kab fil-kab fo-kab fr-kab fr_CA-kab fr_FR-kab frm-kab frp-kab fur-kab fy-kab ga-kab gd-kab gl-kab gn-kab gu-kab guc-kab gv-kab ha-kab he-kab hi-kab hil-kab hr-kab ht-kab hu-kab hy-kab ia-kab id-kab ig-kab io-kab is-kab it-kab iu-kab ja-kab jbo-kab jv-kab ka-kab ace-kg af-kg ak-kg am-kg an-kg ar-kg as-kg ast-kg az-kg be-kg bg-kg bn-kg bo-kg br-kg bs-kg ca-kg ce-kg ckb-kg co-kg crh-kg cs-kg csb-kg cy-kg da-kg de-kg de_AT-kg de_DE-kg dsb-kg dv-kg dz-kg el-kg en-kg en_AU-kg en_CA-kg en_GB-kg eo-kg es-kg es_ES-kg es_PR-kg et-kg eu-kg fa-kg fa_AF-kg fi-kg fil-kg fo-kg fr-kg fr_CA-kg fr_FR-kg frm-kg frp-kg fur-kg fy-kg ga-kg gd-kg gl-kg gn-kg gu-kg gv-kg ha-kg he-kg hi-kg hr-kg ht-kg hu-kg hy-kg ia-kg id-kg ig-kg io-kg is-kg it-kg ja-kg jbo-kg jv-kg ka-kg kab-kg ace-kk af-kk ak-kk am-kk an-kk ang-kk ar-kk ar_SY-kk ary-kk as-kk ast-kk az-kk ba-kk bal-kk be-kk bem-kk ber-kk bg-kk bho-kk bn-kk bn_IN-kk bo-kk br-kk brx-kk bs-kk bua-kk byn-kk ca-kk ce-kk ceb-kk chr-kk ckb-kk co-kk crh-kk cs-kk csb-kk cv-kk cy-kk da-kk de-kk de_AT-kk de_DE-kk dsb-kk dv-kk dz-kk el-kk en-kk en_AU-kk en_CA-kk en_GB-kk en_NZ-kk en_US-kk eo-kk es-kk es_AR-kk es_CL-kk es_CO-kk es_CR-kk es_DO-kk es_EC-kk es_ES-kk es_GT-kk es_HN-kk es_MX-kk es_NI-kk es_PA-kk es_PE-kk es_PR-kk es_SV-kk es_UY-kk es_VE-kk et-kk eu-kk fa-kk fa_AF-kk ff-kk fi-kk fil-kk fo-kk fr-kk fr_CA-kk fr_FR-kk frm-kk frp-kk fur-kk fy-kk ga-kk gd-kk gl-kk gn-kk gu-kk guc-kk gv-kk ha-kk haw-kk he-kk hi-kk hil-kk hne-kk hr-kk hsb-kk ht-kk hu-kk hy-kk ia-kk id-kk ig-kk io-kk is-kk it-kk iu-kk ja-kk jbo-kk jv-kk ka-kk kab-kk kg-kk ace-kl af-kl ak-kl am-kl an-kl ar-kl ary-kl as-kl ast-kl az-kl be-kl bem-kl bg-kl bn-kl bn_IN-kl bo-kl br-kl brx-kl bs-kl byn-kl ca-kl ce-kl ckb-kl co-kl crh-kl cs-kl csb-kl cv-kl cy-kl da-kl de-kl de_AT-kl de_DE-kl dsb-kl dv-kl dz-kl el-kl en-kl en_AU-kl en_CA-kl en_GB-kl en_US-kl eo-kl es-kl es_AR-kl es_CL-kl es_CO-kl es_CR-kl es_DO-kl es_EC-kl es_ES-kl es_GT-kl es_HN-kl es_MX-kl es_NI-kl es_PA-kl es_PE-kl es_PR-kl es_SV-kl es_UY-kl es_VE-kl et-kl eu-kl fa-kl fa_AF-kl ff-kl fi-kl fil-kl fo-kl fr-kl fr_CA-kl fr_FR-kl frm-kl frp-kl fur-kl fy-kl ga-kl gd-kl gl-kl gn-kl gu-kl guc-kl gv-kl ha-kl he-kl hi-kl hr-kl ht-kl hu-kl hy-kl ia-kl id-kl ig-kl io-kl is-kl it-kl iu-kl ja-kl jbo-kl jv-kl ka-kl kab-kl kg-kl kk-kl ace-km af-km ak-km am-km an-km ang-km ar-km ary-km as-km ast-km az-km ba-km bal-km be-km bem-km ber-km bg-km bho-km bn-km bn_IN-km bo-km br-km brx-km bs-km bua-km byn-km ca-km ce-km ceb-km chr-km ckb-km co-km crh-km cs-km csb-km cv-km cy-km da-km de-km de_AT-km de_DE-km dsb-km dv-km dz-km el-km en-km en_AU-km en_CA-km en_GB-km en_NZ-km en_US-km eo-km es-km es_AR-km es_CL-km es_CO-km es_CR-km es_DO-km es_EC-km es_ES-km es_GT-km es_HN-km es_MX-km es_NI-km es_PA-km es_PE-km es_PR-km es_SV-km es_UY-km es_VE-km et-km eu-km fa-km fa_AF-km ff-km fi-km fil-km fo-km fr-km fr_CA-km fr_FR-km frm-km frp-km fur-km fy-km ga-km gd-km gl-km gn-km gu-km guc-km gv-km ha-km haw-km he-km hi-km hil-km hne-km hr-km ht-km hu-km hy-km ia-km id-km ig-km io-km is-km it-km iu-km ja-km jbo-km jv-km ka-km kab-km kg-km kk-km kl-km ace-kn af-kn ak-kn am-kn an-kn ang-kn ar-kn ary-kn as-kn ast-kn az-kn ba-kn bal-kn be-kn bem-kn ber-kn bg-kn bho-kn bn-kn bn_IN-kn bo-kn br-kn brx-kn bs-kn bua-kn byn-kn ca-kn ce-kn ceb-kn chr-kn ckb-kn co-kn crh-kn cs-kn csb-kn cv-kn cy-kn da-kn de-kn de_AT-kn de_DE-kn dsb-kn dv-kn dz-kn el-kn en-kn en_AU-kn en_CA-kn en_GB-kn en_NZ-kn en_US-kn eo-kn es-kn es_AR-kn es_CL-kn es_CO-kn es_CR-kn es_DO-kn es_EC-kn es_ES-kn es_GT-kn es_HN-kn es_MX-kn es_NI-kn es_PA-kn es_PE-kn es_PR-kn es_SV-kn es_UY-kn es_VE-kn et-kn eu-kn fa-kn fa_AF-kn ff-kn fi-kn fil-kn fo-kn fr-kn fr_CA-kn fr_FR-kn frm-kn frp-kn fur-kn fy-kn ga-kn gd-kn gl-kn gn-kn gu-kn guc-kn gv-kn ha-kn haw-kn he-kn hi-kn hil-kn hne-kn hr-kn ht-kn hu-kn hy-kn ia-kn id-kn ig-kn io-kn is-kn it-kn iu-kn ja-kn jbo-kn jv-kn ka-kn kab-kn kg-kn kk-kn kl-kn km-kn ace-ko af-ko ak-ko am-ko an-ko ang-ko ar-ko ar_SY-ko ary-ko as-ko ast-ko az-ko ba-ko bal-ko be-ko bem-ko ber-ko bg-ko bho-ko bn-ko bn_IN-ko bo-ko br-ko brx-ko bs-ko bua-ko byn-ko ca-ko ce-ko ceb-ko chr-ko ckb-ko co-ko crh-ko cs-ko csb-ko cv-ko cy-ko da-ko de-ko de_AT-ko de_DE-ko dsb-ko dv-ko dz-ko el-ko en-ko en_AU-ko en_CA-ko en_GB-ko en_NZ-ko en_US-ko eo-ko es-ko es_AR-ko es_CL-ko es_CO-ko es_CR-ko es_DO-ko es_EC-ko es_ES-ko es_GT-ko es_HN-ko es_MX-ko es_NI-ko es_PA-ko es_PE-ko es_PR-ko es_SV-ko es_UY-ko es_VE-ko et-ko eu-ko fa-ko fa_AF-ko ff-ko fi-ko fil-ko fo-ko fr-ko fr_CA-ko fr_FR-ko frm-ko frp-ko fur-ko fy-ko ga-ko gd-ko gl-ko gn-ko grc-ko gu-ko guc-ko gv-ko ha-ko haw-ko he-ko hi-ko hil-ko hne-ko hr-ko hsb-ko ht-ko hu-ko hy-ko ia-ko id-ko ig-ko io-ko is-ko it-ko iu-ko ja-ko jbo-ko jv-ko ka-ko kab-ko kg-ko kk-ko kl-ko km-ko kn-ko ace-kok af-kok ak-kok am-kok an-kok ar-kok as-kok ast-kok az-kok be-kok bg-kok bn-kok bo-kok br-kok bs-kok ca-kok ckb-kok co-kok crh-kok cs-kok csb-kok cv-kok cy-kok da-kok de-kok de_AT-kok de_DE-kok dsb-kok dv-kok dz-kok el-kok en-kok en_AU-kok en_CA-kok en_GB-kok eo-kok es-kok es_ES-kok es_PR-kok et-kok eu-kok fa-kok fa_AF-kok fi-kok fil-kok fo-kok fr-kok fr_FR-kok frp-kok fur-kok fy-kok ga-kok gd-kok gl-kok gu-kok he-kok hi-kok hil-kok hr-kok ht-kok hu-kok hy-kok id-kok ig-kok is-kok it-kok ja-kok jv-kok ka-kok kab-kok kk-kok km-kok kn-kok ko-kok af-ks am-ks an-ks ar-ks as-ks ast-ks az-ks bal-ks be-ks bg-ks bn-ks bo-ks br-ks bs-ks ca-ks ckb-ks crh-ks cs-ks csb-ks cv-ks cy-ks da-ks de-ks dv-ks dz-ks el-ks en-ks en_AU-ks en_CA-ks en_GB-ks eo-ks es-ks et-ks eu-ks fa-ks fi-ks fil-ks fo-ks fr-ks fr_CA-ks frp-ks fur-ks fy-ks ga-ks gd-ks gl-ks gu-ks gv-ks haw-ks he-ks hi-ks hr-ks hu-ks hy-ks ia-ks id-ks is-ks it-ks ja-ks jbo-ks jv-ks ka-ks kk-ks km-ks kn-ks ko-ks ace-ksh af-ksh am-ksh an-ksh ar-ksh as-ksh ast-ksh az-ksh be-ksh ber-ksh bg-ksh bn-ksh bo-ksh br-ksh bs-ksh ca-ksh ckb-ksh crh-ksh cs-ksh cy-ksh da-ksh de-ksh dv-ksh dz-ksh el-ksh en-ksh en_AU-ksh en_CA-ksh en_GB-ksh eo-ksh es-ksh et-ksh eu-ksh fa-ksh ff-ksh fi-ksh fil-ksh fo-ksh fr-ksh fr_CA-ksh frp-ksh fur-ksh fy-ksh ga-ksh gd-ksh gl-ksh gu-ksh gv-ksh ha-ksh he-ksh hi-ksh hr-ksh hu-ksh hy-ksh id-ksh ig-ksh io-ksh is-ksh it-ksh ja-ksh jbo-ksh jv-ksh ka-ksh kk-ksh km-ksh kn-ksh ko-ksh ace-ku af-ku ak-ku am-ku an-ku ang-ku ar-ku ary-ku as-ku ast-ku az-ku ba-ku bal-ku be-ku bem-ku ber-ku bg-ku bho-ku bn-ku bn_IN-ku bo-ku br-ku brx-ku bs-ku bua-ku byn-ku ca-ku ce-ku ceb-ku chr-ku ckb-ku co-ku crh-ku cs-ku csb-ku cv-ku cy-ku da-ku de-ku de_AT-ku de_DE-ku dsb-ku dv-ku dz-ku el-ku en-ku en_AU-ku en_CA-ku en_GB-ku en_NZ-ku en_US-ku eo-ku es-ku es_AR-ku es_CL-ku es_CO-ku es_CR-ku es_DO-ku es_EC-ku es_ES-ku es_GT-ku es_HN-ku es_MX-ku es_NI-ku es_PA-ku es_PE-ku es_PR-ku es_SV-ku es_UY-ku es_VE-ku et-ku eu-ku fa-ku fa_AF-ku ff-ku fi-ku fil-ku fo-ku fr-ku fr_CA-ku fr_FR-ku frm-ku frp-ku fur-ku fy-ku ga-ku gd-ku gl-ku gn-ku grc-ku gu-ku guc-ku gv-ku ha-ku haw-ku he-ku hi-ku hil-ku hne-ku hr-ku ht-ku hu-ku hy-ku ia-ku id-ku ig-ku io-ku is-ku it-ku iu-ku ja-ku jbo-ku jv-ku ka-ku kab-ku kg-ku kk-ku kl-ku km-ku kn-ku ko-ku kok-ku ks-ku ksh-ku ace-kw af-kw ak-kw am-kw an-kw ar-kw ary-kw as-kw ast-kw az-kw be-kw bem-kw ber-kw bg-kw bho-kw bn-kw bn_IN-kw bo-kw br-kw brx-kw bs-kw byn-kw ca-kw ce-kw ceb-kw chr-kw ckb-kw co-kw crh-kw cs-kw csb-kw cv-kw cy-kw da-kw de-kw de_AT-kw de_DE-kw dsb-kw dv-kw dz-kw el-kw en-kw en_AU-kw en_CA-kw en_GB-kw eo-kw es-kw es_CO-kw es_ES-kw es_PR-kw es_UY-kw et-kw eu-kw fa-kw fa_AF-kw ff-kw fi-kw fil-kw fo-kw fr-kw fr_CA-kw fr_FR-kw frm-kw frp-kw fur-kw fy-kw ga-kw gd-kw gl-kw gn-kw gu-kw guc-kw gv-kw ha-kw haw-kw he-kw hi-kw hil-kw hne-kw hr-kw ht-kw hu-kw hy-kw ia-kw id-kw ig-kw io-kw is-kw it-kw iu-kw ja-kw jbo-kw jv-kw ka-kw kab-kw kg-kw kk-kw kl-kw km-kw kn-kw ko-kw kok-kw ks-kw ku-kw ace-ky af-ky ak-ky am-ky an-ky ang-ky ar-ky ar_SY-ky ary-ky as-ky ast-ky az-ky be-ky bem-ky ber-ky bg-ky bho-ky bn-ky bn_IN-ky bo-ky br-ky brx-ky bs-ky byn-ky ca-ky ce-ky ceb-ky chr-ky ckb-ky co-ky crh-ky cs-ky csb-ky cv-ky cy-ky da-ky de-ky de_AT-ky de_DE-ky dsb-ky dv-ky dz-ky el-ky en-ky en_AU-ky en_CA-ky en_GB-ky en_US-ky eo-ky es-ky es_AR-ky es_CL-ky es_CO-ky es_CR-ky es_DO-ky es_EC-ky es_ES-ky es_GT-ky es_HN-ky es_MX-ky es_NI-ky es_PA-ky es_PE-ky es_PR-ky es_SV-ky es_UY-ky es_VE-ky et-ky eu-ky fa-ky fa_AF-ky ff-ky fi-ky fil-ky fo-ky fr-ky fr_CA-ky fr_FR-ky frm-ky frp-ky fur-ky fy-ky ga-ky gd-ky gl-ky gn-ky gu-ky guc-ky gv-ky ha-ky haw-ky he-ky hi-ky hil-ky hne-ky hr-ky ht-ky hu-ky hy-ky ia-ky id-ky ig-ky io-ky is-ky it-ky iu-ky ja-ky jbo-ky jv-ky ka-ky kab-ky kg-ky kk-ky kl-ky km-ky kn-ky ko-ky kok-ky ks-ky ksh-ky ku-ky kw-ky ace-la af-la ak-la am-la an-la ang-la ar-la ary-la as-la ast-la az-la be-la bem-la ber-la bg-la bn-la bo-la br-la brx-la bs-la byn-la ca-la ce-la ceb-la ckb-la co-la crh-la cs-la csb-la cv-la cy-la da-la de-la de_AT-la de_DE-la dsb-la dv-la dz-la el-la en-la en_AU-la en_CA-la en_GB-la eo-la es-la es_CO-la es_ES-la es_PR-la et-la eu-la fa-la fa_AF-la ff-la fi-la fil-la fo-la fr-la fr_CA-la fr_FR-la frm-la frp-la fur-la fy-la ga-la gd-la gl-la gn-la gu-la guc-la gv-la ha-la he-la hi-la hil-la hr-la ht-la hu-la hy-la ia-la id-la ig-la io-la is-la it-la iu-la ja-la jbo-la jv-la ka-la kab-la kg-la kk-la kl-la km-la kn-la ko-la kok-la ks-la ksh-la ku-la kw-la ky-la ace-lb af-lb ak-lb am-lb an-lb ar-lb ary-lb as-lb ast-lb az-lb ba-lb be-lb bem-lb ber-lb bg-lb bho-lb bn-lb bo-lb br-lb brx-lb bs-lb bua-lb byn-lb ca-lb ce-lb ceb-lb ckb-lb co-lb crh-lb cs-lb csb-lb cv-lb cy-lb da-lb de-lb de_AT-lb de_DE-lb dsb-lb dv-lb dz-lb el-lb en-lb en_AU-lb en_CA-lb en_GB-lb en_NZ-lb eo-lb es-lb es_CO-lb es_ES-lb es_PR-lb es_UY-lb et-lb eu-lb fa-lb fa_AF-lb ff-lb fi-lb fil-lb fo-lb fr-lb fr_CA-lb fr_FR-lb frm-lb frp-lb fur-lb fy-lb ga-lb gd-lb gl-lb gn-lb gu-lb guc-lb gv-lb ha-lb haw-lb he-lb hi-lb hil-lb hne-lb hr-lb ht-lb hu-lb hy-lb ia-lb id-lb ig-lb io-lb is-lb it-lb iu-lb ja-lb jbo-lb jv-lb ka-lb kab-lb kg-lb kk-lb kl-lb km-lb kn-lb ko-lb kok-lb ks-lb ksh-lb ku-lb kw-lb ky-lb la-lb ace-lg af-lg ak-lg am-lg an-lg ar-lg as-lg ast-lg az-lg be-lg bg-lg bn-lg bo-lg br-lg bs-lg ca-lg ce-lg ckb-lg co-lg crh-lg cs-lg csb-lg cv-lg cy-lg da-lg de-lg de_AT-lg de_DE-lg dsb-lg dv-lg dz-lg el-lg en-lg en_AU-lg en_CA-lg en_GB-lg eo-lg es-lg es_ES-lg es_PR-lg et-lg eu-lg fa-lg fa_AF-lg ff-lg fi-lg fil-lg fo-lg fr-lg fr_CA-lg fr_FR-lg frm-lg frp-lg fur-lg fy-lg ga-lg gd-lg gl-lg gn-lg gu-lg gv-lg ha-lg he-lg hi-lg hil-lg hr-lg ht-lg hu-lg hy-lg ia-lg id-lg ig-lg io-lg is-lg it-lg ja-lg jbo-lg jv-lg ka-lg kab-lg kg-lg kk-lg kl-lg km-lg kn-lg ko-lg kok-lg ku-lg kw-lg ky-lg la-lg lb-lg ace-li af-li ak-li am-li an-li ang-li ar-li ary-li as-li ast-li az-li be-li bem-li ber-li bg-li bn-li bo-li br-li brx-li bs-li byn-li ca-li ce-li ceb-li ckb-li co-li crh-li cs-li csb-li cv-li cy-li da-li de-li de_AT-li de_DE-li dsb-li dv-li dz-li el-li en-li en_AU-li en_CA-li en_GB-li eo-li es-li es_ES-li es_PR-li et-li eu-li fa-li fa_AF-li ff-li fi-li fil-li fo-li fr-li fr_CA-li fr_FR-li frm-li frp-li fur-li fy-li ga-li gd-li gl-li gn-li gu-li guc-li gv-li ha-li he-li hi-li hil-li hr-li ht-li hu-li hy-li ia-li id-li ig-li io-li is-li it-li iu-li ja-li jbo-li jv-li ka-li kab-li kg-li kk-li kl-li km-li kn-li ko-li kok-li ks-li ksh-li ku-li kw-li ky-li la-li lb-li lg-li af-lij am-lij ar-lij as-lij ast-lij az-lij be-lij bg-lij bn-lij bo-lij br-lij bs-lij ca-lij cs-lij cy-lij da-lij de-lij dz-lij el-lij en-lij en_AU-lij en_CA-lij en_GB-lij eo-lij es-lij et-lij eu-lij fa-lij fi-lij fil-lij fo-lij fr-lij fur-lij fy-lij ga-lij gd-lij gl-lij gu-lij gv-lij he-lij hi-lij hr-lij hu-lij hy-lij id-lij is-lij it-lij ja-lij jbo-lij jv-lij ka-lij kk-lij km-lij kn-lij ko-lij ku-lij ky-lij lb-lij ace-lld af-lld am-lld an-lld ar-lld ary-lld as-lld ast-lld az-lld be-lld bem-lld ber-lld bg-lld bn-lld bo-lld br-lld brx-lld bs-lld byn-lld ca-lld ce-lld ceb-lld ckb-lld crh-lld cs-lld csb-lld cv-lld cy-lld da-lld de-lld dv-lld dz-lld el-lld en-lld en_AU-lld en_CA-lld en_GB-lld eo-lld es-lld et-lld eu-lld fa-lld ff-lld fi-lld fil-lld fo-lld fr-lld fr_CA-lld frp-lld fur-lld fy-lld ga-lld gd-lld gl-lld gn-lld gu-lld guc-lld gv-lld ha-lld he-lld hi-lld hr-lld ht-lld hu-lld hy-lld id-lld ig-lld io-lld is-lld it-lld iu-lld ja-lld jbo-lld jv-lld ka-lld kab-lld kk-lld kl-lld km-lld kn-lld ko-lld ksh-lld ku-lld kw-lld ky-lld la-lld lb-lld li-lld ace-ln af-ln ak-ln am-ln an-ln ar-ln ary-ln as-ln ast-ln az-ln be-ln bem-ln bg-ln bn-ln bo-ln br-ln brx-ln bs-ln byn-ln ca-ln ce-ln ckb-ln co-ln crh-ln cs-ln csb-ln cv-ln cy-ln da-ln de-ln de_AT-ln de_DE-ln dsb-ln dv-ln dz-ln el-ln en-ln en_AU-ln en_CA-ln en_GB-ln eo-ln es-ln es_ES-ln es_PR-ln et-ln eu-ln fa-ln fa_AF-ln ff-ln fi-ln fil-ln fo-ln fr-ln fr_CA-ln fr_FR-ln frm-ln frp-ln fur-ln fy-ln ga-ln gd-ln gl-ln gn-ln gu-ln guc-ln gv-ln ha-ln he-ln hi-ln hil-ln hr-ln ht-ln hu-ln hy-ln ia-ln id-ln ig-ln io-ln is-ln it-ln iu-ln ja-ln jbo-ln jv-ln ka-ln kab-ln kg-ln kk-ln kl-ln km-ln kn-ln ko-ln kok-ln ku-ln kw-ln ky-ln la-ln lb-ln lg-ln li-ln lld-ln ace-lo af-lo ak-lo am-lo an-lo ang-lo ar-lo ary-lo as-lo ast-lo az-lo ba-lo be-lo bem-lo ber-lo bg-lo bn-lo bo-lo br-lo brx-lo bs-lo bua-lo byn-lo ca-lo ce-lo ceb-lo ckb-lo co-lo crh-lo cs-lo csb-lo cv-lo cy-lo da-lo de-lo de_AT-lo de_DE-lo dsb-lo dv-lo dz-lo el-lo en-lo en_AU-lo en_CA-lo en_GB-lo en_NZ-lo en_US-lo eo-lo es-lo es_CO-lo es_ES-lo es_MX-lo es_PR-lo et-lo eu-lo fa-lo fa_AF-lo ff-lo fi-lo fil-lo fo-lo fr-lo fr_CA-lo fr_FR-lo frm-lo frp-lo fur-lo fy-lo ga-lo gd-lo gl-lo gn-lo gu-lo guc-lo gv-lo ha-lo he-lo hi-lo hil-lo hne-lo hr-lo ht-lo hu-lo hy-lo ia-lo id-lo ig-lo io-lo is-lo it-lo iu-lo ja-lo jbo-lo jv-lo ka-lo kab-lo kg-lo kk-lo kl-lo km-lo kn-lo ko-lo kok-lo ks-lo ksh-lo ku-lo kw-lo ky-lo la-lo lb-lo lg-lo li-lo lij-lo lld-lo ln-lo ace-lt af-lt ak-lt am-lt an-lt ang-lt ar-lt ar_SY-lt ary-lt as-lt ast-lt az-lt ba-lt bal-lt be-lt bem-lt ber-lt bg-lt bho-lt bn-lt bn_IN-lt bo-lt br-lt brx-lt bs-lt bua-lt byn-lt ca-lt ce-lt ceb-lt chr-lt ckb-lt co-lt crh-lt cs-lt csb-lt cv-lt cy-lt da-lt de-lt de_AT-lt de_DE-lt dsb-lt dv-lt dz-lt el-lt en-lt en_AU-lt en_CA-lt en_GB-lt en_NZ-lt en_US-lt eo-lt es-lt es_AR-lt es_CL-lt es_CO-lt es_CR-lt es_DO-lt es_EC-lt es_ES-lt es_GT-lt es_HN-lt es_MX-lt es_NI-lt es_PA-lt es_PE-lt es_PR-lt es_SV-lt es_UY-lt es_VE-lt et-lt eu-lt fa-lt fa_AF-lt ff-lt fi-lt fil-lt fo-lt fr-lt fr_CA-lt fr_FR-lt frm-lt frp-lt fur-lt fy-lt ga-lt gd-lt gl-lt gn-lt gu-lt guc-lt gv-lt ha-lt haw-lt he-lt hi-lt hil-lt hne-lt hr-lt hsb-lt ht-lt hu-lt hy-lt ia-lt id-lt ig-lt io-lt is-lt it-lt iu-lt ja-lt jbo-lt jv-lt ka-lt kab-lt kg-lt kk-lt kl-lt km-lt kn-lt ko-lt kok-lt ks-lt ksh-lt ku-lt kw-lt ky-lt la-lt lb-lt lg-lt li-lt lij-lt lld-lt ln-lt lo-lt ace-ltg af-ltg am-ltg an-ltg ar-ltg ary-ltg as-ltg ast-ltg az-ltg be-ltg bem-ltg ber-ltg bg-ltg bn-ltg bn_IN-ltg bo-ltg br-ltg brx-ltg bs-ltg byn-ltg ca-ltg ce-ltg ckb-ltg crh-ltg cs-ltg csb-ltg cv-ltg cy-ltg da-ltg de-ltg dv-ltg dz-ltg el-ltg en-ltg en_AU-ltg en_CA-ltg en_GB-ltg en_US-ltg eo-ltg es-ltg es_CO-ltg et-ltg eu-ltg fa-ltg ff-ltg fi-ltg fil-ltg fo-ltg fr-ltg fr_CA-ltg frp-ltg fur-ltg fy-ltg ga-ltg gd-ltg gl-ltg gn-ltg gu-ltg guc-ltg gv-ltg he-ltg hi-ltg hr-ltg ht-ltg hu-ltg hy-ltg id-ltg is-ltg it-ltg iu-ltg ja-ltg jbo-ltg jv-ltg ka-ltg kab-ltg kk-ltg kl-ltg km-ltg kn-ltg ko-ltg ku-ltg kw-ltg ky-ltg la-ltg lb-ltg li-ltg lld-ltg ln-ltg lo-ltg lt-ltg ace-lv af-lv ak-lv am-lv an-lv ang-lv ar-lv ar_SY-lv ary-lv as-lv ast-lv az-lv ba-lv bal-lv be-lv bem-lv ber-lv bg-lv bho-lv bn-lv bn_IN-lv bo-lv br-lv brx-lv bs-lv bua-lv byn-lv ca-lv ce-lv ceb-lv chr-lv ckb-lv co-lv crh-lv cs-lv csb-lv cv-lv cy-lv da-lv de-lv de_AT-lv de_DE-lv dsb-lv dv-lv dz-lv el-lv en-lv en_AU-lv en_CA-lv en_GB-lv en_NZ-lv en_US-lv eo-lv es-lv es_AR-lv es_CL-lv es_CO-lv es_CR-lv es_DO-lv es_EC-lv es_ES-lv es_GT-lv es_HN-lv es_MX-lv es_NI-lv es_PA-lv es_PE-lv es_PR-lv es_SV-lv es_UY-lv es_VE-lv et-lv eu-lv fa-lv fa_AF-lv ff-lv fi-lv fil-lv fo-lv fr-lv fr_CA-lv fr_FR-lv frm-lv frp-lv fur-lv fy-lv ga-lv gd-lv gl-lv gn-lv gu-lv guc-lv gv-lv ha-lv haw-lv he-lv hi-lv hil-lv hne-lv hr-lv hsb-lv ht-lv hu-lv hy-lv ia-lv id-lv ig-lv io-lv is-lv it-lv iu-lv ja-lv jbo-lv jv-lv ka-lv kab-lv kg-lv kk-lv kl-lv km-lv kn-lv ko-lv kok-lv ks-lv ksh-lv ku-lv kw-lv ky-lv la-lv lb-lv lg-lv li-lv lij-lv lld-lv ln-lv lo-lv lt-lv ltg-lv ace-mai af-mai ak-mai am-mai an-mai ang-mai ar-mai as-mai ast-mai az-mai ba-mai bal-mai be-mai ber-mai bg-mai bho-mai bn-mai bn_IN-mai bo-mai br-mai bs-mai bua-mai ca-mai ce-mai ceb-mai chr-mai ckb-mai co-mai crh-mai cs-mai csb-mai cv-mai cy-mai da-mai de-mai de_AT-mai de_DE-mai dsb-mai dv-mai dz-mai el-mai en-mai en_AU-mai en_CA-mai en_GB-mai en_NZ-mai en_US-mai eo-mai es-mai es_AR-mai es_CL-mai es_CO-mai es_CR-mai es_DO-mai es_EC-mai es_ES-mai es_GT-mai es_HN-mai es_MX-mai es_NI-mai es_PA-mai es_PE-mai es_PR-mai es_SV-mai es_UY-mai es_VE-mai et-mai eu-mai fa-mai fa_AF-mai ff-mai fi-mai fil-mai fo-mai fr-mai fr_CA-mai fr_FR-mai frm-mai frp-mai fur-mai fy-mai ga-mai gd-mai gl-mai gn-mai gu-mai gv-mai ha-mai haw-mai he-mai hi-mai hil-mai hr-mai hsb-mai ht-mai hu-mai hy-mai ia-mai id-mai ig-mai io-mai is-mai it-mai ja-mai jbo-mai jv-mai ka-mai kab-mai kg-mai kk-mai kl-mai km-mai kn-mai ko-mai kok-mai ks-mai ksh-mai ku-mai kw-mai ky-mai la-mai lb-mai lg-mai li-mai lld-mai ln-mai lo-mai lt-mai ltg-mai lv-mai ace-mg af-mg ak-mg am-mg an-mg ang-mg ar-mg ary-mg as-mg ast-mg az-mg bal-mg be-mg bem-mg ber-mg bg-mg bho-mg bn-mg bn_IN-mg bo-mg br-mg brx-mg bs-mg byn-mg ca-mg ce-mg ceb-mg chr-mg ckb-mg co-mg crh-mg cs-mg csb-mg cv-mg cy-mg da-mg de-mg de_AT-mg de_DE-mg dsb-mg dv-mg dz-mg el-mg en-mg en_AU-mg en_CA-mg en_GB-mg en_US-mg eo-mg es-mg es_AR-mg es_CL-mg es_CO-mg es_CR-mg es_DO-mg es_EC-mg es_ES-mg es_GT-mg es_HN-mg es_MX-mg es_NI-mg es_PA-mg es_PE-mg es_PR-mg es_SV-mg es_UY-mg es_VE-mg et-mg eu-mg fa-mg fa_AF-mg ff-mg fi-mg fil-mg fo-mg fr-mg fr_CA-mg fr_FR-mg frm-mg frp-mg fur-mg fy-mg ga-mg gd-mg gl-mg gn-mg gu-mg guc-mg gv-mg ha-mg haw-mg he-mg hi-mg hil-mg hr-mg ht-mg hu-mg hy-mg ia-mg id-mg ig-mg io-mg is-mg it-mg iu-mg ja-mg jbo-mg jv-mg ka-mg kab-mg kg-mg kk-mg kl-mg km-mg kn-mg ko-mg kok-mg ks-mg ksh-mg ku-mg kw-mg ky-mg la-mg lb-mg lg-mg li-mg lld-mg ln-mg lo-mg lt-mg ltg-mg lv-mg mai-mg bg-mh bs-mh ca-mh cs-mh da-mh de-mh el-mh en-mh en_AU-mh en_CA-mh en_GB-mh eo-mh es-mh et-mh eu-mh fi-mh fr-mh fr_CA-mh gl-mh hu-mh id-mh is-mh it-mh ja-mh km-mh ko-mh lb-mh lv-mh ace-mhr af-mhr ak-mhr am-mhr an-mhr ar-mhr ary-mhr as-mhr ast-mhr az-mhr ba-mhr be-mhr bem-mhr ber-mhr bg-mhr bn-mhr bn_IN-mhr bo-mhr br-mhr brx-mhr bs-mhr bua-mhr byn-mhr ca-mhr ce-mhr ceb-mhr ckb-mhr co-mhr crh-mhr cs-mhr csb-mhr cv-mhr cy-mhr da-mhr de-mhr de_AT-mhr de_DE-mhr dsb-mhr dv-mhr dz-mhr el-mhr en-mhr en_AU-mhr en_CA-mhr en_GB-mhr en_NZ-mhr en_US-mhr eo-mhr es-mhr es_AR-mhr es_CL-mhr es_CO-mhr es_CR-mhr es_DO-mhr es_EC-mhr es_ES-mhr es_GT-mhr es_HN-mhr es_MX-mhr es_NI-mhr es_PA-mhr es_PE-mhr es_PR-mhr es_SV-mhr es_UY-mhr es_VE-mhr et-mhr eu-mhr fa-mhr fa_AF-mhr ff-mhr fi-mhr fil-mhr fo-mhr fr-mhr fr_CA-mhr fr_FR-mhr frm-mhr frp-mhr fur-mhr fy-mhr ga-mhr gd-mhr gl-mhr gn-mhr gu-mhr guc-mhr gv-mhr ha-mhr he-mhr hi-mhr hr-mhr ht-mhr hu-mhr hy-mhr ia-mhr id-mhr ig-mhr io-mhr is-mhr it-mhr iu-mhr ja-mhr jbo-mhr jv-mhr ka-mhr kab-mhr kg-mhr kk-mhr kl-mhr km-mhr kn-mhr ko-mhr ks-mhr ksh-mhr ku-mhr kw-mhr ky-mhr la-mhr lb-mhr lg-mhr li-mhr lld-mhr ln-mhr lo-mhr lt-mhr ltg-mhr lv-mhr mai-mhr mg-mhr ace-mi af-mi ak-mi am-mi an-mi ang-mi ar-mi ary-mi as-mi ast-mi az-mi be-mi bem-mi ber-mi bg-mi bn-mi bo-mi br-mi brx-mi bs-mi byn-mi ca-mi ce-mi ceb-mi chr-mi ckb-mi co-mi crh-mi cs-mi csb-mi cv-mi cy-mi da-mi de-mi de_AT-mi de_DE-mi dsb-mi dv-mi dz-mi el-mi en-mi en_AU-mi en_CA-mi en_GB-mi eo-mi es-mi es_CO-mi es_ES-mi es_PR-mi et-mi eu-mi fa-mi fa_AF-mi ff-mi fi-mi fil-mi fo-mi fr-mi fr_CA-mi fr_FR-mi frm-mi frp-mi fur-mi fy-mi ga-mi gd-mi gl-mi gn-mi gu-mi guc-mi gv-mi ha-mi he-mi hi-mi hil-mi hne-mi hr-mi ht-mi hu-mi hy-mi ia-mi id-mi ig-mi io-mi is-mi it-mi iu-mi ja-mi jbo-mi jv-mi ka-mi kab-mi kg-mi kk-mi kl-mi km-mi kn-mi ko-mi kok-mi ks-mi ksh-mi ku-mi kw-mi ky-mi la-mi lb-mi lg-mi li-mi lij-mi lld-mi ln-mi lo-mi lt-mi ltg-mi lv-mi mai-mi mg-mi mhr-mi ace-miq af-miq am-miq an-miq ar-miq ary-miq as-miq ast-miq az-miq be-miq bem-miq ber-miq bg-miq bn-miq bo-miq br-miq brx-miq bs-miq byn-miq ca-miq ce-miq ceb-miq ckb-miq crh-miq cs-miq csb-miq cv-miq cy-miq da-miq de-miq de_DE-miq dsb-miq dv-miq dz-miq el-miq en-miq en_AU-miq en_CA-miq en_GB-miq en_US-miq eo-miq es-miq es_CO-miq es_ES-miq et-miq eu-miq fa-miq fa_AF-miq ff-miq fi-miq fil-miq fo-miq fr-miq fr_CA-miq frp-miq fur-miq fy-miq ga-miq gd-miq gl-miq gn-miq gu-miq guc-miq gv-miq ha-miq he-miq hi-miq hr-miq ht-miq hu-miq hy-miq id-miq ig-miq io-miq is-miq it-miq iu-miq ja-miq jbo-miq jv-miq ka-miq kab-miq kk-miq kl-miq km-miq kn-miq ko-miq ksh-miq ku-miq kw-miq ky-miq la-miq lb-miq li-miq lld-miq ln-miq lo-miq lt-miq ltg-miq lv-miq mai-miq mg-miq mhr-miq mi-miq ace-mk af-mk ak-mk am-mk an-mk ang-mk ar-mk ary-mk as-mk ast-mk az-mk ba-mk bal-mk be-mk bem-mk ber-mk bg-mk bho-mk bn-mk bn_IN-mk bo-mk br-mk brx-mk bs-mk bua-mk byn-mk ca-mk ce-mk ceb-mk chr-mk ckb-mk co-mk crh-mk cs-mk csb-mk cv-mk cy-mk da-mk de-mk de_AT-mk de_DE-mk dsb-mk dv-mk dz-mk el-mk en-mk en_AU-mk en_CA-mk en_GB-mk en_NZ-mk en_US-mk eo-mk es-mk es_AR-mk es_CL-mk es_CO-mk es_CR-mk es_DO-mk es_EC-mk es_ES-mk es_GT-mk es_HN-mk es_MX-mk es_NI-mk es_PA-mk es_PE-mk es_PR-mk es_SV-mk es_UY-mk es_VE-mk et-mk eu-mk fa-mk fa_AF-mk ff-mk fi-mk fil-mk fo-mk fr-mk fr_CA-mk fr_FR-mk frm-mk frp-mk fur-mk fy-mk ga-mk gd-mk gl-mk gn-mk gu-mk guc-mk gv-mk ha-mk haw-mk he-mk hi-mk hil-mk hne-mk hr-mk ht-mk hu-mk hy-mk ia-mk id-mk ig-mk io-mk is-mk it-mk iu-mk ja-mk jbo-mk jv-mk ka-mk kab-mk kg-mk kk-mk kl-mk km-mk kn-mk ko-mk kok-mk ks-mk ksh-mk ku-mk kw-mk ky-mk la-mk lb-mk lg-mk li-mk lij-mk lld-mk ln-mk lo-mk lt-mk ltg-mk lv-mk mai-mk mg-mk mhr-mk mi-mk miq-mk ace-ml af-ml ak-ml am-ml an-ml ang-ml ar-ml ary-ml as-ml ast-ml az-ml ba-ml bal-ml be-ml bem-ml ber-ml bg-ml bho-ml bn-ml bn_IN-ml bo-ml br-ml brx-ml bs-ml bua-ml byn-ml ca-ml ce-ml ceb-ml chr-ml ckb-ml co-ml crh-ml cs-ml csb-ml cv-ml cy-ml da-ml de-ml de_AT-ml de_DE-ml dsb-ml dv-ml dz-ml el-ml en-ml en_AU-ml en_CA-ml en_GB-ml en_NZ-ml en_US-ml eo-ml es-ml es_AR-ml es_CL-ml es_CO-ml es_CR-ml es_DO-ml es_EC-ml es_ES-ml es_GT-ml es_HN-ml es_MX-ml es_NI-ml es_PA-ml es_PE-ml es_PR-ml es_SV-ml es_UY-ml es_VE-ml et-ml eu-ml fa-ml fa_AF-ml ff-ml fi-ml fil-ml fo-ml fr-ml fr_CA-ml fr_FR-ml frm-ml frp-ml fur-ml fy-ml ga-ml gd-ml gl-ml gn-ml gu-ml guc-ml gv-ml ha-ml haw-ml he-ml hi-ml hil-ml hne-ml hr-ml ht-ml hu-ml hy-ml ia-ml id-ml ig-ml io-ml is-ml it-ml iu-ml ja-ml jbo-ml jv-ml ka-ml kab-ml kg-ml kk-ml kl-ml km-ml kn-ml ko-ml kok-ml ks-ml ksh-ml ku-ml kw-ml ky-ml la-ml lb-ml lg-ml li-ml lij-ml lld-ml ln-ml lo-ml lt-ml ltg-ml lv-ml mai-ml mg-ml mhr-ml mi-ml miq-ml mk-ml ace-mn af-mn ak-mn am-mn an-mn ang-mn ar-mn ary-mn as-mn ast-mn az-mn ba-mn bal-mn be-mn bem-mn ber-mn bg-mn bho-mn bn-mn bn_IN-mn bo-mn br-mn brx-mn bs-mn bua-mn byn-mn ca-mn ce-mn ceb-mn chr-mn ckb-mn co-mn crh-mn cs-mn csb-mn cv-mn cy-mn da-mn de-mn de_AT-mn de_DE-mn dsb-mn dv-mn dz-mn el-mn en-mn en_AU-mn en_CA-mn en_GB-mn en_NZ-mn en_US-mn eo-mn es-mn es_AR-mn es_CL-mn es_CO-mn es_CR-mn es_DO-mn es_EC-mn es_ES-mn es_GT-mn es_HN-mn es_MX-mn es_NI-mn es_PA-mn es_PE-mn es_PR-mn es_SV-mn es_UY-mn es_VE-mn et-mn eu-mn fa-mn fa_AF-mn ff-mn fi-mn fil-mn fo-mn fr-mn fr_CA-mn fr_FR-mn frm-mn frp-mn fur-mn fy-mn ga-mn gd-mn gl-mn gn-mn gu-mn guc-mn gv-mn ha-mn haw-mn he-mn hi-mn hil-mn hne-mn hr-mn ht-mn hu-mn hy-mn ia-mn id-mn ig-mn io-mn is-mn it-mn iu-mn ja-mn jbo-mn jv-mn ka-mn kab-mn kg-mn kk-mn kl-mn km-mn kn-mn ko-mn kok-mn ks-mn ksh-mn ku-mn kw-mn ky-mn la-mn lb-mn lg-mn li-mn lij-mn lld-mn ln-mn lo-mn lt-mn ltg-mn lv-mn mai-mn mg-mn mhr-mn mi-mn miq-mn mk-mn ml-mn af-mo am-mo ar-mo as-mo ast-mo az-mo be-mo bg-mo bn-mo bo-mo br-mo bs-mo ca-mo ckb-mo crh-mo cs-mo cv-mo cy-mo da-mo de-mo dz-mo el-mo en_AU-mo en_CA-mo en_GB-mo eo-mo es-mo et-mo eu-mo fa-mo fi-mo fr-mo fr_CA-mo frp-mo fur-mo ga-mo gd-mo gl-mo gu-mo he-mo hi-mo hr-mo hu-mo id-mo is-mo it-mo ja-mo ka-mo kk-mo km-mo kn-mo ko-mo ks-mo ku-mo ky-mo la-mo lt-mo lv-mo mai-mo mg-mo mi-mo mk-mo ml-mo mn-mo ace-mr af-mr ak-mr am-mr an-mr ang-mr ar-mr ary-mr as-mr ast-mr az-mr ba-mr bal-mr be-mr bem-mr ber-mr bg-mr bho-mr bn-mr bn_IN-mr bo-mr br-mr brx-mr bs-mr bua-mr byn-mr ca-mr ce-mr ceb-mr chr-mr ckb-mr co-mr crh-mr cs-mr csb-mr cv-mr cy-mr da-mr de-mr de_AT-mr de_DE-mr dsb-mr dv-mr dz-mr el-mr en-mr en_AU-mr en_CA-mr en_GB-mr en_NZ-mr en_US-mr eo-mr es-mr es_AR-mr es_CL-mr es_CO-mr es_CR-mr es_DO-mr es_EC-mr es_ES-mr es_GT-mr es_HN-mr es_MX-mr es_NI-mr es_PA-mr es_PE-mr es_PR-mr es_SV-mr es_UY-mr es_VE-mr et-mr eu-mr fa-mr fa_AF-mr ff-mr fi-mr fil-mr fo-mr fr-mr fr_CA-mr fr_FR-mr frm-mr frp-mr fur-mr fy-mr ga-mr gd-mr gl-mr gn-mr gu-mr guc-mr gv-mr ha-mr haw-mr he-mr hi-mr hil-mr hne-mr hr-mr ht-mr hu-mr hy-mr ia-mr id-mr ig-mr io-mr is-mr it-mr iu-mr ja-mr jbo-mr jv-mr ka-mr kab-mr kg-mr kk-mr kl-mr km-mr kn-mr ko-mr kok-mr ks-mr ksh-mr ku-mr kw-mr ky-mr la-mr lb-mr lg-mr li-mr lij-mr lld-mr ln-mr lo-mr lt-mr ltg-mr lv-mr mai-mr mg-mr mh-mr mhr-mr mi-mr miq-mr mk-mr ml-mr mn-mr mo-mr ace-ms af-ms ak-ms am-ms an-ms ang-ms ar-ms ar_SY-ms ary-ms as-ms ast-ms az-ms ba-ms bal-ms be-ms bem-ms ber-ms bg-ms bho-ms bn-ms bn_IN-ms bo-ms br-ms brx-ms bs-ms bua-ms byn-ms ca-ms ce-ms ceb-ms chr-ms ckb-ms co-ms crh-ms cs-ms csb-ms cv-ms cy-ms da-ms de-ms de_AT-ms de_DE-ms dsb-ms dv-ms dz-ms el-ms en-ms en_AU-ms en_CA-ms en_GB-ms en_NZ-ms en_US-ms eo-ms es-ms es_AR-ms es_CL-ms es_CO-ms es_CR-ms es_DO-ms es_EC-ms es_ES-ms es_GT-ms es_HN-ms es_MX-ms es_NI-ms es_PA-ms es_PE-ms es_PR-ms es_SV-ms es_UY-ms es_VE-ms et-ms eu-ms fa-ms fa_AF-ms ff-ms fi-ms fil-ms fo-ms fr-ms fr_CA-ms fr_FR-ms frm-ms frp-ms fur-ms fy-ms ga-ms gd-ms gl-ms gn-ms grc-ms gu-ms guc-ms gv-ms ha-ms haw-ms he-ms hi-ms hil-ms hne-ms hr-ms hsb-ms ht-ms hu-ms hy-ms ia-ms id-ms ig-ms io-ms is-ms it-ms iu-ms ja-ms jbo-ms jv-ms ka-ms kab-ms kg-ms kk-ms kl-ms km-ms kn-ms ko-ms kok-ms ks-ms ksh-ms ku-ms kw-ms ky-ms la-ms lb-ms lg-ms li-ms lij-ms lld-ms ln-ms lo-ms lt-ms ltg-ms lv-ms mai-ms mg-ms mh-ms mhr-ms mi-ms miq-ms mk-ms ml-ms mn-ms mo-ms mr-ms ace-mt af-mt ak-mt am-mt an-mt ang-mt ar-mt ary-mt as-mt ast-mt az-mt be-mt bem-mt ber-mt bg-mt bn-mt bo-mt br-mt brx-mt bs-mt byn-mt ca-mt ce-mt ceb-mt ckb-mt co-mt crh-mt cs-mt csb-mt cv-mt cy-mt da-mt de-mt de_AT-mt de_DE-mt dsb-mt dv-mt dz-mt el-mt en-mt en_AU-mt en_CA-mt en_GB-mt eo-mt es-mt es_ES-mt es_PR-mt et-mt eu-mt fa-mt fa_AF-mt ff-mt fi-mt fil-mt fo-mt fr-mt fr_CA-mt fr_FR-mt frm-mt frp-mt fur-mt fy-mt ga-mt gd-mt gl-mt gn-mt gu-mt guc-mt gv-mt ha-mt he-mt hi-mt hil-mt hr-mt ht-mt hu-mt hy-mt ia-mt id-mt ig-mt io-mt is-mt it-mt iu-mt ja-mt jbo-mt jv-mt ka-mt kab-mt kg-mt kk-mt kl-mt km-mt kn-mt ko-mt kok-mt ku-mt kw-mt ky-mt la-mt lb-mt lg-mt li-mt lld-mt ln-mt lo-mt lt-mt ltg-mt lv-mt mai-mt mg-mt mhr-mt mi-mt miq-mt mk-mt ml-mt mn-mt mr-mt ms-mt ace-mus af-mus ak-mus am-mus an-mus ar-mus ary-mus as-mus ast-mus az-mus be-mus bem-mus bg-mus bn-mus bo-mus br-mus brx-mus bs-mus byn-mus ca-mus ce-mus ckb-mus co-mus crh-mus cs-mus csb-mus cv-mus cy-mus da-mus de-mus de_AT-mus de_DE-mus dsb-mus dv-mus dz-mus el-mus en-mus en_AU-mus en_CA-mus en_GB-mus eo-mus es-mus es_ES-mus es_PR-mus et-mus eu-mus fa-mus fa_AF-mus ff-mus fi-mus fil-mus fo-mus fr-mus fr_CA-mus fr_FR-mus frm-mus frp-mus fur-mus fy-mus ga-mus gd-mus gl-mus gn-mus gu-mus guc-mus gv-mus ha-mus he-mus hi-mus hil-mus hr-mus ht-mus hu-mus hy-mus ia-mus id-mus ig-mus io-mus is-mus it-mus iu-mus ja-mus jbo-mus jv-mus ka-mus kab-mus kg-mus kk-mus kl-mus km-mus kn-mus ko-mus kok-mus ku-mus kw-mus ky-mus la-mus lb-mus lg-mus li-mus lld-mus ln-mus lo-mus lt-mus ltg-mus lv-mus mai-mus mg-mus mhr-mus mi-mus miq-mus mk-mus ml-mus mn-mus mr-mus ms-mus mt-mus ace-my af-my ak-my am-my an-my ang-my ar-my ary-my as-my ast-my az-my ba-my bal-my be-my bem-my ber-my bg-my bho-my bn-my bn_IN-my bo-my br-my brx-my bs-my bua-my byn-my ca-my ce-my ceb-my chr-my ckb-my co-my crh-my cs-my csb-my cv-my cy-my da-my de-my de_AT-my de_DE-my dsb-my dv-my dz-my el-my en-my en_AU-my en_CA-my en_GB-my en_NZ-my en_US-my eo-my es-my es_AR-my es_CL-my es_CO-my es_CR-my es_DO-my es_EC-my es_ES-my es_GT-my es_HN-my es_MX-my es_NI-my es_PA-my es_PE-my es_PR-my es_SV-my es_UY-my es_VE-my et-my eu-my fa-my fa_AF-my ff-my fi-my fil-my fo-my fr-my fr_CA-my fr_FR-my frm-my frp-my fur-my fy-my ga-my gd-my gl-my gn-my gu-my guc-my gv-my ha-my haw-my he-my hi-my hil-my hne-my hr-my ht-my hu-my hy-my ia-my id-my ig-my io-my is-my it-my iu-my ja-my jbo-my jv-my ka-my kab-my kg-my kk-my kl-my km-my kn-my ko-my kok-my ks-my ksh-my ku-my kw-my ky-my la-my lb-my lg-my li-my lij-my lld-my ln-my lo-my lt-my ltg-my lv-my mai-my mg-my mh-my mhr-my mi-my miq-my mk-my ml-my mn-my mo-my mr-my ms-my mt-my mus-my ace-nan af-nan ak-nan am-nan an-nan ar-nan ary-nan as-nan ast-nan az-nan be-nan bem-nan ber-nan bg-nan bn-nan bo-nan br-nan brx-nan bs-nan byn-nan ca-nan ce-nan ckb-nan co-nan crh-nan cs-nan csb-nan cv-nan cy-nan da-nan de-nan de_AT-nan de_DE-nan dsb-nan dv-nan dz-nan el-nan en-nan en_AU-nan en_CA-nan en_GB-nan eo-nan es-nan es_ES-nan es_PR-nan et-nan eu-nan fa-nan fa_AF-nan ff-nan fi-nan fil-nan fo-nan fr-nan fr_CA-nan fr_FR-nan frm-nan frp-nan fur-nan fy-nan ga-nan gd-nan gl-nan gn-nan gu-nan guc-nan gv-nan ha-nan he-nan hi-nan hil-nan hr-nan ht-nan hu-nan hy-nan ia-nan id-nan ig-nan io-nan is-nan it-nan iu-nan ja-nan jbo-nan jv-nan ka-nan kab-nan kg-nan kk-nan kl-nan km-nan kn-nan ko-nan kok-nan ksh-nan ku-nan kw-nan ky-nan la-nan lb-nan lg-nan li-nan lld-nan ln-nan lo-nan lt-nan ltg-nan lv-nan mai-nan mg-nan mhr-nan mi-nan miq-nan mk-nan ml-nan mn-nan mr-nan ms-nan mt-nan mus-nan my-nan ace-nap af-nap ak-nap am-nap an-nap ar-nap as-nap ast-nap az-nap be-nap bg-nap bn-nap bo-nap br-nap bs-nap ca-nap ceb-nap ckb-nap co-nap crh-nap cs-nap csb-nap cv-nap cy-nap da-nap de-nap de_AT-nap de_DE-nap dsb-nap dv-nap dz-nap el-nap en-nap en_AU-nap en_CA-nap en_GB-nap eo-nap es-nap es_ES-nap es_PR-nap et-nap eu-nap fa-nap fa_AF-nap fi-nap fil-nap fo-nap fr-nap fr_CA-nap fr_FR-nap frp-nap fur-nap fy-nap ga-nap gd-nap gl-nap gu-nap he-nap hi-nap hil-nap hr-nap ht-nap hu-nap hy-nap ia-nap id-nap ig-nap is-nap it-nap ja-nap jv-nap ka-nap kab-nap kk-nap km-nap kn-nap ko-nap kok-nap ku-nap kw-nap ky-nap la-nap lb-nap lg-nap li-nap ln-nap lo-nap lt-nap lv-nap mai-nap mg-nap mi-nap mk-nap ml-nap mn-nap mr-nap ms-nap mt-nap mus-nap my-nap nan-nap ace-nb af-nb ak-nb am-nb an-nb ang-nb ar-nb ar_SY-nb ary-nb as-nb ast-nb az-nb ba-nb bal-nb be-nb bem-nb ber-nb bg-nb bho-nb bn-nb bn_IN-nb bo-nb br-nb brx-nb bs-nb bua-nb byn-nb ca-nb ce-nb ceb-nb chr-nb ckb-nb co-nb crh-nb cs-nb csb-nb cv-nb cy-nb da-nb de-nb de_AT-nb de_DE-nb dsb-nb dv-nb dz-nb el-nb en-nb en_AU-nb en_CA-nb en_GB-nb en_NZ-nb en_US-nb eo-nb es-nb es_AR-nb es_CL-nb es_CO-nb es_CR-nb es_DO-nb es_EC-nb es_ES-nb es_GT-nb es_HN-nb es_MX-nb es_NI-nb es_PA-nb es_PE-nb es_PR-nb es_SV-nb es_UY-nb es_VE-nb et-nb eu-nb fa-nb fa_AF-nb ff-nb fi-nb fil-nb fo-nb fr-nb fr_CA-nb fr_FR-nb frm-nb frp-nb fur-nb fy-nb ga-nb gd-nb gl-nb gn-nb grc-nb gu-nb guc-nb gv-nb ha-nb haw-nb he-nb hi-nb hil-nb hne-nb hr-nb hsb-nb ht-nb hu-nb hy-nb ia-nb id-nb ig-nb io-nb is-nb it-nb iu-nb ja-nb jbo-nb jv-nb ka-nb kab-nb kg-nb kk-nb kl-nb km-nb kn-nb ko-nb kok-nb ks-nb ksh-nb ku-nb kw-nb ky-nb la-nb lb-nb lg-nb li-nb lij-nb lld-nb ln-nb lo-nb lt-nb ltg-nb lv-nb mai-nb mg-nb mh-nb mhr-nb mi-nb miq-nb mk-nb ml-nb mn-nb mo-nb mr-nb ms-nb mt-nb mus-nb my-nb nan-nb nap-nb ace-nds af-nds ak-nds am-nds an-nds ang-nds ar-nds ary-nds as-nds ast-nds az-nds ba-nds bal-nds be-nds bem-nds ber-nds bg-nds bho-nds bn-nds bn_IN-nds bo-nds br-nds brx-nds bs-nds bua-nds byn-nds ca-nds ce-nds ceb-nds ckb-nds co-nds crh-nds cs-nds csb-nds cv-nds cy-nds da-nds de-nds de_AT-nds de_DE-nds dsb-nds dv-nds dz-nds el-nds en-nds en_AU-nds en_CA-nds en_GB-nds en_NZ-nds en_US-nds eo-nds es-nds es_AR-nds es_CL-nds es_CO-nds es_CR-nds es_DO-nds es_EC-nds es_ES-nds es_GT-nds es_HN-nds es_MX-nds es_NI-nds es_PA-nds es_PE-nds es_PR-nds es_SV-nds es_UY-nds es_VE-nds et-nds eu-nds fa-nds fa_AF-nds ff-nds fi-nds fil-nds fo-nds fr-nds fr_CA-nds fr_FR-nds frm-nds frp-nds fur-nds fy-nds ga-nds gd-nds gl-nds gn-nds grc-nds gu-nds guc-nds gv-nds ha-nds haw-nds he-nds hi-nds hil-nds hne-nds hr-nds hsb-nds ht-nds hu-nds hy-nds ia-nds id-nds ig-nds io-nds is-nds it-nds iu-nds ja-nds jbo-nds jv-nds ka-nds kab-nds kg-nds kk-nds kl-nds km-nds kn-nds ko-nds kok-nds ks-nds ksh-nds ku-nds kw-nds ky-nds la-nds lb-nds lg-nds li-nds lij-nds lld-nds ln-nds lo-nds lt-nds ltg-nds lv-nds mai-nds mg-nds mhr-nds mi-nds miq-nds mk-nds ml-nds mn-nds mo-nds mr-nds ms-nds mt-nds mus-nds my-nds nan-nds nap-nds nb-nds ace-ne af-ne ak-ne am-ne an-ne ang-ne ar-ne ary-ne as-ne ast-ne az-ne ba-ne bal-ne be-ne bem-ne ber-ne bg-ne bho-ne bn-ne bn_IN-ne bo-ne br-ne brx-ne bs-ne bua-ne byn-ne ca-ne ce-ne ceb-ne chr-ne ckb-ne co-ne crh-ne cs-ne csb-ne cv-ne cy-ne da-ne de-ne de_AT-ne de_DE-ne dsb-ne dv-ne dz-ne el-ne en-ne en_AU-ne en_CA-ne en_GB-ne en_NZ-ne en_US-ne eo-ne es-ne es_AR-ne es_CL-ne es_CO-ne es_CR-ne es_DO-ne es_EC-ne es_ES-ne es_GT-ne es_HN-ne es_MX-ne es_NI-ne es_PA-ne es_PE-ne es_PR-ne es_SV-ne es_UY-ne es_VE-ne et-ne eu-ne fa-ne fa_AF-ne ff-ne fi-ne fil-ne fo-ne fr-ne fr_CA-ne fr_FR-ne frm-ne frp-ne fur-ne fy-ne ga-ne gd-ne gl-ne gn-ne gu-ne guc-ne gv-ne ha-ne haw-ne he-ne hi-ne hil-ne hne-ne hr-ne ht-ne hu-ne hy-ne ia-ne id-ne ig-ne io-ne is-ne it-ne iu-ne ja-ne jbo-ne jv-ne ka-ne kab-ne kg-ne kk-ne kl-ne km-ne kn-ne ko-ne kok-ne ks-ne ksh-ne ku-ne kw-ne ky-ne la-ne lb-ne lg-ne li-ne lij-ne lld-ne ln-ne lo-ne lt-ne ltg-ne lv-ne mai-ne mg-ne mhr-ne mi-ne miq-ne mk-ne ml-ne mn-ne mo-ne mr-ne ms-ne mt-ne mus-ne my-ne nan-ne nap-ne nb-ne nds-ne ace-nhn af-nhn an-nhn ar-nhn as-nhn ast-nhn az-nhn be-nhn bg-nhn bn-nhn br-nhn bs-nhn ca-nhn ckb-nhn crh-nhn cs-nhn csb-nhn cv-nhn cy-nhn da-nhn de-nhn dv-nhn dz-nhn el-nhn en-nhn en_AU-nhn en_CA-nhn en_GB-nhn eo-nhn es-nhn et-nhn eu-nhn fa-nhn fi-nhn fil-nhn fo-nhn fr-nhn fr_CA-nhn fur-nhn fy-nhn ga-nhn gd-nhn gl-nhn gu-nhn gv-nhn he-nhn hi-nhn hr-nhn ht-nhn hu-nhn id-nhn is-nhn it-nhn ja-nhn jv-nhn ka-nhn kk-nhn kl-nhn km-nhn kn-nhn ko-nhn ku-nhn ky-nhn lb-nhn lld-nhn lt-nhn lv-nhn mai-nhn mg-nhn mi-nhn mk-nhn ml-nhn mn-nhn mr-nhn ms-nhn my-nhn nb-nhn nds-nhn ne-nhn ace-nl af-nl ak-nl am-nl an-nl ang-nl ar-nl ar_SY-nl ary-nl as-nl ast-nl az-nl ba-nl bal-nl be-nl bem-nl ber-nl bg-nl bho-nl bn-nl bn_IN-nl bo-nl br-nl brx-nl bs-nl bua-nl byn-nl ca-nl ce-nl ceb-nl chr-nl ckb-nl co-nl crh-nl cs-nl csb-nl cv-nl cy-nl da-nl de-nl de_AT-nl de_DE-nl dsb-nl dv-nl dz-nl el-nl en-nl en_AU-nl en_CA-nl en_GB-nl en_NZ-nl en_US-nl eo-nl es-nl es_AR-nl es_CL-nl es_CO-nl es_CR-nl es_DO-nl es_EC-nl es_ES-nl es_GT-nl es_HN-nl es_MX-nl es_NI-nl es_PA-nl es_PE-nl es_PR-nl es_SV-nl es_UY-nl es_VE-nl et-nl eu-nl fa-nl fa_AF-nl ff-nl fi-nl fil-nl fo-nl fr-nl fr_CA-nl fr_FR-nl frm-nl frp-nl fur-nl fy-nl ga-nl gd-nl gl-nl gn-nl grc-nl gu-nl guc-nl gv-nl ha-nl haw-nl he-nl hi-nl hil-nl hne-nl hr-nl hsb-nl ht-nl hu-nl hy-nl ia-nl id-nl ig-nl io-nl is-nl it-nl iu-nl ja-nl jbo-nl jv-nl ka-nl kab-nl kg-nl kk-nl kl-nl km-nl kn-nl ko-nl kok-nl ks-nl ksh-nl ku-nl kw-nl ky-nl la-nl lb-nl lg-nl li-nl lij-nl lld-nl ln-nl lo-nl lt-nl ltg-nl lv-nl mai-nl mg-nl mh-nl mhr-nl mi-nl miq-nl mk-nl ml-nl mn-nl mo-nl mr-nl ms-nl mt-nl mus-nl my-nl nan-nl nap-nl nb-nl nds-nl ne-nl nhn-nl ar-nl_NL ast-nl_NL be-nl_NL bg-nl_NL bn-nl_NL bs-nl_NL cs-nl_NL da-nl_NL de-nl_NL el-nl_NL en-nl_NL en_AU-nl_NL en_CA-nl_NL en_GB-nl_NL eo-nl_NL es-nl_NL eu-nl_NL fa-nl_NL fi-nl_NL fr-nl_NL gl-nl_NL he-nl_NL id-nl_NL is-nl_NL it-nl_NL ja-nl_NL kn-nl_NL ko-nl_NL ku-nl_NL ms-nl_NL my-nl_NL nb-nl_NL nl-nl_NL ace-nn af-nn ak-nn am-nn an-nn ang-nn ar-nn ar_SY-nn ary-nn as-nn ast-nn az-nn ba-nn bal-nn be-nn bem-nn ber-nn bg-nn bho-nn bn-nn bn_IN-nn bo-nn br-nn brx-nn bs-nn bua-nn byn-nn ca-nn ce-nn ceb-nn chr-nn ckb-nn co-nn crh-nn cs-nn csb-nn cv-nn cy-nn da-nn de-nn de_AT-nn de_DE-nn dsb-nn dv-nn dz-nn el-nn en-nn en_AU-nn en_CA-nn en_GB-nn en_NZ-nn en_US-nn eo-nn es-nn es_AR-nn es_CL-nn es_CO-nn es_CR-nn es_DO-nn es_EC-nn es_ES-nn es_GT-nn es_HN-nn es_MX-nn es_NI-nn es_PA-nn es_PE-nn es_PR-nn es_SV-nn es_UY-nn es_VE-nn et-nn eu-nn fa-nn fa_AF-nn ff-nn fi-nn fil-nn fo-nn fr-nn fr_CA-nn fr_FR-nn frm-nn frp-nn fur-nn fy-nn ga-nn gd-nn gl-nn gn-nn grc-nn gu-nn guc-nn gv-nn ha-nn haw-nn he-nn hi-nn hil-nn hne-nn hr-nn hsb-nn ht-nn hu-nn hy-nn ia-nn id-nn ig-nn io-nn is-nn it-nn iu-nn ja-nn jbo-nn jv-nn ka-nn kab-nn kg-nn kk-nn kl-nn km-nn kn-nn ko-nn kok-nn ks-nn ksh-nn ku-nn kw-nn ky-nn la-nn lb-nn lg-nn li-nn lij-nn lld-nn ln-nn lo-nn lt-nn ltg-nn lv-nn mai-nn mg-nn mhr-nn mi-nn miq-nn mk-nn ml-nn mn-nn mo-nn mr-nn ms-nn mt-nn mus-nn my-nn nan-nn nap-nn nb-nn nds-nn ne-nn nhn-nn nl-nn ace-no af-no ak-no am-no an-no ang-no ar-no ar_SY-no as-no ast-no az-no be-no ber-no bg-no bho-no bn-no bo-no br-no bs-no ca-no ce-no ceb-no chr-no ckb-no co-no crh-no cs-no csb-no cv-no cy-no da-no de-no de_AT-no de_DE-no dsb-no dv-no dz-no el-no en-no en_AU-no en_CA-no en_GB-no en_US-no eo-no es-no es_ES-no es_PR-no es_UY-no et-no eu-no fa-no fa_AF-no ff-no fi-no fil-no fo-no fr-no fr_CA-no fr_FR-no frm-no frp-no fur-no fy-no ga-no gd-no gl-no gn-no gu-no gv-no ha-no haw-no he-no hi-no hil-no hr-no ht-no hu-no hy-no ia-no id-no ig-no io-no is-no it-no ja-no jbo-no jv-no ka-no kab-no kg-no kk-no kl-no km-no kn-no ko-no kok-no ks-no ksh-no ku-no kw-no ky-no la-no lb-no lg-no li-no lij-no lld-no ln-no lo-no lt-no lv-no mai-no mg-no mhr-no mi-no miq-no mk-no ml-no mn-no mo-no mr-no ms-no mt-no mus-no my-no nan-no nap-no nb-no nds-no ne-no nl-no nn-no ace-nso af-nso ak-nso am-nso an-nso ang-nso ar-nso ary-nso as-nso ast-nso az-nso ba-nso be-nso bem-nso bg-nso bn-nso bo-nso br-nso brx-nso bs-nso bua-nso byn-nso ca-nso ce-nso ckb-nso co-nso crh-nso cs-nso csb-nso cv-nso cy-nso da-nso de-nso de_AT-nso de_DE-nso dsb-nso dv-nso dz-nso el-nso en-nso en_AU-nso en_CA-nso en_GB-nso en_NZ-nso eo-nso es-nso es_ES-nso es_PR-nso et-nso eu-nso fa-nso fa_AF-nso ff-nso fi-nso fil-nso fo-nso fr-nso fr_CA-nso fr_FR-nso frm-nso frp-nso fur-nso fy-nso ga-nso gd-nso gl-nso gn-nso gu-nso guc-nso gv-nso ha-nso he-nso hi-nso hil-nso hr-nso ht-nso hu-nso hy-nso ia-nso id-nso ig-nso io-nso is-nso it-nso iu-nso ja-nso jbo-nso jv-nso ka-nso kab-nso kg-nso kk-nso kl-nso km-nso kn-nso ko-nso kok-nso ks-nso ksh-nso ku-nso kw-nso ky-nso la-nso lb-nso lg-nso li-nso lld-nso ln-nso lo-nso lt-nso ltg-nso lv-nso mai-nso mg-nso mhr-nso mi-nso miq-nso mk-nso ml-nso mn-nso mo-nso mr-nso ms-nso mt-nso mus-nso my-nso nan-nso nap-nso nb-nso nds-nso ne-nso nl-nso nn-nso no-nso ace-ny af-ny am-ny an-ny ar-ny ast-ny az-ny be-ny bg-ny bn-ny bo-ny br-ny bs-ny ca-ny crh-ny cs-ny csb-ny cv-ny cy-ny da-ny de-ny dv-ny el-ny en-ny en_AU-ny en_CA-ny en_GB-ny eo-ny es-ny et-ny eu-ny fa-ny fi-ny fil-ny fo-ny fr-ny fr_CA-ny fur-ny fy-ny gd-ny gl-ny gu-ny gv-ny he-ny hi-ny hr-ny hu-ny hy-ny id-ny is-ny it-ny ja-ny jbo-ny ka-ny kk-ny km-ny kn-ny ko-ny ku-ny kw-ny ky-ny lb-ny lt-ny lv-ny mg-ny mhr-ny mi-ny mk-ny ml-ny mr-ny ms-ny my-ny nb-ny ne-ny nl-ny nn-ny ace-oc af-oc ak-oc am-oc an-oc ang-oc ar-oc ar_SY-oc ary-oc as-oc ast-oc az-oc ba-oc bal-oc be-oc bem-oc ber-oc bg-oc bho-oc bn-oc bn_IN-oc bo-oc br-oc brx-oc bs-oc bua-oc byn-oc ca-oc ce-oc ceb-oc chr-oc ckb-oc co-oc crh-oc cs-oc csb-oc cv-oc cy-oc da-oc de-oc de_AT-oc de_DE-oc dsb-oc dv-oc dz-oc el-oc en-oc en_AU-oc en_CA-oc en_GB-oc en_NZ-oc en_US-oc eo-oc es-oc es_AR-oc es_CL-oc es_CO-oc es_CR-oc es_DO-oc es_EC-oc es_ES-oc es_GT-oc es_HN-oc es_MX-oc es_NI-oc es_PA-oc es_PE-oc es_PR-oc es_SV-oc es_UY-oc es_VE-oc et-oc eu-oc fa-oc ff-oc fi-oc fil-oc fo-oc fr-oc fr_CA-oc fr_FR-oc frm-oc frp-oc fur-oc fy-oc ga-oc gd-oc gl-oc gn-oc grc-oc gu-oc guc-oc gv-oc ha-oc haw-oc he-oc hi-oc hil-oc hne-oc hr-oc hsb-oc ht-oc hu-oc hy-oc ia-oc id-oc ig-oc io-oc is-oc it-oc iu-oc ja-oc jbo-oc jv-oc ka-oc kab-oc kg-oc kk-oc kl-oc km-oc kn-oc ko-oc kok-oc ks-oc ksh-oc ku-oc kw-oc ky-oc la-oc lb-oc lg-oc li-oc lij-oc lld-oc ln-oc lo-oc lt-oc ltg-oc lv-oc mai-oc mg-oc mh-oc mhr-oc mi-oc miq-oc mk-oc ml-oc mn-oc mo-oc mr-oc ms-oc mt-oc mus-oc my-oc nan-oc nap-oc nb-oc nds-oc ne-oc nhn-oc nl-oc nl_NL-oc nn-oc no-oc nso-oc ny-oc af-oj ar-oj as-oj ast-oj bal-oj be-oj bg-oj bn-oj br-oj bs-oj ca-oj crh-oj cs-oj csb-oj cv-oj cy-oj da-oj de-oj dv-oj el-oj en-oj en_AU-oj en_CA-oj en_GB-oj eo-oj es-oj et-oj eu-oj fa-oj fi-oj fr-oj ga-oj gl-oj gu-oj he-oj hi-oj hr-oj hu-oj ia-oj id-oj is-oj it-oj ja-oj ka-oj kk-oj km-oj kn-oj ko-oj ks-oj ku-oj lt-oj lv-oj mai-oj ml-oj mn-oj mr-oj ms-oj my-oj nb-oj nds-oj nl-oj nn-oj oc-oj ace-om af-om ak-om am-om an-om ar-om ary-om as-om ast-om az-om be-om bem-om ber-om bg-om bn-om bo-om br-om brx-om bs-om byn-om ca-om ce-om chr-om ckb-om co-om crh-om cs-om csb-om cv-om cy-om da-om de-om de_AT-om de_DE-om dsb-om dv-om dz-om el-om en-om en_AU-om en_CA-om en_GB-om en_US-om eo-om es-om es_ES-om es_PR-om et-om eu-om fa-om fa_AF-om ff-om fi-om fil-om fo-om fr-om fr_CA-om fr_FR-om frm-om frp-om fur-om fy-om ga-om gd-om gl-om gn-om gu-om guc-om gv-om ha-om he-om hi-om hil-om hr-om ht-om hu-om hy-om ia-om id-om ig-om io-om is-om it-om iu-om ja-om jbo-om jv-om ka-om kab-om kg-om kk-om kl-om km-om kn-om ko-om kok-om ksh-om ku-om kw-om ky-om la-om lb-om lg-om li-om lld-om ln-om lo-om lt-om ltg-om lv-om mai-om mg-om mhr-om mi-om miq-om mk-om ml-om mn-om mr-om ms-om mt-om mus-om my-om nan-om nap-om nb-om nds-om ne-om nl-om nn-om no-om nso-om oc-om ace-or af-or ak-or am-or an-or ang-or ar-or ary-or as-or ast-or az-or ba-or bal-or be-or bem-or ber-or bg-or bho-or bn-or bn_IN-or bo-or br-or brx-or bs-or bua-or byn-or ca-or ce-or ceb-or chr-or ckb-or co-or crh-or cs-or csb-or cv-or cy-or da-or de-or de_AT-or de_DE-or dsb-or dv-or dz-or el-or en-or en_AU-or en_CA-or en_GB-or en_NZ-or en_US-or eo-or es-or es_AR-or es_CL-or es_CO-or es_CR-or es_DO-or es_EC-or es_ES-or es_GT-or es_HN-or es_MX-or es_NI-or es_PA-or es_PE-or es_PR-or es_SV-or es_UY-or es_VE-or et-or eu-or fa-or fa_AF-or ff-or fi-or fil-or fo-or fr-or fr_CA-or fr_FR-or frm-or frp-or fur-or fy-or ga-or gd-or gl-or gn-or gu-or guc-or gv-or ha-or haw-or he-or hi-or hil-or hr-or ht-or hu-or hy-or ia-or id-or ig-or io-or is-or it-or iu-or ja-or jbo-or jv-or ka-or kab-or kg-or kk-or kl-or km-or kn-or ko-or kok-or ks-or ksh-or ku-or kw-or ky-or la-or lb-or lg-or li-or lij-or lld-or ln-or lo-or lt-or ltg-or lv-or mai-or mg-or mhr-or mi-or miq-or mk-or ml-or mn-or mo-or mr-or ms-or mt-or mus-or my-or nan-or nap-or nb-or nds-or ne-or nhn-or nl-or nn-or no-or nso-or oc-or oj-or om-or ace-os af-os am-os an-os ar-os ary-os as-os ast-os az-os be-os bem-os ber-os bg-os bn-os bo-os br-os brx-os bs-os byn-os ca-os ce-os ceb-os ckb-os crh-os cs-os csb-os cv-os cy-os da-os de-os dv-os dz-os el-os en-os en_AU-os en_CA-os en_GB-os en_US-os eo-os es-os es_CO-os et-os eu-os fa-os fa_AF-os ff-os fi-os fil-os fo-os fr-os fr_CA-os frp-os fur-os fy-os ga-os gd-os gl-os gn-os gu-os guc-os gv-os ha-os he-os hi-os hr-os ht-os hu-os hy-os id-os ig-os io-os is-os it-os iu-os ja-os jbo-os jv-os ka-os kab-os kk-os kl-os km-os kn-os ko-os ksh-os ku-os kw-os ky-os la-os lb-os li-os lld-os ln-os lo-os lt-os ltg-os lv-os mai-os mg-os mhr-os mi-os miq-os mk-os ml-os mn-os mr-os ms-os mt-os mus-os my-os nan-os nb-os nds-os ne-os nl-os nn-os no-os nso-os ny-os oc-os om-os or-os ace-pa af-pa ak-pa am-pa an-pa ang-pa ar-pa ar_SY-pa ary-pa as-pa ast-pa az-pa ba-pa bal-pa be-pa bem-pa ber-pa bg-pa bho-pa bn-pa bn_IN-pa bo-pa br-pa brx-pa bs-pa bua-pa byn-pa ca-pa ce-pa ceb-pa chr-pa ckb-pa co-pa crh-pa cs-pa csb-pa cv-pa cy-pa da-pa de-pa de_AT-pa de_DE-pa dsb-pa dv-pa dz-pa el-pa en-pa en_AU-pa en_CA-pa en_GB-pa en_NZ-pa en_US-pa eo-pa es-pa es_AR-pa es_CL-pa es_CO-pa es_CR-pa es_DO-pa es_EC-pa es_ES-pa es_GT-pa es_HN-pa es_MX-pa es_NI-pa es_PA-pa es_PE-pa es_PR-pa es_SV-pa es_UY-pa es_VE-pa et-pa eu-pa fa-pa fa_AF-pa ff-pa fi-pa fil-pa fo-pa fr-pa fr_CA-pa fr_FR-pa frm-pa frp-pa fur-pa fy-pa ga-pa gd-pa gl-pa gn-pa gu-pa guc-pa gv-pa ha-pa haw-pa he-pa hi-pa hil-pa hne-pa hr-pa hsb-pa ht-pa hu-pa hy-pa ia-pa id-pa ig-pa io-pa is-pa it-pa iu-pa ja-pa jbo-pa jv-pa ka-pa kab-pa kg-pa kk-pa kl-pa km-pa kn-pa ko-pa kok-pa ks-pa ksh-pa ku-pa kw-pa ky-pa la-pa lb-pa lg-pa li-pa lij-pa lld-pa ln-pa lo-pa lt-pa ltg-pa lv-pa mai-pa mg-pa mhr-pa mi-pa miq-pa mk-pa ml-pa mn-pa mo-pa mr-pa ms-pa mt-pa mus-pa my-pa nan-pa nap-pa nb-pa nds-pa ne-pa nhn-pa nl-pa nn-pa no-pa nso-pa ny-pa oc-pa oj-pa om-pa or-pa os-pa af-pam am-pam an-pam ar-pam ary-pam ast-pam az-pam be-pam bg-pam bn-pam bo-pam br-pam bs-pam ca-pam ckb-pam crh-pam cs-pam csb-pam cv-pam cy-pam da-pam de-pam dv-pam el-pam en-pam en_AU-pam en_CA-pam en_GB-pam eo-pam es-pam et-pam eu-pam fa-pam fa_AF-pam fi-pam fil-pam fo-pam fr-pam fr_CA-pam frp-pam fur-pam fy-pam ga-pam gd-pam gl-pam gu-pam gv-pam he-pam hi-pam hr-pam ht-pam hu-pam hy-pam id-pam is-pam it-pam ja-pam jv-pam ka-pam kk-pam km-pam kn-pam ko-pam ku-pam kw-pam ky-pam lb-pam ln-pam lo-pam lt-pam lv-pam mg-pam mhr-pam mi-pam mk-pam ml-pam mn-pam mr-pam ms-pam my-pam nb-pam nds-pam ne-pam nl-pam nn-pam oc-pam os-pam pa-pam ace-pap af-pap ak-pap am-pap an-pap ar-pap ary-pap as-pap ast-pap az-pap be-pap bem-pap ber-pap bg-pap bn-pap bo-pap br-pap brx-pap bs-pap byn-pap ca-pap ce-pap ckb-pap co-pap crh-pap cs-pap csb-pap cv-pap cy-pap da-pap de-pap de_AT-pap de_DE-pap dsb-pap dv-pap dz-pap el-pap en-pap en_AU-pap en_CA-pap en_GB-pap eo-pap es-pap es_CO-pap es_ES-pap es_PR-pap et-pap eu-pap fa-pap fa_AF-pap ff-pap fi-pap fil-pap fo-pap fr-pap fr_CA-pap fr_FR-pap frm-pap frp-pap fur-pap fy-pap ga-pap gd-pap gl-pap gn-pap gu-pap guc-pap gv-pap ha-pap he-pap hi-pap hr-pap ht-pap hu-pap hy-pap ia-pap id-pap ig-pap io-pap is-pap it-pap iu-pap ja-pap jbo-pap jv-pap ka-pap kab-pap kg-pap kk-pap kl-pap km-pap kn-pap ko-pap ku-pap kw-pap ky-pap la-pap lb-pap lg-pap li-pap lij-pap lld-pap ln-pap lo-pap lt-pap ltg-pap lv-pap mai-pap mg-pap mhr-pap mi-pap miq-pap mk-pap ml-pap mn-pap mr-pap ms-pap mt-pap mus-pap my-pap nan-pap nb-pap nds-pap ne-pap nl-pap nn-pap no-pap nso-pap oc-pap om-pap or-pap os-pap pa-pap ace-pl af-pl ak-pl am-pl an-pl ang-pl ar-pl ar_SY-pl ary-pl as-pl ast-pl az-pl ba-pl bal-pl be-pl bem-pl ber-pl bg-pl bho-pl bn-pl bn_IN-pl bo-pl br-pl brx-pl bs-pl bua-pl byn-pl ca-pl ce-pl ceb-pl chr-pl ckb-pl co-pl crh-pl cs-pl csb-pl cv-pl cy-pl da-pl de-pl de_AT-pl de_DE-pl dsb-pl dv-pl dz-pl el-pl en-pl en_AU-pl en_CA-pl en_GB-pl en_NZ-pl en_US-pl eo-pl es-pl es_AR-pl es_CL-pl es_CO-pl es_CR-pl es_DO-pl es_EC-pl es_ES-pl es_GT-pl es_HN-pl es_MX-pl es_NI-pl es_PA-pl es_PE-pl es_PR-pl es_SV-pl es_UY-pl es_VE-pl et-pl eu-pl fa-pl fa_AF-pl ff-pl fi-pl fil-pl fo-pl fr-pl fr_CA-pl fr_FR-pl frm-pl frp-pl fur-pl fy-pl ga-pl gd-pl gl-pl gn-pl grc-pl gu-pl guc-pl gv-pl ha-pl haw-pl he-pl hi-pl hil-pl hne-pl hr-pl hsb-pl ht-pl hu-pl hy-pl ia-pl id-pl ig-pl io-pl is-pl it-pl iu-pl ja-pl jbo-pl jv-pl ka-pl kab-pl kg-pl kk-pl kl-pl km-pl kn-pl ko-pl kok-pl ks-pl ksh-pl ku-pl kw-pl ky-pl la-pl lb-pl lg-pl li-pl lij-pl lld-pl ln-pl lo-pl lt-pl ltg-pl lv-pl mai-pl mg-pl mh-pl mhr-pl mi-pl miq-pl mk-pl ml-pl mn-pl mo-pl mr-pl ms-pl mt-pl mus-pl my-pl nan-pl nap-pl nb-pl nds-pl ne-pl nhn-pl nl-pl nl_NL-pl nn-pl no-pl nso-pl ny-pl oc-pl oj-pl om-pl or-pl os-pl pa-pl pam-pl pap-pl ace-pms af-pms ak-pms am-pms an-pms ar-pms as-pms ast-pms az-pms be-pms bg-pms bn-pms bo-pms br-pms bs-pms ca-pms ckb-pms co-pms crh-pms cs-pms csb-pms cv-pms cy-pms da-pms de-pms de_AT-pms de_DE-pms dsb-pms dv-pms dz-pms el-pms en-pms en_AU-pms en_CA-pms en_GB-pms eo-pms es-pms es_ES-pms es_PR-pms et-pms eu-pms fa-pms fa_AF-pms ff-pms fi-pms fil-pms fo-pms fr-pms fr_CA-pms fr_FR-pms frp-pms fur-pms fy-pms ga-pms gd-pms gl-pms gu-pms gv-pms ha-pms he-pms hi-pms hil-pms hne-pms hr-pms ht-pms hu-pms hy-pms id-pms ig-pms io-pms is-pms it-pms ja-pms jbo-pms jv-pms ka-pms kab-pms kk-pms km-pms kn-pms ko-pms kok-pms ksh-pms ku-pms kw-pms ky-pms la-pms lb-pms lg-pms li-pms lld-pms ln-pms lo-pms lt-pms lv-pms mai-pms mg-pms mhr-pms mi-pms miq-pms mk-pms ml-pms mn-pms mr-pms ms-pms mt-pms mus-pms my-pms nan-pms nap-pms nb-pms nds-pms ne-pms nl-pms nn-pms no-pms nso-pms oc-pms om-pms or-pms os-pms pa-pms pl-pms ace-pmy af-pmy am-pmy an-pmy ar-pmy ary-pmy as-pmy ast-pmy az-pmy be-pmy bem-pmy ber-pmy bg-pmy bn-pmy bo-pmy br-pmy brx-pmy bs-pmy byn-pmy ca-pmy ce-pmy ckb-pmy crh-pmy cs-pmy csb-pmy cv-pmy cy-pmy da-pmy de-pmy dv-pmy el-pmy en-pmy en_AU-pmy en_CA-pmy en_GB-pmy eo-pmy es-pmy es_CO-pmy et-pmy eu-pmy fa-pmy ff-pmy fi-pmy fil-pmy fo-pmy fr-pmy fr_CA-pmy frp-pmy fur-pmy fy-pmy ga-pmy gd-pmy gl-pmy gn-pmy gu-pmy guc-pmy gv-pmy he-pmy hi-pmy hr-pmy ht-pmy hu-pmy hy-pmy id-pmy is-pmy it-pmy iu-pmy ja-pmy jbo-pmy jv-pmy ka-pmy kab-pmy kk-pmy kl-pmy km-pmy kn-pmy ko-pmy ku-pmy kw-pmy ky-pmy la-pmy lb-pmy li-pmy lld-pmy ln-pmy lo-pmy lt-pmy ltg-pmy lv-pmy mg-pmy mhr-pmy mi-pmy miq-pmy mk-pmy ml-pmy mn-pmy mr-pmy ms-pmy mt-pmy mus-pmy my-pmy nan-pmy nb-pmy nds-pmy ne-pmy nl-pmy nn-pmy nso-pmy oc-pmy om-pmy or-pmy os-pmy pa-pmy pap-pmy pl-pmy ace-ps af-ps ak-ps am-ps an-ps ang-ps ar-ps ar_SY-ps ary-ps as-ps ast-ps az-ps ba-ps be-ps ber-ps bg-ps bho-ps bn-ps bn_IN-ps bo-ps br-ps brx-ps bs-ps bua-ps ca-ps ce-ps ceb-ps chr-ps ckb-ps co-ps crh-ps cs-ps csb-ps cv-ps cy-ps da-ps de-ps de_AT-ps de_DE-ps dsb-ps dv-ps dz-ps el-ps en-ps en_AU-ps en_CA-ps en_GB-ps en_NZ-ps en_US-ps eo-ps es-ps es_AR-ps es_ES-ps es_MX-ps es_PR-ps es_UY-ps et-ps eu-ps fa-ps fa_AF-ps ff-ps fi-ps fil-ps fo-ps fr-ps fr_CA-ps fr_FR-ps frm-ps frp-ps fur-ps fy-ps ga-ps gd-ps gl-ps gn-ps grc-ps gu-ps gv-ps ha-ps haw-ps he-ps hi-ps hil-ps hne-ps hr-ps ht-ps hu-ps hy-ps ia-ps id-ps ig-ps io-ps is-ps it-ps ja-ps jbo-ps jv-ps ka-ps kab-ps kg-ps kk-ps kl-ps km-ps kn-ps ko-ps kok-ps ks-ps ksh-ps ku-ps kw-ps ky-ps la-ps lb-ps lg-ps li-ps lij-ps lld-ps ln-ps lo-ps lt-ps ltg-ps lv-ps mai-ps mg-ps mhr-ps mi-ps miq-ps mk-ps ml-ps mn-ps mo-ps mr-ps ms-ps mt-ps mus-ps my-ps nan-ps nap-ps nb-ps nds-ps ne-ps nhn-ps nl-ps nn-ps no-ps nso-ps ny-ps oc-ps om-ps or-ps os-ps pa-ps pam-ps pap-ps pl-ps pms-ps pmy-ps ace-pt af-pt ak-pt am-pt an-pt ang-pt ar-pt ar_SY-pt ary-pt as-pt ast-pt az-pt ba-pt bal-pt be-pt bem-pt ber-pt bg-pt bho-pt bn-pt bn_IN-pt bo-pt br-pt brx-pt bs-pt bua-pt byn-pt ca-pt ce-pt ceb-pt chr-pt ckb-pt co-pt crh-pt cs-pt csb-pt cv-pt cy-pt da-pt de-pt de_AT-pt de_DE-pt dsb-pt dv-pt dz-pt el-pt en-pt en_AU-pt en_CA-pt en_GB-pt en_NZ-pt en_US-pt eo-pt es-pt es_AR-pt es_CL-pt es_CO-pt es_CR-pt es_DO-pt es_EC-pt es_ES-pt es_GT-pt es_HN-pt es_MX-pt es_NI-pt es_PA-pt es_PE-pt es_PR-pt es_SV-pt es_UY-pt es_VE-pt et-pt eu-pt fa-pt ff-pt fi-pt fil-pt fo-pt fr-pt fr_CA-pt fr_FR-pt frm-pt frp-pt fur-pt fy-pt ga-pt gd-pt gl-pt gn-pt grc-pt gu-pt guc-pt gv-pt ha-pt haw-pt he-pt hi-pt hil-pt hne-pt hr-pt hsb-pt ht-pt hu-pt hy-pt ia-pt id-pt ig-pt io-pt is-pt it-pt iu-pt ja-pt jbo-pt jv-pt ka-pt kab-pt kg-pt kk-pt kl-pt km-pt kn-pt ko-pt kok-pt ks-pt ksh-pt ku-pt kw-pt ky-pt la-pt lb-pt lg-pt li-pt lij-pt lld-pt ln-pt lo-pt lt-pt ltg-pt lv-pt mai-pt mg-pt mh-pt mhr-pt mi-pt miq-pt mk-pt ml-pt mn-pt mo-pt mr-pt ms-pt mt-pt mus-pt my-pt nan-pt nap-pt nb-pt nds-pt ne-pt nhn-pt nl-pt nl_NL-pt nn-pt no-pt nso-pt ny-pt oc-pt oj-pt om-pt or-pt os-pt pa-pt pam-pt pap-pt pl-pt pms-pt pmy-pt ps-pt ace-pt_BR af-pt_BR ak-pt_BR am-pt_BR an-pt_BR ang-pt_BR ar-pt_BR ar_SY-pt_BR ary-pt_BR as-pt_BR ast-pt_BR az-pt_BR ba-pt_BR bal-pt_BR be-pt_BR bem-pt_BR ber-pt_BR bg-pt_BR bho-pt_BR bn-pt_BR bn_IN-pt_BR bo-pt_BR br-pt_BR brx-pt_BR bs-pt_BR bua-pt_BR byn-pt_BR ca-pt_BR ce-pt_BR ceb-pt_BR chr-pt_BR ckb-pt_BR co-pt_BR crh-pt_BR cs-pt_BR csb-pt_BR cv-pt_BR cy-pt_BR da-pt_BR de-pt_BR de_AT-pt_BR de_DE-pt_BR dsb-pt_BR dv-pt_BR dz-pt_BR el-pt_BR en-pt_BR en_AU-pt_BR en_CA-pt_BR en_GB-pt_BR en_NZ-pt_BR en_US-pt_BR eo-pt_BR es-pt_BR es_AR-pt_BR es_CL-pt_BR es_CO-pt_BR es_CR-pt_BR es_DO-pt_BR es_EC-pt_BR es_ES-pt_BR es_GT-pt_BR es_HN-pt_BR es_MX-pt_BR es_NI-pt_BR es_PA-pt_BR es_PE-pt_BR es_PR-pt_BR es_SV-pt_BR es_UY-pt_BR es_VE-pt_BR et-pt_BR eu-pt_BR fa-pt_BR ff-pt_BR fi-pt_BR fil-pt_BR fo-pt_BR fr-pt_BR fr_CA-pt_BR fr_FR-pt_BR frm-pt_BR frp-pt_BR fur-pt_BR fy-pt_BR ga-pt_BR gd-pt_BR gl-pt_BR gn-pt_BR grc-pt_BR gu-pt_BR guc-pt_BR gv-pt_BR ha-pt_BR haw-pt_BR he-pt_BR hi-pt_BR hil-pt_BR hne-pt_BR hr-pt_BR hsb-pt_BR ht-pt_BR hu-pt_BR hy-pt_BR ia-pt_BR id-pt_BR ig-pt_BR io-pt_BR is-pt_BR it-pt_BR iu-pt_BR ja-pt_BR jbo-pt_BR jv-pt_BR ka-pt_BR kab-pt_BR kg-pt_BR kk-pt_BR kl-pt_BR km-pt_BR kn-pt_BR ko-pt_BR kok-pt_BR ks-pt_BR ksh-pt_BR ku-pt_BR kw-pt_BR ky-pt_BR la-pt_BR lb-pt_BR lg-pt_BR li-pt_BR lij-pt_BR lld-pt_BR ln-pt_BR lo-pt_BR lt-pt_BR ltg-pt_BR lv-pt_BR mai-pt_BR mg-pt_BR mh-pt_BR mhr-pt_BR mi-pt_BR miq-pt_BR mk-pt_BR ml-pt_BR mn-pt_BR mo-pt_BR mr-pt_BR ms-pt_BR mt-pt_BR mus-pt_BR my-pt_BR nan-pt_BR nap-pt_BR nb-pt_BR nds-pt_BR ne-pt_BR nhn-pt_BR nl-pt_BR nl_NL-pt_BR nn-pt_BR no-pt_BR nso-pt_BR ny-pt_BR oc-pt_BR oj-pt_BR om-pt_BR or-pt_BR os-pt_BR pa-pt_BR pam-pt_BR pap-pt_BR pl-pt_BR pms-pt_BR pmy-pt_BR ps-pt_BR pt-pt_BR ace-pt_PT af-pt_PT ak-pt_PT am-pt_PT an-pt_PT ar-pt_PT ary-pt_PT as-pt_PT ast-pt_PT az-pt_PT ba-pt_PT be-pt_PT bem-pt_PT bg-pt_PT bn-pt_PT bo-pt_PT br-pt_PT brx-pt_PT bs-pt_PT bua-pt_PT byn-pt_PT ca-pt_PT ce-pt_PT ckb-pt_PT co-pt_PT crh-pt_PT cs-pt_PT csb-pt_PT cv-pt_PT cy-pt_PT da-pt_PT de-pt_PT de_AT-pt_PT de_DE-pt_PT dsb-pt_PT dv-pt_PT dz-pt_PT el-pt_PT en-pt_PT en_AU-pt_PT en_CA-pt_PT en_GB-pt_PT en_NZ-pt_PT eo-pt_PT es-pt_PT es_ES-pt_PT es_PR-pt_PT et-pt_PT eu-pt_PT fa-pt_PT fa_AF-pt_PT ff-pt_PT fi-pt_PT fil-pt_PT fo-pt_PT fr-pt_PT fr_CA-pt_PT fr_FR-pt_PT frm-pt_PT frp-pt_PT fur-pt_PT fy-pt_PT ga-pt_PT gd-pt_PT gl-pt_PT gn-pt_PT gu-pt_PT guc-pt_PT gv-pt_PT ha-pt_PT he-pt_PT hi-pt_PT hr-pt_PT ht-pt_PT hu-pt_PT hy-pt_PT ia-pt_PT id-pt_PT ig-pt_PT io-pt_PT is-pt_PT it-pt_PT iu-pt_PT ja-pt_PT jbo-pt_PT jv-pt_PT ka-pt_PT kab-pt_PT kg-pt_PT kk-pt_PT kl-pt_PT km-pt_PT kn-pt_PT ko-pt_PT ku-pt_PT kw-pt_PT ky-pt_PT la-pt_PT lb-pt_PT lg-pt_PT li-pt_PT lld-pt_PT ln-pt_PT lo-pt_PT lt-pt_PT ltg-pt_PT lv-pt_PT mai-pt_PT mg-pt_PT mhr-pt_PT mi-pt_PT miq-pt_PT mk-pt_PT ml-pt_PT mn-pt_PT mr-pt_PT ms-pt_PT mt-pt_PT mus-pt_PT my-pt_PT nan-pt_PT nb-pt_PT nds-pt_PT ne-pt_PT nl-pt_PT nn-pt_PT no-pt_PT nso-pt_PT oc-pt_PT om-pt_PT or-pt_PT os-pt_PT pa-pt_PT pap-pt_PT pl-pt_PT pmy-pt_PT ps-pt_PT pt-pt_PT pt_BR-pt_PT ace-qu af-qu ak-qu am-qu an-qu ang-qu ar-qu as-qu ast-qu az-qu ba-qu be-qu bg-qu bn-qu bo-qu br-qu brx-qu bs-qu bua-qu ca-qu ce-qu ceb-qu ckb-qu co-qu crh-qu cs-qu csb-qu cv-qu cy-qu da-qu de-qu de_AT-qu de_DE-qu dsb-qu dv-qu dz-qu el-qu en-qu en_AU-qu en_CA-qu en_GB-qu en_NZ-qu eo-qu es-qu es_ES-qu es_PR-qu et-qu eu-qu fa-qu fa_AF-qu fi-qu fil-qu fo-qu fr-qu fr_CA-qu fr_FR-qu frm-qu frp-qu fur-qu fy-qu ga-qu gd-qu gl-qu gn-qu gu-qu gv-qu ha-qu he-qu hi-qu hil-qu hne-qu hr-qu ht-qu hu-qu hy-qu ia-qu id-qu ig-qu io-qu is-qu it-qu ja-qu jbo-qu jv-qu ka-qu kab-qu kg-qu kk-qu kl-qu km-qu kn-qu ko-qu kok-qu ku-qu kw-qu ky-qu la-qu lb-qu lg-qu li-qu ln-qu lo-qu lt-qu lv-qu mai-qu mg-qu mhr-qu mi-qu miq-qu mk-qu ml-qu mn-qu mr-qu ms-qu mt-qu mus-qu my-qu nan-qu nap-qu nb-qu nds-qu ne-qu nl-qu nn-qu no-qu nso-qu oc-qu om-qu or-qu pa-qu pap-qu pl-qu pms-qu ps-qu pt-qu pt_BR-qu pt_PT-qu ace-rm af-rm ak-rm am-rm ar-rm ast-rm az-rm be-rm bg-rm bn-rm br-rm bs-rm ca-rm ckb-rm cs-rm cv-rm cy-rm da-rm de-rm dv-rm el-rm en-rm en_AU-rm en_CA-rm en_GB-rm eo-rm es-rm et-rm eu-rm fa-rm ff-rm fi-rm fil-rm fo-rm fr-rm fr_CA-rm fy-rm ga-rm gd-rm gl-rm gu-rm he-rm hi-rm hr-rm ht-rm hu-rm hy-rm id-rm is-rm it-rm ja-rm jv-rm ka-rm kk-rm km-rm kn-rm ko-rm ku-rm ky-rm lb-rm lg-rm lt-rm lv-rm mk-rm ml-rm mn-rm mr-rm ms-rm my-rm nb-rm nds-rm ne-rm nl-rm nn-rm nso-rm oc-rm pl-rm ps-rm pt-rm pt_BR-rm pt_PT-rm ace-ro af-ro ak-ro am-ro an-ro ang-ro ar-ro ar_SY-ro ary-ro as-ro ast-ro az-ro ba-ro bal-ro be-ro bem-ro ber-ro bg-ro bho-ro bn-ro bn_IN-ro bo-ro br-ro brx-ro bs-ro bua-ro byn-ro ca-ro ce-ro ceb-ro chr-ro ckb-ro co-ro crh-ro cs-ro csb-ro cv-ro cy-ro da-ro de-ro de_AT-ro de_DE-ro dsb-ro dv-ro dz-ro el-ro en-ro en_AU-ro en_CA-ro en_GB-ro en_NZ-ro en_US-ro eo-ro es-ro es_AR-ro es_CL-ro es_CO-ro es_CR-ro es_DO-ro es_EC-ro es_ES-ro es_GT-ro es_HN-ro es_MX-ro es_NI-ro es_PA-ro es_PE-ro es_PR-ro es_SV-ro es_UY-ro es_VE-ro et-ro eu-ro fa-ro fa_AF-ro ff-ro fi-ro fil-ro fo-ro fr-ro fr_CA-ro fr_FR-ro frm-ro frp-ro fur-ro fy-ro ga-ro gd-ro gl-ro gn-ro grc-ro gu-ro guc-ro gv-ro ha-ro haw-ro he-ro hi-ro hil-ro hne-ro hr-ro hsb-ro ht-ro hu-ro hy-ro ia-ro id-ro ig-ro io-ro is-ro it-ro iu-ro ja-ro jbo-ro jv-ro ka-ro kab-ro kg-ro kk-ro kl-ro km-ro kn-ro ko-ro kok-ro ks-ro ksh-ro ku-ro kw-ro ky-ro la-ro lb-ro lg-ro li-ro lij-ro lld-ro ln-ro lo-ro lt-ro ltg-ro lv-ro mai-ro mg-ro mh-ro mhr-ro mi-ro miq-ro mk-ro ml-ro mn-ro mo-ro mr-ro ms-ro mt-ro mus-ro my-ro nan-ro nap-ro nb-ro nds-ro ne-ro nhn-ro nl-ro nl_NL-ro nn-ro no-ro nso-ro ny-ro oc-ro oj-ro om-ro or-ro os-ro pa-ro pam-ro pap-ro pl-ro pms-ro pmy-ro ps-ro pt-ro pt_BR-ro pt_PT-ro qu-ro rm-ro ace-rom af-rom ak-rom am-rom an-rom ar-rom as-rom ast-rom az-rom be-rom bg-rom bn-rom bo-rom br-rom bs-rom ca-rom ce-rom ckb-rom co-rom crh-rom cs-rom csb-rom cy-rom da-rom de-rom de_AT-rom de_DE-rom dsb-rom dv-rom dz-rom el-rom en-rom en_AU-rom en_CA-rom en_GB-rom eo-rom es-rom es_ES-rom es_PR-rom et-rom eu-rom fa-rom fa_AF-rom fi-rom fil-rom fo-rom fr-rom fr_CA-rom fr_FR-rom frm-rom frp-rom fur-rom fy-rom ga-rom gd-rom gl-rom gn-rom gu-rom gv-rom ha-rom he-rom hi-rom hr-rom ht-rom hu-rom hy-rom ia-rom id-rom ig-rom io-rom is-rom it-rom ja-rom jbo-rom jv-rom ka-rom kab-rom kg-rom kk-rom kl-rom km-rom kn-rom ko-rom ku-rom kw-rom ky-rom la-rom lb-rom lg-rom li-rom ln-rom lo-rom lt-rom lv-rom mai-rom mg-rom mhr-rom mi-rom mk-rom ml-rom mn-rom mr-rom ms-rom mt-rom mus-rom my-rom nan-rom nb-rom nds-rom ne-rom nl-rom nn-rom no-rom nso-rom oc-rom om-rom or-rom pa-rom pap-rom pl-rom ps-rom pt-rom pt_BR-rom pt_PT-rom qu-rom ro-rom ace-ru af-ru ak-ru am-ru an-ru ang-ru ar-ru ar_SY-ru ary-ru as-ru ast-ru az-ru ba-ru bal-ru be-ru bem-ru ber-ru bg-ru bho-ru bn-ru bn_IN-ru bo-ru br-ru brx-ru bs-ru bua-ru byn-ru ca-ru ce-ru ceb-ru chr-ru ckb-ru co-ru crh-ru cs-ru csb-ru cv-ru cy-ru da-ru de-ru de_AT-ru de_DE-ru dsb-ru dv-ru dz-ru el-ru en-ru en_AU-ru en_CA-ru en_GB-ru en_NZ-ru en_US-ru eo-ru es-ru es_AR-ru es_CL-ru es_CO-ru es_CR-ru es_DO-ru es_EC-ru es_ES-ru es_GT-ru es_HN-ru es_MX-ru es_NI-ru es_PA-ru es_PE-ru es_PR-ru es_SV-ru es_UY-ru es_VE-ru et-ru eu-ru fa-ru fa_AF-ru ff-ru fi-ru fil-ru fo-ru fr-ru fr_CA-ru fr_FR-ru frm-ru frp-ru fur-ru fy-ru ga-ru gd-ru gl-ru gn-ru grc-ru gu-ru guc-ru gv-ru ha-ru haw-ru he-ru hi-ru hil-ru hne-ru hr-ru hsb-ru ht-ru hu-ru hy-ru ia-ru id-ru ig-ru io-ru is-ru it-ru iu-ru ja-ru jbo-ru jv-ru ka-ru kab-ru kg-ru kk-ru kl-ru km-ru kn-ru ko-ru kok-ru ks-ru ksh-ru ku-ru kw-ru ky-ru la-ru lb-ru lg-ru li-ru lij-ru lld-ru ln-ru lo-ru lt-ru ltg-ru lv-ru mai-ru mg-ru mh-ru mhr-ru mi-ru miq-ru mk-ru ml-ru mn-ru mo-ru mr-ru ms-ru mt-ru mus-ru my-ru nan-ru nap-ru nb-ru nds-ru ne-ru nhn-ru nl-ru nl_NL-ru nn-ru no-ru nso-ru ny-ru oc-ru oj-ru om-ru or-ru os-ru pa-ru pam-ru pap-ru pl-ru pms-ru pmy-ru ps-ru pt-ru pt_BR-ru pt_PT-ru qu-ru rm-ru ro-ru rom-ru ace-rw af-rw ak-rw am-rw an-rw ang-rw ar-rw ar_SY-rw as-rw ast-rw az-rw be-rw bem-rw ber-rw bg-rw bho-rw bn-rw bn_IN-rw bo-rw br-rw brx-rw bs-rw ca-rw ce-rw ceb-rw chr-rw ckb-rw co-rw crh-rw cs-rw csb-rw cv-rw cy-rw da-rw de-rw de_AT-rw de_DE-rw dsb-rw dv-rw dz-rw el-rw en-rw en_AU-rw en_CA-rw en_GB-rw en_US-rw eo-rw es-rw es_AR-rw es_CL-rw es_CO-rw es_CR-rw es_DO-rw es_EC-rw es_ES-rw es_GT-rw es_HN-rw es_MX-rw es_NI-rw es_PA-rw es_PE-rw es_PR-rw es_SV-rw es_UY-rw es_VE-rw et-rw eu-rw fa-rw fa_AF-rw ff-rw fi-rw fil-rw fo-rw fr-rw fr_CA-rw fr_FR-rw frm-rw frp-rw fur-rw fy-rw ga-rw gd-rw gl-rw gn-rw gu-rw gv-rw ha-rw haw-rw he-rw hi-rw hil-rw hne-rw hr-rw ht-rw hu-rw hy-rw ia-rw id-rw ig-rw io-rw is-rw it-rw ja-rw jbo-rw jv-rw ka-rw kab-rw kg-rw kk-rw kl-rw km-rw kn-rw ko-rw kok-rw ks-rw ksh-rw ku-rw kw-rw ky-rw la-rw lb-rw lg-rw li-rw lij-rw lld-rw ln-rw lo-rw lt-rw ltg-rw lv-rw mai-rw mg-rw mhr-rw mi-rw miq-rw mk-rw ml-rw mn-rw mo-rw mr-rw ms-rw mt-rw mus-rw my-rw nan-rw nap-rw nb-rw nds-rw ne-rw nl-rw nn-rw no-rw nso-rw oc-rw om-rw or-rw os-rw pa-rw pap-rw pl-rw pms-rw pmy-rw ps-rw pt-rw pt_BR-rw pt_PT-rw qu-rw rm-rw ro-rw rom-rw ru-rw ace-sa af-sa ak-sa am-sa an-sa ar-sa ary-sa as-sa ast-sa az-sa be-sa bem-sa ber-sa bg-sa bho-sa bn-sa bo-sa br-sa brx-sa bs-sa byn-sa ca-sa ce-sa ceb-sa chr-sa ckb-sa co-sa crh-sa cs-sa csb-sa cv-sa cy-sa da-sa de-sa de_AT-sa de_DE-sa dsb-sa dv-sa dz-sa el-sa en-sa en_AU-sa en_CA-sa en_GB-sa eo-sa es-sa es_CO-sa es_ES-sa es_PR-sa es_UY-sa et-sa eu-sa fa-sa fa_AF-sa ff-sa fi-sa fil-sa fo-sa fr-sa fr_CA-sa fr_FR-sa frm-sa frp-sa fur-sa fy-sa ga-sa gd-sa gl-sa gn-sa gu-sa guc-sa gv-sa ha-sa haw-sa he-sa hi-sa hil-sa hne-sa hr-sa ht-sa hu-sa hy-sa ia-sa id-sa ig-sa io-sa is-sa it-sa iu-sa ja-sa jbo-sa jv-sa ka-sa kab-sa kg-sa kk-sa kl-sa km-sa kn-sa ko-sa kok-sa ks-sa ksh-sa ku-sa kw-sa ky-sa la-sa lb-sa lg-sa li-sa lld-sa ln-sa lo-sa lt-sa ltg-sa lv-sa mai-sa mg-sa mhr-sa mi-sa miq-sa mk-sa ml-sa mn-sa mr-sa ms-sa mt-sa mus-sa my-sa nan-sa nap-sa nb-sa nds-sa ne-sa nl-sa nn-sa no-sa nso-sa ny-sa oc-sa om-sa or-sa os-sa pa-sa pam-sa pap-sa pl-sa pms-sa pmy-sa ps-sa pt-sa pt_BR-sa pt_PT-sa qu-sa ro-sa rom-sa ru-sa rw-sa ace-sc af-sc ak-sc am-sc an-sc ar-sc ary-sc as-sc ast-sc az-sc ba-sc be-sc bem-sc ber-sc bg-sc bho-sc bn-sc bo-sc br-sc brx-sc bs-sc bua-sc byn-sc ca-sc ce-sc ceb-sc ckb-sc co-sc crh-sc cs-sc csb-sc cv-sc cy-sc da-sc de-sc de_AT-sc de_DE-sc dsb-sc dv-sc dz-sc el-sc en-sc en_AU-sc en_CA-sc en_GB-sc en_NZ-sc eo-sc es-sc es_CO-sc es_ES-sc es_PR-sc es_UY-sc et-sc eu-sc fa-sc fa_AF-sc ff-sc fi-sc fil-sc fo-sc fr-sc fr_CA-sc fr_FR-sc frm-sc frp-sc fur-sc fy-sc ga-sc gd-sc gl-sc gn-sc gu-sc guc-sc gv-sc ha-sc he-sc hi-sc hil-sc hr-sc ht-sc hu-sc hy-sc ia-sc id-sc ig-sc io-sc is-sc it-sc iu-sc ja-sc jbo-sc jv-sc ka-sc kab-sc kg-sc kk-sc kl-sc km-sc kn-sc ko-sc kok-sc ks-sc ksh-sc ku-sc kw-sc ky-sc la-sc lb-sc lg-sc li-sc lij-sc lld-sc ln-sc lo-sc lt-sc ltg-sc lv-sc mai-sc mg-sc mhr-sc mi-sc miq-sc mk-sc ml-sc mn-sc mr-sc ms-sc mt-sc mus-sc my-sc nan-sc nap-sc nb-sc nds-sc ne-sc nl-sc nn-sc no-sc nso-sc ny-sc oc-sc om-sc or-sc os-sc pa-sc pam-sc pap-sc pl-sc pms-sc pmy-sc ps-sc pt-sc pt_BR-sc pt_PT-sc qu-sc ro-sc rom-sc ru-sc rw-sc sa-sc ace-sco af-sco ak-sco am-sco an-sco ar-sco ary-sco as-sco ast-sco az-sco be-sco bem-sco ber-sco bg-sco bn-sco bo-sco br-sco brx-sco bs-sco byn-sco ca-sco ce-sco ceb-sco ckb-sco co-sco crh-sco cs-sco csb-sco cv-sco cy-sco da-sco de-sco de_AT-sco de_DE-sco dsb-sco dv-sco dz-sco el-sco en-sco en_AU-sco en_CA-sco en_GB-sco en_US-sco eo-sco es-sco es_ES-sco es_PR-sco et-sco eu-sco fa-sco fa_AF-sco ff-sco fi-sco fil-sco fo-sco fr-sco fr_CA-sco fr_FR-sco frm-sco frp-sco fur-sco fy-sco ga-sco gd-sco gl-sco gn-sco gu-sco guc-sco gv-sco ha-sco he-sco hi-sco hil-sco hr-sco ht-sco hu-sco hy-sco ia-sco id-sco ig-sco io-sco is-sco it-sco iu-sco ja-sco jbo-sco jv-sco ka-sco kab-sco kg-sco kk-sco kl-sco km-sco kn-sco ko-sco kok-sco ksh-sco ku-sco kw-sco ky-sco la-sco lb-sco lg-sco li-sco lld-sco ln-sco lo-sco lt-sco ltg-sco lv-sco mai-sco mg-sco mhr-sco mi-sco miq-sco mk-sco ml-sco mn-sco mr-sco ms-sco mt-sco mus-sco my-sco nan-sco nap-sco nb-sco nds-sco ne-sco nl-sco nn-sco no-sco nso-sco oc-sco om-sco or-sco os-sco pa-sco pap-sco pl-sco pms-sco pmy-sco ps-sco pt-sco pt_BR-sco pt_PT-sco qu-sco rm-sco ro-sco rom-sco ru-sco rw-sco sa-sco sc-sco ace-sd af-sd ak-sd am-sd an-sd ang-sd ar-sd ary-sd as-sd ast-sd az-sd bal-sd be-sd bem-sd ber-sd bg-sd bho-sd bn-sd bn_IN-sd bo-sd br-sd brx-sd bs-sd byn-sd ca-sd ce-sd ceb-sd chr-sd ckb-sd co-sd crh-sd cs-sd csb-sd cv-sd cy-sd da-sd de-sd de_AT-sd de_DE-sd dsb-sd dv-sd dz-sd el-sd en-sd en_AU-sd en_CA-sd en_GB-sd en_US-sd eo-sd es-sd es_CO-sd es_ES-sd es_MX-sd es_PR-sd es_UY-sd et-sd eu-sd fa-sd fa_AF-sd ff-sd fi-sd fil-sd fo-sd fr-sd fr_CA-sd fr_FR-sd frm-sd frp-sd fur-sd fy-sd ga-sd gd-sd gl-sd gn-sd gu-sd guc-sd gv-sd ha-sd haw-sd he-sd hi-sd hil-sd hne-sd hr-sd ht-sd hu-sd hy-sd ia-sd id-sd ig-sd io-sd is-sd it-sd iu-sd ja-sd jbo-sd jv-sd ka-sd kab-sd kg-sd kk-sd kl-sd km-sd kn-sd ko-sd kok-sd ks-sd ksh-sd ku-sd kw-sd ky-sd la-sd lb-sd lg-sd li-sd lld-sd ln-sd lo-sd lt-sd ltg-sd lv-sd mai-sd mg-sd mhr-sd mi-sd miq-sd mk-sd ml-sd mn-sd mo-sd mr-sd ms-sd mt-sd mus-sd my-sd nan-sd nap-sd nb-sd nds-sd ne-sd nl-sd nn-sd no-sd nso-sd ny-sd oc-sd oj-sd om-sd or-sd os-sd pa-sd pam-sd pap-sd pl-sd pms-sd pmy-sd ps-sd pt-sd pt_BR-sd pt_PT-sd qu-sd ro-sd rom-sd ru-sd rw-sd sa-sd sc-sd sco-sd ace-se af-se ak-se am-se an-se ar-se ary-se as-se ast-se az-se ba-se bal-se be-se bem-se ber-se bg-se bho-se bn-se bn_IN-se bo-se br-se brx-se bs-se bua-se byn-se ca-se ce-se ceb-se chr-se ckb-se co-se crh-se cs-se csb-se cv-se cy-se da-se de-se de_AT-se de_DE-se dsb-se dv-se dz-se el-se en-se en_AU-se en_CA-se en_GB-se en_NZ-se en_US-se eo-se es-se es_CO-se es_ES-se es_MX-se es_PR-se es_UY-se et-se eu-se fa-se fa_AF-se ff-se fi-se fil-se fo-se fr-se fr_CA-se fr_FR-se frm-se frp-se fur-se fy-se ga-se gd-se gl-se gn-se gu-se guc-se gv-se ha-se haw-se he-se hi-se hil-se hne-se hr-se hsb-se ht-se hu-se hy-se ia-se id-se ig-se io-se is-se it-se iu-se ja-se jbo-se jv-se ka-se kab-se kg-se kk-se kl-se km-se kn-se ko-se kok-se ks-se ksh-se ku-se kw-se ky-se la-se lb-se lg-se li-se lld-se ln-se lo-se lt-se ltg-se lv-se mai-se mg-se mhr-se mi-se miq-se mk-se ml-se mn-se mo-se mr-se ms-se mt-se mus-se my-se nan-se nap-se nb-se nds-se ne-se nhn-se nl-se nn-se no-se nso-se ny-se oc-se om-se or-se os-se pa-se pam-se pap-se pl-se pms-se pmy-se ps-se pt-se pt_BR-se pt_PT-se qu-se rm-se ro-se rom-se ru-se rw-se sa-se sc-se sco-se sd-se ace-shn af-shn ak-shn am-shn an-shn ang-shn ar-shn ary-shn as-shn ast-shn az-shn ba-shn bal-shn be-shn bem-shn ber-shn bg-shn bn-shn bn_IN-shn bo-shn br-shn brx-shn bs-shn bua-shn byn-shn ca-shn ce-shn ceb-shn chr-shn ckb-shn co-shn crh-shn cs-shn csb-shn cv-shn cy-shn da-shn de-shn de_AT-shn de_DE-shn dsb-shn dv-shn dz-shn el-shn en-shn en_AU-shn en_CA-shn en_GB-shn en_NZ-shn en_US-shn eo-shn es-shn es_AR-shn es_CL-shn es_CO-shn es_CR-shn es_DO-shn es_EC-shn es_ES-shn es_GT-shn es_HN-shn es_MX-shn es_NI-shn es_PA-shn es_PE-shn es_PR-shn es_SV-shn es_UY-shn es_VE-shn et-shn eu-shn fa-shn fa_AF-shn ff-shn fi-shn fil-shn fo-shn fr-shn fr_CA-shn fr_FR-shn frm-shn frp-shn fur-shn fy-shn ga-shn gd-shn gl-shn gn-shn gu-shn guc-shn gv-shn ha-shn haw-shn he-shn hi-shn hil-shn hne-shn hr-shn ht-shn hu-shn hy-shn ia-shn id-shn ig-shn io-shn is-shn it-shn iu-shn ja-shn jbo-shn jv-shn ka-shn kab-shn kg-shn kk-shn kl-shn km-shn kn-shn ko-shn kok-shn ks-shn ksh-shn ku-shn kw-shn ky-shn la-shn lb-shn lg-shn li-shn lij-shn lld-shn ln-shn lo-shn lt-shn ltg-shn lv-shn mai-shn mg-shn mhr-shn mi-shn miq-shn mk-shn ml-shn mn-shn mr-shn ms-shn mt-shn mus-shn my-shn nan-shn nap-shn nb-shn nds-shn ne-shn nl-shn nn-shn no-shn nso-shn ny-shn oc-shn oj-shn om-shn or-shn os-shn pa-shn pam-shn pap-shn pl-shn pms-shn pmy-shn ps-shn pt-shn pt_BR-shn pt_PT-shn qu-shn ro-shn rom-shn ru-shn rw-shn sa-shn sc-shn sco-shn sd-shn se-shn ace-shs af-shs ak-shs am-shs an-shs ang-shs ar-shs as-shs ast-shs az-shs be-shs bg-shs bn-shs bo-shs br-shs bs-shs ca-shs ce-shs ckb-shs co-shs crh-shs cs-shs csb-shs cv-shs cy-shs da-shs de-shs de_AT-shs de_DE-shs dsb-shs dv-shs dz-shs el-shs en-shs en_AU-shs en_CA-shs en_GB-shs eo-shs es-shs es_ES-shs es_PR-shs et-shs eu-shs fa-shs fa_AF-shs fi-shs fil-shs fo-shs fr-shs fr_CA-shs fr_FR-shs frm-shs frp-shs fur-shs fy-shs ga-shs gd-shs gl-shs gn-shs gu-shs gv-shs ha-shs he-shs hi-shs hil-shs hr-shs ht-shs hu-shs hy-shs ia-shs id-shs ig-shs io-shs is-shs it-shs ja-shs jbo-shs jv-shs ka-shs kab-shs kg-shs kk-shs kl-shs km-shs kn-shs ko-shs kok-shs ku-shs kw-shs ky-shs la-shs lb-shs lg-shs li-shs ln-shs lo-shs lt-shs lv-shs mai-shs mg-shs mhr-shs mi-shs mk-shs ml-shs mn-shs mr-shs ms-shs mt-shs mus-shs my-shs nan-shs nap-shs nb-shs nds-shs ne-shs nl-shs nn-shs no-shs nso-shs oc-shs om-shs or-shs pa-shs pap-shs pl-shs pms-shs ps-shs pt-shs pt_BR-shs pt_PT-shs qu-shs ro-shs rom-shs ru-shs rw-shs sa-shs sc-shs sco-shs sd-shs se-shs shn-shs ace-si af-si ak-si am-si an-si ang-si ar-si ary-si as-si ast-si az-si ba-si bal-si be-si bem-si ber-si bg-si bho-si bn-si bn_IN-si bo-si br-si brx-si bs-si bua-si byn-si ca-si ce-si ceb-si chr-si ckb-si co-si crh-si cs-si csb-si cv-si cy-si da-si de-si de_AT-si de_DE-si dsb-si dv-si dz-si el-si en-si en_AU-si en_CA-si en_GB-si en_NZ-si en_US-si eo-si es-si es_AR-si es_CL-si es_CO-si es_CR-si es_DO-si es_EC-si es_ES-si es_GT-si es_HN-si es_MX-si es_NI-si es_PA-si es_PE-si es_PR-si es_SV-si es_UY-si es_VE-si et-si eu-si fa-si fa_AF-si ff-si fi-si fil-si fo-si fr-si fr_CA-si fr_FR-si frm-si frp-si fur-si fy-si ga-si gd-si gl-si gn-si grc-si gu-si guc-si gv-si ha-si haw-si he-si hi-si hil-si hne-si hr-si ht-si hu-si hy-si ia-si id-si ig-si io-si is-si it-si iu-si ja-si jbo-si jv-si ka-si kab-si kg-si kk-si kl-si km-si kn-si ko-si kok-si ks-si ksh-si ku-si kw-si ky-si la-si lb-si lg-si li-si lij-si lld-si ln-si lo-si lt-si ltg-si lv-si mai-si mg-si mhr-si mi-si miq-si mk-si ml-si mn-si mo-si mr-si ms-si mt-si mus-si my-si nan-si nap-si nb-si nds-si ne-si nhn-si nl-si nn-si no-si nso-si ny-si oc-si oj-si om-si or-si os-si pa-si pam-si pap-si pl-si pms-si pmy-si ps-si pt-si pt_BR-si pt_PT-si qu-si rm-si ro-si rom-si ru-si rw-si sa-si sc-si sco-si sd-si se-si shn-si shs-si ace-sk af-sk ak-sk am-sk an-sk ang-sk ar-sk ar_SY-sk ary-sk as-sk ast-sk az-sk ba-sk bal-sk be-sk bem-sk ber-sk bg-sk bho-sk bn-sk bn_IN-sk bo-sk br-sk brx-sk bs-sk bua-sk byn-sk ca-sk ce-sk ceb-sk chr-sk ckb-sk co-sk crh-sk cs-sk csb-sk cv-sk cy-sk da-sk de-sk de_AT-sk de_DE-sk dsb-sk dv-sk dz-sk el-sk en-sk en_AU-sk en_CA-sk en_GB-sk en_NZ-sk en_US-sk eo-sk es-sk es_AR-sk es_CL-sk es_CO-sk es_CR-sk es_DO-sk es_EC-sk es_ES-sk es_GT-sk es_HN-sk es_MX-sk es_NI-sk es_PA-sk es_PE-sk es_PR-sk es_SV-sk es_UY-sk es_VE-sk et-sk eu-sk fa-sk fa_AF-sk ff-sk fi-sk fil-sk fo-sk fr-sk fr_CA-sk fr_FR-sk frm-sk frp-sk fur-sk fy-sk ga-sk gd-sk gl-sk gn-sk grc-sk gu-sk guc-sk gv-sk ha-sk haw-sk he-sk hi-sk hil-sk hne-sk hr-sk hsb-sk ht-sk hu-sk hy-sk ia-sk id-sk ig-sk io-sk is-sk it-sk iu-sk ja-sk jbo-sk jv-sk ka-sk kab-sk kg-sk kk-sk kl-sk km-sk kn-sk ko-sk kok-sk ks-sk ksh-sk ku-sk kw-sk ky-sk la-sk lb-sk lg-sk li-sk lij-sk lld-sk ln-sk lo-sk lt-sk ltg-sk lv-sk mai-sk mg-sk mhr-sk mi-sk miq-sk mk-sk ml-sk mn-sk mo-sk mr-sk ms-sk mt-sk mus-sk my-sk nan-sk nap-sk nb-sk nds-sk ne-sk nhn-sk nl-sk nl_NL-sk nn-sk no-sk nso-sk ny-sk oc-sk oj-sk om-sk or-sk os-sk pa-sk pam-sk pap-sk pl-sk pms-sk pmy-sk ps-sk pt-sk pt_BR-sk pt_PT-sk qu-sk rm-sk ro-sk rom-sk ru-sk rw-sk sa-sk sc-sk sco-sk sd-sk se-sk shn-sk shs-sk si-sk ace-sl af-sl ak-sl am-sl an-sl ang-sl ar-sl ar_SY-sl ary-sl as-sl ast-sl az-sl ba-sl bal-sl be-sl bem-sl ber-sl bg-sl bho-sl bn-sl bn_IN-sl bo-sl br-sl brx-sl bs-sl bua-sl byn-sl ca-sl ce-sl ceb-sl chr-sl ckb-sl co-sl crh-sl cs-sl csb-sl cv-sl cy-sl da-sl de-sl de_AT-sl de_DE-sl dsb-sl dv-sl dz-sl el-sl en-sl en_AU-sl en_CA-sl en_GB-sl en_NZ-sl en_US-sl eo-sl es-sl es_AR-sl es_CL-sl es_CO-sl es_CR-sl es_DO-sl es_EC-sl es_ES-sl es_GT-sl es_HN-sl es_MX-sl es_NI-sl es_PA-sl es_PE-sl es_PR-sl es_SV-sl es_UY-sl es_VE-sl et-sl eu-sl fa-sl fa_AF-sl ff-sl fi-sl fil-sl fo-sl fr-sl fr_CA-sl fr_FR-sl frm-sl frp-sl fur-sl fy-sl ga-sl gd-sl gl-sl gn-sl grc-sl gu-sl guc-sl gv-sl ha-sl haw-sl he-sl hi-sl hil-sl hne-sl hr-sl hsb-sl ht-sl hu-sl hy-sl ia-sl id-sl ig-sl io-sl is-sl it-sl iu-sl ja-sl jbo-sl jv-sl ka-sl kab-sl kg-sl kk-sl kl-sl km-sl kn-sl ko-sl kok-sl ks-sl ksh-sl ku-sl kw-sl ky-sl la-sl lb-sl lg-sl li-sl lij-sl lld-sl ln-sl lo-sl lt-sl ltg-sl lv-sl mai-sl mg-sl mh-sl mhr-sl mi-sl miq-sl mk-sl ml-sl mn-sl mo-sl mr-sl ms-sl mt-sl mus-sl my-sl nan-sl nap-sl nb-sl nds-sl ne-sl nhn-sl nl-sl nl_NL-sl nn-sl no-sl nso-sl ny-sl oc-sl oj-sl om-sl or-sl os-sl pa-sl pam-sl pap-sl pl-sl pms-sl pmy-sl ps-sl pt-sl pt_BR-sl pt_PT-sl qu-sl rm-sl ro-sl rom-sl ru-sl rw-sl sa-sl sc-sl sco-sl sd-sl se-sl shn-sl shs-sl si-sl sk-sl ace-sm af-sm ak-sm am-sm an-sm ar-sm as-sm ast-sm az-sm be-sm bg-sm bn-sm bo-sm br-sm bs-sm ca-sm ce-sm ckb-sm co-sm crh-sm cs-sm csb-sm cy-sm da-sm de-sm de_AT-sm de_DE-sm dsb-sm dv-sm dz-sm el-sm en-sm en_AU-sm en_CA-sm en_GB-sm eo-sm es-sm es_ES-sm es_PR-sm et-sm eu-sm fa-sm fa_AF-sm fi-sm fil-sm fo-sm fr-sm fr_CA-sm fr_FR-sm frm-sm frp-sm fur-sm fy-sm ga-sm gd-sm gl-sm gn-sm gu-sm gv-sm ha-sm he-sm hi-sm hr-sm ht-sm hu-sm hy-sm ia-sm id-sm ig-sm io-sm is-sm it-sm ja-sm jbo-sm jv-sm ka-sm kab-sm kg-sm kk-sm kl-sm km-sm kn-sm ko-sm ku-sm kw-sm ky-sm la-sm lb-sm lg-sm li-sm ln-sm lo-sm lt-sm lv-sm mai-sm mg-sm mhr-sm mi-sm mk-sm ml-sm mn-sm mr-sm ms-sm mt-sm mus-sm my-sm nan-sm nb-sm nds-sm ne-sm nl-sm nn-sm no-sm nso-sm oc-sm om-sm or-sm pa-sm pap-sm pl-sm ps-sm pt-sm pt_BR-sm pt_PT-sm qu-sm ro-sm rom-sm ru-sm rw-sm sa-sm sc-sm sco-sm sd-sm se-sm shn-sm shs-sm si-sm sk-sm sl-sm ace-sml af-sml am-sml an-sml ar-sml as-sml ast-sml az-sml be-sml bem-sml bg-sml bn-sml bo-sml br-sml brx-sml bs-sml byn-sml ca-sml ce-sml ckb-sml crh-sml cs-sml csb-sml cv-sml cy-sml da-sml de-sml dv-sml dz-sml el-sml en-sml en_AU-sml en_CA-sml en_GB-sml eo-sml es-sml et-sml eu-sml fa-sml ff-sml fi-sml fil-sml fo-sml fr-sml fr_CA-sml frp-sml fur-sml fy-sml ga-sml gd-sml gl-sml gn-sml gu-sml guc-sml gv-sml ha-sml he-sml hi-sml hr-sml ht-sml hu-sml hy-sml id-sml ig-sml io-sml is-sml it-sml iu-sml ja-sml jbo-sml jv-sml ka-sml kab-sml kk-sml kl-sml km-sml kn-sml ko-sml ksh-sml ku-sml kw-sml ky-sml la-sml lb-sml li-sml lld-sml ln-sml lo-sml lt-sml ltg-sml lv-sml mai-sml mg-sml mhr-sml mi-sml miq-sml mk-sml ml-sml mn-sml mr-sml ms-sml mt-sml mus-sml my-sml nan-sml nb-sml nds-sml ne-sml nl-sml nn-sml no-sml nso-sml oc-sml om-sml or-sml os-sml pa-sml pap-sml pl-sml pms-sml pmy-sml ps-sml pt-sml pt_BR-sml pt_PT-sml ro-sml ru-sml rw-sml sa-sml sc-sml sco-sml sd-sml se-sml shn-sml si-sml sk-sml sl-sml ace-sn af-sn ak-sn am-sn an-sn ar-sn ary-sn as-sn ast-sn az-sn be-sn bem-sn bg-sn bn-sn bo-sn br-sn brx-sn bs-sn byn-sn ca-sn ce-sn ckb-sn co-sn crh-sn cs-sn csb-sn cv-sn cy-sn da-sn de-sn de_AT-sn de_DE-sn dsb-sn dv-sn dz-sn el-sn en-sn en_AU-sn en_CA-sn en_GB-sn eo-sn es-sn es_ES-sn es_PR-sn et-sn eu-sn fa-sn fa_AF-sn ff-sn fi-sn fil-sn fo-sn fr-sn fr_CA-sn fr_FR-sn frm-sn frp-sn fur-sn fy-sn ga-sn gd-sn gl-sn gn-sn gu-sn guc-sn gv-sn ha-sn he-sn hi-sn hil-sn hr-sn ht-sn hu-sn hy-sn ia-sn id-sn ig-sn io-sn is-sn it-sn iu-sn ja-sn jbo-sn jv-sn ka-sn kab-sn kg-sn kk-sn kl-sn km-sn kn-sn ko-sn kok-sn ksh-sn ku-sn kw-sn ky-sn la-sn lb-sn lg-sn li-sn lld-sn ln-sn lo-sn lt-sn ltg-sn lv-sn mai-sn mg-sn mhr-sn mi-sn miq-sn mk-sn ml-sn mn-sn mr-sn ms-sn mt-sn mus-sn my-sn nan-sn nap-sn nb-sn nds-sn ne-sn nl-sn nn-sn no-sn nso-sn oc-sn om-sn or-sn os-sn pa-sn pap-sn pl-sn pms-sn pmy-sn ps-sn pt-sn pt_BR-sn pt_PT-sn qu-sn ro-sn rom-sn ru-sn rw-sn sa-sn sc-sn sco-sn sd-sn se-sn shn-sn shs-sn si-sn sk-sn sl-sn sm-sn sml-sn ace-so af-so ak-so am-so an-so ar-so as-so ast-so az-so be-so bem-so bg-so bn-so bo-so br-so brx-so bs-so byn-so ca-so ce-so ckb-so co-so crh-so cs-so csb-so cv-so cy-so da-so de-so de_AT-so de_DE-so dsb-so dv-so dz-so el-so en-so en_AU-so en_CA-so en_GB-so eo-so es-so es_ES-so es_PR-so et-so eu-so fa-so fa_AF-so ff-so fi-so fil-so fo-so fr-so fr_CA-so fr_FR-so frp-so fur-so fy-so ga-so gd-so gl-so gn-so gu-so guc-so gv-so he-so hi-so hil-so hr-so ht-so hu-so hy-so id-so ig-so is-so it-so iu-so ja-so jbo-so jv-so ka-so kab-so kk-so kl-so km-so kn-so ko-so kok-so ku-so kw-so ky-so la-so lb-so lg-so li-so lld-so ln-so lo-so lt-so ltg-so lv-so mai-so mg-so mhr-so mi-so miq-so mk-so ml-so mn-so mr-so ms-so mt-so mus-so my-so nan-so nap-so nb-so nds-so ne-so nl-so nn-so no-so nso-so oc-so om-so or-so os-so pa-so pap-so pl-so pms-so pmy-so ps-so pt-so pt_BR-so pt_PT-so qu-so ro-so ru-so rw-so sa-so sc-so sco-so sd-so se-so shn-so shs-so si-so sk-so sl-so sml-so sn-so af-son ak-son ast-son az-son be-son bs-son cs-son da-son de-son el-son en-son en_AU-son en_GB-son eo-son es-son et-son eu-son fa-son ff-son fi-son fo-son fr-son fr_CA-son ga-son gl-son he-son hr-son hu-son hy-son id-son is-son it-son ja-son ko-son ky-son lg-son lt-son lv-son mn-son ms-son my-son nb-son nl-son nso-son oc-son pl-son pt-son pt_BR-son rm-son ro-son ru-son rw-son se-son sk-son sl-son ace-sq af-sq ak-sq am-sq an-sq ang-sq ar-sq ar_SY-sq ary-sq as-sq ast-sq az-sq ba-sq bal-sq be-sq bem-sq ber-sq bg-sq bho-sq bn-sq bn_IN-sq bo-sq br-sq brx-sq bs-sq bua-sq byn-sq ca-sq ce-sq ceb-sq chr-sq ckb-sq co-sq crh-sq cs-sq csb-sq cv-sq cy-sq da-sq de-sq de_AT-sq de_DE-sq dsb-sq dv-sq dz-sq el-sq en-sq en_AU-sq en_CA-sq en_GB-sq en_NZ-sq en_US-sq eo-sq es-sq es_AR-sq es_CL-sq es_CO-sq es_CR-sq es_DO-sq es_EC-sq es_ES-sq es_GT-sq es_HN-sq es_MX-sq es_NI-sq es_PA-sq es_PE-sq es_PR-sq es_SV-sq es_UY-sq es_VE-sq et-sq eu-sq fa-sq fa_AF-sq ff-sq fi-sq fil-sq fo-sq fr-sq fr_CA-sq fr_FR-sq frm-sq frp-sq fur-sq fy-sq ga-sq gd-sq gl-sq gn-sq grc-sq gu-sq guc-sq gv-sq ha-sq haw-sq he-sq hi-sq hil-sq hne-sq hr-sq hsb-sq ht-sq hu-sq hy-sq ia-sq id-sq ig-sq io-sq is-sq it-sq iu-sq ja-sq jbo-sq jv-sq ka-sq kab-sq kg-sq kk-sq kl-sq km-sq kn-sq ko-sq kok-sq ks-sq ksh-sq ku-sq kw-sq ky-sq la-sq lb-sq lg-sq li-sq lij-sq lld-sq ln-sq lo-sq lt-sq ltg-sq lv-sq mai-sq mg-sq mh-sq mhr-sq mi-sq miq-sq mk-sq ml-sq mn-sq mo-sq mr-sq ms-sq mt-sq mus-sq my-sq nan-sq nap-sq nb-sq nds-sq ne-sq nhn-sq nl-sq nl_NL-sq nn-sq no-sq nso-sq ny-sq oc-sq oj-sq om-sq or-sq os-sq pa-sq pam-sq pap-sq pl-sq pms-sq pmy-sq ps-sq pt-sq pt_BR-sq pt_PT-sq qu-sq rm-sq ro-sq rom-sq ru-sq rw-sq sa-sq sc-sq sco-sq sd-sq se-sq shn-sq shs-sq si-sq sk-sq sl-sq sm-sq sml-sq sn-sq so-sq son-sq ace-sr af-sr ak-sr am-sr an-sr ang-sr ar-sr ar_SY-sr ary-sr as-sr ast-sr az-sr ba-sr bal-sr be-sr bem-sr ber-sr bg-sr bho-sr bn-sr bn_IN-sr bo-sr br-sr brx-sr bs-sr bua-sr byn-sr ca-sr ce-sr ceb-sr chr-sr ckb-sr co-sr crh-sr cs-sr csb-sr cv-sr cy-sr da-sr de-sr de_AT-sr de_DE-sr dsb-sr dv-sr dz-sr el-sr en-sr en_AU-sr en_CA-sr en_GB-sr en_NZ-sr en_US-sr eo-sr es-sr es_AR-sr es_CL-sr es_CO-sr es_CR-sr es_DO-sr es_EC-sr es_ES-sr es_GT-sr es_HN-sr es_MX-sr es_NI-sr es_PA-sr es_PE-sr es_PR-sr es_SV-sr es_UY-sr es_VE-sr et-sr eu-sr fa-sr fa_AF-sr ff-sr fi-sr fil-sr fo-sr fr-sr fr_CA-sr fr_FR-sr frm-sr frp-sr fur-sr fy-sr ga-sr gd-sr gl-sr gn-sr grc-sr gu-sr guc-sr gv-sr ha-sr haw-sr he-sr hi-sr hil-sr hne-sr hr-sr hsb-sr ht-sr hu-sr hy-sr ia-sr id-sr ig-sr io-sr is-sr it-sr iu-sr ja-sr jbo-sr jv-sr ka-sr kab-sr kg-sr kk-sr kl-sr km-sr kn-sr ko-sr kok-sr ks-sr ksh-sr ku-sr kw-sr ky-sr la-sr lb-sr lg-sr li-sr lij-sr lld-sr ln-sr lo-sr lt-sr ltg-sr lv-sr mai-sr mg-sr mh-sr mhr-sr mi-sr miq-sr mk-sr ml-sr mn-sr mo-sr mr-sr ms-sr mt-sr mus-sr my-sr nan-sr nap-sr nb-sr nds-sr ne-sr nhn-sr nl-sr nl_NL-sr nn-sr no-sr nso-sr ny-sr oc-sr oj-sr om-sr or-sr os-sr pa-sr pam-sr pap-sr pl-sr pms-sr pmy-sr ps-sr pt-sr pt_BR-sr pt_PT-sr qu-sr rm-sr ro-sr rom-sr ru-sr rw-sr sa-sr sc-sr sco-sr sd-sr se-sr shn-sr shs-sr si-sr sk-sr sl-sr sm-sr sml-sr sn-sr so-sr son-sr sq-sr ace-st af-st ak-st am-st an-st ar-st as-st ast-st az-st be-st bg-st bn-st bo-st br-st bs-st ca-st ce-st ckb-st co-st crh-st cs-st csb-st cv-st cy-st da-st de-st de_AT-st de_DE-st dsb-st dv-st dz-st el-st en-st en_AU-st en_CA-st en_GB-st eo-st es-st es_ES-st es_PR-st et-st eu-st fa-st fa_AF-st ff-st fi-st fil-st fo-st fr-st fr_CA-st fr_FR-st frm-st frp-st fur-st fy-st ga-st gd-st gl-st gn-st gu-st gv-st ha-st haw-st he-st hi-st hil-st hr-st ht-st hu-st hy-st ia-st id-st ig-st io-st is-st it-st ja-st jbo-st jv-st ka-st kab-st kg-st kk-st kl-st km-st kn-st ko-st kok-st ks-st ku-st kw-st ky-st la-st lb-st lg-st li-st ln-st lo-st lt-st lv-st mai-st mg-st mhr-st mi-st mk-st ml-st mn-st mr-st ms-st mt-st mus-st my-st nan-st nap-st nb-st nds-st ne-st nl-st nn-st no-st nso-st oc-st om-st or-st pa-st pap-st pl-st pms-st ps-st pt-st pt_BR-st pt_PT-st qu-st rm-st ro-st rom-st ru-st rw-st sa-st sc-st sco-st sd-st se-st shn-st shs-st si-st sk-st sl-st sm-st sn-st so-st son-st sq-st sr-st ace-sv af-sv ak-sv am-sv an-sv ang-sv ar-sv ar_SY-sv ary-sv as-sv ast-sv az-sv ba-sv bal-sv be-sv bem-sv ber-sv bg-sv bho-sv bn-sv bn_IN-sv bo-sv br-sv brx-sv bs-sv bua-sv byn-sv ca-sv ce-sv ceb-sv chr-sv ckb-sv co-sv crh-sv cs-sv csb-sv cv-sv cy-sv da-sv de-sv de_AT-sv de_DE-sv dsb-sv dv-sv dz-sv el-sv en-sv en_AU-sv en_CA-sv en_GB-sv en_NZ-sv en_US-sv eo-sv es-sv es_AR-sv es_CL-sv es_CO-sv es_CR-sv es_DO-sv es_EC-sv es_ES-sv es_GT-sv es_HN-sv es_MX-sv es_NI-sv es_PA-sv es_PE-sv es_PR-sv es_SV-sv es_UY-sv es_VE-sv et-sv eu-sv fa-sv fa_AF-sv ff-sv fi-sv fil-sv fo-sv fr-sv fr_CA-sv fr_FR-sv frm-sv frp-sv fur-sv fy-sv ga-sv gd-sv gl-sv gn-sv grc-sv gu-sv guc-sv gv-sv ha-sv haw-sv he-sv hi-sv hil-sv hne-sv hr-sv hsb-sv ht-sv hu-sv hy-sv ia-sv id-sv ig-sv io-sv is-sv it-sv iu-sv ja-sv jbo-sv jv-sv ka-sv kab-sv kg-sv kk-sv kl-sv km-sv kn-sv ko-sv kok-sv ks-sv ksh-sv ku-sv kw-sv ky-sv la-sv lb-sv lg-sv li-sv lij-sv lld-sv ln-sv lo-sv lt-sv ltg-sv lv-sv mai-sv mg-sv mh-sv mhr-sv mi-sv miq-sv mk-sv ml-sv mn-sv mo-sv mr-sv ms-sv mt-sv mus-sv my-sv nan-sv nap-sv nb-sv nds-sv ne-sv nhn-sv nl-sv nl_NL-sv nn-sv no-sv nso-sv ny-sv oc-sv oj-sv om-sv or-sv os-sv pa-sv pam-sv pap-sv pl-sv pms-sv pmy-sv ps-sv pt-sv pt_BR-sv pt_PT-sv qu-sv rm-sv ro-sv rom-sv ru-sv rw-sv sa-sv sc-sv sco-sv sd-sv se-sv shn-sv shs-sv si-sv sk-sv sl-sv sm-sv sml-sv sn-sv so-sv son-sv sq-sv sr-sv st-sv ace-sw af-sw ak-sw am-sw an-sw ang-sw ar-sw ary-sw as-sw ast-sw az-sw ba-sw be-sw bem-sw ber-sw bg-sw bn-sw bn_IN-sw bo-sw br-sw brx-sw bs-sw bua-sw byn-sw ca-sw ce-sw ceb-sw chr-sw ckb-sw co-sw crh-sw cs-sw csb-sw cv-sw cy-sw da-sw de-sw de_AT-sw de_DE-sw dsb-sw dv-sw dz-sw el-sw en-sw en_AU-sw en_CA-sw en_GB-sw en_NZ-sw eo-sw es-sw es_CO-sw es_ES-sw es_PR-sw et-sw eu-sw fa-sw fa_AF-sw ff-sw fi-sw fil-sw fo-sw fr-sw fr_CA-sw fr_FR-sw frm-sw frp-sw fur-sw fy-sw ga-sw gd-sw gl-sw gn-sw gu-sw guc-sw gv-sw ha-sw haw-sw he-sw hi-sw hil-sw hr-sw ht-sw hu-sw hy-sw ia-sw id-sw ig-sw io-sw is-sw it-sw iu-sw ja-sw jbo-sw jv-sw ka-sw kab-sw kg-sw kk-sw kl-sw km-sw kn-sw ko-sw kok-sw ks-sw ksh-sw ku-sw kw-sw ky-sw la-sw lb-sw lg-sw li-sw lld-sw ln-sw lo-sw lt-sw ltg-sw lv-sw mai-sw mg-sw mhr-sw mi-sw miq-sw mk-sw ml-sw mn-sw mr-sw ms-sw mt-sw mus-sw my-sw nan-sw nap-sw nb-sw nds-sw ne-sw nhn-sw nl-sw nn-sw no-sw nso-sw oc-sw om-sw or-sw os-sw pa-sw pap-sw pl-sw pms-sw pmy-sw ps-sw pt-sw pt_BR-sw pt_PT-sw qu-sw ro-sw rom-sw ru-sw rw-sw sa-sw sc-sw sco-sw sd-sw se-sw shn-sw shs-sw si-sw sk-sw sl-sw sm-sw sml-sw sn-sw so-sw sq-sw sr-sw st-sw sv-sw ace-syr af-syr ak-syr am-syr an-syr ar-syr as-syr ast-syr az-syr be-syr bg-syr bn-syr bo-syr br-syr bs-syr ca-syr ce-syr ckb-syr co-syr crh-syr cs-syr csb-syr cv-syr cy-syr da-syr de-syr de_AT-syr de_DE-syr dsb-syr dv-syr dz-syr el-syr en-syr en_AU-syr en_CA-syr en_GB-syr eo-syr es-syr es_ES-syr es_PR-syr et-syr eu-syr fa-syr fa_AF-syr fi-syr fil-syr fo-syr fr-syr fr_CA-syr fr_FR-syr frm-syr frp-syr fur-syr fy-syr ga-syr gd-syr gl-syr gn-syr gu-syr gv-syr ha-syr he-syr hi-syr hil-syr hr-syr ht-syr hu-syr hy-syr ia-syr id-syr ig-syr io-syr is-syr it-syr ja-syr jbo-syr jv-syr ka-syr kab-syr kg-syr kk-syr kl-syr km-syr kn-syr ko-syr kok-syr ku-syr kw-syr ky-syr la-syr lb-syr lg-syr li-syr ln-syr lo-syr lt-syr lv-syr mai-syr mg-syr mhr-syr mi-syr mk-syr ml-syr mn-syr mr-syr ms-syr mt-syr mus-syr my-syr nan-syr nap-syr nb-syr nds-syr ne-syr nl-syr nn-syr no-syr nso-syr oc-syr om-syr or-syr pa-syr pap-syr pl-syr pms-syr ps-syr pt-syr pt_BR-syr pt_PT-syr qu-syr ro-syr rom-syr ru-syr rw-syr sa-syr sc-syr sco-syr sd-syr se-syr shn-syr shs-syr si-syr sk-syr sl-syr sm-syr sn-syr so-syr sq-syr sr-syr st-syr sv-syr sw-syr ace-szl af-szl ak-szl am-szl an-szl ar-szl ary-szl as-szl ast-szl az-szl be-szl bem-szl ber-szl bg-szl bn-szl bo-szl br-szl brx-szl bs-szl byn-szl ca-szl ce-szl ceb-szl ckb-szl co-szl crh-szl cs-szl csb-szl cv-szl cy-szl da-szl de-szl de_AT-szl de_DE-szl dsb-szl dv-szl dz-szl el-szl en-szl en_AU-szl en_CA-szl en_GB-szl eo-szl es-szl es_CO-szl es_ES-szl es_PR-szl et-szl eu-szl fa-szl fa_AF-szl ff-szl fi-szl fil-szl fo-szl fr-szl fr_CA-szl fr_FR-szl frm-szl frp-szl fur-szl fy-szl ga-szl gd-szl gl-szl gn-szl gu-szl guc-szl gv-szl ha-szl he-szl hi-szl hr-szl ht-szl hu-szl hy-szl ia-szl id-szl ig-szl io-szl is-szl it-szl iu-szl ja-szl jbo-szl jv-szl ka-szl kab-szl kg-szl kk-szl kl-szl km-szl kn-szl ko-szl ksh-szl ku-szl kw-szl ky-szl la-szl lb-szl lg-szl li-szl lld-szl ln-szl lo-szl lt-szl ltg-szl lv-szl mai-szl mg-szl mhr-szl mi-szl miq-szl mk-szl ml-szl mn-szl mr-szl ms-szl mt-szl mus-szl my-szl nan-szl nap-szl nb-szl nds-szl ne-szl nl-szl nn-szl no-szl nso-szl oc-szl om-szl or-szl os-szl pa-szl pam-szl pap-szl pl-szl pms-szl pmy-szl ps-szl pt-szl pt_BR-szl pt_PT-szl qu-szl rm-szl ro-szl rom-szl ru-szl rw-szl sa-szl sc-szl sco-szl sd-szl se-szl shn-szl shs-szl si-szl sk-szl sl-szl sm-szl sml-szl sn-szl so-szl sq-szl sr-szl st-szl sv-szl sw-szl syr-szl ace-ta af-ta ak-ta am-ta an-ta ang-ta ar-ta ar_SY-ta ary-ta as-ta ast-ta az-ta ba-ta bal-ta be-ta bem-ta ber-ta bg-ta bho-ta bn-ta bn_IN-ta bo-ta br-ta brx-ta bs-ta bua-ta byn-ta ca-ta ce-ta ceb-ta chr-ta ckb-ta co-ta crh-ta cs-ta csb-ta cv-ta cy-ta da-ta de-ta de_AT-ta de_DE-ta dsb-ta dv-ta dz-ta el-ta en-ta en_AU-ta en_CA-ta en_GB-ta en_NZ-ta en_US-ta eo-ta es-ta es_AR-ta es_CL-ta es_CO-ta es_CR-ta es_DO-ta es_EC-ta es_ES-ta es_GT-ta es_HN-ta es_MX-ta es_NI-ta es_PA-ta es_PE-ta es_PR-ta es_SV-ta es_UY-ta es_VE-ta et-ta eu-ta fa-ta fa_AF-ta ff-ta fi-ta fil-ta fo-ta fr-ta fr_CA-ta fr_FR-ta frm-ta frp-ta fur-ta fy-ta ga-ta gd-ta gl-ta gn-ta gu-ta guc-ta gv-ta ha-ta haw-ta he-ta hi-ta hil-ta hne-ta hr-ta ht-ta hu-ta hy-ta ia-ta id-ta ig-ta io-ta is-ta it-ta iu-ta ja-ta jbo-ta jv-ta ka-ta kab-ta kg-ta kk-ta kl-ta km-ta kn-ta ko-ta kok-ta ks-ta ksh-ta ku-ta kw-ta ky-ta la-ta lb-ta lg-ta li-ta lij-ta lld-ta ln-ta lo-ta lt-ta ltg-ta lv-ta mai-ta mg-ta mhr-ta mi-ta miq-ta mk-ta ml-ta mn-ta mo-ta mr-ta ms-ta mt-ta mus-ta my-ta nan-ta nap-ta nb-ta nds-ta ne-ta nhn-ta nl-ta nl_NL-ta nn-ta no-ta nso-ta ny-ta oc-ta oj-ta om-ta or-ta os-ta pa-ta pam-ta pap-ta pl-ta pms-ta pmy-ta ps-ta pt-ta pt_BR-ta pt_PT-ta qu-ta rm-ta ro-ta rom-ta ru-ta rw-ta sa-ta sc-ta sco-ta sd-ta se-ta shn-ta shs-ta si-ta sk-ta sl-ta sm-ta sml-ta sn-ta so-ta sq-ta sr-ta st-ta sv-ta sw-ta syr-ta szl-ta ace-ta_LK af-ta_LK ak-ta_LK am-ta_LK an-ta_LK ang-ta_LK ar-ta_LK ary-ta_LK as-ta_LK ast-ta_LK az-ta_LK be-ta_LK bem-ta_LK ber-ta_LK bg-ta_LK bn-ta_LK bn_IN-ta_LK bo-ta_LK br-ta_LK brx-ta_LK bs-ta_LK byn-ta_LK ca-ta_LK ce-ta_LK ceb-ta_LK chr-ta_LK ckb-ta_LK co-ta_LK crh-ta_LK cs-ta_LK csb-ta_LK cv-ta_LK cy-ta_LK da-ta_LK de-ta_LK de_AT-ta_LK de_DE-ta_LK dsb-ta_LK dv-ta_LK dz-ta_LK el-ta_LK en-ta_LK en_AU-ta_LK en_CA-ta_LK en_GB-ta_LK en_US-ta_LK eo-ta_LK es-ta_LK es_ES-ta_LK es_PR-ta_LK et-ta_LK eu-ta_LK fa-ta_LK fa_AF-ta_LK ff-ta_LK fi-ta_LK fil-ta_LK fo-ta_LK fr-ta_LK fr_CA-ta_LK fr_FR-ta_LK frm-ta_LK frp-ta_LK fur-ta_LK fy-ta_LK ga-ta_LK gd-ta_LK gl-ta_LK gn-ta_LK gu-ta_LK guc-ta_LK gv-ta_LK ha-ta_LK he-ta_LK hi-ta_LK hr-ta_LK ht-ta_LK hu-ta_LK hy-ta_LK ia-ta_LK id-ta_LK ig-ta_LK io-ta_LK is-ta_LK it-ta_LK iu-ta_LK ja-ta_LK jbo-ta_LK jv-ta_LK ka-ta_LK kab-ta_LK kg-ta_LK kk-ta_LK kl-ta_LK km-ta_LK kn-ta_LK ko-ta_LK ks-ta_LK ku-ta_LK kw-ta_LK ky-ta_LK la-ta_LK lb-ta_LK lg-ta_LK li-ta_LK lij-ta_LK lld-ta_LK ln-ta_LK lo-ta_LK lt-ta_LK ltg-ta_LK lv-ta_LK mai-ta_LK mg-ta_LK mhr-ta_LK mi-ta_LK miq-ta_LK mk-ta_LK ml-ta_LK mn-ta_LK mo-ta_LK mr-ta_LK ms-ta_LK mt-ta_LK mus-ta_LK my-ta_LK nan-ta_LK nb-ta_LK nds-ta_LK ne-ta_LK nl-ta_LK nn-ta_LK no-ta_LK nso-ta_LK ny-ta_LK oc-ta_LK om-ta_LK or-ta_LK os-ta_LK pa-ta_LK pap-ta_LK pl-ta_LK pmy-ta_LK ps-ta_LK pt-ta_LK pt_BR-ta_LK pt_PT-ta_LK qu-ta_LK ro-ta_LK rom-ta_LK ru-ta_LK rw-ta_LK sa-ta_LK sc-ta_LK sco-ta_LK sd-ta_LK se-ta_LK shn-ta_LK shs-ta_LK si-ta_LK sk-ta_LK sl-ta_LK sm-ta_LK sml-ta_LK sn-ta_LK so-ta_LK sq-ta_LK sr-ta_LK st-ta_LK sv-ta_LK sw-ta_LK syr-ta_LK szl-ta_LK ta-ta_LK ace-te af-te ak-te am-te an-te ang-te ar-te ary-te as-te ast-te az-te ba-te bal-te be-te bem-te ber-te bg-te bho-te bn-te bn_IN-te bo-te br-te brx-te bs-te bua-te byn-te ca-te ce-te ceb-te chr-te ckb-te co-te crh-te cs-te csb-te cv-te cy-te da-te de-te de_AT-te de_DE-te dsb-te dv-te dz-te el-te en-te en_AU-te en_CA-te en_GB-te en_NZ-te en_US-te eo-te es-te es_AR-te es_CL-te es_CO-te es_CR-te es_DO-te es_EC-te es_ES-te es_GT-te es_HN-te es_MX-te es_NI-te es_PA-te es_PE-te es_PR-te es_SV-te es_UY-te es_VE-te et-te eu-te fa-te fa_AF-te ff-te fi-te fil-te fo-te fr-te fr_CA-te fr_FR-te frm-te frp-te fur-te fy-te ga-te gd-te gl-te gn-te gu-te guc-te gv-te ha-te haw-te he-te hi-te hil-te hne-te hr-te ht-te hu-te hy-te ia-te id-te ig-te io-te is-te it-te iu-te ja-te jbo-te jv-te ka-te kab-te kg-te kk-te kl-te km-te kn-te ko-te kok-te ks-te ksh-te ku-te kw-te ky-te la-te lb-te lg-te li-te lij-te lld-te ln-te lo-te lt-te ltg-te lv-te mai-te mg-te mhr-te mi-te miq-te mk-te ml-te mn-te mo-te mr-te ms-te mt-te mus-te my-te nan-te nap-te nb-te nds-te ne-te nhn-te nl-te nn-te no-te nso-te ny-te oc-te oj-te om-te or-te os-te pa-te pam-te pap-te pl-te pms-te pmy-te ps-te pt-te pt_BR-te pt_PT-te qu-te rm-te ro-te rom-te ru-te rw-te sa-te sc-te sco-te sd-te se-te shn-te shs-te si-te sk-te sl-te sm-te sml-te sn-te so-te sq-te sr-te st-te sv-te sw-te syr-te szl-te ta-te ta_LK-te ace-tet af-tet ak-tet am-tet an-tet ar-tet ary-tet as-tet ast-tet az-tet be-tet bem-tet bg-tet bn-tet bo-tet br-tet brx-tet bs-tet byn-tet ca-tet ce-tet ckb-tet co-tet crh-tet cs-tet csb-tet cv-tet cy-tet da-tet de-tet de_AT-tet de_DE-tet dsb-tet dv-tet dz-tet el-tet en-tet en_AU-tet en_CA-tet en_GB-tet eo-tet es-tet es_ES-tet es_PR-tet et-tet eu-tet fa-tet fa_AF-tet ff-tet fi-tet fil-tet fo-tet fr-tet fr_CA-tet fr_FR-tet frm-tet frp-tet fur-tet fy-tet ga-tet gd-tet gl-tet gn-tet gu-tet guc-tet gv-tet ha-tet he-tet hi-tet hil-tet hr-tet ht-tet hu-tet hy-tet ia-tet id-tet ig-tet io-tet is-tet it-tet iu-tet ja-tet jbo-tet jv-tet ka-tet kab-tet kg-tet kk-tet kl-tet km-tet kn-tet ko-tet kok-tet ku-tet kw-tet ky-tet la-tet lb-tet lg-tet li-tet lld-tet ln-tet lo-tet lt-tet ltg-tet lv-tet mai-tet mg-tet mhr-tet mi-tet miq-tet mk-tet ml-tet mn-tet mr-tet ms-tet mt-tet mus-tet my-tet nan-tet nap-tet nb-tet nds-tet ne-tet nl-tet nn-tet no-tet nso-tet oc-tet om-tet or-tet os-tet pa-tet pap-tet pl-tet pms-tet pmy-tet ps-tet pt-tet pt_BR-tet pt_PT-tet qu-tet ro-tet rom-tet ru-tet rw-tet sa-tet sc-tet sco-tet sd-tet se-tet shn-tet shs-tet si-tet sk-tet sl-tet sm-tet sml-tet sn-tet so-tet sq-tet sr-tet st-tet sv-tet sw-tet syr-tet szl-tet ta-tet ta_LK-tet te-tet ace-tg af-tg ak-tg am-tg an-tg ar-tg ary-tg as-tg ast-tg az-tg bal-tg be-tg bem-tg ber-tg bg-tg bn-tg bn_IN-tg bo-tg br-tg brx-tg bs-tg byn-tg ca-tg ce-tg ceb-tg chr-tg ckb-tg co-tg crh-tg cs-tg csb-tg cv-tg cy-tg da-tg de-tg de_AT-tg de_DE-tg dsb-tg dv-tg dz-tg el-tg en-tg en_AU-tg en_CA-tg en_GB-tg eo-tg es-tg es_CO-tg es_ES-tg es_PR-tg et-tg eu-tg fa-tg fa_AF-tg ff-tg fi-tg fil-tg fo-tg fr-tg fr_CA-tg fr_FR-tg frm-tg frp-tg fur-tg fy-tg ga-tg gd-tg gl-tg gn-tg gu-tg guc-tg gv-tg ha-tg haw-tg he-tg hi-tg hil-tg hne-tg hr-tg ht-tg hu-tg hy-tg ia-tg id-tg ig-tg io-tg is-tg it-tg iu-tg ja-tg jbo-tg jv-tg ka-tg kab-tg kg-tg kk-tg kl-tg km-tg kn-tg ko-tg kok-tg ks-tg ksh-tg ku-tg kw-tg ky-tg la-tg lb-tg lg-tg li-tg lld-tg ln-tg lo-tg lt-tg ltg-tg lv-tg mai-tg mg-tg mhr-tg mi-tg miq-tg mk-tg ml-tg mn-tg mo-tg mr-tg ms-tg mt-tg mus-tg my-tg nan-tg nap-tg nb-tg nds-tg ne-tg nhn-tg nl-tg nn-tg no-tg nso-tg ny-tg oc-tg oj-tg om-tg or-tg os-tg pa-tg pam-tg pap-tg pl-tg pms-tg pmy-tg ps-tg pt-tg pt_BR-tg pt_PT-tg qu-tg ro-tg rom-tg ru-tg rw-tg sa-tg sc-tg sco-tg sd-tg se-tg shn-tg shs-tg si-tg sk-tg sl-tg sm-tg sml-tg sn-tg so-tg sq-tg sr-tg st-tg sv-tg sw-tg syr-tg szl-tg ta-tg ta_LK-tg te-tg tet-tg ace-th af-th ak-th am-th an-th ang-th ar-th ar_SY-th ary-th as-th ast-th az-th ba-th bal-th be-th bem-th ber-th bg-th bho-th bn-th bn_IN-th bo-th br-th brx-th bs-th bua-th byn-th ca-th ce-th ceb-th chr-th ckb-th co-th crh-th cs-th csb-th cv-th cy-th da-th de-th de_AT-th de_DE-th dsb-th dv-th dz-th el-th en-th en_AU-th en_CA-th en_GB-th en_NZ-th en_US-th eo-th es-th es_AR-th es_CL-th es_CO-th es_CR-th es_DO-th es_EC-th es_ES-th es_GT-th es_HN-th es_MX-th es_NI-th es_PA-th es_PE-th es_PR-th es_SV-th es_UY-th es_VE-th et-th eu-th fa-th fa_AF-th ff-th fi-th fil-th fo-th fr-th fr_CA-th fr_FR-th frm-th frp-th fur-th fy-th ga-th gd-th gl-th gn-th gu-th guc-th gv-th ha-th haw-th he-th hi-th hil-th hne-th hr-th hsb-th ht-th hu-th hy-th ia-th id-th ig-th io-th is-th it-th iu-th ja-th jbo-th jv-th ka-th kab-th kg-th kk-th kl-th km-th kn-th ko-th kok-th ks-th ksh-th ku-th kw-th ky-th la-th lb-th lg-th li-th lij-th lld-th ln-th lo-th lt-th ltg-th lv-th mai-th mg-th mhr-th mi-th miq-th mk-th ml-th mn-th mo-th mr-th ms-th mt-th mus-th my-th nan-th nap-th nb-th nds-th ne-th nhn-th nl-th nn-th no-th nso-th ny-th oc-th oj-th om-th or-th os-th pa-th pam-th pap-th pl-th pms-th pmy-th ps-th pt-th pt_BR-th pt_PT-th qu-th rm-th ro-th rom-th ru-th rw-th sa-th sc-th sco-th sd-th se-th shn-th shs-th si-th sk-th sl-th sm-th sml-th sn-th so-th son-th sq-th sr-th st-th sv-th sw-th syr-th szl-th ta-th ta_LK-th te-th tet-th tg-th ace-ti af-ti ak-ti am-ti an-ti ar-ti as-ti ast-ti az-ti be-ti bem-ti ber-ti bg-ti bho-ti bn-ti bo-ti br-ti brx-ti bs-ti byn-ti ca-ti ce-ti ceb-ti chr-ti ckb-ti co-ti crh-ti cs-ti csb-ti cv-ti cy-ti da-ti de-ti de_AT-ti de_DE-ti dsb-ti dv-ti dz-ti el-ti en-ti en_AU-ti en_CA-ti en_GB-ti eo-ti es-ti es_CO-ti es_ES-ti es_PR-ti es_UY-ti et-ti eu-ti fa-ti fa_AF-ti ff-ti fi-ti fil-ti fo-ti fr-ti fr_CA-ti fr_FR-ti frm-ti frp-ti fur-ti fy-ti ga-ti gd-ti gl-ti gn-ti gu-ti guc-ti gv-ti ha-ti he-ti hi-ti hil-ti hr-ti ht-ti hu-ti hy-ti ia-ti id-ti ig-ti io-ti is-ti it-ti iu-ti ja-ti jbo-ti jv-ti ka-ti kab-ti kg-ti kk-ti kl-ti km-ti kn-ti ko-ti kok-ti ksh-ti ku-ti kw-ti ky-ti la-ti lb-ti lg-ti li-ti lld-ti ln-ti lo-ti lt-ti ltg-ti lv-ti mai-ti mg-ti mhr-ti mi-ti miq-ti mk-ti ml-ti mn-ti mr-ti ms-ti mt-ti mus-ti my-ti nan-ti nap-ti nb-ti nds-ti ne-ti nl-ti nn-ti no-ti nso-ti oc-ti om-ti or-ti os-ti pa-ti pap-ti pl-ti pms-ti pmy-ti ps-ti pt-ti pt_BR-ti pt_PT-ti qu-ti ro-ti rom-ti ru-ti rw-ti sa-ti sc-ti sco-ti sd-ti se-ti shn-ti shs-ti si-ti sk-ti sl-ti sm-ti sml-ti sn-ti so-ti sq-ti sr-ti st-ti sv-ti sw-ti syr-ti szl-ti ta-ti ta_LK-ti te-ti tet-ti tg-ti th-ti ace-tk af-tk ak-tk am-tk an-tk ang-tk ar-tk ary-tk as-tk ast-tk az-tk be-tk ber-tk bg-tk bn-tk bo-tk br-tk bs-tk ca-tk ceb-tk ckb-tk co-tk crh-tk cs-tk csb-tk cv-tk cy-tk da-tk de-tk de_AT-tk de_DE-tk dsb-tk dv-tk dz-tk el-tk en-tk en_AU-tk en_CA-tk en_GB-tk en_US-tk eo-tk es-tk es_ES-tk es_PR-tk et-tk eu-tk fa-tk fa_AF-tk ff-tk fi-tk fil-tk fo-tk fr-tk fr_CA-tk fr_FR-tk frp-tk fur-tk fy-tk ga-tk gd-tk gl-tk gu-tk gv-tk ha-tk he-tk hi-tk hil-tk hr-tk ht-tk hu-tk hy-tk ia-tk id-tk ig-tk io-tk is-tk it-tk ja-tk jbo-tk jv-tk ka-tk kab-tk kg-tk kk-tk kl-tk km-tk kn-tk ko-tk kok-tk ks-tk ksh-tk ku-tk kw-tk ky-tk la-tk lb-tk lg-tk li-tk lld-tk ln-tk lo-tk lt-tk ltg-tk lv-tk mai-tk mg-tk mhr-tk mi-tk miq-tk mk-tk ml-tk mn-tk mr-tk ms-tk mt-tk mus-tk my-tk nan-tk nap-tk nb-tk nds-tk ne-tk nhn-tk nl-tk nn-tk no-tk nso-tk oc-tk om-tk or-tk os-tk pa-tk pam-tk pl-tk pms-tk ps-tk pt-tk pt_BR-tk qu-tk ro-tk ru-tk rw-tk sa-tk sc-tk sco-tk sd-tk se-tk shn-tk shs-tk si-tk sk-tk sl-tk sml-tk sn-tk so-tk sq-tk sr-tk st-tk sv-tk sw-tk syr-tk szl-tk ta-tk ta_LK-tk te-tk tet-tk tg-tk th-tk ti-tk ace-tl af-tl ak-tl am-tl an-tl ang-tl ar-tl ary-tl as-tl ast-tl az-tl ba-tl bal-tl be-tl bem-tl ber-tl bg-tl bho-tl bn-tl bn_IN-tl bo-tl br-tl brx-tl bs-tl bua-tl byn-tl ca-tl ce-tl ceb-tl ckb-tl co-tl crh-tl cs-tl csb-tl cv-tl cy-tl da-tl de-tl de_AT-tl de_DE-tl dsb-tl dv-tl dz-tl el-tl en-tl en_AU-tl en_CA-tl en_GB-tl en_NZ-tl en_US-tl eo-tl es-tl es_AR-tl es_CO-tl es_ES-tl es_MX-tl es_PR-tl es_UY-tl et-tl eu-tl fa-tl fa_AF-tl ff-tl fi-tl fil-tl fo-tl fr-tl fr_CA-tl fr_FR-tl frm-tl frp-tl fur-tl fy-tl ga-tl gd-tl gl-tl gn-tl gu-tl guc-tl gv-tl ha-tl he-tl hi-tl hil-tl hne-tl hr-tl ht-tl hu-tl hy-tl ia-tl id-tl ig-tl io-tl is-tl it-tl iu-tl ja-tl jbo-tl jv-tl ka-tl kab-tl kg-tl kk-tl kl-tl km-tl kn-tl ko-tl kok-tl ks-tl ku-tl kw-tl ky-tl la-tl lb-tl lg-tl li-tl lij-tl lld-tl ln-tl lo-tl lt-tl ltg-tl lv-tl mai-tl mg-tl mhr-tl mi-tl miq-tl mk-tl ml-tl mn-tl mr-tl ms-tl mt-tl mus-tl my-tl nan-tl nap-tl nb-tl nds-tl ne-tl nl-tl nl_NL-tl nn-tl no-tl nso-tl oc-tl om-tl or-tl os-tl pa-tl pam-tl pap-tl pl-tl pms-tl pmy-tl ps-tl pt-tl pt_BR-tl pt_PT-tl qu-tl rm-tl ro-tl rom-tl ru-tl rw-tl sa-tl sc-tl sco-tl sd-tl se-tl shn-tl shs-tl si-tl sk-tl sl-tl sm-tl sml-tl sn-tl so-tl sq-tl sr-tl st-tl sv-tl sw-tl syr-tl szl-tl ta-tl ta_LK-tl te-tl tet-tl tg-tl th-tl ti-tl tk-tl ace-tlh af-tlh ak-tlh am-tlh an-tlh ar-tlh as-tlh ast-tlh az-tlh be-tlh bem-tlh bg-tlh bn-tlh bo-tlh br-tlh brx-tlh bs-tlh byn-tlh ca-tlh ce-tlh ckb-tlh co-tlh crh-tlh cs-tlh csb-tlh cv-tlh cy-tlh da-tlh de-tlh de_AT-tlh de_DE-tlh dsb-tlh dv-tlh dz-tlh el-tlh en-tlh en_AU-tlh en_CA-tlh en_GB-tlh eo-tlh es-tlh es_ES-tlh es_PR-tlh et-tlh eu-tlh fa-tlh fa_AF-tlh ff-tlh fi-tlh fil-tlh fo-tlh fr-tlh fr_CA-tlh fr_FR-tlh frm-tlh frp-tlh fur-tlh fy-tlh ga-tlh gd-tlh gl-tlh gn-tlh gu-tlh guc-tlh gv-tlh ha-tlh he-tlh hi-tlh hr-tlh ht-tlh hu-tlh hy-tlh ia-tlh id-tlh ig-tlh io-tlh is-tlh it-tlh iu-tlh ja-tlh jbo-tlh jv-tlh ka-tlh kab-tlh kg-tlh kk-tlh kl-tlh km-tlh kn-tlh ko-tlh ku-tlh kw-tlh ky-tlh la-tlh lb-tlh lg-tlh li-tlh lld-tlh ln-tlh lo-tlh lt-tlh ltg-tlh lv-tlh mai-tlh mg-tlh mhr-tlh mi-tlh miq-tlh mk-tlh ml-tlh mn-tlh mr-tlh ms-tlh mt-tlh mus-tlh my-tlh nan-tlh nb-tlh nds-tlh ne-tlh nl-tlh nn-tlh no-tlh nso-tlh oc-tlh om-tlh or-tlh os-tlh pa-tlh pap-tlh pl-tlh pmy-tlh ps-tlh pt-tlh pt_BR-tlh pt_PT-tlh qu-tlh ro-tlh rom-tlh ru-tlh rw-tlh sa-tlh sc-tlh sco-tlh sd-tlh se-tlh shn-tlh shs-tlh si-tlh sk-tlh sl-tlh sm-tlh sml-tlh sn-tlh so-tlh sq-tlh sr-tlh st-tlh sv-tlh sw-tlh syr-tlh szl-tlh ta-tlh ta_LK-tlh te-tlh tet-tlh tg-tlh th-tlh ti-tlh tl-tlh ace-tr af-tr ak-tr am-tr an-tr ang-tr ar-tr ar_SY-tr ary-tr as-tr ast-tr az-tr ba-tr bal-tr be-tr bem-tr ber-tr bg-tr bho-tr bn-tr bn_IN-tr bo-tr br-tr brx-tr bs-tr bua-tr byn-tr ca-tr ce-tr ceb-tr chr-tr ckb-tr co-tr crh-tr cs-tr csb-tr cv-tr cy-tr da-tr de-tr de_AT-tr de_DE-tr dsb-tr dv-tr dz-tr el-tr en-tr en_AU-tr en_CA-tr en_GB-tr en_NZ-tr en_US-tr eo-tr es-tr es_AR-tr es_CL-tr es_CO-tr es_CR-tr es_DO-tr es_EC-tr es_ES-tr es_GT-tr es_HN-tr es_MX-tr es_NI-tr es_PA-tr es_PE-tr es_PR-tr es_SV-tr es_UY-tr es_VE-tr et-tr eu-tr fa-tr fa_AF-tr ff-tr fi-tr fil-tr fo-tr fr-tr fr_CA-tr fr_FR-tr frm-tr frp-tr fur-tr fy-tr ga-tr gd-tr gl-tr gn-tr grc-tr gu-tr guc-tr gv-tr ha-tr haw-tr he-tr hi-tr hil-tr hne-tr hr-tr hsb-tr ht-tr hu-tr hy-tr ia-tr id-tr ig-tr io-tr is-tr it-tr iu-tr ja-tr jbo-tr jv-tr ka-tr kab-tr kg-tr kk-tr kl-tr km-tr kn-tr ko-tr kok-tr ks-tr ksh-tr ku-tr kw-tr ky-tr la-tr lb-tr lg-tr li-tr lij-tr lld-tr ln-tr lo-tr lt-tr ltg-tr lv-tr mai-tr mg-tr mh-tr mhr-tr mi-tr miq-tr mk-tr ml-tr mn-tr mo-tr mr-tr ms-tr mt-tr mus-tr my-tr nan-tr nap-tr nb-tr nds-tr ne-tr nhn-tr nl-tr nl_NL-tr nn-tr no-tr nso-tr ny-tr oc-tr oj-tr om-tr or-tr os-tr pa-tr pam-tr pap-tr pl-tr pms-tr pmy-tr ps-tr pt-tr pt_BR-tr pt_PT-tr qu-tr rm-tr ro-tr rom-tr ru-tr rw-tr sa-tr sc-tr sco-tr sd-tr se-tr shn-tr shs-tr si-tr sk-tr sl-tr sm-tr sml-tr sn-tr so-tr son-tr sq-tr sr-tr st-tr sv-tr sw-tr syr-tr szl-tr ta-tr ta_LK-tr te-tr tet-tr tg-tr th-tr ti-tr tk-tr tl-tr tlh-tr ace-trv af-trv ak-trv am-trv an-trv ar-trv ary-trv as-trv ast-trv az-trv be-trv bg-trv bn-trv bo-trv br-trv bs-trv ca-trv ckb-trv co-trv crh-trv cs-trv csb-trv cv-trv cy-trv da-trv de-trv de_AT-trv de_DE-trv dsb-trv dv-trv dz-trv el-trv en-trv en_AU-trv en_CA-trv en_GB-trv eo-trv es-trv es_ES-trv es_PR-trv et-trv eu-trv fa-trv fa_AF-trv fi-trv fil-trv fo-trv fr-trv fr_CA-trv fr_FR-trv frp-trv fur-trv fy-trv ga-trv gd-trv gl-trv gu-trv gv-trv he-trv hi-trv hil-trv hr-trv ht-trv hu-trv hy-trv id-trv ig-trv is-trv it-trv ja-trv jv-trv ka-trv kab-trv kk-trv km-trv kn-trv ko-trv kok-trv ku-trv kw-trv ky-trv la-trv lb-trv lg-trv li-trv ln-trv lo-trv lt-trv lv-trv mai-trv mg-trv mhr-trv mi-trv mk-trv ml-trv mn-trv mr-trv ms-trv mt-trv mus-trv my-trv nan-trv nap-trv nb-trv nds-trv ne-trv nl-trv nn-trv no-trv nso-trv oc-trv om-trv or-trv os-trv pa-trv pam-trv pl-trv pms-trv ps-trv pt-trv pt_BR-trv qu-trv ro-trv ru-trv rw-trv sa-trv sc-trv sco-trv sd-trv se-trv shn-trv shs-trv si-trv sk-trv sl-trv sn-trv so-trv sq-trv sr-trv st-trv sv-trv sw-trv syr-trv szl-trv ta-trv te-trv tet-trv tg-trv th-trv ti-trv tk-trv tl-trv tr-trv ace-ts af-ts ak-ts am-ts an-ts ar-ts ary-ts as-ts ast-ts az-ts be-ts bem-ts ber-ts bg-ts bn-ts bo-ts br-ts brx-ts bs-ts byn-ts ca-ts ce-ts ckb-ts co-ts crh-ts cs-ts csb-ts cv-ts cy-ts da-ts de-ts de_AT-ts de_DE-ts dsb-ts dv-ts dz-ts el-ts en-ts en_AU-ts en_CA-ts en_GB-ts eo-ts es-ts es_CO-ts es_ES-ts es_PR-ts et-ts eu-ts fa-ts fa_AF-ts ff-ts fi-ts fil-ts fo-ts fr-ts fr_CA-ts fr_FR-ts frm-ts frp-ts fur-ts fy-ts ga-ts gd-ts gl-ts gn-ts gu-ts guc-ts gv-ts ha-ts he-ts hi-ts hil-ts hr-ts ht-ts hu-ts hy-ts ia-ts id-ts ig-ts io-ts is-ts it-ts iu-ts ja-ts jbo-ts jv-ts ka-ts kab-ts kg-ts kk-ts kl-ts km-ts kn-ts ko-ts kok-ts ks-ts ku-ts kw-ts ky-ts la-ts lb-ts lg-ts li-ts lld-ts ln-ts lo-ts lt-ts ltg-ts lv-ts mai-ts mg-ts mhr-ts mi-ts miq-ts mk-ts ml-ts mn-ts mr-ts ms-ts mt-ts mus-ts my-ts nan-ts nap-ts nb-ts nds-ts ne-ts nl-ts nn-ts no-ts nso-ts oc-ts om-ts or-ts os-ts pa-ts pap-ts pl-ts pms-ts pmy-ts ps-ts pt-ts pt_BR-ts pt_PT-ts qu-ts ro-ts rom-ts ru-ts rw-ts sa-ts sc-ts sco-ts sd-ts se-ts shn-ts shs-ts si-ts sk-ts sl-ts sm-ts sml-ts sn-ts so-ts sq-ts sr-ts st-ts sv-ts sw-ts syr-ts szl-ts ta-ts ta_LK-ts te-ts tet-ts tg-ts th-ts ti-ts tk-ts tl-ts tlh-ts tr-ts trv-ts ace-tt af-tt ak-tt am-tt an-tt ang-tt ar-tt ary-tt as-tt ast-tt az-tt be-tt bem-tt ber-tt bg-tt bn-tt bn_IN-tt bo-tt br-tt brx-tt bs-tt byn-tt ca-tt ce-tt ceb-tt ckb-tt co-tt crh-tt cs-tt csb-tt cv-tt cy-tt da-tt de-tt de_AT-tt de_DE-tt dsb-tt dv-tt dz-tt el-tt en-tt en_AU-tt en_CA-tt en_GB-tt en_US-tt eo-tt es-tt es_CO-tt es_ES-tt es_PR-tt et-tt eu-tt fa-tt fa_AF-tt ff-tt fi-tt fil-tt fo-tt fr-tt fr_CA-tt fr_FR-tt frm-tt frp-tt fur-tt fy-tt ga-tt gd-tt gl-tt gn-tt gu-tt guc-tt gv-tt ha-tt haw-tt he-tt hi-tt hil-tt hr-tt ht-tt hu-tt hy-tt ia-tt id-tt ig-tt io-tt is-tt it-tt iu-tt ja-tt jbo-tt jv-tt ka-tt kab-tt kg-tt kk-tt kl-tt km-tt kn-tt ko-tt kok-tt ks-tt ksh-tt ku-tt kw-tt ky-tt la-tt lb-tt lg-tt li-tt lij-tt lld-tt ln-tt lo-tt lt-tt ltg-tt lv-tt mai-tt mg-tt mhr-tt mi-tt miq-tt mk-tt ml-tt mn-tt mr-tt ms-tt mt-tt mus-tt my-tt nan-tt nap-tt nb-tt nds-tt ne-tt nhn-tt nl-tt nn-tt no-tt nso-tt ny-tt oc-tt om-tt or-tt os-tt pa-tt pam-tt pap-tt pl-tt pms-tt pmy-tt ps-tt pt-tt pt_BR-tt pt_PT-tt qu-tt ro-tt rom-tt ru-tt rw-tt sa-tt sc-tt sco-tt sd-tt se-tt shn-tt shs-tt si-tt sk-tt sl-tt sm-tt sml-tt sn-tt so-tt sq-tt sr-tt st-tt sv-tt sw-tt syr-tt szl-tt ta-tt ta_LK-tt te-tt tet-tt tg-tt th-tt ti-tt tk-tt tl-tt tlh-tt tr-tt trv-tt ts-tt ace-ug af-ug ak-ug am-ug an-ug ang-ug ar-ug ar_SY-ug ary-ug as-ug ast-ug az-ug ba-ug bal-ug be-ug bem-ug ber-ug bg-ug bho-ug bn-ug bn_IN-ug bo-ug br-ug brx-ug bs-ug bua-ug byn-ug ca-ug ce-ug ceb-ug chr-ug ckb-ug co-ug crh-ug cs-ug csb-ug cv-ug cy-ug da-ug de-ug de_AT-ug de_DE-ug dsb-ug dv-ug dz-ug el-ug en-ug en_AU-ug en_CA-ug en_GB-ug en_NZ-ug en_US-ug eo-ug es-ug es_AR-ug es_CL-ug es_CO-ug es_CR-ug es_DO-ug es_EC-ug es_ES-ug es_GT-ug es_HN-ug es_MX-ug es_NI-ug es_PA-ug es_PE-ug es_PR-ug es_SV-ug es_UY-ug es_VE-ug et-ug eu-ug fa-ug fa_AF-ug ff-ug fi-ug fil-ug fo-ug fr-ug fr_CA-ug fr_FR-ug frm-ug frp-ug fur-ug fy-ug ga-ug gd-ug gl-ug gn-ug grc-ug gu-ug guc-ug gv-ug ha-ug haw-ug he-ug hi-ug hil-ug hne-ug hr-ug hsb-ug ht-ug hu-ug hy-ug ia-ug id-ug ig-ug io-ug is-ug it-ug iu-ug ja-ug jbo-ug jv-ug ka-ug kab-ug kg-ug kk-ug kl-ug km-ug kn-ug ko-ug kok-ug ks-ug ksh-ug ku-ug kw-ug ky-ug la-ug lb-ug lg-ug li-ug lij-ug lld-ug ln-ug lo-ug lt-ug ltg-ug lv-ug mai-ug mg-ug mh-ug mhr-ug mi-ug miq-ug mk-ug ml-ug mn-ug mo-ug mr-ug ms-ug mt-ug mus-ug my-ug nan-ug nap-ug nb-ug nds-ug ne-ug nhn-ug nl-ug nl_NL-ug nn-ug no-ug nso-ug ny-ug oc-ug oj-ug om-ug or-ug os-ug pa-ug pam-ug pap-ug pl-ug pms-ug pmy-ug ps-ug pt-ug pt_BR-ug pt_PT-ug qu-ug rm-ug ro-ug rom-ug ru-ug rw-ug sa-ug sc-ug sco-ug sd-ug se-ug shn-ug shs-ug si-ug sk-ug sl-ug sm-ug sml-ug sn-ug so-ug son-ug sq-ug sr-ug st-ug sv-ug sw-ug syr-ug szl-ug ta-ug ta_LK-ug te-ug tet-ug tg-ug th-ug ti-ug tk-ug tl-ug tlh-ug tr-ug trv-ug ts-ug tt-ug ace-uk af-uk ak-uk am-uk an-uk ang-uk ar-uk ar_SY-uk ary-uk as-uk ast-uk az-uk ba-uk bal-uk be-uk bem-uk ber-uk bg-uk bho-uk bn-uk bn_IN-uk bo-uk br-uk brx-uk bs-uk bua-uk byn-uk ca-uk ce-uk ceb-uk chr-uk ckb-uk co-uk crh-uk cs-uk csb-uk cv-uk cy-uk da-uk de-uk de_AT-uk de_DE-uk dsb-uk dv-uk dz-uk el-uk en-uk en_AU-uk en_CA-uk en_GB-uk en_NZ-uk en_US-uk eo-uk es-uk es_AR-uk es_CL-uk es_CO-uk es_CR-uk es_DO-uk es_EC-uk es_ES-uk es_GT-uk es_HN-uk es_MX-uk es_NI-uk es_PA-uk es_PE-uk es_PR-uk es_SV-uk es_UY-uk es_VE-uk et-uk eu-uk fa-uk fa_AF-uk ff-uk fi-uk fil-uk fo-uk fr-uk fr_CA-uk fr_FR-uk frm-uk frp-uk fur-uk fy-uk ga-uk gd-uk gl-uk gn-uk grc-uk gu-uk guc-uk gv-uk ha-uk haw-uk he-uk hi-uk hil-uk hne-uk hr-uk hsb-uk ht-uk hu-uk hy-uk ia-uk id-uk ig-uk io-uk is-uk it-uk iu-uk ja-uk jbo-uk jv-uk ka-uk kab-uk kg-uk kk-uk kl-uk km-uk kn-uk ko-uk kok-uk ks-uk ksh-uk ku-uk kw-uk ky-uk la-uk lb-uk lg-uk li-uk lij-uk lld-uk ln-uk lo-uk lt-uk ltg-uk lv-uk mai-uk mg-uk mh-uk mhr-uk mi-uk miq-uk mk-uk ml-uk mn-uk mo-uk mr-uk ms-uk mt-uk mus-uk my-uk nan-uk nap-uk nb-uk nds-uk ne-uk nhn-uk nl-uk nl_NL-uk nn-uk no-uk nso-uk ny-uk oc-uk oj-uk om-uk or-uk os-uk pa-uk pam-uk pap-uk pl-uk pms-uk pmy-uk ps-uk pt-uk pt_BR-uk pt_PT-uk qu-uk rm-uk ro-uk rom-uk ru-uk rw-uk sa-uk sc-uk sco-uk sd-uk se-uk shn-uk shs-uk si-uk sk-uk sl-uk sm-uk sml-uk sn-uk so-uk son-uk sq-uk sr-uk st-uk sv-uk sw-uk syr-uk szl-uk ta-uk ta_LK-uk te-uk tet-uk tg-uk th-uk ti-uk tk-uk tl-uk tlh-uk tr-uk trv-uk ts-uk tt-uk ug-uk ace-ur af-ur ak-ur am-ur an-ur ang-ur ar-ur ary-ur as-ur ast-ur az-ur ba-ur bal-ur be-ur bem-ur ber-ur bg-ur bho-ur bn-ur bn_IN-ur bo-ur br-ur brx-ur bs-ur bua-ur byn-ur ca-ur ce-ur ceb-ur chr-ur ckb-ur co-ur crh-ur cs-ur csb-ur cv-ur cy-ur da-ur de-ur de_AT-ur de_DE-ur dsb-ur dv-ur dz-ur el-ur en-ur en_AU-ur en_CA-ur en_GB-ur en_NZ-ur en_US-ur eo-ur es-ur es_CO-ur es_ES-ur es_PR-ur es_UY-ur et-ur eu-ur fa-ur fa_AF-ur ff-ur fi-ur fil-ur fo-ur fr-ur fr_CA-ur fr_FR-ur frm-ur frp-ur fur-ur fy-ur ga-ur gd-ur gl-ur gn-ur gu-ur guc-ur gv-ur ha-ur he-ur hi-ur hil-ur hne-ur hr-ur ht-ur hu-ur hy-ur ia-ur id-ur ig-ur io-ur is-ur it-ur iu-ur ja-ur jbo-ur jv-ur ka-ur kab-ur kg-ur kk-ur kl-ur km-ur kn-ur ko-ur kok-ur ks-ur ksh-ur ku-ur kw-ur ky-ur la-ur lb-ur lg-ur li-ur lij-ur lld-ur ln-ur lo-ur lt-ur ltg-ur lv-ur mai-ur mg-ur mhr-ur mi-ur miq-ur mk-ur ml-ur mn-ur mr-ur ms-ur mt-ur mus-ur my-ur nan-ur nap-ur nb-ur nds-ur ne-ur nhn-ur nl-ur nn-ur no-ur nso-ur ny-ur oc-ur oj-ur om-ur or-ur os-ur pa-ur pam-ur pap-ur pl-ur pms-ur pmy-ur ps-ur pt-ur pt_BR-ur pt_PT-ur qu-ur rm-ur ro-ur rom-ur ru-ur rw-ur sa-ur sc-ur sco-ur sd-ur se-ur shn-ur shs-ur si-ur sk-ur sl-ur sm-ur sml-ur sn-ur so-ur sq-ur sr-ur st-ur sv-ur sw-ur syr-ur szl-ur ta-ur ta_LK-ur te-ur tet-ur tg-ur th-ur ti-ur tk-ur tl-ur tlh-ur tr-ur trv-ur ts-ur tt-ur ug-ur uk-ur ace-uz af-uz ak-uz am-uz an-uz ang-uz ar-uz ary-uz as-uz ast-uz az-uz ba-uz be-uz bem-uz ber-uz bg-uz bho-uz bn-uz bn_IN-uz bo-uz br-uz brx-uz bs-uz bua-uz byn-uz ca-uz ce-uz ceb-uz chr-uz ckb-uz co-uz crh-uz cs-uz csb-uz cv-uz cy-uz da-uz de-uz de_AT-uz de_DE-uz dsb-uz dv-uz dz-uz el-uz en-uz en_AU-uz en_CA-uz en_GB-uz en_NZ-uz en_US-uz eo-uz es-uz es_CO-uz es_ES-uz es_PR-uz es_UY-uz et-uz eu-uz fa-uz fa_AF-uz ff-uz fi-uz fil-uz fo-uz fr-uz fr_CA-uz fr_FR-uz frm-uz frp-uz fur-uz fy-uz ga-uz gd-uz gl-uz gn-uz gu-uz guc-uz gv-uz ha-uz haw-uz he-uz hi-uz hil-uz hne-uz hr-uz ht-uz hu-uz hy-uz ia-uz id-uz ig-uz io-uz is-uz it-uz iu-uz ja-uz jbo-uz jv-uz ka-uz kab-uz kg-uz kk-uz kl-uz km-uz kn-uz ko-uz kok-uz ks-uz ksh-uz ku-uz kw-uz ky-uz la-uz lb-uz lg-uz li-uz lij-uz lld-uz ln-uz lo-uz lt-uz ltg-uz lv-uz mai-uz mg-uz mhr-uz mi-uz miq-uz mk-uz ml-uz mn-uz mo-uz mr-uz ms-uz mt-uz mus-uz my-uz nan-uz nap-uz nb-uz nds-uz ne-uz nhn-uz nl-uz nn-uz no-uz nso-uz ny-uz oc-uz om-uz or-uz os-uz pa-uz pam-uz pap-uz pl-uz pms-uz pmy-uz ps-uz pt-uz pt_BR-uz pt_PT-uz qu-uz rm-uz ro-uz rom-uz ru-uz rw-uz sa-uz sc-uz sco-uz sd-uz se-uz shn-uz shs-uz si-uz sk-uz sl-uz sm-uz sml-uz sn-uz so-uz sq-uz sr-uz st-uz sv-uz sw-uz syr-uz szl-uz ta-uz ta_LK-uz te-uz tet-uz tg-uz th-uz ti-uz tk-uz tl-uz tlh-uz tr-uz trv-uz ts-uz tt-uz ug-uz uk-uz ur-uz ace-ve af-ve ak-ve am-ve an-ve ar-ve as-ve ast-ve az-ve be-ve bg-ve bn-ve bo-ve br-ve bs-ve ca-ve ce-ve ckb-ve co-ve crh-ve cs-ve csb-ve cy-ve da-ve de-ve de_AT-ve de_DE-ve dsb-ve dv-ve dz-ve el-ve en-ve en_AU-ve en_CA-ve en_GB-ve eo-ve es-ve es_ES-ve es_PR-ve et-ve eu-ve fa-ve fa_AF-ve fi-ve fil-ve fo-ve fr-ve fr_CA-ve fr_FR-ve frm-ve frp-ve fur-ve fy-ve ga-ve gd-ve gl-ve gn-ve gu-ve gv-ve ha-ve he-ve hi-ve hr-ve ht-ve hu-ve hy-ve ia-ve id-ve ig-ve io-ve is-ve it-ve ja-ve jbo-ve jv-ve ka-ve kab-ve kg-ve kk-ve kl-ve km-ve kn-ve ko-ve ku-ve kw-ve ky-ve la-ve lb-ve lg-ve li-ve ln-ve lo-ve lt-ve lv-ve mai-ve mg-ve mhr-ve mi-ve mk-ve ml-ve mn-ve mr-ve ms-ve mt-ve mus-ve my-ve nan-ve nb-ve nds-ve ne-ve nl-ve nn-ve no-ve nso-ve oc-ve om-ve or-ve pa-ve pap-ve pl-ve ps-ve pt-ve pt_BR-ve pt_PT-ve qu-ve ro-ve rom-ve ru-ve rw-ve sa-ve sc-ve sco-ve sd-ve se-ve shn-ve shs-ve si-ve sk-ve sl-ve sm-ve sn-ve sq-ve sr-ve st-ve sv-ve sw-ve syr-ve szl-ve ta-ve ta_LK-ve te-ve tet-ve tg-ve th-ve ti-ve tl-ve tlh-ve tr-ve ts-ve tt-ve ug-ve uk-ve ur-ve uz-ve ace-vec af-vec ak-vec am-vec an-vec ar-vec ary-vec as-vec ast-vec az-vec be-vec bem-vec ber-vec bg-vec bho-vec bn-vec bo-vec br-vec brx-vec bs-vec byn-vec ca-vec ce-vec ceb-vec ckb-vec crh-vec cs-vec csb-vec cv-vec cy-vec da-vec de-vec dv-vec dz-vec el-vec en-vec en_AU-vec en_CA-vec en_GB-vec eo-vec es-vec es_CO-vec es_UY-vec et-vec eu-vec fa-vec fa_AF-vec ff-vec fi-vec fil-vec fo-vec fr-vec fr_CA-vec frp-vec fur-vec fy-vec ga-vec gd-vec gl-vec gn-vec gu-vec guc-vec gv-vec ha-vec he-vec hi-vec hil-vec hr-vec ht-vec hu-vec hy-vec id-vec ig-vec io-vec is-vec it-vec iu-vec ja-vec jbo-vec jv-vec ka-vec kab-vec kk-vec kl-vec km-vec kn-vec ko-vec ksh-vec ku-vec kw-vec ky-vec la-vec lb-vec li-vec lij-vec lld-vec ln-vec lo-vec lt-vec ltg-vec lv-vec mai-vec mg-vec mhr-vec mi-vec miq-vec mk-vec ml-vec mn-vec mr-vec ms-vec mt-vec mus-vec my-vec nan-vec nap-vec nb-vec nds-vec ne-vec nl-vec nn-vec no-vec nso-vec ny-vec oc-vec om-vec or-vec os-vec pa-vec pam-vec pap-vec pl-vec pms-vec pmy-vec ps-vec pt-vec pt_BR-vec pt_PT-vec ro-vec ru-vec rw-vec sa-vec sc-vec sco-vec sd-vec se-vec shn-vec si-vec sk-vec sl-vec sml-vec sn-vec so-vec sq-vec sr-vec sv-vec sw-vec szl-vec ta-vec ta_LK-vec te-vec tet-vec tg-vec th-vec ti-vec tk-vec tl-vec tlh-vec tr-vec trv-vec ts-vec tt-vec ug-vec uk-vec ur-vec uz-vec ace-vi af-vi ak-vi am-vi an-vi ang-vi ar-vi ar_SY-vi ary-vi as-vi ast-vi az-vi ba-vi bal-vi be-vi bem-vi ber-vi bg-vi bho-vi bn-vi bn_IN-vi bo-vi br-vi brx-vi bs-vi bua-vi byn-vi ca-vi ce-vi ceb-vi chr-vi ckb-vi co-vi crh-vi cs-vi csb-vi cv-vi cy-vi da-vi de-vi de_AT-vi de_DE-vi dsb-vi dv-vi dz-vi el-vi en-vi en_AU-vi en_CA-vi en_GB-vi en_NZ-vi en_US-vi eo-vi es-vi es_AR-vi es_CL-vi es_CO-vi es_CR-vi es_DO-vi es_EC-vi es_ES-vi es_GT-vi es_HN-vi es_MX-vi es_NI-vi es_PA-vi es_PE-vi es_PR-vi es_SV-vi es_UY-vi es_VE-vi et-vi eu-vi fa-vi fa_AF-vi ff-vi fi-vi fil-vi fo-vi fr-vi fr_CA-vi fr_FR-vi frm-vi frp-vi fur-vi fy-vi ga-vi gd-vi gl-vi gn-vi grc-vi gu-vi guc-vi gv-vi ha-vi haw-vi he-vi hi-vi hil-vi hne-vi hr-vi ht-vi hu-vi hy-vi ia-vi id-vi ig-vi io-vi is-vi it-vi iu-vi ja-vi jbo-vi jv-vi ka-vi kab-vi kg-vi kk-vi kl-vi km-vi kn-vi ko-vi kok-vi ks-vi ksh-vi ku-vi kw-vi ky-vi la-vi lb-vi lg-vi li-vi lij-vi lld-vi ln-vi lo-vi lt-vi ltg-vi lv-vi mai-vi mg-vi mhr-vi mi-vi miq-vi mk-vi ml-vi mn-vi mo-vi mr-vi ms-vi mt-vi mus-vi my-vi nan-vi nap-vi nb-vi nds-vi ne-vi nhn-vi nl-vi nl_NL-vi nn-vi no-vi nso-vi ny-vi oc-vi oj-vi om-vi or-vi os-vi pa-vi pam-vi pap-vi pl-vi pms-vi pmy-vi ps-vi pt-vi pt_BR-vi pt_PT-vi qu-vi rm-vi ro-vi rom-vi ru-vi rw-vi sa-vi sc-vi sco-vi sd-vi se-vi shn-vi shs-vi si-vi sk-vi sl-vi sm-vi sml-vi sn-vi so-vi son-vi sq-vi sr-vi st-vi sv-vi sw-vi syr-vi szl-vi ta-vi ta_LK-vi te-vi tet-vi tg-vi th-vi ti-vi tk-vi tl-vi tlh-vi tr-vi trv-vi ts-vi tt-vi ug-vi uk-vi ur-vi uz-vi ve-vi vec-vi ace-wa af-wa ak-wa am-wa an-wa ang-wa ar-wa as-wa ast-wa az-wa be-wa ber-wa bg-wa bho-wa bn-wa bn_IN-wa bo-wa br-wa bs-wa ca-wa ce-wa ceb-wa chr-wa ckb-wa co-wa crh-wa cs-wa csb-wa cv-wa cy-wa da-wa de-wa de_AT-wa de_DE-wa dsb-wa dv-wa dz-wa el-wa en-wa en_AU-wa en_CA-wa en_GB-wa en_US-wa eo-wa es-wa es_AR-wa es_CL-wa es_CO-wa es_CR-wa es_DO-wa es_EC-wa es_ES-wa es_GT-wa es_HN-wa es_MX-wa es_NI-wa es_PA-wa es_PE-wa es_PR-wa es_SV-wa es_UY-wa es_VE-wa et-wa eu-wa fa-wa fa_AF-wa ff-wa fi-wa fil-wa fo-wa fr-wa fr_CA-wa fr_FR-wa frm-wa frp-wa fur-wa fy-wa ga-wa gd-wa gl-wa gn-wa gu-wa gv-wa ha-wa haw-wa he-wa hi-wa hil-wa hr-wa ht-wa hu-wa hy-wa ia-wa id-wa ig-wa io-wa is-wa it-wa ja-wa jbo-wa jv-wa ka-wa kab-wa kg-wa kk-wa kl-wa km-wa kn-wa ko-wa kok-wa ks-wa ksh-wa ku-wa kw-wa ky-wa la-wa lb-wa lg-wa li-wa lld-wa ln-wa lo-wa lt-wa ltg-wa lv-wa mai-wa mg-wa mhr-wa mi-wa miq-wa mk-wa ml-wa mn-wa mo-wa mr-wa ms-wa mt-wa mus-wa my-wa nan-wa nap-wa nb-wa nds-wa ne-wa nl-wa nn-wa no-wa nso-wa oc-wa om-wa or-wa os-wa pa-wa pap-wa pl-wa pms-wa ps-wa pt-wa pt_BR-wa pt_PT-wa qu-wa rm-wa ro-wa rom-wa ru-wa rw-wa sa-wa sc-wa sco-wa sd-wa se-wa shn-wa shs-wa si-wa sk-wa sl-wa sm-wa sml-wa sn-wa so-wa son-wa sq-wa sr-wa st-wa sv-wa sw-wa syr-wa szl-wa ta-wa ta_LK-wa te-wa tet-wa tg-wa th-wa ti-wa tk-wa tl-wa tlh-wa tr-wa trv-wa ts-wa tt-wa ug-wa uk-wa ur-wa uz-wa ve-wa vec-wa vi-wa ace-wae af-wae am-wae an-wae ang-wae ar-wae ary-wae as-wae ast-wae az-wae be-wae bem-wae ber-wae bg-wae bn-wae bo-wae br-wae brx-wae bs-wae byn-wae ca-wae ce-wae ceb-wae ckb-wae crh-wae cs-wae csb-wae cv-wae cy-wae da-wae de-wae de_DE-wae dv-wae dz-wae el-wae en-wae en_AU-wae en_CA-wae en_GB-wae eo-wae es-wae es_CO-wae et-wae eu-wae fa-wae ff-wae fi-wae fil-wae fo-wae fr-wae fr_CA-wae fr_FR-wae frp-wae fur-wae fy-wae ga-wae gd-wae gl-wae gn-wae gu-wae guc-wae gv-wae ha-wae he-wae hi-wae hr-wae ht-wae hu-wae hy-wae ia-wae id-wae ig-wae io-wae is-wae it-wae iu-wae ja-wae jbo-wae jv-wae ka-wae kab-wae kg-wae kk-wae kl-wae km-wae kn-wae ko-wae ksh-wae ku-wae kw-wae ky-wae la-wae lb-wae lg-wae li-wae lld-wae ln-wae lo-wae lt-wae ltg-wae lv-wae mai-wae mg-wae mhr-wae mi-wae miq-wae mk-wae ml-wae mn-wae mr-wae ms-wae mt-wae mus-wae my-wae nan-wae nb-wae nds-wae ne-wae nl-wae nn-wae no-wae nso-wae oc-wae om-wae or-wae os-wae pa-wae pap-wae pl-wae pms-wae pmy-wae ps-wae pt-wae pt_BR-wae pt_PT-wae qu-wae ro-wae ru-wae rw-wae sa-wae sc-wae sco-wae sd-wae se-wae shn-wae shs-wae si-wae sk-wae sl-wae sml-wae sn-wae so-wae sq-wae sr-wae sv-wae sw-wae szl-wae ta-wae ta_LK-wae te-wae tet-wae tg-wae th-wae ti-wae tk-wae tl-wae tlh-wae tr-wae ts-wae tt-wae ug-wae uk-wae ur-wae uz-wae vec-wae vi-wae wa-wae ace-wo af-wo ak-wo am-wo an-wo ar-wo as-wo ast-wo az-wo bal-wo be-wo bg-wo bn-wo bo-wo br-wo bs-wo ca-wo ce-wo ckb-wo co-wo crh-wo cs-wo csb-wo cv-wo cy-wo da-wo de-wo de_AT-wo de_DE-wo dsb-wo dv-wo dz-wo el-wo en-wo en_AU-wo en_CA-wo en_GB-wo eo-wo es-wo es_ES-wo es_PR-wo et-wo eu-wo fa-wo fa_AF-wo fi-wo fil-wo fo-wo fr-wo fr_CA-wo fr_FR-wo frm-wo frp-wo fur-wo fy-wo ga-wo gd-wo gl-wo gn-wo gu-wo gv-wo ha-wo he-wo hi-wo hil-wo hr-wo ht-wo hu-wo hy-wo ia-wo id-wo ig-wo io-wo is-wo it-wo ja-wo jbo-wo jv-wo ka-wo kab-wo kg-wo kk-wo kl-wo km-wo kn-wo ko-wo kok-wo ku-wo kw-wo ky-wo la-wo lb-wo lg-wo li-wo lij-wo ln-wo lo-wo lt-wo lv-wo mai-wo mg-wo mhr-wo mi-wo mk-wo ml-wo mn-wo mr-wo ms-wo mt-wo mus-wo my-wo nan-wo nap-wo nb-wo nds-wo ne-wo nl-wo nn-wo no-wo nso-wo oc-wo om-wo or-wo pa-wo pap-wo pl-wo pms-wo ps-wo pt-wo pt_BR-wo pt_PT-wo qu-wo ro-wo rom-wo ru-wo rw-wo sa-wo sc-wo sco-wo sd-wo se-wo shn-wo shs-wo si-wo sk-wo sl-wo sm-wo sn-wo so-wo sq-wo sr-wo st-wo sv-wo sw-wo syr-wo szl-wo ta-wo ta_LK-wo te-wo tet-wo tg-wo th-wo ti-wo tk-wo tl-wo tlh-wo tr-wo trv-wo ts-wo tt-wo ug-wo uk-wo ur-wo uz-wo ve-wo vec-wo vi-wo wa-wo ace-xal af-xal ak-xal am-xal an-xal ar-xal as-xal ast-xal az-xal be-xal bg-xal bn-xal bo-xal br-xal bs-xal ca-xal ce-xal ckb-xal co-xal crh-xal cs-xal csb-xal cv-xal cy-xal da-xal de-xal de_AT-xal de_DE-xal dsb-xal dv-xal dz-xal el-xal en-xal en_AU-xal en_CA-xal en_GB-xal eo-xal es-xal es_ES-xal es_PR-xal et-xal eu-xal fa-xal fa_AF-xal fi-xal fil-xal fo-xal fr-xal fr_CA-xal fr_FR-xal frm-xal frp-xal fur-xal fy-xal ga-xal gd-xal gl-xal gn-xal gu-xal gv-xal ha-xal he-xal hi-xal hil-xal hr-xal ht-xal hu-xal hy-xal ia-xal id-xal ig-xal io-xal is-xal it-xal ja-xal jbo-xal jv-xal ka-xal kab-xal kg-xal kk-xal kl-xal km-xal kn-xal ko-xal kok-xal ku-xal kw-xal ky-xal la-xal lb-xal lg-xal li-xal ln-xal lo-xal lt-xal lv-xal mai-xal mg-xal mhr-xal mi-xal mk-xal ml-xal mn-xal mr-xal ms-xal mt-xal mus-xal my-xal nan-xal nap-xal nb-xal nds-xal ne-xal nl-xal nn-xal no-xal nso-xal oc-xal om-xal or-xal pa-xal pap-xal pl-xal pms-xal ps-xal pt-xal pt_BR-xal pt_PT-xal qu-xal ro-xal rom-xal ru-xal rw-xal sa-xal sc-xal sco-xal sd-xal se-xal shn-xal shs-xal si-xal sk-xal sl-xal sm-xal sn-xal so-xal sq-xal sr-xal st-xal sv-xal sw-xal syr-xal szl-xal ta-xal ta_LK-xal te-xal tet-xal tg-xal th-xal ti-xal tk-xal tl-xal tlh-xal tr-xal trv-xal ts-xal tt-xal ug-xal uk-xal ur-xal uz-xal ve-xal vi-xal wa-xal wo-xal ace-xh af-xh ak-xh am-xh an-xh ang-xh ar-xh ary-xh as-xh ast-xh az-xh ba-xh bal-xh be-xh bem-xh ber-xh bg-xh bho-xh bn-xh bn_IN-xh bo-xh br-xh brx-xh bs-xh bua-xh ca-xh ce-xh ceb-xh chr-xh ckb-xh co-xh crh-xh cs-xh csb-xh cv-xh cy-xh da-xh de-xh de_AT-xh de_DE-xh dsb-xh dv-xh dz-xh el-xh en-xh en_AU-xh en_CA-xh en_GB-xh en_NZ-xh en_US-xh eo-xh es-xh es_AR-xh es_CL-xh es_CO-xh es_CR-xh es_DO-xh es_EC-xh es_ES-xh es_GT-xh es_HN-xh es_MX-xh es_NI-xh es_PA-xh es_PE-xh es_PR-xh es_SV-xh es_UY-xh es_VE-xh et-xh eu-xh fa-xh fa_AF-xh ff-xh fi-xh fil-xh fo-xh fr-xh fr_CA-xh fr_FR-xh frm-xh frp-xh fur-xh fy-xh ga-xh gd-xh gl-xh gn-xh gu-xh gv-xh ha-xh he-xh hi-xh hil-xh hne-xh hr-xh ht-xh hu-xh hy-xh ia-xh id-xh ig-xh io-xh is-xh it-xh ja-xh jbo-xh jv-xh ka-xh kab-xh kg-xh kk-xh kl-xh km-xh kn-xh ko-xh kok-xh ks-xh ksh-xh ku-xh kw-xh ky-xh la-xh lb-xh lg-xh li-xh lij-xh lld-xh ln-xh lo-xh lt-xh ltg-xh lv-xh mai-xh mg-xh mhr-xh mi-xh miq-xh mk-xh ml-xh mn-xh mo-xh mr-xh ms-xh mt-xh mus-xh my-xh nan-xh nap-xh nb-xh nds-xh ne-xh nhn-xh nl-xh nn-xh no-xh nso-xh oc-xh om-xh or-xh os-xh pa-xh pam-xh pap-xh pl-xh pms-xh pmy-xh ps-xh pt-xh pt_BR-xh pt_PT-xh qu-xh ro-xh rom-xh ru-xh rw-xh sa-xh sc-xh sco-xh sd-xh se-xh shn-xh shs-xh si-xh sk-xh sl-xh sm-xh sml-xh sn-xh so-xh sq-xh sr-xh st-xh sv-xh sw-xh syr-xh szl-xh ta-xh ta_LK-xh te-xh tet-xh tg-xh th-xh ti-xh tk-xh tl-xh tlh-xh tr-xh trv-xh ts-xh tt-xh ug-xh uk-xh ur-xh uz-xh ve-xh vec-xh vi-xh wa-xh wae-xh wo-xh xal-xh ace-yi af-yi ak-yi am-yi an-yi ang-yi ar-yi as-yi ast-yi az-yi be-yi bem-yi bg-yi bn-yi bo-yi br-yi brx-yi bs-yi byn-yi ca-yi ce-yi ckb-yi co-yi crh-yi cs-yi csb-yi cv-yi cy-yi da-yi de-yi de_AT-yi de_DE-yi dsb-yi dv-yi dz-yi el-yi en-yi en_AU-yi en_CA-yi en_GB-yi eo-yi es-yi es_ES-yi es_PR-yi et-yi eu-yi fa-yi fa_AF-yi ff-yi fi-yi fil-yi fo-yi fr-yi fr_CA-yi fr_FR-yi frp-yi fur-yi fy-yi ga-yi gd-yi gl-yi gn-yi gu-yi guc-yi gv-yi ha-yi he-yi hi-yi hil-yi hr-yi ht-yi hu-yi hy-yi ia-yi id-yi ig-yi io-yi is-yi it-yi iu-yi ja-yi jbo-yi jv-yi ka-yi kab-yi kg-yi kk-yi kl-yi km-yi kn-yi ko-yi kok-yi ksh-yi ku-yi kw-yi ky-yi la-yi lb-yi lg-yi li-yi lld-yi ln-yi lo-yi lt-yi ltg-yi lv-yi mai-yi mg-yi mhr-yi mi-yi miq-yi mk-yi ml-yi mn-yi mr-yi ms-yi mt-yi mus-yi my-yi nan-yi nap-yi nb-yi nds-yi ne-yi nl-yi nn-yi no-yi nso-yi oc-yi om-yi or-yi os-yi pa-yi pap-yi pl-yi pms-yi pmy-yi ps-yi pt-yi pt_BR-yi pt_PT-yi qu-yi ro-yi ru-yi rw-yi sa-yi sc-yi sco-yi sd-yi se-yi shn-yi shs-yi si-yi sk-yi sl-yi sml-yi sn-yi so-yi sq-yi sr-yi st-yi sv-yi sw-yi syr-yi szl-yi ta-yi ta_LK-yi te-yi tet-yi tg-yi th-yi ti-yi tk-yi tl-yi tlh-yi tr-yi trv-yi ts-yi tt-yi ug-yi uk-yi ur-yi uz-yi vec-yi vi-yi wa-yi wae-yi wo-yi xal-yi xh-yi ace-yo af-yo ak-yo am-yo an-yo ar-yo as-yo ast-yo az-yo be-yo bg-yo bn-yo bo-yo br-yo bs-yo ca-yo ce-yo ckb-yo co-yo crh-yo cs-yo csb-yo cv-yo cy-yo da-yo de-yo de_AT-yo de_DE-yo dsb-yo dv-yo dz-yo el-yo en-yo en_AU-yo en_CA-yo en_GB-yo eo-yo es-yo es_ES-yo es_PR-yo et-yo eu-yo fa-yo fa_AF-yo ff-yo fi-yo fil-yo fo-yo fr-yo fr_CA-yo fr_FR-yo frm-yo frp-yo fur-yo fy-yo ga-yo gd-yo gl-yo gn-yo gu-yo gv-yo ha-yo he-yo hi-yo hil-yo hr-yo ht-yo hu-yo hy-yo ia-yo id-yo ig-yo io-yo is-yo it-yo ja-yo jbo-yo jv-yo ka-yo kab-yo kg-yo kk-yo kl-yo km-yo kn-yo ko-yo kok-yo ksh-yo ku-yo kw-yo ky-yo la-yo lb-yo lg-yo li-yo lld-yo ln-yo lo-yo lt-yo lv-yo mai-yo mg-yo mhr-yo mi-yo miq-yo mk-yo ml-yo mn-yo mr-yo ms-yo mt-yo mus-yo my-yo nan-yo nap-yo nb-yo nds-yo ne-yo nl-yo nn-yo no-yo nso-yo oc-yo om-yo or-yo os-yo pa-yo pap-yo pl-yo pms-yo ps-yo pt-yo pt_BR-yo pt_PT-yo qu-yo ro-yo rom-yo ru-yo rw-yo sa-yo sc-yo sco-yo sd-yo se-yo shn-yo shs-yo si-yo sk-yo sl-yo sm-yo sml-yo sn-yo so-yo sq-yo sr-yo st-yo sv-yo sw-yo syr-yo szl-yo ta-yo ta_LK-yo te-yo tet-yo tg-yo th-yo ti-yo tk-yo tl-yo tlh-yo tr-yo trv-yo ts-yo tt-yo ug-yo uk-yo ur-yo uz-yo ve-yo vec-yo vi-yo wa-yo wae-yo wo-yo xal-yo xh-yo yi-yo ast-zh bg-zh bs-zh ca-zh cs-zh da-zh de-zh el-zh en-zh en_AU-zh en_GB-zh es-zh fa-zh fi-zh fr-zh gl-zh he-zh hi-zh hr-zh hu-zh id-zh it-zh ja-zh ko-zh ku-zh lv-zh mk-zh ms-zh nb-zh nl-zh oc-zh pl-zh pt-zh pt_BR-zh ro-zh ru-zh sl-zh sq-zh sr-zh sv-zh th-zh tr-zh ug-zh uk-zh vi-zh ace-zh_CN af-zh_CN ak-zh_CN am-zh_CN an-zh_CN ang-zh_CN ar-zh_CN ar_SY-zh_CN ary-zh_CN as-zh_CN ast-zh_CN az-zh_CN ba-zh_CN bal-zh_CN be-zh_CN bem-zh_CN ber-zh_CN bg-zh_CN bho-zh_CN bn-zh_CN bn_IN-zh_CN bo-zh_CN br-zh_CN brx-zh_CN bs-zh_CN bua-zh_CN byn-zh_CN ca-zh_CN ce-zh_CN ceb-zh_CN chr-zh_CN ckb-zh_CN co-zh_CN crh-zh_CN cs-zh_CN csb-zh_CN cv-zh_CN cy-zh_CN da-zh_CN de-zh_CN de_AT-zh_CN de_DE-zh_CN dsb-zh_CN dv-zh_CN dz-zh_CN el-zh_CN en-zh_CN en_AU-zh_CN en_CA-zh_CN en_GB-zh_CN en_NZ-zh_CN en_US-zh_CN eo-zh_CN es-zh_CN es_AR-zh_CN es_CL-zh_CN es_CO-zh_CN es_CR-zh_CN es_DO-zh_CN es_EC-zh_CN es_ES-zh_CN es_GT-zh_CN es_HN-zh_CN es_MX-zh_CN es_NI-zh_CN es_PA-zh_CN es_PE-zh_CN es_PR-zh_CN es_SV-zh_CN es_UY-zh_CN es_VE-zh_CN et-zh_CN eu-zh_CN fa-zh_CN fa_AF-zh_CN ff-zh_CN fi-zh_CN fil-zh_CN fo-zh_CN fr-zh_CN fr_CA-zh_CN fr_FR-zh_CN frm-zh_CN frp-zh_CN fur-zh_CN fy-zh_CN ga-zh_CN gd-zh_CN gl-zh_CN gn-zh_CN grc-zh_CN gu-zh_CN guc-zh_CN gv-zh_CN ha-zh_CN haw-zh_CN he-zh_CN hi-zh_CN hil-zh_CN hne-zh_CN hr-zh_CN hsb-zh_CN ht-zh_CN hu-zh_CN hy-zh_CN ia-zh_CN id-zh_CN ig-zh_CN io-zh_CN is-zh_CN it-zh_CN iu-zh_CN ja-zh_CN jbo-zh_CN jv-zh_CN ka-zh_CN kab-zh_CN kg-zh_CN kk-zh_CN kl-zh_CN km-zh_CN kn-zh_CN ko-zh_CN kok-zh_CN ks-zh_CN ksh-zh_CN ku-zh_CN kw-zh_CN ky-zh_CN la-zh_CN lb-zh_CN lg-zh_CN li-zh_CN lij-zh_CN lld-zh_CN ln-zh_CN lo-zh_CN lt-zh_CN ltg-zh_CN lv-zh_CN mai-zh_CN mg-zh_CN mh-zh_CN mhr-zh_CN mi-zh_CN miq-zh_CN mk-zh_CN ml-zh_CN mn-zh_CN mo-zh_CN mr-zh_CN ms-zh_CN mt-zh_CN mus-zh_CN my-zh_CN nan-zh_CN nap-zh_CN nb-zh_CN nds-zh_CN ne-zh_CN nhn-zh_CN nl-zh_CN nl_NL-zh_CN nn-zh_CN no-zh_CN nso-zh_CN ny-zh_CN oc-zh_CN oj-zh_CN om-zh_CN or-zh_CN os-zh_CN pa-zh_CN pam-zh_CN pap-zh_CN pl-zh_CN pms-zh_CN pmy-zh_CN ps-zh_CN pt-zh_CN pt_BR-zh_CN pt_PT-zh_CN qu-zh_CN rm-zh_CN ro-zh_CN rom-zh_CN ru-zh_CN rw-zh_CN sa-zh_CN sc-zh_CN sco-zh_CN sd-zh_CN se-zh_CN shn-zh_CN shs-zh_CN si-zh_CN sk-zh_CN sl-zh_CN sm-zh_CN sml-zh_CN sn-zh_CN so-zh_CN son-zh_CN sq-zh_CN sr-zh_CN st-zh_CN sv-zh_CN sw-zh_CN syr-zh_CN szl-zh_CN ta-zh_CN ta_LK-zh_CN te-zh_CN tet-zh_CN tg-zh_CN th-zh_CN ti-zh_CN tk-zh_CN tl-zh_CN tlh-zh_CN tr-zh_CN trv-zh_CN ts-zh_CN tt-zh_CN ug-zh_CN uk-zh_CN ur-zh_CN uz-zh_CN ve-zh_CN vec-zh_CN vi-zh_CN wa-zh_CN wae-zh_CN wo-zh_CN xal-zh_CN xh-zh_CN yi-zh_CN yo-zh_CN zh-zh_CN ace-zh_HK af-zh_HK ak-zh_HK am-zh_HK an-zh_HK ang-zh_HK ar-zh_HK ary-zh_HK as-zh_HK ast-zh_HK az-zh_HK ba-zh_HK bal-zh_HK be-zh_HK bem-zh_HK ber-zh_HK bg-zh_HK bho-zh_HK bn-zh_HK bn_IN-zh_HK bo-zh_HK br-zh_HK brx-zh_HK bs-zh_HK bua-zh_HK byn-zh_HK ca-zh_HK ce-zh_HK ceb-zh_HK chr-zh_HK ckb-zh_HK co-zh_HK crh-zh_HK cs-zh_HK csb-zh_HK cv-zh_HK cy-zh_HK da-zh_HK de-zh_HK de_AT-zh_HK de_DE-zh_HK dsb-zh_HK dv-zh_HK dz-zh_HK el-zh_HK en-zh_HK en_AU-zh_HK en_CA-zh_HK en_GB-zh_HK en_NZ-zh_HK en_US-zh_HK eo-zh_HK es-zh_HK es_AR-zh_HK es_CL-zh_HK es_CO-zh_HK es_CR-zh_HK es_DO-zh_HK es_EC-zh_HK es_ES-zh_HK es_GT-zh_HK es_HN-zh_HK es_MX-zh_HK es_NI-zh_HK es_PA-zh_HK es_PE-zh_HK es_PR-zh_HK es_SV-zh_HK es_UY-zh_HK es_VE-zh_HK et-zh_HK eu-zh_HK fa-zh_HK fa_AF-zh_HK ff-zh_HK fi-zh_HK fil-zh_HK fo-zh_HK fr-zh_HK fr_CA-zh_HK fr_FR-zh_HK frm-zh_HK frp-zh_HK fur-zh_HK fy-zh_HK ga-zh_HK gd-zh_HK gl-zh_HK gn-zh_HK gu-zh_HK guc-zh_HK gv-zh_HK ha-zh_HK haw-zh_HK he-zh_HK hi-zh_HK hil-zh_HK hne-zh_HK hr-zh_HK ht-zh_HK hu-zh_HK hy-zh_HK ia-zh_HK id-zh_HK ig-zh_HK io-zh_HK is-zh_HK it-zh_HK iu-zh_HK ja-zh_HK jbo-zh_HK jv-zh_HK ka-zh_HK kab-zh_HK kg-zh_HK kk-zh_HK kl-zh_HK km-zh_HK kn-zh_HK ko-zh_HK kok-zh_HK ks-zh_HK ksh-zh_HK ku-zh_HK kw-zh_HK ky-zh_HK la-zh_HK lb-zh_HK lg-zh_HK li-zh_HK lij-zh_HK lld-zh_HK ln-zh_HK lo-zh_HK lt-zh_HK ltg-zh_HK lv-zh_HK mai-zh_HK mg-zh_HK mhr-zh_HK mi-zh_HK miq-zh_HK mk-zh_HK ml-zh_HK mn-zh_HK mo-zh_HK mr-zh_HK ms-zh_HK mt-zh_HK mus-zh_HK my-zh_HK nan-zh_HK nap-zh_HK nb-zh_HK nds-zh_HK ne-zh_HK nhn-zh_HK nl-zh_HK nl_NL-zh_HK nn-zh_HK no-zh_HK nso-zh_HK ny-zh_HK oc-zh_HK oj-zh_HK om-zh_HK or-zh_HK os-zh_HK pa-zh_HK pam-zh_HK pap-zh_HK pl-zh_HK pms-zh_HK pmy-zh_HK ps-zh_HK pt-zh_HK pt_BR-zh_HK pt_PT-zh_HK qu-zh_HK rm-zh_HK ro-zh_HK rom-zh_HK ru-zh_HK rw-zh_HK sa-zh_HK sc-zh_HK sco-zh_HK sd-zh_HK se-zh_HK shn-zh_HK shs-zh_HK si-zh_HK sk-zh_HK sl-zh_HK sm-zh_HK sml-zh_HK sn-zh_HK so-zh_HK son-zh_HK sq-zh_HK sr-zh_HK st-zh_HK sv-zh_HK sw-zh_HK syr-zh_HK szl-zh_HK ta-zh_HK ta_LK-zh_HK te-zh_HK tet-zh_HK tg-zh_HK th-zh_HK ti-zh_HK tk-zh_HK tl-zh_HK tlh-zh_HK tr-zh_HK trv-zh_HK ts-zh_HK tt-zh_HK ug-zh_HK uk-zh_HK ur-zh_HK uz-zh_HK ve-zh_HK vec-zh_HK vi-zh_HK wa-zh_HK wae-zh_HK wo-zh_HK xal-zh_HK xh-zh_HK yi-zh_HK yo-zh_HK zh_CN-zh_HK ace-zh_TW af-zh_TW ak-zh_TW am-zh_TW an-zh_TW ang-zh_TW ar-zh_TW ar_SY-zh_TW ary-zh_TW as-zh_TW ast-zh_TW az-zh_TW ba-zh_TW bal-zh_TW be-zh_TW bem-zh_TW ber-zh_TW bg-zh_TW bho-zh_TW bn-zh_TW bn_IN-zh_TW bo-zh_TW br-zh_TW brx-zh_TW bs-zh_TW bua-zh_TW byn-zh_TW ca-zh_TW ce-zh_TW ceb-zh_TW chr-zh_TW ckb-zh_TW co-zh_TW crh-zh_TW cs-zh_TW csb-zh_TW cv-zh_TW cy-zh_TW da-zh_TW de-zh_TW de_AT-zh_TW de_DE-zh_TW dsb-zh_TW dv-zh_TW dz-zh_TW el-zh_TW en-zh_TW en_AU-zh_TW en_CA-zh_TW en_GB-zh_TW en_NZ-zh_TW en_US-zh_TW eo-zh_TW es-zh_TW es_AR-zh_TW es_CL-zh_TW es_CO-zh_TW es_CR-zh_TW es_DO-zh_TW es_EC-zh_TW es_ES-zh_TW es_GT-zh_TW es_HN-zh_TW es_MX-zh_TW es_NI-zh_TW es_PA-zh_TW es_PE-zh_TW es_PR-zh_TW es_SV-zh_TW es_UY-zh_TW es_VE-zh_TW et-zh_TW eu-zh_TW fa-zh_TW fa_AF-zh_TW ff-zh_TW fi-zh_TW fil-zh_TW fo-zh_TW fr-zh_TW fr_CA-zh_TW fr_FR-zh_TW frm-zh_TW frp-zh_TW fur-zh_TW fy-zh_TW ga-zh_TW gd-zh_TW gl-zh_TW gn-zh_TW grc-zh_TW gu-zh_TW guc-zh_TW gv-zh_TW ha-zh_TW haw-zh_TW he-zh_TW hi-zh_TW hil-zh_TW hne-zh_TW hr-zh_TW hsb-zh_TW ht-zh_TW hu-zh_TW hy-zh_TW ia-zh_TW id-zh_TW ig-zh_TW io-zh_TW is-zh_TW it-zh_TW iu-zh_TW ja-zh_TW jbo-zh_TW jv-zh_TW ka-zh_TW kab-zh_TW kg-zh_TW kk-zh_TW kl-zh_TW km-zh_TW kn-zh_TW ko-zh_TW kok-zh_TW ks-zh_TW ksh-zh_TW ku-zh_TW kw-zh_TW ky-zh_TW la-zh_TW lb-zh_TW lg-zh_TW li-zh_TW lij-zh_TW lld-zh_TW ln-zh_TW lo-zh_TW lt-zh_TW ltg-zh_TW lv-zh_TW mai-zh_TW mg-zh_TW mh-zh_TW mhr-zh_TW mi-zh_TW miq-zh_TW mk-zh_TW ml-zh_TW mn-zh_TW mo-zh_TW mr-zh_TW ms-zh_TW mt-zh_TW mus-zh_TW my-zh_TW nan-zh_TW nap-zh_TW nb-zh_TW nds-zh_TW ne-zh_TW nhn-zh_TW nl-zh_TW nl_NL-zh_TW nn-zh_TW no-zh_TW nso-zh_TW ny-zh_TW oc-zh_TW oj-zh_TW om-zh_TW or-zh_TW os-zh_TW pa-zh_TW pam-zh_TW pap-zh_TW pl-zh_TW pms-zh_TW pmy-zh_TW ps-zh_TW pt-zh_TW pt_BR-zh_TW pt_PT-zh_TW qu-zh_TW rm-zh_TW ro-zh_TW rom-zh_TW ru-zh_TW rw-zh_TW sa-zh_TW sc-zh_TW sco-zh_TW sd-zh_TW se-zh_TW shn-zh_TW shs-zh_TW si-zh_TW sk-zh_TW sl-zh_TW sm-zh_TW sml-zh_TW sn-zh_TW so-zh_TW son-zh_TW sq-zh_TW sr-zh_TW st-zh_TW sv-zh_TW sw-zh_TW syr-zh_TW szl-zh_TW ta-zh_TW ta_LK-zh_TW te-zh_TW tet-zh_TW tg-zh_TW th-zh_TW ti-zh_TW tk-zh_TW tl-zh_TW tlh-zh_TW tr-zh_TW trv-zh_TW ts-zh_TW tt-zh_TW ug-zh_TW uk-zh_TW ur-zh_TW uz-zh_TW ve-zh_TW vec-zh_TW vi-zh_TW wa-zh_TW wae-zh_TW wo-zh_TW xal-zh_TW xh-zh_TW yi-zh_TW yo-zh_TW zh-zh_TW zh_CN-zh_TW zh_HK-zh_TW ace-zu af-zu ak-zu am-zu an-zu ar-zu as-zu ast-zu az-zu ba-zu bal-zu be-zu bem-zu ber-zu bg-zu bho-zu bn-zu bn_IN-zu bo-zu br-zu brx-zu bs-zu bua-zu byn-zu ca-zu ce-zu ceb-zu chr-zu ckb-zu co-zu crh-zu cs-zu csb-zu cv-zu cy-zu da-zu de-zu de_AT-zu de_DE-zu dsb-zu dv-zu dz-zu el-zu en-zu en_AU-zu en_CA-zu en_GB-zu en_NZ-zu en_US-zu eo-zu es-zu es_ES-zu es_PR-zu es_UY-zu et-zu eu-zu fa-zu fa_AF-zu ff-zu fi-zu fil-zu fo-zu fr-zu fr_CA-zu fr_FR-zu frm-zu frp-zu fur-zu fy-zu ga-zu gd-zu gl-zu gn-zu gu-zu guc-zu gv-zu ha-zu haw-zu he-zu hi-zu hil-zu hr-zu ht-zu hu-zu hy-zu ia-zu id-zu ig-zu io-zu is-zu it-zu iu-zu ja-zu jbo-zu jv-zu ka-zu kab-zu kg-zu kk-zu kl-zu km-zu kn-zu ko-zu kok-zu ks-zu ksh-zu ku-zu kw-zu ky-zu la-zu lb-zu lg-zu li-zu lij-zu lld-zu ln-zu lo-zu lt-zu ltg-zu lv-zu mai-zu mg-zu mhr-zu mi-zu miq-zu mk-zu ml-zu mn-zu mo-zu mr-zu ms-zu mt-zu mus-zu my-zu nan-zu nap-zu nb-zu nds-zu ne-zu nl-zu nn-zu no-zu nso-zu oc-zu oj-zu om-zu or-zu os-zu pa-zu pap-zu pl-zu pms-zu pmy-zu ps-zu pt-zu pt_BR-zu pt_PT-zu qu-zu rm-zu ro-zu rom-zu ru-zu rw-zu sa-zu sc-zu sco-zu sd-zu se-zu shn-zu shs-zu si-zu sk-zu sl-zu sm-zu sml-zu sn-zu so-zu son-zu sq-zu sr-zu st-zu sv-zu sw-zu syr-zu szl-zu ta-zu ta_LK-zu te-zu tet-zu tg-zu th-zu ti-zu tk-zu tl-zu tlh-zu tr-zu trv-zu ts-zu tt-zu ug-zu uk-zu ur-zu uz-zu ve-zu vec-zu vi-zu wa-zu wae-zu wo-zu xal-zu xh-zu yi-zu yo-zu zh_CN-zu zh_HK-zu zh_TW-zu ace-zza af-zza ak-zza am-zza an-zza ang-zza ar-zza ary-zza as-zza ast-zza az-zza be-zza bem-zza ber-zza bg-zza bn-zza bo-zza br-zza brx-zza bs-zza byn-zza ca-zza ce-zza ceb-zza ckb-zza co-zza crh-zza cs-zza csb-zza cv-zza cy-zza da-zza de-zza de_AT-zza de_DE-zza dsb-zza dv-zza dz-zza el-zza en-zza en_AU-zza en_CA-zza en_GB-zza eo-zza es-zza es_ES-zza es_PR-zza et-zza eu-zza fa-zza fa_AF-zza ff-zza fi-zza fil-zza fo-zza fr-zza fr_CA-zza fr_FR-zza frm-zza frp-zza fur-zza fy-zza ga-zza gd-zza gl-zza gn-zza gu-zza guc-zza gv-zza ha-zza he-zza hi-zza hil-zza hr-zza ht-zza hu-zza hy-zza ia-zza id-zza ig-zza io-zza is-zza it-zza iu-zza ja-zza jbo-zza jv-zza ka-zza kab-zza kg-zza kk-zza kl-zza km-zza kn-zza ko-zza kok-zza ku-zza kw-zza ky-zza la-zza lb-zza lg-zza li-zza lld-zza ln-zza lo-zza lt-zza ltg-zza lv-zza mai-zza mg-zza mhr-zza mi-zza miq-zza mk-zza ml-zza mn-zza mr-zza ms-zza mt-zza mus-zza my-zza nan-zza nap-zza nb-zza nds-zza ne-zza nl-zza nn-zza no-zza nso-zza oc-zza om-zza or-zza os-zza pa-zza pap-zza pl-zza pms-zza pmy-zza ps-zza pt-zza pt_BR-zza pt_PT-zza qu-zza ro-zza rom-zza ru-zza rw-zza sa-zza sc-zza sco-zza sd-zza se-zza shn-zza shs-zza si-zza sk-zza sl-zza sm-zza sml-zza sn-zza so-zza sq-zza sr-zza st-zza sv-zza sw-zza syr-zza szl-zza ta-zza ta_LK-zza te-zza tet-zza tg-zza th-zza ti-zza tk-zza tl-zza tlh-zza tr-zza trv-zza ts-zza tt-zza ug-zza uk-zza ur-zza uz-zza ve-zza vec-zza vi-zza wa-zza wae-zza wo-zza xal-zza xh-zza yi-zza yo-zza zh_CN-zza zh_HK-zza zh_TW-zza zu-zza
TildeMODEL_v2018	TildeMODEL/v2018/moses/%s-%s.txt.zip	bg-cs bg-da cs-da bg-de cs-de da-de bg-el cs-el da-el de-el bg-en cs-en da-en de-en el-en bg-es cs-es da-es de-es el-es en-es bg-et cs-et da-et de-et el-et en-et es-et bg-fi cs-fi da-fi de-fi el-fi en-fi es-fi et-fi bg-fr cs-fr da-fr de-fr el-fr en-fr es-fr et-fr fi-fr bg-hr cs-hr da-hr de-hr el-hr en-hr es-hr et-hr fi-hr fr-hr bg-hu cs-hu da-hu de-hu el-hu en-hu es-hu et-hu fi-hu fr-hu hr-hu de-is en-is fr-is bg-it cs-it da-it de-it el-it en-it es-it et-it fi-it fr-it hr-it hu-it bg-lt cs-lt da-lt de-lt el-lt en-lt es-lt et-lt fi-lt fr-lt hr-lt hu-lt it-lt bg-lv cs-lv da-lv de-lv el-lv en-lv es-lv et-lv fi-lv fr-lv hr-lv hu-lv it-lv lt-lv bg-mt cs-mt da-mt de-mt el-mt en-mt es-mt et-mt fi-mt fr-mt hr-mt hu-mt it-mt lt-mt lv-mt bg-nl cs-nl da-nl de-nl el-nl en-nl es-nl et-nl fi-nl fr-nl hr-nl hu-nl it-nl lt-nl lv-nl mt-nl de-no en-no fr-no bg-pl cs-pl da-pl de-pl el-pl en-pl es-pl et-pl fi-pl fr-pl hr-pl hu-pl it-pl lt-pl lv-pl mt-pl nl-pl bg-pt cs-pt da-pt de-pt el-pt en-pt es-pt et-pt fi-pt fr-pt hr-pt hu-pt it-pt lt-pt lv-pt mt-pt nl-pt pl-pt bg-ro cs-ro da-ro de-ro el-ro en-ro es-ro et-ro fi-ro fr-ro hr-ro hu-ro it-ro lt-ro lv-ro mt-ro nl-ro pl-ro pt-ro de-ru en-ru es-ru et-ru fi-ru fr-ru it-ru lt-ru lv-ru pl-ru pt-ru bg-sk cs-sk da-sk de-sk el-sk en-sk es-sk et-sk fi-sk fr-sk hr-sk hu-sk it-sk lt-sk lv-sk mt-sk nl-sk pl-sk pt-sk ro-sk bg-sl cs-sl da-sl de-sl el-sl en-sl es-sl et-sl fi-sl fr-sl hr-sl hu-sl it-sl lt-sl lv-sl mt-sl nl-sl pl-sl pt-sl ro-sl sk-sl en-sq en-sr bg-sv cs-sv da-sv de-sv el-sv en-sv es-sv et-sv fi-sv fr-sv hr-sv hu-sv it-sv lt-sv lv-sv mt-sv nl-sv pl-sv pt-sv ro-sv sk-sv sl-sv en-tr en-uk
TED2013_v1.1	TED2013/v1.1/moses/%s-%s.txt.zip	ar-en de-en en-es en-fa en-fr en-it en-nl en-pl en-pt en-ro en-ru en-sl en-tr en-zh
TedTalks_v1	TedTalks/v1/moses/%s-%s.txt.zip	en-hr
TEP_v1	TEP/v1/moses/%s-%s.txt.zip	en-fa
Tanzil_v1	Tanzil/v1/moses/%s-%s.txt.zip	am-ar ar-ar am-az ar-az az-az am-bg ar-bg az-bg am-bn ar-bn az-bn bg-bn bn-bn am-bs ar-bs az-bs bg-bs bn-bs bs-bs am-cs ar-cs az-cs bg-cs bn-cs bs-cs cs-cs am-de ar-de az-de bg-de bn-de bs-de cs-de de-de am-dv ar-dv az-dv bg-dv bn-dv bs-dv cs-dv de-dv am-en ar-en az-en bg-en bn-en bs-en cs-en de-en dv-en en-en am-es ar-es az-es bg-es bn-es bs-es cs-es de-es dv-es en-es am-fa ar-fa az-fa bg-fa bn-fa bs-fa cs-fa de-fa dv-fa en-fa es-fa fa-fa am-fr ar-fr az-fr bg-fr bn-fr bs-fr cs-fr de-fr dv-fr en-fr es-fr fa-fr am-ha ar-ha az-ha bg-ha bn-ha bs-ha cs-ha de-ha dv-ha en-ha es-ha fa-ha fr-ha am-hi ar-hi az-hi bg-hi bn-hi bs-hi cs-hi de-hi dv-hi en-hi es-hi fa-hi fr-hi ha-hi hi-hi am-id ar-id az-id bg-id bn-id bs-id cs-id de-id dv-id en-id es-id fa-id fr-id ha-id hi-id id-id am-it ar-it az-it bg-it bn-it bs-it cs-it de-it dv-it en-it es-it fa-it fr-it ha-it hi-it id-it am-ja ar-ja az-ja bg-ja bn-ja bs-ja cs-ja de-ja dv-ja en-ja es-ja fa-ja fr-ja ha-ja hi-ja id-ja it-ja am-ko ar-ko az-ko bg-ko bn-ko bs-ko cs-ko de-ko dv-ko en-ko es-ko fa-ko fr-ko ha-ko hi-ko id-ko it-ko ja-ko am-ku ar-ku az-ku bg-ku bn-ku bs-ku cs-ku de-ku dv-ku en-ku es-ku fa-ku fr-ku ha-ku hi-ku id-ku it-ku ja-ku ko-ku am-ml ar-ml az-ml bg-ml bn-ml bs-ml cs-ml de-ml dv-ml en-ml es-ml fa-ml fr-ml ha-ml hi-ml id-ml it-ml ja-ml ko-ml ku-ml ml-ml am-ms ar-ms az-ms bg-ms bn-ms bs-ms cs-ms de-ms dv-ms en-ms es-ms fa-ms fr-ms ha-ms hi-ms id-ms it-ms ja-ms ko-ms ku-ms ml-ms am-nl ar-nl az-nl bg-nl bn-nl bs-nl cs-nl de-nl dv-nl en-nl es-nl fa-nl fr-nl ha-nl hi-nl id-nl it-nl ja-nl ko-nl ku-nl ml-nl ms-nl nl-nl am-no ar-no az-no bg-no bn-no bs-no cs-no de-no dv-no en-no es-no fa-no fr-no ha-no hi-no id-no it-no ja-no ko-no ku-no ml-no ms-no nl-no am-pl ar-pl az-pl bg-pl bn-pl bs-pl cs-pl de-pl dv-pl en-pl es-pl fa-pl fr-pl ha-pl hi-pl id-pl it-pl ja-pl ko-pl ku-pl ml-pl ms-pl nl-pl no-pl am-pt ar-pt az-pt bg-pt bn-pt bs-pt cs-pt de-pt dv-pt en-pt es-pt fa-pt fr-pt ha-pt hi-pt id-pt it-pt ja-pt ko-pt ku-pt ml-pt ms-pt nl-pt no-pt pl-pt am-ro ar-ro az-ro bg-ro bn-ro bs-ro cs-ro de-ro dv-ro en-ro es-ro fa-ro fr-ro ha-ro hi-ro id-ro it-ro ja-ro ko-ro ku-ro ml-ro ms-ro nl-ro no-ro pl-ro pt-ro am-ru ar-ru az-ru bg-ru bn-ru bs-ru cs-ru de-ru dv-ru en-ru es-ru fa-ru fr-ru ha-ru hi-ru id-ru it-ru ja-ru ko-ru ku-ru ml-ru ms-ru nl-ru no-ru pl-ru pt-ru ro-ru ru-ru am-sd ar-sd az-sd bg-sd bn-sd bs-sd cs-sd de-sd dv-sd en-sd es-sd fa-sd fr-sd ha-sd hi-sd id-sd it-sd ja-sd ko-sd ku-sd ml-sd ms-sd nl-sd no-sd pl-sd pt-sd ro-sd ru-sd am-so ar-so az-so bg-so bn-so bs-so cs-so de-so dv-so en-so es-so fa-so fr-so ha-so hi-so id-so it-so ja-so ko-so ku-so ml-so ms-so nl-so no-so pl-so pt-so ro-so ru-so sd-so am-sq ar-sq az-sq bg-sq bn-sq bs-sq cs-sq de-sq dv-sq en-sq es-sq fa-sq fr-sq ha-sq hi-sq id-sq it-sq ja-sq ko-sq ku-sq ml-sq ms-sq nl-sq no-sq pl-sq pt-sq ro-sq ru-sq sd-sq so-sq sq-sq am-sv ar-sv az-sv bg-sv bn-sv bs-sv cs-sv de-sv dv-sv en-sv es-sv fa-sv fr-sv ha-sv hi-sv id-sv it-sv ja-sv ko-sv ku-sv ml-sv ms-sv nl-sv no-sv pl-sv pt-sv ro-sv ru-sv sd-sv so-sv sq-sv am-sw ar-sw az-sw bg-sw bn-sw bs-sw cs-sw de-sw dv-sw en-sw es-sw fa-sw fr-sw ha-sw hi-sw id-sw it-sw ja-sw ko-sw ku-sw ml-sw ms-sw nl-sw no-sw pl-sw pt-sw ro-sw ru-sw sd-sw so-sw sq-sw sv-sw am-ta ar-ta az-ta bg-ta bn-ta bs-ta cs-ta de-ta dv-ta en-ta es-ta fa-ta fr-ta ha-ta hi-ta id-ta it-ta ja-ta ko-ta ku-ta ml-ta ms-ta nl-ta no-ta pl-ta pt-ta ro-ta ru-ta sd-ta so-ta sq-ta sv-ta sw-ta am-tg ar-tg az-tg bg-tg bn-tg bs-tg cs-tg de-tg dv-tg en-tg es-tg fa-tg fr-tg ha-tg hi-tg id-tg it-tg ja-tg ko-tg ku-tg ml-tg ms-tg nl-tg no-tg pl-tg pt-tg ro-tg ru-tg sd-tg so-tg sq-tg sv-tg sw-tg ta-tg am-th ar-th az-th bg-th bn-th bs-th cs-th de-th dv-th en-th es-th fa-th fr-th ha-th hi-th id-th it-th ja-th ko-th ku-th ml-th ms-th nl-th no-th pl-th pt-th ro-th ru-th sd-th so-th sq-th sv-th sw-th ta-th tg-th am-tr ar-tr az-tr bg-tr bn-tr bs-tr cs-tr de-tr dv-tr en-tr es-tr fa-tr fr-tr ha-tr hi-tr id-tr it-tr ja-tr ko-tr ku-tr ml-tr ms-tr nl-tr no-tr pl-tr pt-tr ro-tr ru-tr sd-tr so-tr sq-tr sv-tr sw-tr ta-tr tg-tr th-tr tr-tr am-tt ar-tt az-tt bg-tt bn-tt bs-tt cs-tt de-tt dv-tt en-tt es-tt fa-tt fr-tt ha-tt hi-tt id-tt it-tt ja-tt ko-tt ku-tt ml-tt ms-tt nl-tt no-tt pl-tt pt-tt ro-tt ru-tt sd-tt so-tt sq-tt sv-tt sw-tt ta-tt tg-tt th-tt tr-tt am-ug ar-ug az-ug bg-ug bn-ug bs-ug cs-ug de-ug dv-ug en-ug es-ug fa-ug fr-ug ha-ug hi-ug id-ug it-ug ja-ug ko-ug ku-ug ml-ug ms-ug nl-ug no-ug pl-ug pt-ug ro-ug ru-ug sd-ug so-ug sq-ug sv-ug sw-ug ta-ug tg-ug th-ug tr-ug tt-ug am-ur ar-ur az-ur bg-ur bn-ur bs-ur cs-ur de-ur dv-ur en-ur es-ur fa-ur fr-ur ha-ur hi-ur id-ur it-ur ja-ur ko-ur ku-ur ml-ur ms-ur nl-ur no-ur pl-ur pt-ur ro-ur ru-ur sd-ur so-ur sq-ur sv-ur sw-ur ta-ur tg-ur th-ur tr-ur tt-ur ug-ur ur-ur am-uz ar-uz az-uz bg-uz bn-uz bs-uz cs-uz de-uz dv-uz en-uz es-uz fa-uz fr-uz ha-uz hi-uz id-uz it-uz ja-uz ko-uz ku-uz ml-uz ms-uz nl-uz no-uz pl-uz pt-uz ro-uz ru-uz sd-uz so-uz sq-uz sv-uz sw-uz ta-uz tg-uz th-uz tr-uz tt-uz ug-uz ur-uz am-zh ar-zh az-zh bg-zh bn-zh bs-zh cs-zh de-zh dv-zh en-zh es-zh fa-zh fr-zh ha-zh hi-zh id-zh it-zh ja-zh ko-zh ku-zh ml-zh ms-zh nl-zh no-zh pl-zh pt-zh ro-zh ru-zh sd-zh so-zh sq-zh sv-zh sw-zh ta-zh tg-zh th-zh tr-zh tt-zh ug-zh ur-zh uz-zh zh-zh
Tatoeba_v20190709	Tatoeba/v20190709/moses/%s-%s.txt.zip	ar-ber ar-bg az-bg bg-bg af-cmn ar-cmn arz-cmn avk-cmn az-cmn be-cmn ber-cmn bg-cmn bn-cmn bs-cmn ca-cmn ce-cmn cmn-cmn af-cs be-cs br-cs ch-cs cmn-cs cs-cs cmn-cy cmn-cycl cmn-da af-de afb-de ang-de ar-de ast-de avk-de az-de bar-de be-de ber-de bg-de bn-de br-de bs-de ca-de ceb-de ch-de chr-de cmn-de co-de cs-de csb-de cy-de cycl-de da-de de-de de-dng de-dsb cmn-dtp de-dtp cmn-dws cs-dws de-dws de-egl ar-el arz-el bg-el ca-el cmn-el cs-el de-el el-el ab-en acm-en ady-en af-en afb-en afh-en ain-en akl-en aln-en am-en an-en ang-en aoz-en apc-en ar-en arq-en ary-en arz-en as-en ast-en avk-en awa-en az-en ba-en bar-en be-en ber-en bg-en bho-en bm-en bn-en bo-en br-en brx-en bs-en bua-en bvy-en ca-en cbk-en ce-en ceb-en ch-en cho-en chr-en cjy-en ckt-en cmn-en co-en crh-en cs-en csb-en cv-en cy-en cycl-en da-en de-en dng-en dsb-en dtp-en dws-en ee-en egl-en el-en en-en af-eo ang-eo ar-eo be-eo ber-eo bg-eo br-eo bs-eo ca-eo ce-eo ceb-eo cmn-eo cs-eo cv-eo da-eo de-eo dsb-eo dtp-eo dws-eo el-eo en-eo eo-eo af-es afh-es an-es ang-es apc-es ar-es arq-es ast-es avk-es az-es be-es ber-es bg-es bjn-es bn-es bs-es ca-es cbk-es ce-es ceb-es cjy-es cmn-es crh-es cs-es csb-es cv-es cy-es cycl-es da-es de-es dng-es dsb-es dws-es egl-es el-es en-es eo-es es-es af-et be-et de-et en-et eo-et es-et cmn-eu de-eu en-eu eo-eu es-eu en-ext ar-fi bg-fi ca-fi cmn-fi cs-fi cycl-fi da-fi de-fi en-fi eo-fi es-fi et-fi fi-fi en-fj en-fkv fi-fkv cmn-fo cs-fo en-fo eo-fo et-fo af-fr afh-fr ain-fr an-fr ang-fr aoz-fr ar-fr arq-fr ary-fr arz-fr ast-fr avk-fr az-fr be-fr ber-fr bg-fr bho-fr bn-fr br-fr bs-fr bua-fr ca-fr cbk-fr ce-fr ceb-fr ch-fr cho-fr cmn-fr cs-fr cy-fr cycl-fr da-fr de-fr dtp-fr dws-fr egl-fr el-fr en-fr eo-fr es-fr et-fr eu-fr fi-fr fj-fr fkv-fr fo-fr fr-fr en-frm fr-frm en-fuc es-fuc fr-fuc en-fur es-fur en-fuv es-fuv cmn-fy cs-fy de-fy en-fy eo-fy es-fy et-fy fr-fy de-ga en-ga es-ga fr-ga en-gan en-gbm en-gcf es-gcf fr-gcf de-gd en-gd es-gd fr-gd en-gil cmn-gl de-gl el-gl en-gl eo-gl es-gl fr-gl cmn-gn de-gn en-gn es-gn fi-gn fr-gn de-gos en-gos es-gos de-got en-got es-got fr-got cs-grc de-grc en-grc eo-grc es-grc fr-grc de-gsw en-gsw es-gsw en-gu es-gu en-ha en-hak en-haw ar-he be-he cmn-he cs-he de-he en-he eo-he es-he fi-he fr-he gn-he he-he cmn-hi de-hi en-hi es-hi fr-hi en-hif cmn-hil en-hil en-hnj en-hoc es-hoc cmn-hr cs-hr de-hr en-hr eo-hr es-hr fi-hr fr-hr de-hrx en-hrx cs-hsb de-hsb en-hsb eo-hsb es-hsb cmn-hsn en-hsn es-hsn en-ht eo-ht es-ht fr-ht ar-hu bg-hu cmn-hu cs-hu de-hu en-hu eo-hu es-hu fi-hu fr-hu he-hu cmn-hy de-hy en-hy eo-hy es-hy fr-hy de-ia en-ia eo-ia es-ia fi-ia fr-ia en-iba fr-iba arz-id bg-id cmn-id cs-id de-id el-id en-id eo-id es-id fi-id fr-id he-id hu-id cmn-ie de-ie en-ie eo-ie es-ie fr-ie en-ig en-ike cmn-ilo de-ilo en-ilo fr-ilo cmn-io de-io en-io eo-io es-io fr-io id-io cmn-is de-is en-is eo-is es-is fr-is he-is af-it ang-it ar-it avk-it be-it ber-it bg-it bn-it br-it bs-it ca-it ceb-it cmn-it cs-it cy-it cycl-it da-it de-it egl-it el-it en-it eo-it es-it et-it eu-it fi-it fr-it fuc-it fur-it fy-it gd-it gl-it he-it hr-it hu-it ia-it id-it io-it is-it it-it en-izh acm-ja af-ja ar-ja arq-ja arz-ja ast-ja avk-ja awa-ja az-ja be-ja ber-ja bg-ja bho-ja bn-ja br-ja bs-ja ca-ja ce-ja ceb-ja ch-ja cmn-ja cs-ja cv-ja cy-ja cycl-ja da-ja de-ja dng-ja dsb-ja dtp-ja dws-ja ee-ja el-ja en-ja eo-ja es-ja et-ja eu-ja fi-ja fr-ja fy-ja ga-ja gl-ja gn-ja got-ja gu-ja he-ja hi-ja hil-ja hr-ja hu-ja hy-ja ia-ja id-ja ie-ja ilo-ja io-ja is-ja it-ja ja-ja en-jam fr-jam cmn-jbo cs-jbo de-jbo en-jbo eo-jbo es-jbo et-jbo fi-jbo fr-jbo it-jbo ja-jbo en-jdt de-jv en-jv es-jv cmn-ka de-ka en-ka eo-ka fr-ka is-ka ja-ka ka-ka cmn-kab de-kab en-kab es-kab fr-kab ja-kab en-kam en-kek es-kek en-kha eo-kha es-kha fr-kha en-kjh cmn-kk de-kk en-kk eo-kk es-kk fr-kk id-kk it-kk en-kl es-kl fr-kl cmn-km de-km en-km eo-km es-km fi-km fr-km id-km ja-km en-kn ar-ko az-ko cmn-ko cs-ko de-ko en-ko eo-ko es-ko fi-ko fr-ko hu-ko id-ko it-ko ja-ko ko-ko en-koi eo-koi en-kpv en-krl fr-krl en-ksh ja-ksh cmn-ku de-ku en-ku fi-ku fr-ku it-ku ja-ku en-kum fr-kum cmn-kw cs-kw de-kw el-kw en-kw eo-kw es-kw fi-kw fr-kw it-kw ja-kw de-ky en-ky ja-ky cmn-kzj en-kzj es-kzj ja-kzj ko-kzj be-la bg-la cmn-la cs-la de-la en-la eo-la es-la fi-la fr-la he-la hu-la ia-la is-la it-la ja-la ko-la la-la de-lad en-lad es-lad fr-lad ja-lad de-lb en-lb en-ldn fr-ldn ja-ldn en-lfn es-lfn fr-lfn ja-lfn en-lg en-lij fr-lij it-lij en-liv es-liv ja-liv en-lkt en-lld es-lld fr-lld en-lmo fr-lmo cmn-ln en-ln es-ln fr-ln cmn-lo en-lo fr-lo ja-lo ar-lt cmn-lt de-lt en-lt eo-lt es-lt fi-lt fr-lt id-lt it-lt ja-lt cmn-lv de-lv en-lv es-lv fr-lv it-lv ja-lv cmn-lzh de-lzh en-lzh es-lzh fr-lzh he-lzh it-lzh ja-lzh en-mad en-mai es-mai en-max id-max en-mdf en-mfe en-mg en-mgm en-mh cmn-mhr de-mhr en-mhr es-mhr fr-mhr it-mhr ja-mhr en-mi en-mic en-min id-min de-mk en-mk eo-mk es-mk fr-mk en-ml fr-ml ja-ml cmn-mn de-mn en-mn es-mn fr-mn ja-mn ko-mn en-mnw es-moh de-mr en-mr fr-mr ja-mr ar-mt cs-mt de-mt el-mt en-mt es-mt fr-mt it-mt ja-mt en-mvv en-mwl en-mww es-mww cmn-my en-my es-my ja-my en-myv fr-myv en-na fr-na en-nah es-nah ja-nah cmn-nan en-nan ja-nan af-nb be-nb ber-nb br-nb ce-nb ceb-nb cmn-nb cs-nb cy-nb da-nb de-nb dws-nb el-nb en-nb eo-nb es-nb eu-nb fi-nb fkv-nb fo-nb fr-nb fy-nb got-nb he-nb hi-nb hr-nb hu-nb ia-nb id-nb io-nb is-nb it-nb izh-nb ja-nb ka-nb kk-nb ko-nb krl-nb kw-nb la-nb nb-nb en-nch es-nch fr-nch cmn-nds cs-nds de-nds el-nds en-nds eo-nds es-nds fr-nds it-nds ja-nds nb-nds en-ngt en-ngu en-niu af-nl ar-nl be-nl bg-nl br-nl ca-nl cmn-nl cs-nl da-nl de-nl dsb-nl el-nl en-nl eo-nl es-nl et-nl fi-nl fr-nl fy-nl gl-nl gos-nl he-nl ht-nl hu-nl ia-nl id-nl io-nl it-nl ja-nl ka-nl ko-nl krl-nl kw-nl la-nl mt-nl nb-nl nds-nl nl-nl en-nlv cmn-nn de-nn en-nn eo-nn es-nn fi-nn fr-nn ja-nn nb-nn en-nog en-non fr-non de-nov en-nov es-nov fi-nov fr-nov ja-nov en-npi ja-npi en-nst en-nv en-ny en-oar cmn-oc de-oc en-oc eo-oc es-oc fi-oc fr-oc it-oc ja-oc nl-oc en-or de-orv en-orv eo-orv es-orv fr-orv it-orv ja-orv la-orv en-os eo-os fi-os fr-os ja-os en-ota es-otk en-pa cs-pag de-pag en-pag fr-pag en-pam es-pam fr-pam el-pap en-pap fr-pap id-pap nl-pap en-pau es-pcd fr-pcd de-pdc en-pdc cmn-pes de-pes el-pes en-pes eo-pes es-pes fr-pes id-pes it-pes ja-pes af-pl ar-pl arz-pl be-pl ber-pl bg-pl ca-pl cmn-pl cs-pl cy-pl da-pl de-pl dsb-pl el-pl en-pl eo-pl es-pl et-pl eu-pl fi-pl fo-pl fr-pl fy-pl gd-pl gl-pl he-pl hi-pl hr-pl hu-pl ia-pl id-pl io-pl is-pl it-pl ja-pl jbo-pl ka-pl kab-pl kk-pl kl-pl km-pl ko-pl ku-pl kw-pl la-pl lt-pl lv-pl lzh-pl mhr-pl mt-pl nb-pl nds-pl nl-pl oc-pl orv-pl pes-pl pl-pl cmn-pms de-pms en-pms es-pms fr-pms it-pms ja-pms pl-pms en-pnb en-ppl ja-ppl de-prg en-prg es-prg fr-prg ja-prg pl-prg en-ps af-pt az-pt ber-pt bg-pt ca-pt cbk-pt ce-pt ceb-pt cmn-pt cs-pt da-pt de-pt el-pt en-pt eo-pt es-pt fi-pt fr-pt fy-pt gd-pt gl-pt gn-pt he-pt hr-pt hu-pt ia-pt id-pt ie-pt is-pt it-pt ja-pt ko-pt kw-pt la-pt lfn-pt lt-pt lzh-pt mt-pt nb-pt nds-pt nl-pt pes-pt pl-pt pt-pt en-qu es-qu fr-qu en-quc en-qya es-qya en-rap en-rif es-rif fr-rif de-rm en-rm es-rm fr-rm pt-rm ar-rn de-rn en-rn es-rn fr-rn cmn-ro cs-ro de-ro en-ro eo-ro es-ro et-ro fi-ro fr-ro it-ro ja-ro ko-ro la-ro nb-ro nl-ro pl-ro pt-ro cmn-rom de-rom en-rom fr-rom af-ru ar-ru be-ru ber-ru bg-ru bs-ru bua-ru ca-ru ce-ru ceb-ru cmn-ru cs-ru cv-ru cy-ru cycl-ru da-ru de-ru el-ru en-ru eo-ru es-ru et-ru eu-ru fi-ru fr-ru fuc-ru fy-ru gd-ru gl-ru gn-ru he-ru hi-ru hr-ru hu-ru hy-ru ia-ru id-ru io-ru is-ru it-ru izh-ru ja-ru jbo-ru ka-ru kab-ru kk-ru km-ru ko-ru kw-ru ky-ru la-ru lt-ru lv-ru lzh-ru mhr-ru nb-ru nds-ru nl-ru oc-ru orv-ru os-ru pl-ru pt-ru qya-ru rn-ru ro-ru ru-ru en-rue es-rue en-rw en-sa id-sa ja-sa cmn-sah en-sah ru-sah fr-sc de-scn en-scn es-scn fr-scn ar-sco cmn-sco de-sco en-sco eo-sco fr-sco la-sco nl-sco en-sd en-se es-se en-sg en-sgs es-sgs cmn-shs en-shs es-shs fr-shs it-shs ja-shs ru-shs en-si en-sjn fr-sjn ru-sjn cmn-sl cs-sl de-sl en-sl eo-sl es-sl fi-sl fr-sl it-sl ja-sl nb-sl pl-sl ru-sl en-sm fr-sm en-sma en-sn fr-sn cmn-sq en-sq fr-sq it-sq ja-sq be-sr cmn-sr de-sr en-sr eo-sr es-sr fr-sr it-sr ja-sr la-sr nb-sr pl-sr ru-sr en-su de-sux en-sux es-sux fr-sux ja-sux nb-sux cmn-sv da-sv de-sv el-sv en-sv eo-sv es-sv fi-sv fr-sv hu-sv it-sv ja-sv jbo-sv nb-sv pl-sv pt-sv ru-sv sv-sv de-swg en-swg af-swh avk-swh be-swh de-swh en-swh eo-swh es-swh eu-swh fo-swh fr-swh fy-swh it-swh ja-swh nl-swh pms-swh rn-swh ro-swh ru-swh sv-swh swh-swh en-ta es-ta en-te es-te en-tet cmn-tg de-tg en-tg fr-tg ja-tg cmn-th de-th en-th eo-th es-th fr-th it-th ja-th fr-thv en-ti cmn-tk de-tk en-tk fr-tk ja-tk pl-tk cmn-tl cs-tl de-tl en-tl eo-tl es-tl fr-tl he-tl it-tl ja-tl ka-tl nb-tl pl-tl pt-tl ru-tl cmn-tlh cs-tlh de-tlh en-tlh eo-tlh es-tlh fr-tlh it-tlh ja-tlh ko-tlh la-tlh nb-tlh nl-tlh pl-tlh ru-tlh en-tly fr-tly en-tmw en-to es-to fr-to cmn-toki de-toki en-toki eo-toki es-toki fi-toki fr-toki he-toki it-toki ja-toki nb-toki nl-toki pl-toki pt-toki ru-toki swh-toki de-tpi en-tpi eo-tpi fr-tpi en-tpw es-tpw fr-tpw af-tr ar-tr avk-tr az-tr be-tr bg-tr br-tr ca-tr cmn-tr crh-tr cs-tr cv-tr da-tr de-tr dws-tr el-tr en-tr eo-tr es-tr et-tr fi-tr fo-tr fr-tr fy-tr he-tr hi-tr hr-tr hu-tr ia-tr id-tr it-tr ja-tr ka-tr ko-tr la-tr lfn-tr lt-tr lzz-tr nb-tr nl-tr nn-tr oc-tr pl-tr pt-tr ro-tr ru-tr sco-tr sv-tr swh-tr tl-tr toki-tr tr-tr en-ts cmn-tt de-tt en-tt eo-tt es-tt fi-tt fr-tt it-tt ja-tt nb-tt nl-tt pl-tt ru-tt tr-tt en-tvl en-ty fr-ty ru-ty en-tyv en-tzl es-tzl it-tzl en-udm ru-udm ar-ug cmn-ug cs-ug de-ug en-ug es-ug fr-ug it-ug ja-ug ko-ug pl-ug ru-ug tr-ug af-uk ar-uk be-uk bg-uk ca-uk cmn-uk cs-uk de-uk el-uk en-uk eo-uk es-uk et-uk fi-uk fr-uk fy-uk he-uk hr-uk hu-uk id-uk it-uk ja-uk ka-uk ko-uk la-uk nb-uk nds-uk nl-uk orv-uk pes-uk pl-uk pt-uk ru-uk sl-uk sr-uk swh-uk tr-uk tt-uk ug-uk uk-uk en-umb da-ur de-ur en-ur fr-ur hi-ur hr-ur hu-ur ja-ur pl-ur ru-ur tr-ur ur-ur cmn-uz de-uz en-uz fr-uz ja-uz pl-uz ru-uz tr-uz en-vec fr-vec it-vec fr-vep nb-vep af-vi be-vi bn-vi ce-vi cmn-vi cs-vi de-vi dws-vi en-vi eo-vi es-vi fi-vi fr-vi fy-vi hu-vi id-vi it-vi ja-vi ka-vi kab-vi kha-vi km-vi ko-vi nl-vi pl-vi pt-vi ro-vi ru-vi sl-vi toki-vi tr-vi tt-vi ug-vi uk-vi vi-vi de-vo en-vo eo-vo es-vo fr-vo ja-vo en-vro es-vro et-vro en-wa es-wa fr-wa nl-wa de-war en-war fr-war en-wo es-wo fr-wo ar-wuu cmn-wuu cs-wuu de-wuu en-wuu es-wuu fr-wuu hi-wuu hsn-wuu it-wuu ja-wuu la-wuu lv-wuu pl-wuu sq-wuu wuu-wuu cmn-xal el-xal en-xal es-xal ja-xal ru-xal en-xh cmn-yi de-yi en-yi es-yi fr-yi he-yi it-yi ja-yi pl-yi ru-yi en-yo cmn-yue de-yue en-yue es-yue fi-yue fr-yue it-yue ja-yue ko-yue kzj-yue pl-yue ru-yue uk-yue wuu-yue en-zlm ja-zlm af-zsm ar-zsm arz-zsm be-zsm br-zsm cmn-zsm de-zsm dtp-zsm dws-zsm en-zsm es-zsm fo-zsm fr-zsm fy-zsm he-zsm hu-zsm id-zsm is-zsm it-zsm ja-zsm ko-zsm kzj-zsm nl-zsm pl-zsm pt-zsm ro-zsm ru-zsm uk-zsm ur-zsm vi-zsm yue-zsm en-zu en-zza
SPC_v1	SPC/v1/moses/%s-%s.txt.zip	af-en el-en en-zh
SETIMES_v2	SETIMES/v2/moses/%s-%s.txt.zip	bg-bs bg-el bs-el bg-en bs-en el-en bg-hr bs-hr el-hr en-hr bg-mk bs-mk el-mk en-mk hr-mk bg-ro bs-ro el-ro en-ro hr-ro mk-ro bg-sq bs-sq el-sq en-sq hr-sq mk-sq ro-sq bg-sr bs-sr el-sr en-sr hr-sr mk-sr ro-sr sq-sr bg-tr bs-tr el-tr en-tr hr-tr mk-tr ro-tr sq-tr sr-tr
SciELO_v1	SciELO/v1/moses/%s-%s.txt.zip	en-es en-pt es-pt
sardware_v1	sardware/v1/moses/%s-%s.txt.zip	en-sc
QED_v2.0a	QED/v2.0a/moses/%s-%s.txt.zip	aa-ab aa-ae ab-ae aa-af ab-af aa-aka ab-aka af-aka aa-amh ab-amh af-amh aka-amh aa-an ab-an af-an aka-an amh-an aa-ar ab-ar af-ar aka-ar amh-ar an-ar aa-arq ab-arq af-arq aka-arq amh-arq an-arq ar-arq aa-arz ar-arz arq-arz aa-as ab-as af-as aka-as amh-as an-as ar-as arq-as aa-ase ab-ase af-ase aka-ase amh-ase an-ase ar-ase arq-ase as-ase aa-ast ab-ast af-ast aka-ast amh-ast an-ast ar-ast as-ast ase-ast aa-av ab-av af-av aka-av amh-av an-av ar-av ast-av aa-ay ab-ay af-ay aka-ay amh-ay an-ay ar-ay as-ay ase-ay ast-ay av-ay ab-az af-az aka-az amh-az an-az ar-az arq-az as-az ase-az ast-az av-az ay-az aa-ba ab-ba af-ba aka-ba an-ba as-ba ase-ba ast-ba ay-ba aa-bam ab-bam aka-bam amh-bam ar-bam av-bam ay-bam az-bam af-be amh-be ar-be arq-be ast-be az-be aa-ber ab-ber af-ber aka-ber av-ber aa-bg ab-bg af-bg aka-bg amh-bg an-bg ar-bg arq-bg arz-bg as-bg ase-bg ast-bg av-bg ay-bg az-bg bam-bg be-bg aa-bh ab-bh aka-bh an-bh ar-bh arq-bh ast-bh av-bh ay-bh az-bh af-bi amh-bi ar-bi az-bi bg-bi aa-bn ab-bn af-bn aka-bn amh-bn an-bn ar-bn arq-bn arz-bn as-bn ast-bn av-bn az-bn bam-bn be-bn bg-bn bh-bn aa-bnt ab-bnt af-bnt aka-bnt an-bnt ar-bnt as-bnt ast-bnt av-bnt az-bnt bh-bnt bn-bnt af-bo aka-bo amh-bo an-bo ar-bo ase-bo ast-bo av-bo ay-bo az-bo be-bo bg-bo bh-bo bn-bo bnt-bo ab-br af-br ar-br ase-br ast-br be-br bg-br bn-br bo-br ab-bs af-bs aka-bs amh-bs an-bs ar-bs arq-bs ast-bs av-bs ay-bs az-bs be-bs bg-bs bh-bs bn-bs bnt-bs bo-bs br-bs bg-bug aa-ca ab-ca af-ca aka-ca amh-ca an-ca ar-ca arq-ca as-ca ase-ca ast-ca ay-ca az-ca ba-ca be-ca bg-ca bi-ca bn-ca bo-ca br-ca bs-ca ab-ce ar-ce ab-ceb af-ceb aka-ceb amh-ceb an-ceb ar-ceb as-ceb ast-ceb av-ceb ay-ceb az-ceb be-ceb bg-ceb bh-ceb bn-ceb bnt-ceb bo-ceb bs-ceb ca-ceb ar-ch aa-cho ab-cho af-cho aka-cho ar-cho av-cho ba-cho ber-cho bg-cho bn-cho aa-cku aka-cku amh-cku ar-cku as-cku ase-cku ay-cku bg-cku ca-cku aa-cnh ar-cnh arz-cnh az-cnh be-cnh bg-cnh bn-cnh bs-cnh ca-cnh aka-cr ar-cr aa-cs ab-cs af-cs aka-cs amh-cs an-cs ar-cs arq-cs arz-cs as-cs ase-cs ast-cs av-cs ay-cs az-cs bam-cs be-cs ber-cs bg-cs bh-cs bi-cs bn-cs bnt-cs bo-cs br-cs bs-cs ca-cs ce-cs ceb-cs ch-cs cho-cs cku-cs cnh-cs ab-cu aka-cu amh-cu an-cu ar-cu ast-cu av-cu ay-cu az-cu bg-cu bh-cu bn-cu bnt-cu bo-cu bs-cu ceb-cu cs-cu aa-cv bh-cv ab-cy af-cy amh-cy ar-cy as-cy ast-cy az-cy be-cy bg-cy bn-cy bo-cy br-cy bs-cy ca-cy cs-cy aa-da ab-da af-da aka-da amh-da an-da ar-da arq-da arz-da as-da ase-da ast-da av-da ay-da az-da be-da bg-da bh-da bn-da bnt-da bo-da br-da bs-da ca-da ceb-da cho-da cku-da cnh-da cs-da cu-da cy-da aa-de ab-de af-de aka-de amh-de an-de ar-de arq-de arz-de as-de ase-de ast-de av-de ay-de az-de bam-de be-de ber-de bg-de bi-de bn-de bnt-de bo-de br-de bs-de ca-de ceb-de ch-de cho-de cku-de cnh-de cr-de cs-de cu-de cy-de da-de aa-dv ab-dv af-dv aka-dv an-dv ar-dv as-dv ast-dv av-dv ber-dv bg-dv bh-dv bn-dv bs-dv ca-dv ceb-dv cho-dv cs-dv cv-dv cy-dv da-dv de-dv aa-dz ab-dz af-dz aka-dz av-dz az-dz ber-dz cho-dz cs-dz da-dz de-dz dv-dz aa-ee ab-ee aka-ee amh-ee an-ee ast-ee av-ee ay-ee az-ee bam-ee bg-ee cu-ee de-ee aa-efi ab-efi af-efi aka-efi an-efi ar-efi ast-efi av-efi ay-efi az-efi bg-efi bh-efi bn-efi bnt-efi bo-efi bs-efi ceb-efi cs-efi cu-efi da-efi aa-el ab-el af-el aka-el amh-el an-el ar-el arq-el arz-el as-el ase-el ast-el av-el ay-el az-el bam-el be-el ber-el bg-el bh-el bi-el bn-el bnt-el bo-el br-el bs-el ca-el ceb-el cku-el cnh-el cr-el cs-el cu-el cy-el da-el de-el dv-el ee-el efi-el aa-en ab-en ae-en aeb-en af-en aka-en amh-en an-en ar-en arq-en arz-en as-en ase-en ast-en av-en ay-en az-en ba-en bam-en be-en ber-en bg-en bh-en bi-en bn-en bnt-en bo-en br-en bs-en bug-en ca-en ce-en ceb-en ch-en cho-en cku-en cnh-en cr-en cs-en cu-en cv-en cy-en da-en de-en dv-en dz-en ee-en efi-en el-en aa-eo ab-eo ae-eo af-eo aka-eo amh-eo an-eo ar-eo arq-eo as-eo ase-eo ast-eo av-eo ay-eo az-eo bam-eo be-eo bg-eo bh-eo bn-eo bo-eo br-eo bs-eo ca-eo ceb-eo cku-eo cnh-eo cs-eo cu-eo cy-eo da-eo de-eo dv-eo ee-eo efi-eo el-eo en-eo aa-es ab-es aeb-es af-es aka-es amh-es an-es ar-es arq-es arz-es as-es ase-es ast-es av-es ay-es az-es ba-es bam-es be-es ber-es bg-es bh-es bi-es bn-es bnt-es bo-es br-es bs-es ca-es ceb-es ch-es cku-es cnh-es cs-es cu-es cy-es da-es de-es dv-es ee-es efi-es el-es en-es eo-es aa-et ab-et af-et aka-et amh-et ar-et arq-et arz-et as-et ast-et av-et az-et bam-et be-et bg-et bi-et bn-et bo-et br-et bs-et ca-et ceb-et cnh-et cs-et cy-et da-et de-et dv-et el-et en-et eo-et es-et aa-eu ab-eu af-eu aka-eu amh-eu an-eu ar-eu arq-eu as-eu ase-eu ast-eu av-eu ay-eu az-eu be-eu bg-eu bh-eu bn-eu bnt-eu bo-eu bs-eu ca-eu ceb-eu cku-eu cnh-eu cs-eu cu-eu cy-eu da-eu de-eu dv-eu efi-eu el-eu en-eu eo-eu es-eu et-eu aa-fa ab-fa af-fa aka-fa amh-fa an-fa ar-fa arq-fa arz-fa as-fa ase-fa ast-fa ay-fa az-fa bam-fa be-fa bg-fa bi-fa bn-fa bo-fa br-fa bs-fa ca-fa ceb-fa cku-fa cnh-fa cr-fa cs-fa cy-fa da-fa de-fa dv-fa dz-fa efi-fa el-fa en-fa eo-fa es-fa et-fa eu-fa ar-ff arq-ff bg-ff de-ff en-ff es-ff aa-fi ab-fi af-fi aka-fi amh-fi an-fi ar-fi arq-fi arz-fi as-fi ase-fi ast-fi av-fi az-fi be-fi bg-fi bi-fi bn-fi bnt-fi bo-fi br-fi bs-fi ca-fi ceb-fi cnh-fi cs-fi cy-fi da-fi de-fi dv-fi el-fi en-fi eo-fi es-fi et-fi eu-fi fa-fi aa-fil ab-fil ae-fil af-fil amh-fil ar-fil arq-fil arz-fil as-fil ast-fil az-fil be-fil bg-fil bn-fil bo-fil br-fil bs-fil ca-fil ceb-fil cnh-fil cs-fil cy-fil da-fil de-fil dv-fil el-fil en-fil eo-fil es-fil et-fil eu-fil fa-fil fi-fil aka-fj amh-fj an-fj ar-fj ase-fj ast-fj av-fj ay-fj az-fj bam-fj bg-fj bh-fj bn-fj bnt-fj bo-fj bs-fj ca-fj ceb-fj cs-fj cu-fj da-fj de-fj ee-fj efi-fj el-fj en-fj eo-fj es-fj et-fj eu-fj fi-fj ar-fo bg-fo ca-fo cs-fo de-fo el-fo en-fo es-fo fa-fo aa-fr ab-fr aeb-fr af-fr aka-fr amh-fr an-fr ar-fr arq-fr arz-fr as-fr ase-fr ast-fr av-fr ay-fr az-fr bam-fr be-fr ber-fr bg-fr bh-fr bi-fr bn-fr bnt-fr bo-fr br-fr bs-fr ca-fr ce-fr ceb-fr ch-fr cku-fr cnh-fr co-fr cs-fr cu-fr cv-fr cy-fr da-fr de-fr dv-fr dz-fr ee-fr efi-fr el-fr en-fr eo-fr es-fr et-fr eu-fr fa-fr ff-fr fi-fr fil-fr fj-fr fo-fr aa-ful ab-ful af-ful aka-ful amh-ful an-ful ar-ful arq-ful as-ful ase-ful ast-ful av-ful az-ful bg-ful bh-ful bn-ful bnt-ful bo-ful bs-ful ceb-ful cs-ful cu-ful cv-ful cy-ful da-ful de-ful dv-ful efi-ful el-ful en-ful eo-ful es-ful et-ful eu-ful fi-ful fil-ful fj-ful fr-ful aa-ga ab-ga af-ga aka-ga amh-ga an-ga ar-ga as-ga ast-ga av-ga ay-ga az-ga be-ga bg-ga bh-ga bn-ga bnt-ga bo-ga bs-ga ca-ga ceb-ga cs-ga cu-ga cy-ga da-ga de-ga dv-ga ee-ga efi-ga el-ga en-ga eo-ga es-ga et-ga eu-ga fa-ga fi-ga fil-ga fj-ga fr-ga ful-ga ar-gd as-gd ast-gd bg-gd bn-gd cs-gd cy-gd da-gd de-gd dv-gd el-gd en-gd eo-gd es-gd et-gd fi-gd fil-gd ful-gd ga-gd aa-gl ab-gl af-gl aka-gl amh-gl an-gl ar-gl arq-gl as-gl ase-gl ast-gl av-gl ay-gl az-gl be-gl bg-gl bh-gl bn-gl bnt-gl bo-gl br-gl bs-gl ca-gl ceb-gl cku-gl cs-gl cu-gl cy-gl da-gl de-gl dv-gl efi-gl el-gl en-gl eo-gl es-gl et-gl eu-gl fa-gl fi-gl fil-gl fj-gl fr-gl ful-gl ga-gl ar-gn bg-gn bo-gn ca-gn cs-gn cy-gn da-gn de-gn el-gn en-gn eo-gn es-gn et-gn eu-gn fa-gn fi-gn fil-gn fr-gn gl-gn aa-gu ab-gu af-gu amh-gu ar-gu as-gu ast-gu az-gu ba-gu be-gu ber-gu bg-gu bn-gu bo-gu br-gu bs-gu ca-gu cho-gu cs-gu cy-gu da-gu de-gu el-gu en-gu eo-gu es-gu et-gu eu-gu fa-gu fi-gu fil-gu fr-gu ga-gu gl-gu aa-hai ab-hai aka-hai an-hai ar-hai ast-hai av-hai ay-hai az-hai bh-hai bn-hai bnt-hai bo-hai bs-hai ceb-hai cs-hai cu-hai da-hai de-hai dz-hai efi-hai el-hai en-hai eo-hai es-hai eu-hai fa-hai fj-hai fr-hai ful-hai ga-hai gl-hai af-hau ar-hau az-hau be-hau bg-hau bn-hau ca-hau cs-hau cy-hau da-hau de-hau el-hau en-hau eo-hau es-hau et-hau eu-hau fa-hau fi-hau fil-hau fr-hau ga-hau gl-hau gu-hau aa-haw ab-haw az-haw cs-haw da-haw de-haw dz-haw en-haw fa-haw fr-haw hai-haw af-haz as-haz ba-haz bg-hb cs-hb en-hb es-hb aa-hch aka-hch amh-hch ar-hch as-hch ase-hch ay-hch bg-hch ca-hch cku-hch cs-hch da-hch de-hch el-hch eo-hch es-hch eu-hch fa-hch fr-hch gl-hch aa-he ab-he af-he aka-he amh-he an-he ar-he arq-he arz-he as-he ase-he ast-he av-he ay-he az-he be-he ber-he bg-he bi-he bn-he bo-he br-he bs-he ca-he ceb-he cho-he cnh-he cs-he cu-he cy-he da-he de-he dv-he dz-he efi-he el-he en-he eo-he es-he et-he eu-he fa-he fi-he fil-he fj-he fo-he fr-he ful-he ga-he gd-he gl-he gn-he gu-he hau-he aa-hi ab-hi af-hi aka-hi amh-hi an-hi ar-hi arq-hi arz-hi as-hi ase-hi ast-hi av-hi ay-hi az-hi bam-hi be-hi bg-hi bh-hi bi-hi bn-hi bnt-hi bo-hi br-hi bs-hi ca-hi ceb-hi ch-hi cho-hi cnh-hi cs-hi cu-hi cy-hi da-hi de-hi dv-hi efi-hi el-hi en-hi eo-hi es-hi et-hi eu-hi fa-hi ff-hi fi-hi fil-hi fj-hi fr-hi ful-hi ga-hi gd-hi gl-hi gn-hi gu-hi hai-hi hau-hi he-hi ab-ho bam-ho bn-ho cho-ho en-ho aa-hr ab-hr af-hr aka-hr amh-hr an-hr ar-hr arq-hr arz-hr ast-hr av-hr az-hr be-hr bg-hr bi-hr bn-hr bo-hr br-hr bs-hr ca-hr ceb-hr ch-hr cnh-hr cs-hr cy-hr da-hr de-hr dv-hr el-hr en-hr eo-hr es-hr et-hr eu-hr fa-hr ff-hr fi-hr fil-hr fj-hr fr-hr ga-hr gl-hr gu-hr hau-hr he-hr hi-hr aa-ht ab-ht af-ht amh-ht ar-ht arq-ht arz-ht az-ht be-ht bg-ht bn-ht bo-ht bs-ht ca-ht cho-ht cnh-ht cs-ht cy-ht da-ht de-ht el-ht en-ht eo-ht es-ht et-ht eu-ht fa-ht fi-ht fil-ht fr-ht ga-ht gl-ht gu-ht he-ht hi-ht ho-ht hr-ht aa-hu ab-hu af-hu aka-hu amh-hu an-hu ar-hu arq-hu arz-hu as-hu ase-hu ast-hu av-hu ay-hu az-hu bam-hu be-hu bg-hu bh-hu bi-hu bn-hu bnt-hu bo-hu br-hu bs-hu ca-hu ceb-hu cho-hu cku-hu cnh-hu cr-hu cs-hu cu-hu cv-hu cy-hu da-hu de-hu dv-hu dz-hu ee-hu efi-hu el-hu en-hu eo-hu es-hu et-hu eu-hu fa-hu ff-hu fi-hu fil-hu fj-hu fo-hu fr-hu ful-hu ga-hu gd-hu gl-hu gn-hu gu-hu hai-hu hau-hu haw-hu hch-hu he-hu hi-hu hr-hu ht-hu aa-hup ar-hup az-hup bg-hup bh-hup bs-hup cs-hup cv-hup de-hup dv-hup el-hup en-hup es-hup eu-hup fa-hup fr-hup ful-hup he-hup hr-hup hu-hup ab-hus az-hus da-hus de-hus dz-hus fa-hus haw-hus hu-hus aa-hy ab-hy af-hy aka-hy amh-hy an-hy ar-hy arq-hy arz-hy as-hy ase-hy ast-hy av-hy ay-hy az-hy ba-hy be-hy bg-hy bh-hy bi-hy bn-hy bnt-hy bo-hy bs-hy ca-hy ceb-hy cnh-hy cr-hy cs-hy cu-hy cy-hy da-hy de-hy efi-hy el-hy en-hy eo-hy es-hy et-hy eu-hy fa-hy fi-hy fil-hy fj-hy fo-hy fr-hy ful-hy ga-hy gl-hy gu-hy hai-hy hau-hy he-hy hi-hy hr-hy ht-hy hu-hy ab-hz en-hz es-hz fr-hz hi-hz hu-hz ab-ia af-ia aka-ia ar-ia ast-ia bg-ia ca-ia cs-ia cy-ia da-ia de-ia el-ia en-ia eo-ia es-ia eu-ia fa-ia fi-ia fr-ia gl-ia gn-ia he-ia hu-ia ar-ibo az-ibo be-ibo bg-ibo bs-ibo ca-ibo cnh-ibo da-ibo de-ibo el-ibo en-ibo eo-ibo es-ibo et-ibo eu-ibo fa-ibo fi-ibo fil-ibo fr-ibo he-ibo hi-ibo hr-ibo hu-ibo hy-ibo aa-id ab-id af-id aka-id amh-id an-id ar-id arq-id arz-id as-id ase-id ast-id av-id az-id bam-id be-id bg-id bi-id bn-id bnt-id bo-id br-id bs-id ca-id ceb-id ch-id cnh-id cs-id cy-id da-id de-id dv-id el-id en-id eo-id es-id et-id eu-id fa-id ff-id fi-id fil-id fo-id fr-id ful-id ga-id gd-id gl-id gn-id gu-id hau-id he-id hi-id hr-id ht-id hu-id hup-id hy-id ia-id ibo-id aa-ie aka-ie amh-ie ar-ie as-ie ase-ie ay-ie bg-ie ca-ie cku-ie cs-ie da-ie de-ie el-ie en-ie eo-ie es-ie eu-ie fa-ie fi-ie fr-ie gl-ie hch-ie he-ie hu-ie id-ie aa-ik af-ik de-ik el-ik en-ik es-ik fa-ik fo-ik fr-ik he-ik hy-ik af-inh ar-inh az-inh be-inh bg-inh bn-inh bs-inh ca-inh cs-inh da-inh de-inh el-inh en-inh eo-inh es-inh et-inh eu-inh fa-inh fi-inh fil-inh fr-inh gl-inh he-inh hr-inh hu-inh hup-inh hy-inh id-inh ar-io ast-io bg-io da-io de-io en-io eo-io es-io fa-io fi-io fr-io gu-io he-io hi-io hu-io ik-io ar-iro az-iro de-iro en-iro es-iro fa-iro fr-iro hr-iro id-iro aa-is ab-is af-is amh-is ar-is arq-is arz-is as-is ast-is av-is az-is be-is bg-is bn-is bo-is br-is bs-is ca-is cnh-is cs-is cy-is da-is de-is dv-is el-is en-is eo-is es-is et-is eu-is fa-is fi-is fil-is fr-is ful-is ga-is gd-is gl-is gu-is hau-is he-is hi-is hr-is ht-is hu-is hy-is id-is aa-it ab-it af-it aka-it amh-it an-it ar-it arq-it arz-it as-it ase-it ast-it av-it ay-it az-it bam-it be-it bg-it bi-it bn-it bnt-it bo-it br-it bs-it ca-it ce-it ceb-it ch-it cho-it cku-it cnh-it cs-it cy-it da-it de-it dv-it ee-it efi-it el-it en-it eo-it es-it et-it eu-it fa-it ff-it fi-it fil-it fj-it fo-it fr-it ful-it ga-it gd-it gl-it gn-it gu-it hau-it hch-it he-it hi-it ho-it hr-it ht-it hu-it hup-it hy-it ia-it ibo-it id-it ie-it ik-it inh-it io-it iro-it is-it aka-iu an-iu ar-iu ase-iu ast-iu av-iu ay-iu az-iu bh-iu bn-iu bnt-iu bo-iu bs-iu ceb-iu cs-iu cu-iu da-iu de-iu efi-iu el-iu en-iu eo-iu es-iu eu-iu fi-iu fj-iu fr-iu ful-iu ga-iu gl-iu hai-iu hi-iu hy-iu it-iu aa-ja ab-ja af-ja aka-ja amh-ja an-ja ar-ja arq-ja arz-ja as-ja ase-ja ast-ja av-ja ay-ja az-ja bam-ja be-ja ber-ja bg-ja bh-ja bi-ja bn-ja bo-ja br-ja bs-ja ca-ja ceb-ja ch-ja cho-ja cnh-ja cr-ja cs-ja cu-ja cy-ja da-ja de-ja dv-ja ee-ja el-ja en-ja eo-ja es-ja et-ja eu-ja fa-ja fi-ja fil-ja fj-ja fr-ja ful-ja ga-ja gd-ja gl-ja gn-ja gu-ja hau-ja he-ja hi-ja ho-ja hr-ja ht-ja hu-ja hup-ja hy-ja ia-ja ibo-ja id-ja inh-ja io-ja is-ja it-ja aa-jv ab-jv af-jv ar-jv arz-jv ast-jv az-jv bg-jv bn-jv bo-jv br-jv bs-jv ca-jv cnh-jv cs-jv cy-jv da-jv de-jv el-jv en-jv eo-jv es-jv et-jv fa-jv fi-jv fil-jv fr-jv gl-jv gn-jv gu-jv he-jv hi-jv hr-jv ht-jv hu-jv hy-jv id-jv is-jv it-jv ja-jv aa-ka ab-ka af-ka amh-ka an-ka ar-ka arq-ka arz-ka as-ka ase-ka ast-ka av-ka az-ka ba-ka bam-ka be-ka bg-ka bi-ka bn-ka bo-ka br-ka bs-ka ca-ka ceb-ka cho-ka cnh-ka cs-ka cy-ka da-ka de-ka dv-ka dz-ka efi-ka el-ka en-ka eo-ka es-ka et-ka eu-ka fa-ka fi-ka fil-ka fj-ka fo-ka fr-ka ful-ka ga-ka gd-ka gl-ka gn-ka gu-ka hau-ka haz-ka he-ka hi-ka hr-ka ht-ka hu-ka hup-ka hy-ka ibo-ka id-ka inh-ka is-ka it-ka ja-ka jv-ka ar-kar bg-kar cs-kar da-kar en-kar eo-kar es-kar ka-kar ab-kau en-kau es-kau it-kau aa-kik bh-kik cv-kik dv-kik en-kik fr-kik ful-kik hu-kik hup-kik en-kin hr-kin ab-kj af-kj de-kj en-kj ja-kj ka-kj af-kk amh-kk ar-kk arq-kk as-kk ast-kk az-kk be-kk bg-kk bn-kk bo-kk bs-kk ca-kk ceb-kk cnh-kk cs-kk cy-kk da-kk de-kk dv-kk el-kk en-kk eo-kk es-kk et-kk eu-kk fa-kk fi-kk fil-kk fr-kk ful-kk ga-kk gd-kk gl-kk gu-kk he-kk hi-kk hr-kk ht-kk hu-kk hy-kk ibo-kk id-kk is-kk it-kk ja-kk ka-kk ab-kl bg-kl cr-kl el-kl en-kl es-kl fr-kl he-kl hu-kl aa-km ab-km af-km aka-km amh-km an-km ar-km arq-km as-km ase-km ast-km az-km bg-km bh-km bn-km bo-km br-km bs-km ca-km ceb-km cs-km cv-km cy-km da-km de-km dv-km el-km en-km eo-km es-km et-km eu-km fa-km fi-km fil-km fr-km ful-km ga-km gd-km gl-km gu-km he-km hi-km hr-km ht-km hu-km hup-km hy-km id-km inh-km is-km it-km ja-km ka-km kik-km kj-km kk-km ab-kn af-kn amh-kn ar-kn ast-kn az-kn be-kn bg-kn bn-kn bo-kn br-kn bs-kn ca-kn ceb-kn cs-kn cy-kn da-kn de-kn el-kn en-kn eo-kn es-kn et-kn eu-kn fa-kn fi-kn fil-kn fr-kn ga-kn gl-kn gu-kn hau-kn he-kn hi-kn hr-kn ht-kn hu-kn hy-kn id-kn is-kn it-kn ja-kn jv-kn ka-kn kk-kn km-kn aa-ko ab-ko af-ko aka-ko amh-ko an-ko ar-ko arq-ko arz-ko as-ko ase-ko ast-ko av-ko ay-ko az-ko ba-ko bam-ko be-ko bg-ko bh-ko bi-ko bn-ko bnt-ko bo-ko br-ko bs-ko ca-ko ceb-ko ch-ko cho-ko cnh-ko cs-ko cu-ko cy-ko da-ko de-ko dv-ko ee-ko efi-ko el-ko en-ko eo-ko es-ko et-ko eu-ko fa-ko fi-ko fil-ko fj-ko fo-ko fr-ko ful-ko ga-ko gd-ko gl-ko gn-ko gu-ko hai-ko hau-ko he-ko hi-ko hr-ko ht-ko hu-ko hup-ko hy-ko ia-ko ibo-ko id-ko inh-ko io-ko is-ko it-ko iu-ko ja-ko jv-ko ka-ko kar-ko kk-ko km-ko kn-ko de-ksh en-ksh aa-ku ab-ku af-ku aka-ku amh-ku an-ku ar-ku arq-ku as-ku ase-ku ast-ku av-ku ay-ku az-ku bam-ku be-ku bg-ku bh-ku bn-ku bnt-ku bo-ku br-ku bs-ku ca-ku ceb-ku cs-ku cu-ku cy-ku da-ku de-ku dv-ku ee-ku efi-ku el-ku en-ku eo-ku es-ku et-ku eu-ku fa-ku fi-ku fil-ku fj-ku fo-ku fr-ku ful-ku ga-ku gl-ku gu-ku hai-ku he-ku hi-ku hr-ku hu-ku hy-ku id-ku is-ku it-ku iu-ku ja-ku jv-ku ka-ku kar-ku kk-ku km-ku kn-ku ko-ku ca-kv es-kv fr-kv aa-kw ab-kw aka-kw amh-kw an-kw ar-kw ase-kw ast-kw av-kw ay-kw az-kw bam-kw bg-kw bh-kw bn-kw bnt-kw bo-kw bs-kw ceb-kw cs-kw cu-kw da-kw de-kw ee-kw efi-kw el-kw en-kw eo-kw es-kw eu-kw fi-kw fj-kw fr-kw ful-kw ga-kw gl-kw hai-kw hi-kw hu-kw hy-kw it-kw iu-kw ja-kw ko-kw ku-kw ab-ky af-ky amh-ky ar-ky arq-ky as-ky ast-ky az-ky be-ky bg-ky bn-ky bo-ky br-ky bs-ky ca-ky cs-ky cy-ky da-ky de-ky dv-ky el-ky en-ky eo-ky es-ky et-ky eu-ky fa-ky fi-ky fil-ky fr-ky ful-ky ga-ky gd-ky gl-ky gn-ky gu-ky he-ky hi-ky hr-ky ht-ky hu-ky hy-ky id-ky is-ky it-ky ja-ky jv-ky ka-ky kk-ky km-ky kn-ky ko-ky ku-ky aa-la ab-la af-la aka-la amh-la an-la ar-la arq-la as-la ase-la ast-la av-la ay-la az-la bam-la be-la bg-la bh-la bn-la bnt-la bo-la bs-la ca-la ceb-la cho-la cku-la cs-la cu-la cy-la da-la de-la ee-la efi-la el-la en-la eo-la es-la et-la eu-la fa-la fi-la fil-la fj-la fr-la ful-la ga-la gl-la gu-la hai-la hau-la hch-la he-la hi-la ho-la hr-la ht-la hu-la hy-la id-la ie-la is-la it-la iu-la ja-la ka-la kk-la km-la kn-la ko-la ku-la kw-la ky-la ab-lb af-lb ar-lb as-lb ast-lb bg-lb bn-lb bo-lb br-lb bs-lb ca-lb ceb-lb cs-lb cy-lb da-lb de-lb dv-lb el-lb en-lb eo-lb es-lb et-lb eu-lb fa-lb fi-lb fil-lb fr-lb ful-lb ga-lb gd-lb gl-lb gu-lb he-lb hi-lb hr-lb ht-lb hu-lb hup-lb hy-lb id-lb inh-lb is-lb it-lb ja-lb ka-lb kar-lb kj-lb kk-lb km-lb ko-lb ku-lb ky-lb la-lb aa-lg ab-lg aka-lg amh-lg an-lg ar-lg as-lg ast-lg av-lg ay-lg az-lg bam-lg bg-lg bh-lg bn-lg bnt-lg bo-lg bs-lg ceb-lg cs-lg cu-lg da-lg de-lg ee-lg efi-lg el-lg en-lg eo-lg es-lg eu-lg fj-lg fr-lg ful-lg ga-lg gl-lg hai-lg hi-lg hu-lg hy-lg id-lg it-lg iu-lg ja-lg ko-lg ku-lg kw-lg la-lg ab-li af-li de-li en-li ja-li ka-li kj-li km-li lb-li aa-lin ab-lin aka-lin amh-lin an-lin ast-lin av-lin ay-lin az-lin bam-lin bg-lin bn-lin cu-lin da-lin de-lin ee-lin efi-lin el-lin en-lin eo-lin es-lin fj-lin fr-lin ga-lin hai-lin hu-lin it-lin iu-lin ja-lin ko-lin ku-lin kw-lin la-lin lg-lin bg-lkt cs-lkt en-lkt ka-lkt ko-lkt cs-lld de-lld el-lld en-lld es-lld fr-lld id-lld it-lld ku-lld aa-lo ab-lo af-lo aka-lo an-lo ar-lo ast-lo av-lo ay-lo az-lo be-lo bg-lo bh-lo bn-lo bnt-lo bo-lo br-lo bs-lo ca-lo ceb-lo cnh-lo cs-lo cu-lo cv-lo cy-lo da-lo de-lo dv-lo efi-lo el-lo en-lo eo-lo es-lo et-lo eu-lo fa-lo fi-lo fil-lo fj-lo fr-lo ful-lo ga-lo gl-lo gu-lo hai-lo hau-lo he-lo hi-lo hr-lo ht-lo hu-lo hup-lo hy-lo ibo-lo id-lo inh-lo is-lo it-lo iu-lo ja-lo jv-lo ka-lo kik-lo kk-lo km-lo kn-lo ko-lo ku-lo kw-lo ky-lo la-lo lg-lo lin-lo aa-lt ab-lt af-lt aka-lt amh-lt an-lt ar-lt arq-lt arz-lt as-lt ase-lt ast-lt av-lt ay-lt az-lt be-lt ber-lt bg-lt bh-lt bi-lt bn-lt bnt-lt bo-lt br-lt bs-lt ca-lt ceb-lt cnh-lt cs-lt cu-lt cy-lt da-lt de-lt dv-lt efi-lt el-lt en-lt eo-lt es-lt et-lt eu-lt fa-lt fi-lt fil-lt fj-lt fr-lt ful-lt ga-lt gd-lt gl-lt gu-lt hai-lt hau-lt he-lt hi-lt hr-lt ht-lt hu-lt hup-lt hy-lt ibo-lt id-lt inh-lt io-lt is-lt it-lt iu-lt ja-lt jv-lt ka-lt kk-lt km-lt kn-lt ko-lt ku-lt kw-lt ky-lt la-lt lb-lt lg-lt lo-lt af-ltg amh-ltg ar-ltg arq-ltg ast-ltg az-ltg be-ltg bg-ltg bn-ltg bo-ltg ca-ltg ceb-ltg cs-ltg da-ltg de-ltg el-ltg en-ltg eo-ltg es-ltg et-ltg fa-ltg fi-ltg fil-ltg fr-ltg ga-ltg gl-ltg he-ltg hi-ltg hr-ltg hu-ltg hy-ltg id-ltg it-ltg ja-ltg ka-ltg kk-ltg ko-ltg ku-ltg ky-ltg la-ltg lt-ltg aa-lu af-luo en-luo es-luo fr-luo en-luy fr-luy id-luy aa-lv ab-lv af-lv aka-lv amh-lv an-lv ar-lv arq-lv as-lv ase-lv ast-lv av-lv ay-lv az-lv bam-lv be-lv bg-lv bn-lv bo-lv br-lv bs-lv ca-lv ceb-lv cnh-lv cs-lv cu-lv cy-lv da-lv de-lv dv-lv ee-lv el-lv en-lv eo-lv es-lv et-lv eu-lv fa-lv fi-lv fil-lv fj-lv fo-lv fr-lv ful-lv ga-lv gd-lv gl-lv gu-lv hau-lv he-lv hi-lv hr-lv ht-lv hu-lv hup-lv hy-lv ia-lv ibo-lv id-lv inh-lv is-lv it-lv iu-lv ja-lv jv-lv ka-lv kk-lv km-lv kn-lv ko-lv ku-lv kw-lv ky-lv la-lv lb-lv lg-lv lin-lv lo-lv lt-lv ltg-lv cs-mad da-mad de-mad en-mad es-mad fa-mad fr-mad hu-mad it-mad af-mfe ar-mfe az-mfe be-mfe bg-mfe bn-mfe ca-mfe cs-mfe da-mfe de-mfe el-mfe en-mfe eo-mfe es-mfe et-mfe eu-mfe fa-mfe fi-mfe fil-mfe fr-mfe gl-mfe he-mfe hr-mfe hu-mfe hy-mfe id-mfe inh-mfe it-mfe ja-mfe ka-mfe ko-mfe lo-mfe lt-mfe lv-mfe ab-mi aka-mi an-mi ar-mi as-mi ast-mi av-mi ay-mi az-mi bh-mi bn-mi bnt-mi bo-mi bs-mi ceb-mi cs-mi cu-mi da-mi efi-mi el-mi en-mi eo-mi es-mi eu-mi fj-mi fr-mi ful-mi ga-mi gl-mi hai-mi hi-mi hy-mi id-mi iu-mi ko-mi ku-mi kw-mi la-mi lg-mi lin-mi lo-mi lt-mi ab-mk af-mk amh-mk ar-mk arq-mk arz-mk as-mk ast-mk az-mk bam-mk be-mk bg-mk bn-mk bo-mk bs-mk ca-mk ceb-mk cnh-mk cs-mk cy-mk da-mk de-mk dv-mk el-mk en-mk eo-mk es-mk et-mk eu-mk fa-mk fi-mk fil-mk fr-mk ful-mk ga-mk gd-mk gl-mk gu-mk hau-mk he-mk hi-mk hr-mk ht-mk hu-mk hy-mk ibo-mk id-mk ie-mk inh-mk is-mk it-mk ja-mk jv-mk ka-mk kk-mk km-mk kn-mk ko-mk ku-mk ky-mk la-mk lb-mk lo-mk lt-mk ltg-mk lv-mk mfe-mk ab-ml af-ml amh-ml ar-ml as-ml ase-ml ast-ml az-ml bam-ml be-ml bg-ml bn-ml bo-ml bs-ml ca-ml cs-ml cy-ml da-ml de-ml dv-ml el-ml en-ml eo-ml es-ml et-ml eu-ml fa-ml fi-ml fil-ml fr-ml ful-ml ga-ml gd-ml gl-ml gu-ml he-ml hi-ml hr-ml ht-ml hu-ml hy-ml id-ml is-ml it-ml ja-ml jv-ml ka-ml kk-ml km-ml kn-ml ko-ml ku-ml ky-ml la-ml lb-ml lt-ml lv-ml mk-ml ab-mlg af-mlg amh-mlg ar-mlg arq-mlg az-mlg be-mlg bg-mlg bn-mlg bs-mlg ca-mlg cs-mlg da-mlg de-mlg el-mlg en-mlg eo-mlg es-mlg et-mlg eu-mlg fa-mlg fi-mlg fil-mlg fr-mlg ga-mlg gl-mlg gu-mlg he-mlg hi-mlg hr-mlg hu-mlg hy-mlg id-mlg it-mlg ja-mlg ka-mlg kk-mlg kn-mlg ko-mlg ku-mlg lt-mlg lv-mlg mk-mlg ab-mn af-mn amh-mn an-mn ar-mn arq-mn ast-mn av-mn az-mn be-mn bg-mn bi-mn bn-mn bo-mn bs-mn ca-mn ceb-mn cho-mn cnh-mn cs-mn cy-mn da-mn de-mn dv-mn el-mn en-mn eo-mn es-mn et-mn eu-mn fa-mn fi-mn fil-mn fo-mn fr-mn gl-mn gu-mn he-mn hi-mn hr-mn ht-mn hu-mn hy-mn ibo-mn id-mn inh-mn iro-mn is-mn it-mn ja-mn jv-mn ka-mn kin-mn kk-mn km-mn kn-mn ko-mn ku-mn ky-mn lb-mn lo-mn lt-mn ltg-mn lv-mn mfe-mn mk-mn ml-mn mlg-mn de-mni ko-mni en-mo aa-moh ab-moh af-moh aka-moh ast-moh bnt-moh da-moh de-moh efi-moh en-moh fi-moh fr-moh hu-moh it-moh lo-moh aka-mos an-mos ar-mos ast-mos av-mos ay-mos az-mos bh-mos bn-mos bnt-mos bo-mos bs-mos ceb-mos cs-mos cu-mos da-mos efi-mos el-mos en-mos eo-mos es-mos eu-mos fj-mos fr-mos ful-mos ga-mos gl-mos hai-mos hi-mos hy-mos iu-mos ko-mos ku-mos kw-mos la-mos lg-mos lo-mos lt-mos mi-mos ab-mr af-mr amh-mr an-mr ar-mr arq-mr as-mr ase-mr ast-mr av-mr az-mr be-mr bg-mr bn-mr bo-mr br-mr bs-mr ca-mr ceb-mr cnh-mr cs-mr cy-mr da-mr de-mr dv-mr el-mr en-mr eo-mr es-mr et-mr eu-mr fa-mr fi-mr fil-mr fj-mr fr-mr ful-mr ga-mr gd-mr gl-mr gu-mr hb-mr he-mr hi-mr hr-mr ht-mr hu-mr hy-mr ibo-mr id-mr inh-mr io-mr is-mr it-mr ja-mr jv-mr ka-mr kk-mr km-mr kn-mr ko-mr ku-mr ky-mr la-mr lb-mr lo-mr lt-mr ltg-mr lv-mr mfe-mr mk-mr ml-mr mlg-mr mn-mr aa-ms ab-ms af-ms aka-ms amh-ms an-ms ar-ms arq-ms arz-ms as-ms ase-ms ast-ms av-ms az-ms be-ms bg-ms bn-ms bo-ms br-ms bs-ms ca-ms ceb-ms cho-ms cnh-ms cr-ms cs-ms cy-ms da-ms de-ms dv-ms el-ms en-ms eo-ms es-ms et-ms eu-ms fa-ms fi-ms fil-ms fr-ms ful-ms ga-ms gd-ms gl-ms gu-ms hau-ms he-ms hi-ms hr-ms ht-ms hu-ms hy-ms ia-ms ibo-ms id-ms is-ms it-ms ja-ms jv-ms ka-ms kk-ms km-ms kn-ms ko-ms ku-ms ky-ms la-ms lb-ms lo-ms lt-ms ltg-ms lv-ms mk-ms ml-ms mlg-ms mn-ms mr-ms af-mt an-mt ar-mt ast-mt az-mt be-mt bg-mt bn-mt bs-mt ca-mt cs-mt cy-mt da-mt de-mt dv-mt el-mt en-mt eo-mt es-mt et-mt eu-mt fa-mt fi-mt fil-mt fo-mt fr-mt ga-mt gl-mt gu-mt hau-mt he-mt hi-mt hr-mt ht-mt hu-mt hup-mt hy-mt id-mt is-mt it-mt ja-mt ka-mt kn-mt ko-mt ku-mt ky-mt la-mt lo-mt lt-mt lv-mt mk-mt mn-mt mr-mt ms-mt ab-mus ceb-mus en-mus fr-mus it-mus mi-mus aa-my ab-my af-my amh-my an-my ar-my arq-my ast-my av-my az-my be-my bg-my bi-my bn-my bo-my bs-my ca-my ceb-my cnh-my cs-my cy-my da-my de-my el-my en-my eo-my es-my et-my eu-my fa-my fi-my fil-my fr-my ga-my gl-my gn-my gu-my he-my hi-my hr-my ht-my hu-my hup-my hy-my ibo-my id-my io-my is-my it-my ja-my jv-my ka-my kar-my kk-my km-my kn-my ko-my ku-my ky-my la-my lb-my lo-my lt-my ltg-my lv-my mk-my ml-my mlg-my mn-my mni-my mr-my ms-my mt-my aa-nb ab-nb af-nb aka-nb amh-nb an-nb ar-nb arq-nb arz-nb as-nb ase-nb ast-nb av-nb az-nb be-nb ber-nb bg-nb bi-nb bn-nb bo-nb br-nb bs-nb ca-nb ceb-nb cho-nb cnh-nb cs-nb cy-nb da-nb de-nb dv-nb el-nb en-nb eo-nb es-nb et-nb eu-nb fa-nb fi-nb fil-nb fj-nb fo-nb fr-nb ful-nb ga-nb gd-nb gl-nb gu-nb hau-nb he-nb hi-nb hr-nb ht-nb hu-nb hup-nb hy-nb ibo-nb id-nb inh-nb is-nb it-nb ja-nb jv-nb ka-nb kar-nb kk-nb km-nb kn-nb ko-nb ku-nb ky-nb la-nb lb-nb lo-nb lt-nb ltg-nb lv-nb mfe-nb mk-nb ml-nb mlg-nb mn-nb mr-nb ms-nb mt-nb my-nb hu-nci it-nci de-nd en-nd es-nd ab-ne af-ne amh-ne ar-ne arq-ne az-ne be-ne bg-ne bn-ne bo-ne bs-ne ca-ne cs-ne cy-ne da-ne de-ne el-ne en-ne eo-ne es-ne et-ne eu-ne fa-ne fi-ne fil-ne fr-ne ga-ne gl-ne gu-ne he-ne hi-ne hr-ne ht-ne hu-ne hy-ne id-ne inh-ne is-ne it-ne ja-ne ka-ne kk-ne km-ne kn-ne ko-ne ku-ne ky-ne la-ne lb-ne lo-ne lt-ne ltg-ne lv-ne mfe-ne mk-ne ml-ne mn-ne mr-ne ms-ne my-ne nb-ne aa-nl ab-nl af-nl aka-nl amh-nl an-nl ar-nl arq-nl arz-nl as-nl ase-nl ast-nl av-nl ay-nl az-nl bam-nl be-nl ber-nl bg-nl bh-nl bi-nl bn-nl bnt-nl bo-nl br-nl bs-nl ca-nl ceb-nl ch-nl cho-nl cku-nl cnh-nl cs-nl cu-nl cy-nl da-nl de-nl dv-nl dz-nl ee-nl efi-nl el-nl en-nl eo-nl es-nl et-nl eu-nl fa-nl ff-nl fi-nl fil-nl fj-nl fo-nl fr-nl ful-nl ga-nl gd-nl gl-nl gn-nl gu-nl hai-nl hau-nl haw-nl hch-nl he-nl hi-nl hr-nl ht-nl hu-nl hup-nl hy-nl ia-nl ibo-nl id-nl ie-nl inh-nl io-nl is-nl it-nl iu-nl ja-nl jv-nl ka-nl kar-nl kk-nl km-nl kn-nl ko-nl ku-nl kw-nl ky-nl la-nl lb-nl lg-nl lin-nl lo-nl lt-nl ltg-nl luy-nl lv-nl mad-nl mfe-nl mi-nl mk-nl ml-nl mlg-nl mn-nl moh-nl mos-nl mr-nl ms-nl mt-nl my-nl nb-nl ne-nl ab-nn af-nn amh-nn ar-nn arq-nn ast-nn av-nn az-nn be-nn bg-nn bn-nn bo-nn br-nn bs-nn ca-nn cnh-nn cs-nn cy-nn da-nn de-nn el-nn en-nn eo-nn es-nn et-nn eu-nn fa-nn fi-nn fil-nn fr-nn ga-nn gl-nn gu-nn he-nn hi-nn hr-nn ht-nn hu-nn hup-nn hy-nn ibo-nn id-nn inh-nn is-nn it-nn ja-nn jv-nn ka-nn kk-nn km-nn kn-nn ko-nn ku-nn ky-nn la-nn lb-nn lo-nn lt-nn ltg-nn lv-nn mk-nn ml-nn mn-nn mr-nn ms-nn mt-nn my-nn nb-nn ne-nn nl-nn aa-nv bh-nv cv-nv dv-nv en-nv fr-nv ful-nv hu-nv hup-nv kik-nv km-nv lo-nv aa-nya ab-nya af-nya aka-nya amh-nya an-nya ar-nya arq-nya as-nya ase-nya ast-nya av-nya ay-nya az-nya bh-nya bn-nya bnt-nya bo-nya bs-nya ce-nya ceb-nya cs-nya cu-nya da-nya efi-nya el-nya en-nya eo-nya es-nya eu-nya fj-nya fr-nya ful-nya ga-nya gl-nya hai-nya hi-nya hy-nya it-nya iu-nya km-nya ko-nya ku-nya kw-nya la-nya lg-nya lo-nya lt-nya mi-nya mos-nya nl-nya aa-oc ab-oc af-oc aka-oc amh-oc an-oc ar-oc ase-oc ast-oc av-oc ay-oc az-oc bam-oc be-oc bg-oc bn-oc bo-oc ca-oc ceb-oc cs-oc cy-oc da-oc de-oc ee-oc el-oc en-oc eo-oc es-oc et-oc eu-oc fa-oc fi-oc fil-oc fj-oc fr-oc ga-oc gl-oc he-oc hi-oc hr-oc hu-oc hy-oc id-oc is-oc it-oc ja-oc ka-oc kk-oc km-oc kn-oc ko-oc ku-oc kw-oc ky-oc la-oc lg-oc lin-oc lt-oc ltg-oc lv-oc mk-oc ml-oc mn-oc mr-oc ms-oc mt-oc my-oc nb-oc ne-oc nl-oc ab-or amh-or ar-or ast-or bg-or bn-or bo-or br-or bs-or ca-or cs-or cy-or da-or de-or el-or en-or eo-or es-or et-or fa-or fi-or fil-or fr-or gl-or gu-or he-or hi-or hr-or ht-or hu-or id-or is-or it-or ja-or jv-or ka-or kn-or ko-or ku-or ky-or lo-or lt-or lv-or ml-or mr-or ms-or nb-or ne-or nl-or nn-or ar-orm bg-orm bn-orm ca-orm cs-orm da-orm de-orm el-orm en-orm es-orm et-orm fa-orm fi-orm fr-orm he-orm hi-orm hr-orm hu-orm id-orm it-orm ja-orm ka-orm km-orm ko-orm mk-orm mr-orm ms-orm my-orm nb-orm nl-orm ar-pam ceb-pam de-pam en-pam es-pam fr-pam gl-pam hi-pam it-pam ja-pam ko-pam aa-pan af-pan amh-pan an-pan ar-pan as-pan ast-pan bg-pan bh-pan bn-pan bo-pan bs-pan ca-pan cs-pan cv-pan cy-pan da-pan de-pan dv-pan el-pan en-pan eo-pan es-pan et-pan fa-pan fi-pan fil-pan fr-pan ful-pan ga-pan gd-pan gl-pan gu-pan he-pan hi-pan hr-pan hu-pan hup-pan hy-pan id-pan is-pan it-pan ja-pan ka-pan kik-pan kk-pan km-pan kn-pan ko-pan ku-pan ky-pan lb-pan lo-pan lt-pan lv-pan mk-pan ml-pan mn-pan mr-pan ms-pan mt-pan my-pan nb-pan ne-pan nl-pan nv-pan or-pan cs-pap de-pap en-pap fr-pap hr-pap id-pap lt-pap nl-pap aka-pi an-pi ar-pi as-pi ast-pi av-pi ay-pi az-pi bh-pi bn-pi bnt-pi bo-pi bs-pi ceb-pi cs-pi cu-pi da-pi de-pi efi-pi el-pi en-pi eo-pi es-pi eu-pi fj-pi fr-pi ful-pi ga-pi gl-pi hai-pi hi-pi hy-pi id-pi iu-pi ja-pi ko-pi ku-pi kw-pi la-pi lg-pi lin-pi lo-pi lt-pi mi-pi mos-pi nl-pi nya-pi aa-pl ab-pl af-pl aka-pl amh-pl an-pl ar-pl arq-pl arz-pl as-pl ase-pl ast-pl av-pl ay-pl az-pl bam-pl be-pl bg-pl bi-pl bn-pl bnt-pl bo-pl br-pl bs-pl ca-pl ceb-pl ch-pl cho-pl cnh-pl co-pl cr-pl cs-pl cu-pl cy-pl da-pl de-pl dv-pl ee-pl el-pl en-pl eo-pl es-pl et-pl eu-pl fa-pl ff-pl fi-pl fil-pl fj-pl fo-pl fr-pl ful-pl ga-pl gd-pl gl-pl gn-pl gu-pl hau-pl he-pl hi-pl ho-pl hr-pl ht-pl hu-pl hup-pl hy-pl ia-pl ibo-pl id-pl ie-pl ik-pl inh-pl io-pl is-pl it-pl iu-pl ja-pl jv-pl ka-pl kk-pl km-pl kn-pl ko-pl ku-pl kw-pl ky-pl la-pl lb-pl lg-pl lin-pl lld-pl lo-pl lt-pl ltg-pl luo-pl lv-pl mad-pl mfe-pl mk-pl ml-pl mlg-pl mn-pl moh-pl mos-pl mr-pl ms-pl mt-pl my-pl nb-pl ne-pl nl-pl nn-pl nya-pl oc-pl or-pl orm-pl pam-pl pan-pl aa-pnb ab-pnb ae-pnb fil-pnb aa-prs ab-prs aka-prs amh-prs an-prs ar-prs ast-prs av-prs ay-prs az-prs bam-prs bg-prs bh-prs bn-prs bnt-prs bo-prs bs-prs ceb-prs cs-prs cu-prs da-prs de-prs dv-prs ee-prs efi-prs el-prs en-prs eo-prs es-prs eu-prs fj-prs fr-prs ful-prs ga-prs gl-prs hai-prs hi-prs hu-prs hy-prs it-prs iu-prs ja-prs ko-prs ku-prs kw-prs la-prs lg-prs lin-prs lo-prs lt-prs lv-prs mi-prs mos-prs nl-prs nya-prs oc-prs pi-prs pl-prs ab-ps ar-ps az-ps bg-ps bn-ps bo-ps bs-ps ca-ps cs-ps da-ps de-ps el-ps en-ps es-ps et-ps fa-ps fi-ps fr-ps gu-ps he-ps hi-ps hr-ps ht-ps hu-ps id-ps is-ps it-ps ja-ps ka-ps kk-ps km-ps ko-ps ky-ps la-ps lt-ps lv-ps ml-ps mn-ps mr-ps ms-ps my-ps nb-ps nl-ps pl-ps aa-pt ab-pt ae-pt af-pt aka-pt amh-pt an-pt ar-pt arq-pt arz-pt as-pt ase-pt ast-pt av-pt ay-pt az-pt bam-pt be-pt bg-pt bi-pt bn-pt bnt-pt bo-pt br-pt bs-pt ca-pt ceb-pt ch-pt cho-pt cku-pt cnh-pt cs-pt cy-pt da-pt de-pt dv-pt dz-pt ee-pt efi-pt el-pt en-pt eo-pt es-pt et-pt eu-pt fa-pt ff-pt fi-pt fil-pt fj-pt fo-pt fr-pt ful-pt ga-pt gd-pt gl-pt gn-pt gu-pt hai-pt hau-pt haw-pt he-pt hi-pt hr-pt ht-pt hu-pt hup-pt hy-pt ia-pt ibo-pt id-pt ie-pt ik-pt inh-pt io-pt is-pt it-pt iu-pt ja-pt jv-pt ka-pt kk-pt km-pt kn-pt ko-pt ku-pt kw-pt ky-pt la-pt lb-pt lg-pt lin-pt lld-pt lo-pt lt-pt ltg-pt luo-pt luy-pt lv-pt mfe-pt mk-pt ml-pt mlg-pt mn-pt moh-pt mr-pt ms-pt mt-pt my-pt nb-pt nd-pt ne-pt nl-pt nn-pt nso-pt nya-pt oc-pt or-pt orm-pt pam-pt pan-pt pl-pt prs-pt ps-pt ar-que ay-que de-que en-que es-que fa-que fr-que ja-que ko-que lt-que nb-que nl-que orm-que aa-rm ab-rm aka-rm amh-rm an-rm ar-rm as-rm ase-rm ay-rm bg-rm ca-rm ceb-rm cku-rm cs-rm cy-rm da-rm de-rm efi-rm el-rm en-rm eo-rm es-rm eu-rm fa-rm fi-rm fr-rm gl-rm hch-rm he-rm hi-rm hr-rm hu-rm id-rm ie-rm is-rm it-rm ja-rm kk-rm ko-rm la-rm lt-rm mi-rm ms-rm mus-rm nb-rm nl-rm pl-rm pt-rm aa-ro ab-ro aeb-ro af-ro aka-ro amh-ro an-ro ar-ro arq-ro arz-ro as-ro ase-ro ast-ro av-ro ay-ro az-ro bam-ro be-ro bg-ro bh-ro bi-ro bn-ro bnt-ro bo-ro br-ro bs-ro ca-ro ceb-ro ch-ro cku-ro cnh-ro cr-ro cs-ro cu-ro cy-ro da-ro de-ro dv-ro dz-ro efi-ro el-ro en-ro eo-ro es-ro et-ro eu-ro fa-ro fi-ro fil-ro fj-ro fo-ro fr-ro ful-ro ga-ro gd-ro gl-ro gn-ro gu-ro hai-ro hau-ro hch-ro he-ro hi-ro hr-ro ht-ro hu-ro hup-ro hy-ro ia-ro ibo-ro id-ro ie-ro ik-ro inh-ro io-ro is-ro it-ro iu-ro ja-ro jv-ro ka-ro kk-ro kl-ro km-ro kn-ro ko-ro ku-ro kw-ro ky-ro la-ro lb-ro lg-ro lld-ro lo-ro lt-ro ltg-ro luy-ro lv-ro mfe-ro mi-ro mk-ro ml-ro mlg-ro mn-ro mo-ro mos-ro mr-ro ms-ro mt-ro my-ro nb-ro ne-ro nl-ro nn-ro nya-ro oc-ro or-ro orm-ro pan-ro pi-ro pl-ro prs-ro ps-ro pt-ro que-ro rm-ro aa-ru ab-ru af-ru aka-ru amh-ru an-ru ar-ru arq-ru arz-ru as-ru ase-ru ast-ru av-ru ay-ru az-ru bam-ru be-ru ber-ru bg-ru bh-ru bi-ru bn-ru bnt-ru bo-ru br-ru bs-ru ca-ru ce-ru ceb-ru cku-ru cnh-ru cr-ru cs-ru cu-ru cy-ru da-ru de-ru dv-ru dz-ru ee-ru efi-ru el-ru en-ru eo-ru es-ru et-ru eu-ru fa-ru ff-ru fi-ru fil-ru fj-ru fo-ru fr-ru ga-ru gl-ru gn-ru gu-ru hai-ru hau-ru haw-ru hch-ru he-ru hi-ru hr-ru ht-ru hu-ru hup-ru hus-ru hy-ru ia-ru ibo-ru id-ru ie-ru ik-ru inh-ru io-ru is-ru it-ru iu-ru ja-ru jv-ru ka-ru kar-ru kk-ru km-ru kn-ru ko-ru ku-ru kw-ru ky-ru la-ru lb-ru lg-ru lin-ru lo-ru lt-ru ltg-ru lv-ru mfe-ru mi-ru mk-ru ml-ru mlg-ru mn-ru moh-ru mos-ru mr-ru ms-ru mt-ru my-ru nb-ru ne-ru nl-ru nn-ru nya-ru oc-ru or-ru orm-ru pam-ru pan-ru pi-ru pl-ru prs-ru ps-ru pt-ru que-ru rm-ru ro-ru ar-run en-run es-run fi-run fr-run ga-run it-run ja-run pt-run ar-rup bg-rup bs-rup ca-rup cs-rup de-rup el-rup en-rup es-rup et-rup fa-rup fil-rup fr-rup he-rup hr-rup hu-rup hup-rup id-rup inh-rup is-rup it-rup ja-rup jv-rup km-rup ko-rup lb-rup mk-rup mn-rup nb-rup ne-rup nl-rup nn-rup pl-rup pt-rup ro-rup ru-rup aa-ry aka-ry amh-ry ar-ry as-ry ase-ry ay-ry az-ry bg-ry ca-ry cku-ry cs-ry da-ry de-ry el-ry en-ry eo-ry es-ry eu-ry fa-ry fi-ry fr-ry gl-ry hch-ry he-ry hr-ry hu-ry id-ry ie-ry it-ry ja-ry ko-ry ky-ry la-ry lt-ry lv-ry ne-ry nl-ry pl-ry pt-ry rm-ry ro-ry ru-ry ar-sa cs-sa en-sa es-sa et-sa fi-sa is-sa ja-sa ko-sa nb-sa nl-sa pl-sa pt-sa ru-sa ab-sc aka-sc en-sc es-sc id-sc it-sc aa-scn aka-scn amh-scn ar-scn as-scn ase-scn ay-scn bg-scn ca-scn cku-scn cs-scn da-scn de-scn el-scn eo-scn es-scn eu-scn fa-scn fr-scn gl-scn hch-scn hu-scn ie-scn it-scn la-scn nl-scn rm-scn ro-scn ru-scn ry-scn af-sco ar-sco bg-sco bn-sco bo-sco bs-sco ca-sco cs-sco cy-sco da-sco de-sco el-sco en-sco eo-sco es-sco et-sco eu-sco fa-sco fi-sco fr-sco gu-sco he-sco hi-sco hr-sco ht-sco hu-sco id-sco is-sco it-sco ja-sco ka-sco kk-sco km-sco ko-sco la-sco lb-sco lt-sco lv-sco mk-sco ml-sco mn-sco mr-sco ms-sco my-sco nb-sco nl-sco nn-sco orm-sco pl-sco pt-sco ro-sco ru-sco ar-sd az-sd bg-sd cs-sd da-sd de-sd el-sd en-sd eo-sd es-sd et-sd fa-sd fi-sd fil-sd he-sd hi-sd hr-sd hu-sd id-sd it-sd ja-sd ka-sd ko-sd lt-sd lv-sd mk-sd nb-sd nl-sd nn-sd pl-sd pt-sd ro-sd ru-sd en-sg bg-sgn cs-sgn da-sgn en-sgn ko-sgn nb-sgn af-sh ar-sh arq-sh ase-sh az-sh be-sh bg-sh bn-sh bs-sh ca-sh ceb-sh cs-sh cy-sh da-sh de-sh el-sh en-sh eo-sh es-sh et-sh eu-sh fa-sh fi-sh fil-sh fr-sh gl-sh he-sh hi-sh hr-sh ht-sh hu-sh hy-sh id-sh is-sh it-sh ja-sh jv-sh ka-sh kk-sh km-sh kn-sh ko-sh ku-sh lb-sh lt-sh lv-sh mk-sh ml-sh mn-sh mr-sh ms-sh my-sh nb-sh ne-sh nl-sh nn-sh pl-sh pt-sh rm-sh ro-sh ru-sh af-si aka-si amh-si an-si ar-si arq-si as-si ast-si av-si ay-si az-si be-si bg-si bh-si bn-si bnt-si bo-si br-si bs-si ca-si ceb-si cnh-si cs-si cu-si cy-si da-si de-si dv-si efi-si el-si en-si eo-si es-si et-si eu-si fa-si fi-si fil-si fj-si fr-si ful-si ga-si gd-si gl-si gu-si hai-si he-si hi-si hr-si ht-si hu-si hy-si ibo-si id-si is-si it-si iu-si ja-si ka-si kar-si kk-si km-si kn-si ko-si ku-si kw-si ky-si la-si lb-si lg-si lo-si lt-si ltg-si lv-si mi-si mk-si ml-si mlg-si mn-si mos-si mr-si ms-si mt-si my-si nb-si ne-si nl-si nn-si nya-si or-si pan-si pi-si pl-si prs-si pt-si ro-si ru-si sco-si aa-sk ab-sk af-sk amh-sk an-sk ar-sk arq-sk arz-sk as-sk ase-sk ast-sk av-sk az-sk be-sk bg-sk bi-sk bn-sk bo-sk br-sk bs-sk ca-sk ceb-sk ch-sk cho-sk cnh-sk cs-sk cy-sk da-sk de-sk dv-sk dz-sk el-sk en-sk eo-sk es-sk et-sk eu-sk fa-sk ff-sk fi-sk fil-sk fj-sk fo-sk fr-sk ful-sk ga-sk gd-sk gl-sk gn-sk gu-sk hau-sk he-sk hi-sk hr-sk ht-sk hu-sk hup-sk hy-sk ia-sk ibo-sk id-sk ie-sk inh-sk is-sk it-sk ja-sk jv-sk ka-sk kar-sk kk-sk km-sk kn-sk ko-sk ku-sk ky-sk la-sk lb-sk lo-sk lt-sk ltg-sk luo-sk lv-sk mfe-sk mk-sk ml-sk mlg-sk mn-sk mr-sk ms-sk mt-sk my-sk nb-sk ne-sk nl-sk nn-sk oc-sk or-sk orm-sk pan-sk pl-sk ps-sk pt-sk rm-sk ro-sk ru-sk rup-sk ry-sk sco-sk sd-sk sh-sk si-sk aa-sl ab-sl af-sl amh-sl an-sl ar-sl arq-sl arz-sl as-sl ast-sl az-sl bam-sl be-sl bg-sl bi-sl bn-sl bo-sl br-sl bs-sl ca-sl ceb-sl cnh-sl cs-sl cy-sl da-sl de-sl dv-sl dz-sl el-sl en-sl eo-sl es-sl et-sl eu-sl fa-sl ff-sl fi-sl fil-sl fr-sl ful-sl ga-sl gd-sl gl-sl gu-sl hai-sl hau-sl haw-sl he-sl hi-sl hr-sl ht-sl hu-sl hup-sl hus-sl hy-sl ibo-sl id-sl ie-sl inh-sl is-sl it-sl ja-sl jv-sl ka-sl kk-sl km-sl kn-sl ko-sl ku-sl ky-sl la-sl lb-sl lo-sl lt-sl ltg-sl lv-sl mfe-sl mk-sl ml-sl mlg-sl mn-sl mr-sl ms-sl mt-sl my-sl nb-sl ne-sl nl-sl nn-sl oc-sl or-sl pan-sl pl-sl ps-sl pt-sl rm-sl ro-sl ru-sl rup-sl ry-sl sd-sl sh-sl si-sl sk-sl en-sm aa-sna ab-sna aka-sna amh-sna ar-sna as-sna ase-sna ast-sna ay-sna bg-sna br-sna bs-sna ca-sna cku-sna cs-sna cy-sna da-sna de-sna el-sna en-sna eo-sna es-sna et-sna eu-sna fa-sna fi-sna fil-sna fr-sna gl-sna gu-sna hch-sna he-sna hu-sna id-sna ie-sna is-sna it-sna ja-sna jv-sna ka-sna kn-sna ko-sna ku-sna ky-sna la-sna lo-sna lt-sna lv-sna mr-sna ms-sna nb-sna nl-sna nn-sna or-sna pl-sna pt-sna rm-sna ro-sna ru-sna ry-sna scn-sna sk-sna sl-sna aa-som ab-som af-som aka-som amh-som an-som ar-som arq-som ase-som az-som be-som bg-som bn-som bs-som ca-som cs-som da-som de-som el-som en-som eo-som es-som et-som eu-som fa-som fi-som fil-som fr-som ful-som gl-som gu-som he-som hi-som hr-som ht-som hu-som hy-som id-som is-som it-som ja-som ka-som kk-som kl-som km-som kn-som ko-som ku-som la-som lt-som lv-som mk-som ml-som mlg-som mn-som mr-som ms-som my-som nb-som nl-som nn-som nya-som pl-som ps-som pt-som ro-som ru-som si-som sk-som sl-som ar-sot en-sot es-sot fr-sot hi-sot it-sot ko-sot pl-sot aa-sq ab-sq af-sq aka-sq amh-sq an-sq ar-sq arq-sq arz-sq as-sq ase-sq ast-sq av-sq ay-sq az-sq ba-sq bam-sq be-sq ber-sq bg-sq bi-sq bn-sq bo-sq bs-sq ca-sq ceb-sq cho-sq cnh-sq cr-sq cs-sq cy-sq da-sq de-sq dv-sq dz-sq ee-sq efi-sq el-sq en-sq eo-sq es-sq et-sq eu-sq fa-sq fi-sq fil-sq fo-sq fr-sq ful-sq ga-sq gd-sq gl-sq gn-sq gu-sq hau-sq he-sq hi-sq hr-sq ht-sq hu-sq hup-sq hy-sq ia-sq ibo-sq id-sq ie-sq inh-sq io-sq iro-sq is-sq it-sq ja-sq jv-sq ka-sq kk-sq kl-sq km-sq kn-sq ko-sq ku-sq kw-sq ky-sq la-sq lb-sq lg-sq lin-sq lo-sq lt-sq ltg-sq lv-sq mfe-sq mk-sq ml-sq mlg-sq mn-sq moh-sq mr-sq ms-sq mt-sq my-sq nb-sq nd-sq ne-sq nl-sq nn-sq oc-sq or-sq orm-sq pan-sq pl-sq prs-sq ps-sq pt-sq rm-sq ro-sq ru-sq rup-sq sco-sq sd-sq sh-sq si-sq sk-sq sl-sq som-sq aa-sr ab-sr af-sr amh-sr an-sr ar-sr arq-sr arz-sr as-sr ase-sr ast-sr av-sr az-sr bam-sr be-sr bg-sr bi-sr bn-sr bo-sr br-sr bs-sr ca-sr ceb-sr cho-sr cnh-sr cr-sr cs-sr cy-sr da-sr de-sr dv-sr efi-sr el-sr en-sr eo-sr es-sr et-sr eu-sr fa-sr fi-sr fil-sr fj-sr fo-sr fr-sr ful-sr ga-sr gd-sr gl-sr gn-sr gu-sr hau-sr he-sr hi-sr hr-sr ht-sr hu-sr hup-sr hy-sr ia-sr ibo-sr id-sr ie-sr inh-sr is-sr it-sr ja-sr jv-sr ka-sr kk-sr km-sr kn-sr ko-sr ku-sr ky-sr la-sr lb-sr lo-sr lt-sr ltg-sr lv-sr mfe-sr mk-sr ml-sr mlg-sr mn-sr mr-sr ms-sr mt-sr my-sr nb-sr ne-sr nl-sr nn-sr oc-sr or-sr orm-sr pan-sr pl-sr ps-sr pt-sr ro-sr ru-sr rup-sr ry-sr sco-sr sd-sr sh-sr si-sr sk-sr sl-sr sna-sr som-sr sq-sr amh-srp ar-srp az-srp be-srp bg-srp bn-srp bo-srp bs-srp ca-srp cs-srp da-srp de-srp el-srp en-srp eo-srp es-srp et-srp eu-srp fa-srp fi-srp fil-srp fr-srp gl-srp he-srp hi-srp hr-srp hu-srp hy-srp id-srp it-srp ja-srp ka-srp kk-srp km-srp ko-srp ku-srp lt-srp lv-srp mk-srp mn-srp mr-srp ms-srp my-srp nb-srp ne-srp nl-srp pl-srp pt-srp ro-srp ru-srp sh-srp sk-srp sl-srp sq-srp sr-srp aa-sv ab-sv af-sv aka-sv amh-sv an-sv ar-sv arq-sv arz-sv as-sv ase-sv ast-sv av-sv ay-sv az-sv bam-sv be-sv bg-sv bi-sv bn-sv bo-sv br-sv bs-sv ca-sv ceb-sv cku-sv cnh-sv cr-sv cs-sv cu-sv cy-sv da-sv de-sv dv-sv ee-sv el-sv en-sv eo-sv es-sv et-sv eu-sv fa-sv fi-sv fil-sv fj-sv fr-sv ful-sv ga-sv gd-sv gl-sv gu-sv hau-sv hch-sv he-sv hi-sv hr-sv ht-sv hu-sv hup-sv hy-sv ia-sv ibo-sv id-sv ie-sv inh-sv io-sv is-sv it-sv ja-sv jv-sv ka-sv kk-sv kl-sv km-sv kn-sv ko-sv ku-sv kw-sv ky-sv la-sv lb-sv lg-sv lin-sv lo-sv lt-sv ltg-sv lv-sv mad-sv mfe-sv mk-sv ml-sv mlg-sv mn-sv mr-sv ms-sv mt-sv my-sv nb-sv ne-sv nl-sv nn-sv oc-sv or-sv orm-sv pan-sv pl-sv prs-sv ps-sv pt-sv que-sv rm-sv ro-sv ru-sv rup-sv ry-sv scn-sv sco-sv sd-sv sh-sv si-sv sk-sv sl-sv sna-sv som-sv sq-sv sr-sv srp-sv aa-swa ab-swa af-swa aka-swa amh-swa ar-swa as-swa ase-swa ay-swa az-swa be-swa ber-swa bg-swa bn-swa bo-swa br-swa bs-swa ca-swa cku-swa cs-swa cy-swa da-swa de-swa el-swa en-swa eo-swa es-swa et-swa eu-swa fa-swa fi-swa fil-swa fr-swa ga-swa gl-swa gu-swa hau-swa hch-swa he-swa hi-swa hr-swa ht-swa hu-swa hy-swa id-swa ie-swa is-swa it-swa ja-swa ka-swa kar-swa kk-swa km-swa kn-swa ko-swa ku-swa la-swa lb-swa lg-swa lo-swa lt-swa lv-swa mk-swa ml-swa mlg-swa mn-swa mr-swa ms-swa mt-swa my-swa nb-swa nl-swa nn-swa orm-swa pl-swa ps-swa pt-swa rm-swa ro-swa ru-swa ry-swa scn-swa sh-swa si-swa sk-swa sl-swa sna-swa som-swa sq-swa sr-swa srp-swa sv-swa ar-szl az-szl be-szl bg-szl bs-szl ca-szl cnh-szl da-szl de-szl el-szl en-szl eo-szl es-szl et-szl eu-szl fa-szl fi-szl fil-szl fr-szl he-szl hi-szl hr-szl hu-szl hy-szl ibo-szl id-szl it-szl ja-szl ka-szl kk-szl ko-szl lo-szl lt-szl lv-szl mk-szl mn-szl mr-szl ms-szl my-szl nb-szl nl-szl nn-szl pl-szl pt-szl ro-szl ru-szl si-szl sk-szl sl-szl sq-szl sr-szl sv-szl aa-ta ab-ta af-ta amh-ta an-ta ar-ta arq-ta arz-ta ase-ta ast-ta av-ta az-ta bam-ta be-ta bg-ta bn-ta bo-ta br-ta bs-ta ca-ta ceb-ta cho-ta cnh-ta cs-ta cy-ta da-ta de-ta dv-ta el-ta en-ta eo-ta es-ta et-ta eu-ta fa-ta ff-ta fi-ta fil-ta fj-ta fr-ta ga-ta gl-ta gu-ta hau-ta he-ta hi-ta hr-ta ht-ta hu-ta hy-ta ibo-ta id-ta is-ta it-ta ja-ta jv-ta ka-ta kk-ta km-ta kn-ta ko-ta ku-ta ky-ta la-ta lb-ta lkt-ta lo-ta lt-ta ltg-ta lv-ta mk-ta ml-ta mlg-ta mn-ta mr-ta ms-ta mt-ta my-ta nb-ta ne-ta nl-ta nn-ta oc-ta or-ta orm-ta pan-ta pl-ta ps-ta pt-ta rm-ta ro-ta ru-ta sco-ta sh-ta si-ta sk-ta sl-ta som-ta sq-ta sr-ta srp-ta sv-ta swa-ta szl-ta ab-te af-te amh-te ar-te arq-te as-te ase-te ast-te az-te bam-te be-te bg-te bn-te bo-te bs-te ca-te cs-te cy-te da-te de-te dv-te el-te en-te eo-te es-te et-te eu-te fa-te fi-te fil-te fr-te ful-te ga-te gd-te gl-te gu-te hau-te he-te hi-te hr-te ht-te hu-te hy-te id-te is-te it-te ja-te ka-te kk-te km-te kn-te ko-te ku-te ky-te la-te lb-te lo-te lt-te ltg-te lv-te mk-te ml-te mlg-te mn-te mr-te ms-te mt-te my-te nb-te ne-te nl-te nn-te oc-te or-te orm-te pan-te pl-te ps-te pt-te ro-te ru-te sco-te sd-te sh-te si-te sk-te sl-te som-te sq-te sr-te sv-te swa-te ta-te aka-tet an-tet ar-tet ast-tet av-tet az-tet bh-tet bn-tet bnt-tet bo-tet bs-tet ceb-tet cs-tet cu-tet da-tet efi-tet el-tet en-tet eo-tet es-tet eu-tet fj-tet fr-tet ful-tet ga-tet gl-tet hai-tet hi-tet hy-tet id-tet it-tet iu-tet ko-tet ku-tet kw-tet la-tet lg-tet lin-tet lo-tet lt-tet mi-tet mos-tet ms-tet nl-tet nya-tet pi-tet prs-tet pt-tet ro-tet ru-tet si-tet af-tg ar-tg arq-tg ase-tg az-tg bg-tg bn-tg ca-tg cs-tg da-tg de-tg el-tg en-tg eo-tg es-tg et-tg eu-tg fa-tg fi-tg fil-tg fr-tg gl-tg gu-tg he-tg hi-tg hr-tg hu-tg hy-tg id-tg is-tg it-tg ja-tg ka-tg kk-tg km-tg ko-tg ku-tg ky-tg lt-tg ltg-tg lv-tg mk-tg ml-tg mn-tg mr-tg ms-tg my-tg nb-tg ne-tg nl-tg pl-tg pt-tg ro-tg ru-tg si-tg sk-tg sl-tg som-tg sq-tg sr-tg sv-tg swa-tg ta-tg te-tg aa-th ab-th af-th aka-th amh-th an-th ar-th arq-th arz-th as-th ase-th ast-th av-th ay-th az-th bam-th be-th bg-th bh-th bi-th bn-th bnt-th bo-th br-th bs-th ca-th ceb-th cho-th cnh-th cr-th cs-th cu-th cy-th da-th de-th dv-th efi-th el-th en-th eo-th es-th et-th eu-th fa-th fi-th fil-th fj-th fo-th fr-th ful-th ga-th gd-th gl-th gn-th gu-th hai-th hau-th he-th hi-th hr-th ht-th hu-th hup-th hy-th ia-th ibo-th id-th inh-th iro-th is-th it-th iu-th ja-th jv-th ka-th kar-th kk-th km-th kn-th ko-th ku-th kw-th ky-th la-th lb-th lg-th lkt-th lo-th lt-th ltg-th lv-th mfe-th mi-th mk-th ml-th mlg-th mn-th mos-th mr-th ms-th mt-th my-th nb-th ne-th nl-th nn-th nya-th oc-th or-th orm-th pam-th pan-th pi-th pl-th prs-th ps-th pt-th rm-th ro-th ru-th rup-th ry-th sco-th sd-th sgn-th sh-th si-th sk-th sl-th sna-th som-th sq-th sr-th srp-th sv-th swa-th szl-th ta-th te-th tet-th tg-th aa-tir ab-tir af-tir aka-tir amh-tir an-tir ar-tir ast-tir av-tir ay-tir az-tir bam-tir bg-tir bn-tir bo-tir ca-tir cs-tir da-tir de-tir ee-tir el-tir en-tir eo-tir es-tir et-tir fa-tir fi-tir fil-tir fj-tir fr-tir ga-tir gu-tir he-tir hi-tir hr-tir hu-tir id-tir it-tir ja-tir ka-tir kn-tir ko-tir ku-tir kw-tir la-tir lg-tir lin-tir lt-tir lv-tir ml-tir mr-tir ms-tir nb-tir ne-tir nl-tir oc-tir or-tir pan-tir pl-tir prs-tir pt-tir ro-tir ru-tir si-tir sk-tir sl-tir sq-tir sr-tir sv-tir ta-tir te-tir th-tir aa-tk ab-tk aka-tk amh-tk an-tk ar-tk as-tk ase-tk ast-tk av-tk ay-tk az-tk bam-tk bg-tk bh-tk bn-tk bnt-tk bo-tk bs-tk ca-tk ceb-tk cku-tk cs-tk cu-tk cy-tk da-tk de-tk ee-tk efi-tk el-tk en-tk eo-tk es-tk et-tk eu-tk fa-tk fi-tk fj-tk fr-tk ful-tk ga-tk gl-tk hai-tk hch-tk he-tk hi-tk hr-tk hu-tk hy-tk id-tk ie-tk is-tk it-tk iu-tk ja-tk ka-tk kn-tk ko-tk ku-tk kw-tk la-tk lg-tk lin-tk lo-tk lt-tk lv-tk mi-tk mk-tk mn-tk mos-tk nb-tk ne-tk nl-tk nya-tk oc-tk pi-tk pl-tk prs-tk pt-tk rm-tk ro-tk ru-tk rup-tk ry-tk scn-tk si-tk sk-tk sl-tk sna-tk sq-tk sr-tk sv-tk swa-tk ta-tk tet-tk th-tk tir-tk aa-tl ab-tl af-tl aka-tl amh-tl an-tl ar-tl arq-tl ase-tl ast-tl av-tl ay-tl az-tl bam-tl be-tl ber-tl bg-tl bn-tl bo-tl br-tl bs-tl ca-tl ceb-tl cs-tl cu-tl cy-tl da-tl de-tl ee-tl el-tl en-tl eo-tl es-tl et-tl eu-tl fa-tl fi-tl fil-tl fj-tl fr-tl ga-tl gl-tl gu-tl he-tl hi-tl hr-tl ht-tl hu-tl hy-tl ia-tl id-tl io-tl is-tl it-tl ja-tl jv-tl ka-tl kk-tl km-tl kn-tl ko-tl ku-tl kw-tl ky-tl la-tl lb-tl lg-tl lin-tl lo-tl lt-tl ltg-tl lv-tl mk-tl ml-tl mlg-tl mn-tl mr-tl ms-tl my-tl nb-tl ne-tl nl-tl nn-tl oc-tl or-tl pl-tl prs-tl pt-tl ro-tl ru-tl sco-tl sh-tl si-tl sk-tl sl-tl sna-tl som-tl sq-tl sr-tl sv-tl swa-tl ta-tl te-tl tet-tl tg-tl th-tl tir-tl tk-tl ab-tlh af-tlh ar-tlh be-tlh bg-tlh bs-tlh ca-tlh cs-tlh da-tlh de-tlh el-tlh en-tlh eo-tlh es-tlh fa-tlh fi-tlh fr-tlh gl-tlh he-tlh hi-tlh hr-tlh hu-tlh hup-tlh id-tlh inh-tlh it-tlh ja-tlh ka-tlh kar-tlh km-tlh ko-tlh ku-tlh lb-tlh ml-tlh mt-tlh my-tlh nb-tlh nl-tlh nn-tlh pl-tlh pt-tlh ro-tlh ru-tlh rup-tlh si-tlh sk-tlh sl-tlh sq-tlh sr-tlh sv-tlh swa-tlh th-tlh aka-to an-to ar-to ase-to ast-to av-to az-to bh-to bn-to bnt-to bo-to bs-to ceb-to cs-to cu-to da-to de-to efi-to el-to en-to es-to eu-to fi-to fj-to fr-to ful-to ga-to gl-to hai-to hi-to hy-to it-to iu-to ko-to ku-to kw-to la-to lg-to lo-to lt-to lv-to mi-to mos-to nl-to nya-to pi-to pl-to prs-to pt-to ro-to ru-to si-to tet-to th-to tk-to aa-tr ab-tr af-tr aka-tr amh-tr an-tr ar-tr arq-tr arz-tr as-tr ase-tr ast-tr av-tr ay-tr az-tr ba-tr bam-tr be-tr ber-tr bg-tr bh-tr bi-tr bn-tr bnt-tr bo-tr br-tr bs-tr ca-tr ceb-tr cho-tr cku-tr cnh-tr cs-tr cy-tr da-tr de-tr dv-tr dz-tr ee-tr efi-tr el-tr en-tr eo-tr es-tr et-tr eu-tr fa-tr ff-tr fi-tr fil-tr fj-tr fo-tr fr-tr ful-tr ga-tr gd-tr gl-tr gn-tr gu-tr hai-tr hau-tr hch-tr he-tr hi-tr hr-tr ht-tr hu-tr hup-tr hy-tr ia-tr ibo-tr id-tr ie-tr inh-tr is-tr it-tr iu-tr ja-tr jv-tr ka-tr kar-tr kk-tr kl-tr km-tr kn-tr ko-tr ku-tr kw-tr ky-tr la-tr lb-tr lg-tr lin-tr lld-tr lo-tr lt-tr ltg-tr lv-tr mfe-tr mi-tr mk-tr ml-tr mlg-tr mn-tr mos-tr mr-tr ms-tr mt-tr my-tr nb-tr ne-tr nl-tr nn-tr nya-tr oc-tr or-tr orm-tr pam-tr pan-tr pap-tr pi-tr pl-tr prs-tr ps-tr pt-tr que-tr rm-tr ro-tr ru-tr rup-tr ry-tr sa-tr scn-tr sco-tr sd-tr sgn-tr sh-tr si-tr sk-tr sl-tr sna-tr som-tr sq-tr sr-tr srp-tr sv-tr swa-tr szl-tr ta-tr te-tr tet-tr tg-tr th-tr tir-tr tk-tr tl-tr tlh-tr to-tr en-ts fr-ts he-ts tr-ts aa-tt ab-tt af-tt aka-tt amh-tt an-tt ar-tt arq-tt ast-tt av-tt ay-tt az-tt bam-tt be-tt ber-tt bg-tt bn-tt bo-tt ca-tt ceb-tt cs-tt cu-tt cy-tt da-tt de-tt ee-tt el-tt en-tt eo-tt es-tt et-tt eu-tt fa-tt fi-tt fil-tt fj-tt fr-tt ga-tt gl-tt gu-tt he-tt hi-tt hr-tt hu-tt hy-tt ia-tt id-tt it-tt ja-tt ka-tt kk-tt ko-tt ku-tt kw-tt ky-tt la-tt lg-tt lin-tt lt-tt ltg-tt lv-tt mk-tt mlg-tt mn-tt mr-tt ms-tt my-tt nb-tt ne-tt nl-tt oc-tt pl-tt prs-tt pt-tt ro-tt ru-tt si-tt sk-tt sl-tt som-tt sq-tt sr-tt sv-tt ta-tt te-tt tg-tt th-tt tir-tt tk-tt tl-tt tr-tt aa-tw ab-tw aka-tw amh-tw ast-tw ay-tw de-tw ee-tw el-tw en-tw eo-tw es-tw fr-tw ga-tw hu-tw ja-tw ko-tw ku-tw kw-tw la-tw lg-tw lin-tw lv-tw oc-tw pl-tw prs-tw pt-tw ru-tw sq-tw sv-tw tir-tw tl-tw tr-tw tt-tw af-ug amh-ug an-ug ar-ug arq-ug ase-ug az-ug bam-ug be-ug bg-ug bh-ug bn-ug bo-ug bs-ug ca-ug cnh-ug cs-ug cy-ug da-ug de-ug el-ug en-ug eo-ug es-ug et-ug eu-ug fa-ug fi-ug fil-ug fj-ug fr-ug gl-ug gu-ug he-ug hi-ug hr-ug hu-ug hy-ug ibo-ug id-ug it-ug iu-ug ja-ug ka-ug kar-ug kk-ug km-ug ko-ug ku-ug kw-ug ky-ug la-ug lb-ug lo-ug lt-ug ltg-ug lv-ug mk-ug mlg-ug mn-ug mos-ug mr-ug ms-ug my-ug nb-ug nl-ug nn-ug pan-ug pl-ug pt-ug rm-ug ro-ug ru-ug si-ug sk-ug sl-ug som-ug sq-ug sr-ug sv-ug swa-ug szl-ug ta-ug te-ug tg-ug th-ug tk-ug tl-ug tlh-ug to-ug tr-ug tt-ug aa-uk ab-uk af-uk aka-uk amh-uk an-uk ar-uk arq-uk as-uk ase-uk ast-uk av-uk ay-uk az-uk bam-uk be-uk bg-uk bh-uk bi-uk bn-uk bnt-uk bo-uk br-uk bs-uk ca-uk ceb-uk cho-uk cku-uk cnh-uk cs-uk cu-uk cy-uk da-uk de-uk dv-uk dz-uk efi-uk el-uk en-uk eo-uk es-uk et-uk eu-uk fa-uk fi-uk fil-uk fj-uk fo-uk fr-uk ful-uk ga-uk gl-uk gn-uk gu-uk hai-uk hau-uk haw-uk hb-uk hch-uk he-uk hi-uk hr-uk ht-uk hu-uk hup-uk hy-uk ibo-uk id-uk ie-uk inh-uk is-uk it-uk iu-uk ja-uk jv-uk ka-uk kar-uk kk-uk km-uk kn-uk ko-uk ku-uk kw-uk ky-uk la-uk lb-uk lg-uk lo-uk lt-uk ltg-uk lv-uk mad-uk mfe-uk mi-uk mk-uk ml-uk mlg-uk mn-uk mos-uk mr-uk ms-uk mt-uk my-uk nb-uk ne-uk nl-uk nn-uk nya-uk oc-uk or-uk orm-uk pan-uk pi-uk pl-uk prs-uk ps-uk pt-uk rm-uk ro-uk ru-uk rup-uk ry-uk scn-uk sco-uk sh-uk si-uk sk-uk sl-uk sna-uk som-uk sq-uk sr-uk srp-uk sv-uk swa-uk szl-uk ta-uk te-uk tet-uk tg-uk th-uk tir-uk tk-uk tl-uk tlh-uk to-uk tr-uk tt-uk ug-uk en-umb fr-umb aa-ur ab-ur af-ur amh-ur an-ur ar-ur arq-ur arz-ur as-ur ast-ur av-ur az-ur be-ur bg-ur bn-ur bnt-ur bo-ur bs-ur ca-ur ceb-ur cnh-ur cs-ur cy-ur da-ur de-ur dv-ur el-ur en-ur eo-ur es-ur et-ur eu-ur fa-ur fi-ur fil-ur fr-ur ful-ur ga-ur gl-ur gu-ur hau-ur he-ur hi-ur hr-ur ht-ur hu-ur hy-ur id-ur inh-ur is-ur it-ur ja-ur jv-ur ka-ur kk-ur km-ur kn-ur ko-ur ku-ur ky-ur la-ur lb-ur lg-ur lo-ur lt-ur ltg-ur lv-ur mfe-ur mi-ur mk-ur ml-ur mlg-ur mn-ur mr-ur ms-ur mt-ur my-ur nb-ur ne-ur nl-ur nn-ur nya-ur oc-ur or-ur orm-ur pan-ur pi-ur pl-ur ps-ur pt-ur ro-ur ru-ur sco-ur sg-ur sh-ur si-ur sk-ur sl-ur som-ur sq-ur sr-ur srp-ur sv-ur swa-ur ta-ur te-ur tg-ur th-ur tir-ur tk-ur tl-ur tr-ur tt-ur ug-ur uk-ur aa-uz ab-uz af-uz aka-uz amh-uz an-uz ar-uz arq-uz as-uz ase-uz ast-uz av-uz ay-uz az-uz bam-uz be-uz bg-uz bn-uz bo-uz bs-uz ca-uz ceb-uz cku-uz cnh-uz cs-uz cu-uz da-uz de-uz dz-uz ee-uz el-uz en-uz eo-uz es-uz et-uz eu-uz fa-uz fi-uz fil-uz fj-uz fr-uz ga-uz gl-uz gu-uz hai-uz haw-uz hch-uz he-uz hi-uz hr-uz hu-uz hy-uz ibo-uz id-uz ie-uz inh-uz is-uz it-uz ja-uz ka-uz kk-uz kn-uz ko-uz ku-uz kw-uz ky-uz la-uz lg-uz lin-uz lo-uz lt-uz ltg-uz lv-uz mfe-uz mk-uz ml-uz mlg-uz mn-uz mr-uz ms-uz my-uz nb-uz ne-uz nl-uz nn-uz oc-uz pl-uz prs-uz ps-uz pt-uz rm-uz ro-uz ru-uz ry-uz scn-uz sh-uz si-uz sk-uz sl-uz sna-uz som-uz sq-uz sr-uz srp-uz sv-uz swa-uz szl-uz ta-uz te-uz tg-uz th-uz tir-uz tk-uz tl-uz tr-uz tt-uz tw-uz ug-uz uk-uz ur-uz aa-ve ab-ve ba-ve cho-ve en-ve es-ve gu-ve pt-ve aa-vi ab-vi af-vi aka-vi amh-vi an-vi ar-vi arq-vi arz-vi as-vi ase-vi ast-vi av-vi ay-vi az-vi bam-vi be-vi bg-vi bh-vi bi-vi bn-vi bnt-vi bo-vi br-vi bs-vi ca-vi ceb-vi ch-vi cku-vi cnh-vi cs-vi cu-vi cy-vi da-vi de-vi dv-vi ee-vi efi-vi el-vi en-vi eo-vi es-vi et-vi eu-vi fa-vi ff-vi fi-vi fil-vi fj-vi fo-vi fr-vi ful-vi ga-vi gd-vi gl-vi gn-vi gu-vi hai-vi hau-vi he-vi hi-vi hr-vi ht-vi hu-vi hup-vi hy-vi ia-vi ibo-vi id-vi inh-vi iro-vi is-vi it-vi iu-vi ja-vi jv-vi ka-vi kin-vi kj-vi kk-vi km-vi kn-vi ko-vi ku-vi kw-vi ky-vi la-vi lb-vi lg-vi li-vi lld-vi lo-vi lt-vi ltg-vi luy-vi lv-vi mfe-vi mi-vi mk-vi ml-vi mlg-vi mn-vi mos-vi mr-vi ms-vi mt-vi my-vi nb-vi ne-vi nl-vi nn-vi nya-vi oc-vi or-vi orm-vi pam-vi pan-vi pi-vi pl-vi prs-vi ps-vi pt-vi rm-vi ro-vi ru-vi ry-vi sco-vi sd-vi sh-vi si-vi sk-vi sl-vi sna-vi som-vi sot-vi sq-vi sr-vi srp-vi sv-vi swa-vi szl-vi ta-vi te-vi tet-vi tg-vi th-vi tir-vi tk-vi tl-vi tlh-vi to-vi tr-vi tt-vi ug-vi uk-vi ur-vi uz-vi ve-vi ab-vls cy-vls da-vls de-vls en-vls es-vls eu-vls fi-vls fil-vls fr-vls ga-vls gl-vls hr-vls hu-vls id-vls it-vls ja-vls lt-vls lv-vls nl-vls pl-vls pt-vls ro-vls ru-vls sv-vls th-vls tr-vls aa-vo ab-vo af-vo aka-vo av-vo ber-vo bnt-vo cho-vo da-vo de-vo dv-vo dz-vo en-vo es-vo he-vo nl-vo sq-vo an-wa ar-wa bh-wa bo-wa cs-wa fj-wa hy-wa iu-wa ku-wa kw-wa lt-wa mos-wa ro-wa th-wa tk-wa tr-wa ug-wa uk-wa aa-wol ab-wol af-wol aka-wol ar-wol as-wol ast-wol bg-wol bn-wol bnt-wol ce-wol cs-wol cy-wol da-wol de-wol dv-wol el-wol en-wol eo-wol es-wol et-wol fa-wol fi-wol fil-wol fr-wol ful-wol ga-wol gd-wol gl-wol he-wol hi-wol hu-wol id-wol is-wol it-wol ja-wol ka-wol kk-wol km-wol ko-wol ky-wol lb-wol lo-wol lt-wol lv-wol mk-wol ml-wol moh-wol mos-wol mr-wol ms-wol nb-wol nl-wol pan-wol pl-wol pt-wol ro-wol ru-wol si-wol sk-wol sl-wol som-wol sq-wol sr-wol sv-wol te-wol th-wol tr-wol vi-wol aa-xho af-xho ar-xho bg-xho bn-xho bo-xho br-xho bs-xho ca-xho cs-xho cy-xho da-xho de-xho el-xho en-xho eo-xho es-xho et-xho eu-xho fa-xho fi-xho fr-xho gu-xho he-xho hi-xho hr-xho ht-xho hu-xho id-xho is-xho it-xho ja-xho ka-xho kk-xho km-xho kn-xho ko-xho ky-xho la-xho lb-xho lt-xho lv-xho mk-xho ml-xho mn-xho mr-xho ms-xho my-xho nb-xho nl-xho nn-xho oc-xho pl-xho pt-xho ro-xho ru-xho sco-xho si-xho sk-xho sl-xho som-xho sq-xho sr-xho sv-xho swa-xho ta-xho te-xho th-xho tir-xho tl-xho tr-xho uk-xho ur-xho vi-xho aa-yaq af-yaq de-yaq es-yaq ik-yaq ab-yi af-yi amh-yi ar-yi az-yi be-yi bg-yi bn-yi ca-yi cho-yi cs-yi cy-yi da-yi de-yi el-yi en-yi eo-yi es-yi et-yi eu-yi fa-yi fi-yi fil-yi fr-yi ga-yi gl-yi gu-yi hau-yi he-yi hi-yi ho-yi hr-yi ht-yi hu-yi hy-yi id-yi is-yi it-yi ja-yi ka-yi km-yi kn-yi ko-yi la-yi lo-yi lt-yi lv-yi mk-yi ms-yi mt-yi nb-yi nl-yi pl-yi pt-yi ro-yi ru-yi sk-yi sl-yi sq-yi sr-yi sv-yi swa-yi ta-yi te-yi th-yi tr-yi uk-yi ur-yi vi-yi xho-yi af-yor ar-yor ast-yor bam-yor bg-yor bn-yor ca-yor cs-yor da-yor de-yor efi-yor el-yor en-yor eo-yor es-yor fa-yor fi-yor fr-yor gu-yor hai-yor he-yor hi-yor ht-yor hu-yor id-yor is-yor it-yor ja-yor ka-yor kk-yor kn-yor ko-yor lin-yor lo-yor lt-yor mi-yor mk-yor mn-yor ms-yor nb-yor nl-yor pi-yor pl-yor prs-yor pt-yor ro-yor ru-yor si-yor sq-yor sr-yor sv-yor ta-yor te-yor tet-yor th-yor tr-yor uk-yor ur-yor vi-yor aa-za ab-za ba-za bg-za cho-za cs-za da-za en-za es-za et-za fr-za gu-za hi-za hu-za it-za mn-za ms-za nb-za pl-za pt-za sk-za tr-za ve-za ar-zam arq-zam az-zam bn-zam ca-zam cs-zam da-zam de-zam el-zam en-zam eo-zam es-zam fi-zam fr-zam he-zam hi-zam hu-zam id-zam it-zam ja-zam ko-zam lv-zam mn-zam nb-zam nl-zam pl-zam pt-zam ro-zam ru-zam sk-zam sl-zam sq-zam sr-zam sv-zam te-zam tl-zam tr-zam uk-zam vi-zam aa-zh ab-zh af-zh amh-zh ar-zh arq-zh arz-zh ast-zh az-zh be-zh bg-zh bn-zh bo-zh br-zh bs-zh ca-zh ceb-zh ch-zh cnh-zh cs-zh cy-zh da-zh de-zh el-zh en-zh eo-zh es-zh et-zh eu-zh fa-zh fi-zh fil-zh fr-zh ga-zh gl-zh gu-zh he-zh hi-zh hr-zh ht-zh hu-zh hy-zh id-zh is-zh it-zh ja-zh jv-zh ka-zh kk-zh km-zh kn-zh ko-zh ku-zh ky-zh la-zh lo-zh lt-zh ltg-zh lv-zh mk-zh ml-zh mlg-zh mn-zh mr-zh ms-zh my-zh nb-zh ne-zh nl-zh nn-zh oc-zh or-zh pl-zh pt-zh ro-zh ru-zh sco-zh sh-zh si-zh sk-zh sl-zh sna-zh som-zh sq-zh sr-zh srp-zh sv-zh swa-zh ta-zh te-zh tg-zh th-zh tk-zh tl-zh tr-zh tt-zh ug-zh uk-zh ur-zh uz-zh vi-zh xho-zh aa-zul ab-zul af-zul aka-zul amh-zul an-zul ar-zul ast-zul av-zul ay-zul az-zul bam-zul ber-zul bg-zul bh-zul bn-zul bnt-zul bo-zul br-zul bs-zul ca-zul ceb-zul cho-zul cs-zul cu-zul cy-zul da-zul de-zul dv-zul dz-zul ee-zul efi-zul el-zul en-zul eo-zul es-zul et-zul eu-zul fa-zul fi-zul fil-zul fj-zul fr-zul ful-zul ga-zul gl-zul gu-zul hai-zul haw-zul he-zul hi-zul hr-zul ht-zul hu-zul hy-zul id-zul ik-zul is-zul it-zul iu-zul ja-zul ka-zul kk-zul km-zul kn-zul ko-zul ku-zul kw-zul la-zul lb-zul lg-zul lin-zul lo-zul lt-zul lv-zul mi-zul mk-zul ml-zul mos-zul mr-zul ms-zul my-zul nb-zul nl-zul nn-zul nya-zul oc-zul pan-zul pi-zul pl-zul prs-zul pt-zul ro-zul ru-zul sco-zul si-zul sk-zul sl-zul sq-zul sr-zul sv-zul swa-zul ta-zul te-zul tet-zul th-zul tir-zul tk-zul tl-zul to-zul tr-zul tt-zul uk-zul ur-zul uz-zul vi-zul vo-zul wol-zul xho-zul yaq-zul yor-zul
PHP_v1	PHP/v1/moses/%s-%s.txt.zip	cs-de cs-en de-en cs-es de-es en-es cs-fi de-fi en-fi es-fi cs-fr de-fr en-fr es-fr fi-fr cs-he de-he en-he es-he fi-he fr-he cs-hu de-hu en-hu es-hu fi-hu fr-hu he-hu cs-it de-it en-it es-it fi-it fr-it he-it hu-it cs-ja de-ja en-ja es-ja fi-ja fr-ja he-ja hu-ja it-ja cs-ko de-ko en-ko es-ko fi-ko fr-ko he-ko hu-ko it-ko ja-ko cs-nl de-nl en-nl es-nl fi-nl fr-nl he-nl hu-nl it-nl ja-nl ko-nl cs-pl de-pl en-pl es-pl fi-pl fr-pl he-pl hu-pl it-pl ja-pl ko-pl nl-pl cs-pt_BR de-pt_BR en-pt_BR es-pt_BR fi-pt_BR fr-pt_BR he-pt_BR hu-pt_BR it-pt_BR ja-pt_BR ko-pt_BR nl-pt_BR pl-pt_BR cs-ro de-ro en-ro es-ro fi-ro fr-ro he-ro hu-ro it-ro ja-ro ko-ro nl-ro pl-ro pt_BR-ro cs-ru de-ru en-ru es-ru fi-ru fr-ru he-ru hu-ru it-ru ja-ru ko-ru nl-ru pl-ru pt_BR-ru ro-ru cs-sk de-sk en-sk es-sk fi-sk fr-sk he-sk hu-sk it-sk ja-sk ko-sk nl-sk pl-sk pt_BR-sk ro-sk ru-sk cs-sl de-sl en-sl es-sl fi-sl fr-sl he-sl hu-sl it-sl ja-sl ko-sl nl-sl pl-sl pt_BR-sl ro-sl ru-sl sk-sl cs-sv de-sv en-sv es-sv fi-sv fr-sv he-sv hu-sv it-sv ja-sv ko-sv nl-sv pl-sv pt_BR-sv ro-sv ru-sv sk-sv sl-sv cs-tr de-tr en-tr es-tr fi-tr fr-tr he-tr hu-tr it-tr ja-tr ko-tr nl-tr pl-tr pt_BR-tr ro-tr ru-tr sk-tr sl-tr sv-tr cs-zh de-zh en-zh es-zh fi-zh fr-zh he-zh hu-zh it-zh ja-zh ko-zh nl-zh pl-zh pt_BR-zh ro-zh ru-zh sk-zh sl-zh sv-zh tr-zh zh_TW-zh cs-zh_TW de-zh_TW en-zh_TW es-zh_TW fi-zh_TW fr-zh_TW he-zh_TW hu-zh_TW it-zh_TW ja-zh_TW ko-zh_TW nl-zh_TW pl-zh_TW pt_BR-zh_TW ro-zh_TW ru-zh_TW sk-zh_TW sl-zh_TW sv-zh_TW tr-zh_TW
ParaCrawl_v5	ParaCrawl/v5/moses/%s-%s.txt.zip	bg-en cs-en da-en de-en el-en en-es en-et en-fi en-fr en-ga en-hr en-hu en-it en-lt en-lv en-mt en-nl fr-nl de-pl en-pl en-pt en-ro en-sk en-sl en-sv
OpenSubtitles_v2018	OpenSubtitles/v2018/moses/%s-%s.txt.zip	af-ar af-bg ar-bg af-bn ar-bn bg-bn ar-br bg-br af-bs ar-bs bg-bs bn-bs br-bs ar-ca bg-ca bn-ca br-ca bs-ca af-cs ar-cs bg-cs bn-cs br-cs bs-cs ca-cs af-da ar-da bg-da bn-da br-da bs-da ca-da cs-da af-de ar-de bg-de bn-de br-de bs-de ca-de cs-de da-de af-el ar-el bg-el bn-el br-el bs-el ca-el cs-el da-el de-el af-en ar-en bg-en bn-en br-en bs-en ca-en cs-en da-en de-en el-en af-eo ar-eo bg-eo br-eo bs-eo cs-eo da-eo de-eo el-eo en-eo af-es ar-es bg-es bn-es br-es bs-es ca-es cs-es da-es de-es el-es en-es eo-es af-et ar-et bg-et bn-et br-et bs-et ca-et cs-et da-et de-et el-et en-et eo-et es-et ar-eu bg-eu bn-eu br-eu bs-eu ca-eu cs-eu da-eu de-eu el-eu en-eu eo-eu es-eu et-eu af-fa ar-fa bg-fa bn-fa br-fa bs-fa ca-fa cs-fa da-fa de-fa el-fa en-fa eo-fa es-fa et-fa eu-fa af-fi ar-fi bg-fi bn-fi br-fi bs-fi ca-fi cs-fi da-fi de-fi el-fi en-fi eo-fi es-fi et-fi eu-fi fa-fi af-fr ar-fr bg-fr bn-fr br-fr bs-fr ca-fr cs-fr da-fr de-fr el-fr en-fr eo-fr es-fr et-fr eu-fr fa-fr fi-fr ar-gl bg-gl bn-gl br-gl bs-gl ca-gl cs-gl da-gl de-gl el-gl en-gl eo-gl es-gl et-gl eu-gl fa-gl fi-gl fr-gl af-he ar-he bg-he bn-he br-he bs-he ca-he cs-he da-he de-he el-he en-he eo-he es-he et-he eu-he fa-he fi-he fr-he gl-he af-hi ar-hi bg-hi bn-hi bs-hi ca-hi cs-hi da-hi de-hi el-hi en-hi eo-hi es-hi et-hi eu-hi fa-hi fi-hi fr-hi gl-hi he-hi af-hr ar-hr bg-hr bn-hr br-hr bs-hr ca-hr cs-hr da-hr de-hr el-hr en-hr eo-hr es-hr et-hr eu-hr fa-hr fi-hr fr-hr gl-hr he-hr hi-hr af-hu ar-hu bg-hu bn-hu br-hu bs-hu ca-hu cs-hu da-hu de-hu el-hu en-hu eo-hu es-hu et-hu eu-hu fa-hu fi-hu fr-hu gl-hu he-hu hi-hu hr-hu ar-hy bg-hy bs-hy cs-hy de-hy el-hy en-hy eo-hy es-hy et-hy fi-hy fr-hy he-hy hr-hy hu-hy af-id ar-id bg-id bn-id br-id bs-id ca-id cs-id da-id de-id el-id en-id eo-id es-id et-id eu-id fa-id fi-id fr-id gl-id he-id hi-id hr-id hu-id hy-id ar-is bg-is bn-is br-is bs-is ca-is cs-is da-is de-is el-is en-is eo-is es-is et-is eu-is fa-is fi-is fr-is gl-is he-is hi-is hr-is hu-is id-is af-it ar-it bg-it bn-it br-it bs-it ca-it cs-it da-it de-it el-it en-it eo-it es-it et-it eu-it fa-it fi-it fr-it gl-it he-it hi-it hr-it hu-it hy-it id-it is-it af-ja ar-ja bg-ja bn-ja bs-ja ca-ja cs-ja da-ja de-ja el-ja en-ja eo-ja es-ja et-ja eu-ja fa-ja fi-ja fr-ja gl-ja he-ja hi-ja hr-ja hu-ja id-ja is-ja it-ja ar-ka bg-ka bn-ka bs-ka ca-ka cs-ka da-ka de-ka el-ka en-ka es-ka et-ka eu-ka fa-ka fi-ka fr-ka gl-ka he-ka hi-ka hr-ka hu-ka id-ka is-ka it-ka ja-ka ar-kk bg-kk bs-kk cs-kk da-kk de-kk el-kk en-kk eo-kk es-kk et-kk fa-kk fi-kk fr-kk he-kk hr-kk hu-kk id-kk is-kk it-kk ja-kk ar-ko bg-ko bn-ko bs-ko ca-ko cs-ko da-ko de-ko el-ko en-ko eo-ko es-ko et-ko eu-ko fa-ko fi-ko fr-ko gl-ko he-ko hi-ko hr-ko hu-ko id-ko is-ko it-ko ja-ko ka-ko af-lt ar-lt bg-lt bn-lt bs-lt ca-lt cs-lt da-lt de-lt el-lt en-lt eo-lt es-lt et-lt eu-lt fa-lt fi-lt fr-lt gl-lt he-lt hi-lt hr-lt hu-lt id-lt is-lt it-lt ja-lt ka-lt kk-lt ko-lt af-lv ar-lv bg-lv bn-lv bs-lv ca-lv cs-lv da-lv de-lv el-lv en-lv eo-lv es-lv et-lv eu-lv fa-lv fi-lv fr-lv gl-lv he-lv hi-lv hr-lv hu-lv id-lv is-lv it-lv ja-lv ka-lv kk-lv ko-lv lt-lv af-mk ar-mk bg-mk bn-mk br-mk bs-mk ca-mk cs-mk da-mk de-mk el-mk en-mk eo-mk es-mk et-mk eu-mk fa-mk fi-mk fr-mk gl-mk he-mk hi-mk hr-mk hu-mk hy-mk id-mk is-mk it-mk ja-mk ka-mk ko-mk lt-mk lv-mk af-ml ar-ml bg-ml bn-ml br-ml bs-ml ca-ml cs-ml da-ml de-ml el-ml en-ml eo-ml es-ml et-ml eu-ml fa-ml fi-ml fr-ml gl-ml he-ml hi-ml hr-ml hu-ml hy-ml id-ml is-ml it-ml ja-ml ka-ml ko-ml lt-ml lv-ml mk-ml af-ms ar-ms bg-ms bn-ms bs-ms ca-ms cs-ms da-ms de-ms el-ms en-ms eo-ms es-ms et-ms eu-ms fa-ms fi-ms fr-ms gl-ms he-ms hi-ms hr-ms hu-ms id-ms is-ms it-ms ja-ms ka-ms kk-ms ko-ms lt-ms lv-ms mk-ms ml-ms af-nl ar-nl bg-nl bn-nl br-nl bs-nl ca-nl cs-nl da-nl de-nl el-nl en-nl eo-nl es-nl et-nl eu-nl fa-nl fi-nl fr-nl gl-nl he-nl hi-nl hr-nl hu-nl hy-nl id-nl is-nl it-nl ja-nl ka-nl kk-nl ko-nl lt-nl lv-nl mk-nl ml-nl ms-nl af-no ar-no bg-no bn-no br-no bs-no ca-no cs-no da-no de-no el-no en-no eo-no es-no et-no eu-no fa-no fi-no fr-no gl-no he-no hi-no hr-no hu-no is-no it-no ja-no ka-no kk-no ko-no lt-no lv-no mk-no ml-no ms-no nl-no af-pl ar-pl bg-pl bn-pl br-pl bs-pl ca-pl cs-pl da-pl de-pl el-pl en-pl eo-pl es-pl et-pl eu-pl fa-pl fi-pl fr-pl gl-pl he-pl hi-pl hr-pl hu-pl hy-pl id-pl is-pl it-pl ja-pl ka-pl kk-pl ko-pl lt-pl lv-pl mk-pl ml-pl ms-pl nl-pl no-pl af-pt ar-pt bg-pt bn-pt br-pt bs-pt ca-pt cs-pt da-pt de-pt el-pt en-pt eo-pt es-pt et-pt eu-pt fa-pt fi-pt fr-pt gl-pt he-pt hi-pt hr-pt hu-pt hy-pt id-pt is-pt it-pt ja-pt ka-pt kk-pt ko-pt lt-pt lv-pt mk-pt ml-pt ms-pt nl-pt no-pt pl-pt af-pt_br ar-pt_br bg-pt_br bn-pt_br br-pt_br bs-pt_br ca-pt_br cs-pt_br da-pt_br de-pt_br el-pt_br en-pt_br eo-pt_br es-pt_br et-pt_br eu-pt_br fa-pt_br fi-pt_br fr-pt_br gl-pt_br he-pt_br hi-pt_br hr-pt_br hu-pt_br hy-pt_br id-pt_br is-pt_br it-pt_br ja-pt_br ka-pt_br kk-pt_br ko-pt_br lt-pt_br lv-pt_br mk-pt_br ml-pt_br ms-pt_br nl-pt_br no-pt_br pl-pt_br pt-pt_br af-ro ar-ro bg-ro bn-ro br-ro bs-ro ca-ro cs-ro da-ro de-ro el-ro en-ro eo-ro es-ro et-ro eu-ro fa-ro fi-ro fr-ro gl-ro he-ro hi-ro hr-ro hu-ro hy-ro id-ro is-ro it-ro ja-ro ka-ro kk-ro ko-ro lt-ro lv-ro mk-ro ml-ro ms-ro nl-ro no-ro pl-ro pt-ro pt_br-ro af-ru ar-ru bg-ru bn-ru br-ru bs-ru ca-ru cs-ru da-ru de-ru el-ru en-ru eo-ru es-ru et-ru eu-ru fa-ru fi-ru fr-ru gl-ru he-ru hi-ru hr-ru hu-ru hy-ru id-ru is-ru it-ru ja-ru ka-ru kk-ru ko-ru lt-ru lv-ru mk-ru ml-ru ms-ru nl-ru no-ru pl-ru pt-ru pt_br-ru ro-ru af-si ar-si bg-si bn-si bs-si ca-si cs-si da-si de-si el-si en-si eo-si es-si et-si eu-si fa-si fi-si fr-si gl-si he-si hi-si hr-si hu-si id-si is-si it-si ja-si ka-si ko-si lt-si lv-si mk-si ml-si ms-si nl-si no-si pl-si pt-si pt_br-si ro-si ru-si af-sk ar-sk bg-sk bn-sk br-sk bs-sk ca-sk cs-sk da-sk de-sk el-sk en-sk eo-sk es-sk et-sk eu-sk fa-sk fi-sk fr-sk gl-sk he-sk hi-sk hr-sk hu-sk hy-sk id-sk is-sk it-sk ja-sk ka-sk kk-sk ko-sk lt-sk lv-sk mk-sk ml-sk ms-sk nl-sk no-sk pl-sk pt-sk pt_br-sk ro-sk ru-sk si-sk af-sl ar-sl bg-sl bn-sl br-sl bs-sl ca-sl cs-sl da-sl de-sl el-sl en-sl eo-sl es-sl et-sl eu-sl fa-sl fi-sl fr-sl gl-sl he-sl hi-sl hr-sl hu-sl hy-sl id-sl is-sl it-sl ja-sl ka-sl kk-sl ko-sl lt-sl lv-sl mk-sl ml-sl ms-sl nl-sl no-sl pl-sl pt-sl pt_br-sl ro-sl ru-sl si-sl sk-sl af-sq ar-sq bg-sq bn-sq br-sq bs-sq ca-sq cs-sq da-sq de-sq el-sq en-sq eo-sq es-sq et-sq eu-sq fa-sq fi-sq fr-sq gl-sq he-sq hi-sq hr-sq hu-sq hy-sq id-sq is-sq it-sq ja-sq ka-sq ko-sq lt-sq lv-sq mk-sq ml-sq ms-sq nl-sq no-sq pl-sq pt-sq pt_br-sq ro-sq ru-sq si-sq sk-sq sl-sq af-sr ar-sr bg-sr bn-sr br-sr bs-sr ca-sr cs-sr da-sr de-sr el-sr en-sr eo-sr es-sr et-sr eu-sr fa-sr fi-sr fr-sr gl-sr he-sr hi-sr hr-sr hu-sr hy-sr id-sr is-sr it-sr ja-sr ka-sr kk-sr ko-sr lt-sr lv-sr mk-sr ml-sr ms-sr nl-sr no-sr pl-sr pt-sr pt_br-sr ro-sr ru-sr si-sr sk-sr sl-sr sq-sr af-sv ar-sv bg-sv bn-sv br-sv bs-sv ca-sv cs-sv da-sv de-sv el-sv en-sv eo-sv es-sv et-sv eu-sv fa-sv fi-sv fr-sv gl-sv he-sv hi-sv hr-sv hu-sv hy-sv id-sv is-sv it-sv ja-sv ka-sv kk-sv ko-sv lt-sv lv-sv mk-sv ml-sv ms-sv nl-sv no-sv pl-sv pt-sv pt_br-sv ro-sv ru-sv si-sv sk-sv sl-sv sq-sv sr-sv af-ta ar-ta bg-ta bn-ta bs-ta cs-ta da-ta de-ta el-ta en-ta es-ta et-ta eu-ta fa-ta fi-ta fr-ta he-ta hi-ta hr-ta hu-ta id-ta is-ta it-ta ja-ta ko-ta lt-ta lv-ta mk-ta ml-ta ms-ta nl-ta no-ta pl-ta pt-ta pt_br-ta ro-ta ru-ta si-ta sk-ta sl-ta sq-ta sr-ta sv-ta ar-te bg-te bs-te cs-te da-te de-te el-te en-te es-te et-te eu-te fa-te fi-te fr-te he-te hi-te hr-te hu-te id-te it-te ja-te ko-te lt-te lv-te mk-te ms-te nl-te no-te pl-te pt-te pt_br-te ro-te ru-te si-te sk-te sl-te sq-te sr-te sv-te ta-te af-th ar-th bg-th bn-th bs-th ca-th cs-th da-th de-th el-th en-th eo-th es-th et-th eu-th fa-th fi-th fr-th gl-th he-th hi-th hr-th hu-th id-th is-th it-th ja-th ka-th kk-th ko-th lt-th lv-th mk-th ml-th ms-th nl-th no-th pl-th pt-th pt_br-th ro-th ru-th si-th sk-th sl-th sq-th sr-th sv-th ta-th te-th ar-tl bg-tl bn-tl bs-tl cs-tl da-tl de-tl el-tl en-tl eo-tl es-tl et-tl eu-tl fa-tl fi-tl fr-tl he-tl hi-tl hr-tl hu-tl id-tl is-tl it-tl ja-tl ka-tl ko-tl lt-tl mk-tl ml-tl ms-tl nl-tl no-tl pl-tl pt-tl pt_br-tl ro-tl ru-tl si-tl sk-tl sl-tl sq-tl sr-tl sv-tl th-tl af-tr ar-tr bg-tr bn-tr br-tr bs-tr ca-tr cs-tr da-tr de-tr el-tr en-tr eo-tr es-tr et-tr eu-tr fa-tr fi-tr fr-tr gl-tr he-tr hi-tr hr-tr hu-tr hy-tr id-tr is-tr it-tr ja-tr ka-tr kk-tr ko-tr lt-tr lv-tr mk-tr ml-tr ms-tr nl-tr no-tr pl-tr pt-tr pt_br-tr ro-tr ru-tr si-tr sk-tr sl-tr sq-tr sr-tr sv-tr ta-tr te-tr th-tr tl-tr af-uk ar-uk bg-uk bn-uk br-uk bs-uk ca-uk cs-uk da-uk de-uk el-uk en-uk eo-uk es-uk et-uk eu-uk fa-uk fi-uk fr-uk gl-uk he-uk hi-uk hr-uk hu-uk id-uk is-uk it-uk ja-uk ka-uk kk-uk ko-uk lt-uk lv-uk mk-uk ml-uk ms-uk nl-uk no-uk pl-uk pt-uk pt_br-uk ro-uk ru-uk si-uk sk-uk sl-uk sq-uk sr-uk sv-uk th-uk tl-uk tr-uk ar-ur bg-ur bn-ur bs-ur cs-ur da-ur de-ur el-ur en-ur es-ur et-ur eu-ur fa-ur fi-ur fr-ur gl-ur he-ur hi-ur hr-ur hu-ur id-ur is-ur it-ur ja-ur ka-ur ko-ur lt-ur lv-ur mk-ur ml-ur ms-ur nl-ur no-ur pl-ur pt-ur pt_br-ur ro-ur ru-ur si-ur sk-ur sl-ur sq-ur sr-ur sv-ur th-ur tr-ur uk-ur af-vi ar-vi bg-vi bn-vi bs-vi ca-vi cs-vi da-vi de-vi el-vi en-vi eo-vi es-vi et-vi eu-vi fa-vi fi-vi fr-vi gl-vi he-vi hi-vi hr-vi hu-vi id-vi is-vi it-vi ja-vi ka-vi kk-vi ko-vi lt-vi lv-vi mk-vi ml-vi ms-vi nl-vi no-vi pl-vi pt-vi pt_br-vi ro-vi ru-vi si-vi sk-vi sl-vi sq-vi sr-vi sv-vi ta-vi te-vi th-vi tl-vi tr-vi uk-vi ur-vi af-ze_en ar-ze_en bg-ze_en bn-ze_en bs-ze_en ca-ze_en cs-ze_en da-ze_en de-ze_en el-ze_en en-ze_en eo-ze_en es-ze_en et-ze_en eu-ze_en fa-ze_en fi-ze_en fr-ze_en gl-ze_en he-ze_en hi-ze_en hr-ze_en hu-ze_en id-ze_en is-ze_en it-ze_en ja-ze_en ka-ze_en ko-ze_en lt-ze_en lv-ze_en mk-ze_en ml-ze_en ms-ze_en nl-ze_en no-ze_en pl-ze_en pt-ze_en pt_br-ze_en ro-ze_en ru-ze_en si-ze_en sk-ze_en sl-ze_en sq-ze_en sr-ze_en sv-ze_en ta-ze_en te-ze_en th-ze_en tr-ze_en uk-ze_en vi-ze_en ar-ze_zh bg-ze_zh bn-ze_zh bs-ze_zh ca-ze_zh cs-ze_zh da-ze_zh de-ze_zh el-ze_zh en-ze_zh eo-ze_zh es-ze_zh et-ze_zh eu-ze_zh fa-ze_zh fi-ze_zh fr-ze_zh gl-ze_zh he-ze_zh hi-ze_zh hr-ze_zh hu-ze_zh id-ze_zh is-ze_zh it-ze_zh ja-ze_zh ka-ze_zh ko-ze_zh lt-ze_zh lv-ze_zh mk-ze_zh ml-ze_zh ms-ze_zh nl-ze_zh no-ze_zh pl-ze_zh pt-ze_zh pt_br-ze_zh ro-ze_zh ru-ze_zh si-ze_zh sk-ze_zh sl-ze_zh sq-ze_zh sr-ze_zh sv-ze_zh ta-ze_zh th-ze_zh tr-ze_zh uk-ze_zh vi-ze_zh ze_en-ze_zh af-zh_cn ar-zh_cn bg-zh_cn bn-zh_cn br-zh_cn bs-zh_cn ca-zh_cn cs-zh_cn da-zh_cn de-zh_cn el-zh_cn en-zh_cn eo-zh_cn es-zh_cn et-zh_cn eu-zh_cn fa-zh_cn fi-zh_cn fr-zh_cn gl-zh_cn he-zh_cn hi-zh_cn hr-zh_cn hu-zh_cn hy-zh_cn id-zh_cn is-zh_cn it-zh_cn ja-zh_cn ka-zh_cn kk-zh_cn ko-zh_cn lt-zh_cn lv-zh_cn mk-zh_cn ml-zh_cn ms-zh_cn nl-zh_cn no-zh_cn pl-zh_cn pt-zh_cn pt_br-zh_cn ro-zh_cn ru-zh_cn si-zh_cn sk-zh_cn sl-zh_cn sq-zh_cn sr-zh_cn sv-zh_cn ta-zh_cn te-zh_cn th-zh_cn tl-zh_cn tr-zh_cn uk-zh_cn ur-zh_cn vi-zh_cn ze_en-zh_cn ze_zh-zh_cn af-zh_tw ar-zh_tw bg-zh_tw bn-zh_tw bs-zh_tw ca-zh_tw cs-zh_tw da-zh_tw de-zh_tw el-zh_tw en-zh_tw eo-zh_tw es-zh_tw et-zh_tw eu-zh_tw fa-zh_tw fi-zh_tw fr-zh_tw gl-zh_tw he-zh_tw hi-zh_tw hr-zh_tw hu-zh_tw hy-zh_tw id-zh_tw is-zh_tw it-zh_tw ja-zh_tw ka-zh_tw ko-zh_tw lt-zh_tw lv-zh_tw mk-zh_tw ml-zh_tw ms-zh_tw nl-zh_tw no-zh_tw pl-zh_tw pt-zh_tw pt_br-zh_tw ro-zh_tw ru-zh_tw si-zh_tw sk-zh_tw sl-zh_tw sq-zh_tw sr-zh_tw sv-zh_tw ta-zh_tw te-zh_tw th-zh_tw tl-zh_tw tr-zh_tw uk-zh_tw ur-zh_tw vi-zh_tw ze_en-zh_tw ze_zh-zh_tw zh_cn-zh_tw
OpenSubtitles_v2016	OpenSubtitles/v2016/moses/%s-%s.txt.zip	af-ar af-bg ar-bg ar-bn bg-bn ar-br bg-br af-bs ar-bs bg-bs bn-bs br-bs ar-ca bg-ca bn-ca br-ca bs-ca af-cs ar-cs bg-cs bn-cs br-cs bs-cs ca-cs af-da ar-da bg-da bn-da br-da bs-da ca-da cs-da af-de ar-de bg-de bn-de br-de bs-de ca-de cs-de da-de af-el ar-el bg-el bn-el br-el bs-el ca-el cs-el da-el de-el af-en ar-en bg-en bn-en br-en bs-en ca-en cs-en da-en de-en el-en ar-eo bg-eo br-eo bs-eo cs-eo da-eo de-eo el-eo en-eo af-es ar-es bg-es bn-es br-es bs-es ca-es cs-es da-es de-es el-es en-es eo-es af-et ar-et bg-et bn-et br-et bs-et ca-et cs-et da-et de-et el-et en-et eo-et es-et ar-eu bg-eu bn-eu br-eu bs-eu cs-eu da-eu de-eu el-eu en-eu es-eu et-eu af-fa ar-fa bg-fa bn-fa br-fa bs-fa ca-fa cs-fa da-fa de-fa el-fa en-fa eo-fa es-fa et-fa eu-fa af-fi ar-fi bg-fi bn-fi br-fi bs-fi ca-fi cs-fi da-fi de-fi el-fi en-fi eo-fi es-fi et-fi eu-fi fa-fi af-fr ar-fr bg-fr bn-fr br-fr bs-fr ca-fr cs-fr da-fr de-fr el-fr en-fr eo-fr es-fr et-fr eu-fr fa-fr fi-fr ar-gl bg-gl br-gl bs-gl ca-gl cs-gl da-gl de-gl el-gl en-gl eo-gl es-gl et-gl eu-gl fa-gl fi-gl fr-gl af-he ar-he bg-he bn-he br-he bs-he ca-he cs-he da-he de-he el-he en-he eo-he es-he et-he eu-he fa-he fi-he fr-he gl-he ar-hi bg-hi bn-hi bs-hi ca-hi cs-hi da-hi de-hi el-hi en-hi eo-hi es-hi et-hi eu-hi fa-hi fi-hi fr-hi he-hi af-hr ar-hr bg-hr bn-hr br-hr bs-hr ca-hr cs-hr da-hr de-hr el-hr en-hr eo-hr es-hr et-hr eu-hr fa-hr fi-hr fr-hr gl-hr he-hr hi-hr af-hu ar-hu bg-hu bn-hu br-hu bs-hu ca-hu cs-hu da-hu de-hu el-hu en-hu eo-hu es-hu et-hu eu-hu fa-hu fi-hu fr-hu gl-hu he-hu hi-hu hr-hu cs-hy el-hy en-hy eo-hy es-hy af-id ar-id bg-id bn-id br-id bs-id ca-id cs-id da-id de-id el-id en-id eo-id es-id et-id eu-id fa-id fi-id fr-id gl-id he-id hi-id hr-id hu-id is-id ar-is bg-is bn-is bs-is ca-is cs-is da-is de-is el-is en-is es-is et-is eu-is fa-is fi-is fr-is gl-is he-is hi-is hr-is hu-is id-is af-it ar-it bg-it bn-it br-it bs-it ca-it cs-it da-it de-it el-it en-it eo-it es-it et-it eu-it fa-it fi-it fr-it gl-it he-it hi-it hr-it hu-it id-it is-it af-ja ar-ja bg-ja bn-ja bs-ja ca-ja cs-ja da-ja de-ja el-ja en-ja eo-ja es-ja et-ja eu-ja fa-ja fi-ja fr-ja gl-ja he-ja hi-ja hr-ja hu-ja id-ja is-ja it-ja ar-ka bg-ka bn-ka bs-ka ca-ka cs-ka da-ka de-ka el-ka en-ka es-ka et-ka eu-ka fa-ka fi-ka fr-ka gl-ka he-ka hi-ka hr-ka hu-ka id-ka is-ka it-ka ja-ka bg-kk bs-kk da-kk de-kk en-kk es-kk fi-kk he-kk hr-kk hu-kk is-kk it-kk ar-ko bg-ko bn-ko bs-ko ca-ko cs-ko da-ko de-ko el-ko en-ko es-ko et-ko eu-ko fa-ko fi-ko fr-ko gl-ko he-ko hi-ko hr-ko hu-ko id-ko is-ko it-ko ja-ko ka-ko ar-lt bg-lt bn-lt bs-lt ca-lt cs-lt da-lt de-lt el-lt en-lt eo-lt es-lt et-lt eu-lt fa-lt fi-lt fr-lt gl-lt he-lt hi-lt hr-lt hu-lt id-lt is-lt it-lt ja-lt ka-lt ko-lt af-lv ar-lv bg-lv bn-lv bs-lv ca-lv cs-lv da-lv de-lv el-lv en-lv eo-lv es-lv et-lv eu-lv fa-lv fi-lv fr-lv gl-lv he-lv hi-lv hr-lv hu-lv id-lv is-lv it-lv ja-lv ka-lv ko-lv lt-lv af-mk ar-mk bg-mk bn-mk bs-mk ca-mk cs-mk da-mk de-mk el-mk en-mk eo-mk es-mk et-mk eu-mk fa-mk fi-mk fr-mk gl-mk he-mk hi-mk hr-mk hu-mk id-mk is-mk it-mk ja-mk ka-mk ko-mk lt-mk lv-mk af-ml ar-ml bg-ml bn-ml br-ml bs-ml ca-ml cs-ml da-ml de-ml el-ml en-ml eo-ml es-ml et-ml eu-ml fa-ml fi-ml fr-ml gl-ml he-ml hi-ml hr-ml hu-ml id-ml is-ml it-ml ja-ml ka-ml ko-ml lt-ml lv-ml mk-ml ar-ms bg-ms bn-ms bs-ms ca-ms cs-ms da-ms de-ms el-ms en-ms eo-ms es-ms et-ms eu-ms fa-ms fi-ms fr-ms gl-ms he-ms hi-ms hr-ms hu-ms id-ms is-ms it-ms ja-ms ka-ms ko-ms lt-ms lv-ms mk-ms ml-ms af-nl ar-nl bg-nl bn-nl br-nl bs-nl ca-nl cs-nl da-nl de-nl el-nl en-nl eo-nl es-nl et-nl eu-nl fa-nl fi-nl fr-nl gl-nl he-nl hi-nl hr-nl hu-nl id-nl is-nl it-nl ja-nl ka-nl kk-nl ko-nl lt-nl lv-nl mk-nl ml-nl ms-nl af-no ar-no bg-no bn-no br-no bs-no ca-no cs-no da-no de-no el-no en-no eo-no es-no et-no eu-no fa-no fi-no fr-no gl-no he-no hi-no hr-no hu-no id-no is-no it-no ja-no ka-no kk-no ko-no lt-no lv-no mk-no ml-no ms-no nl-no af-pl ar-pl bg-pl bn-pl br-pl bs-pl ca-pl cs-pl da-pl de-pl el-pl en-pl eo-pl es-pl et-pl eu-pl fa-pl fi-pl fr-pl gl-pl he-pl hi-pl hr-pl hu-pl hy-pl id-pl is-pl it-pl ja-pl ka-pl kk-pl ko-pl lt-pl lv-pl mk-pl ml-pl ms-pl nl-pl no-pl af-pt ar-pt bg-pt bn-pt br-pt bs-pt ca-pt cs-pt da-pt de-pt el-pt en-pt eo-pt es-pt et-pt eu-pt fa-pt fi-pt fr-pt gl-pt he-pt hi-pt hr-pt hu-pt hy-pt id-pt is-pt it-pt ja-pt ka-pt kk-pt ko-pt lt-pt lv-pt mk-pt ml-pt ms-pt nl-pt no-pt pl-pt af-pt_br ar-pt_br bg-pt_br bn-pt_br br-pt_br bs-pt_br ca-pt_br cs-pt_br da-pt_br de-pt_br el-pt_br en-pt_br eo-pt_br es-pt_br et-pt_br eu-pt_br fa-pt_br fi-pt_br fr-pt_br gl-pt_br he-pt_br hi-pt_br hr-pt_br hu-pt_br hy-pt_br id-pt_br is-pt_br it-pt_br ja-pt_br ka-pt_br ko-pt_br lt-pt_br lv-pt_br mk-pt_br ml-pt_br ms-pt_br nl-pt_br no-pt_br pl-pt_br pt-pt_br af-ro ar-ro bg-ro bn-ro br-ro bs-ro ca-ro cs-ro da-ro de-ro el-ro en-ro eo-ro es-ro et-ro eu-ro fa-ro fi-ro fr-ro gl-ro he-ro hi-ro hr-ro hu-ro hy-ro id-ro is-ro it-ro ja-ro ka-ro kk-ro ko-ro lt-ro lv-ro mk-ro ml-ro ms-ro nl-ro no-ro pl-ro pt-ro pt_br-ro af-ru ar-ru bg-ru bn-ru br-ru bs-ru ca-ru cs-ru da-ru de-ru el-ru en-ru eo-ru es-ru et-ru eu-ru fa-ru fi-ru fr-ru gl-ru he-ru hi-ru hr-ru hu-ru id-ru is-ru it-ru ja-ru ka-ru kk-ru ko-ru lt-ru lv-ru mk-ru ml-ru ms-ru nl-ru no-ru pl-ru pt-ru pt_br-ru ro-ru af-si ar-si bg-si bn-si bs-si ca-si cs-si da-si de-si el-si en-si es-si et-si eu-si fa-si fi-si fr-si he-si hi-si hr-si hu-si id-si is-si it-si ja-si ka-si ko-si lt-si lv-si mk-si ml-si ms-si nl-si no-si pl-si pt-si pt_br-si ro-si ru-si af-sk ar-sk bg-sk bn-sk br-sk bs-sk ca-sk cs-sk da-sk de-sk el-sk en-sk eo-sk es-sk et-sk eu-sk fa-sk fi-sk fr-sk gl-sk he-sk hi-sk hr-sk hu-sk id-sk is-sk it-sk ja-sk ka-sk ko-sk lt-sk lv-sk mk-sk ml-sk ms-sk nl-sk no-sk pl-sk pt-sk pt_br-sk ro-sk ru-sk si-sk af-sl ar-sl bg-sl bn-sl br-sl bs-sl ca-sl cs-sl da-sl de-sl el-sl en-sl eo-sl es-sl et-sl eu-sl fa-sl fi-sl fr-sl gl-sl he-sl hi-sl hr-sl hu-sl id-sl is-sl it-sl ja-sl ka-sl kk-sl ko-sl lt-sl lv-sl mk-sl ml-sl ms-sl nl-sl no-sl pl-sl pt-sl pt_br-sl ro-sl ru-sl si-sl sk-sl af-sq ar-sq bg-sq bn-sq bs-sq ca-sq cs-sq da-sq de-sq el-sq en-sq eo-sq es-sq et-sq eu-sq fa-sq fi-sq fr-sq gl-sq he-sq hi-sq hr-sq hu-sq id-sq is-sq it-sq ja-sq ka-sq ko-sq lt-sq lv-sq mk-sq ml-sq ms-sq nl-sq no-sq pl-sq pt-sq pt_br-sq ro-sq ru-sq si-sq sk-sq sl-sq af-sr ar-sr bg-sr bn-sr br-sr bs-sr ca-sr cs-sr da-sr de-sr el-sr en-sr eo-sr es-sr et-sr eu-sr fa-sr fi-sr fr-sr gl-sr he-sr hi-sr hr-sr hu-sr hy-sr id-sr is-sr it-sr ja-sr ka-sr kk-sr ko-sr lt-sr lv-sr mk-sr ml-sr ms-sr nl-sr no-sr pl-sr pt-sr pt_br-sr ro-sr ru-sr si-sr sk-sr sl-sr sq-sr af-sv ar-sv bg-sv bn-sv br-sv bs-sv ca-sv cs-sv da-sv de-sv el-sv en-sv eo-sv es-sv et-sv eu-sv fa-sv fi-sv fr-sv gl-sv he-sv hi-sv hr-sv hu-sv id-sv is-sv it-sv ja-sv ka-sv kk-sv ko-sv lt-sv lv-sv mk-sv ml-sv ms-sv nl-sv no-sv pl-sv pt-sv pt_br-sv ro-sv ru-sv si-sv sk-sv sl-sv sq-sv sr-sv af-ta ar-ta bg-ta bs-ta cs-ta da-ta de-ta el-ta en-ta es-ta et-ta fa-ta fi-ta fr-ta he-ta hi-ta hr-ta hu-ta id-ta it-ta ja-ta lt-ta lv-ta mk-ta ml-ta ms-ta nl-ta no-ta pl-ta pt-ta pt_br-ta ro-ta ru-ta si-ta sk-ta sl-ta sq-ta sr-ta sv-ta ar-te bg-te bs-te cs-te da-te de-te el-te en-te es-te et-te fa-te fi-te fr-te he-te hi-te hr-te hu-te id-te it-te ja-te lt-te lv-te mk-te ms-te nl-te no-te pl-te pt-te pt_br-te ro-te ru-te si-te sk-te sl-te sq-te sr-te sv-te ta-te af-th ar-th bg-th bn-th bs-th ca-th cs-th da-th de-th el-th en-th eo-th es-th et-th eu-th fa-th fi-th fr-th gl-th he-th hi-th hr-th hu-th id-th is-th it-th ja-th ka-th ko-th lt-th lv-th mk-th ml-th ms-th nl-th no-th pl-th pt-th pt_br-th ro-th ru-th si-th sk-th sl-th sq-th sr-th sv-th ta-th te-th ar-tl bg-tl bs-tl cs-tl de-tl el-tl en-tl es-tl fa-tl fi-tl fr-tl he-tl hr-tl hu-tl id-tl it-tl ja-tl ml-tl ms-tl nl-tl pl-tl pt-tl pt_br-tl ro-tl ru-tl sl-tl sq-tl sv-tl th-tl af-tr ar-tr bg-tr bn-tr br-tr bs-tr ca-tr cs-tr da-tr de-tr el-tr en-tr eo-tr es-tr et-tr eu-tr fa-tr fi-tr fr-tr gl-tr he-tr hi-tr hr-tr hu-tr hy-tr id-tr is-tr it-tr ja-tr ka-tr kk-tr ko-tr lt-tr lv-tr mk-tr ml-tr ms-tr nl-tr no-tr pl-tr pt-tr pt_br-tr ro-tr ru-tr si-tr sk-tr sl-tr sq-tr sr-tr sv-tr ta-tr te-tr th-tr tl-tr ar-uk bg-uk bn-uk br-uk bs-uk ca-uk cs-uk da-uk de-uk el-uk en-uk eo-uk es-uk et-uk eu-uk fa-uk fi-uk fr-uk gl-uk he-uk hi-uk hr-uk hu-uk id-uk is-uk it-uk ja-uk ka-uk kk-uk ko-uk lt-uk lv-uk mk-uk ml-uk ms-uk nl-uk no-uk pl-uk pt-uk pt_br-uk ro-uk ru-uk si-uk sk-uk sl-uk sq-uk sr-uk sv-uk th-uk tr-uk ar-ur bg-ur bs-ur cs-ur da-ur de-ur el-ur en-ur es-ur et-ur fa-ur fi-ur fr-ur he-ur hr-ur hu-ur id-ur it-ur ja-ur ka-ur lt-ur mk-ur ms-ur nl-ur no-ur pl-ur pt-ur pt_br-ur ro-ur ru-ur si-ur sk-ur sl-ur sq-ur sr-ur sv-ur th-ur tr-ur af-vi ar-vi bg-vi bn-vi bs-vi ca-vi cs-vi da-vi de-vi el-vi en-vi eo-vi es-vi et-vi eu-vi fa-vi fi-vi fr-vi gl-vi he-vi hi-vi hr-vi hu-vi id-vi is-vi it-vi ja-vi ka-vi ko-vi lt-vi lv-vi mk-vi ml-vi ms-vi nl-vi no-vi pl-vi pt-vi pt_br-vi ro-vi ru-vi si-vi sk-vi sl-vi sq-vi sr-vi sv-vi ta-vi te-vi th-vi tl-vi tr-vi uk-vi ur-vi af-ze_en ar-ze_en bg-ze_en bn-ze_en bs-ze_en ca-ze_en cs-ze_en da-ze_en de-ze_en el-ze_en en-ze_en es-ze_en et-ze_en eu-ze_en fa-ze_en fi-ze_en fr-ze_en gl-ze_en he-ze_en hr-ze_en hu-ze_en id-ze_en is-ze_en it-ze_en ja-ze_en ka-ze_en ko-ze_en lt-ze_en lv-ze_en mk-ze_en ml-ze_en ms-ze_en nl-ze_en no-ze_en pl-ze_en pt-ze_en pt_br-ze_en ro-ze_en ru-ze_en si-ze_en sk-ze_en sl-ze_en sq-ze_en sr-ze_en sv-ze_en th-ze_en tr-ze_en uk-ze_en vi-ze_en ar-ze_zh bg-ze_zh bn-ze_zh bs-ze_zh ca-ze_zh cs-ze_zh da-ze_zh de-ze_zh el-ze_zh en-ze_zh eo-ze_zh es-ze_zh et-ze_zh eu-ze_zh fa-ze_zh fi-ze_zh fr-ze_zh gl-ze_zh he-ze_zh hr-ze_zh hu-ze_zh id-ze_zh is-ze_zh it-ze_zh ja-ze_zh ka-ze_zh ko-ze_zh lt-ze_zh lv-ze_zh mk-ze_zh ml-ze_zh ms-ze_zh nl-ze_zh no-ze_zh pl-ze_zh pt-ze_zh pt_br-ze_zh ro-ze_zh ru-ze_zh si-ze_zh sk-ze_zh sl-ze_zh sq-ze_zh sr-ze_zh sv-ze_zh th-ze_zh tr-ze_zh uk-ze_zh vi-ze_zh ze_en-ze_zh af-zh ar-zh bg-zh bn-zh br-zh bs-zh ca-zh cs-zh da-zh de-zh el-zh en-zh eo-zh es-zh et-zh eu-zh fa-zh fi-zh fr-zh gl-zh he-zh hi-zh hr-zh hu-zh id-zh is-zh it-zh ja-zh ka-zh ko-zh lt-zh lv-zh mk-zh ml-zh ms-zh nl-zh no-zh pl-zh pt-zh pt_br-zh ro-zh ru-zh si-zh sk-zh sl-zh sq-zh sr-zh sv-zh ta-zh te-zh th-zh tl-zh tr-zh uk-zh ur-zh vi-zh af-zh_en ar-zh_en bg-zh_en bn-zh_en bs-zh_en ca-zh_en cs-zh_en da-zh_en de-zh_en el-zh_en en-zh_en es-zh_en et-zh_en eu-zh_en fa-zh_en fi-zh_en fr-zh_en gl-zh_en he-zh_en hr-zh_en hu-zh_en id-zh_en is-zh_en it-zh_en ja-zh_en ka-zh_en ko-zh_en lt-zh_en lv-zh_en mk-zh_en ml-zh_en ms-zh_en nl-zh_en no-zh_en pl-zh_en pt-zh_en pt_br-zh_en ro-zh_en ru-zh_en si-zh_en sk-zh_en sl-zh_en sq-zh_en sr-zh_en sv-zh_en th-zh_en tr-zh_en uk-zh_en vi-zh_en zh-zh_en af-zh_tw ar-zh_tw bg-zh_tw bn-zh_tw bs-zh_tw ca-zh_tw cs-zh_tw da-zh_tw de-zh_tw el-zh_tw en-zh_tw eo-zh_tw es-zh_tw et-zh_tw eu-zh_tw fa-zh_tw fi-zh_tw fr-zh_tw gl-zh_tw he-zh_tw hi-zh_tw hr-zh_tw hu-zh_tw id-zh_tw is-zh_tw it-zh_tw ja-zh_tw ka-zh_tw ko-zh_tw lt-zh_tw lv-zh_tw mk-zh_tw ml-zh_tw ms-zh_tw nl-zh_tw no-zh_tw pl-zh_tw pt-zh_tw pt_br-zh_tw ro-zh_tw ru-zh_tw si-zh_tw sk-zh_tw sl-zh_tw sq-zh_tw sr-zh_tw sv-zh_tw ta-zh_tw te-zh_tw th-zh_tw tr-zh_tw uk-zh_tw ur-zh_tw vi-zh_tw ze_en-zh_tw ze_zh-zh_tw zh-zh_tw zh_en-zh_tw ar-zh_zh bg-zh_zh bn-zh_zh bs-zh_zh ca-zh_zh cs-zh_zh da-zh_zh de-zh_zh el-zh_zh en-zh_zh eo-zh_zh es-zh_zh et-zh_zh eu-zh_zh fa-zh_zh fi-zh_zh fr-zh_zh gl-zh_zh he-zh_zh hr-zh_zh hu-zh_zh id-zh_zh is-zh_zh it-zh_zh ja-zh_zh ka-zh_zh ko-zh_zh lt-zh_zh lv-zh_zh mk-zh_zh ml-zh_zh ms-zh_zh nl-zh_zh no-zh_zh pl-zh_zh pt-zh_zh pt_br-zh_zh ro-zh_zh ru-zh_zh si-zh_zh sk-zh_zh sl-zh_zh sq-zh_zh sr-zh_zh sv-zh_zh th-zh_zh tr-zh_zh uk-zh_zh vi-zh_zh zh-zh_zh zh_en-zh_zh zh_tw-zh_zh
OpenSubtitles_v1	OpenSubtitles/v1/moses/%s-%s.txt.zip	bg-cs bg-da cs-da bg-de cs-de da-de bg-el cs-el da-el de-el bg-en cs-en da-en de-en el-en bg-es cs-es da-es de-es el-es en-es bg-et cs-et da-et de-et el-et en-et es-et bg-fi cs-fi da-fi de-fi el-fi en-fi es-fi et-fi bg-fr cs-fr da-fr de-fr el-fr en-fr es-fr et-fr fi-fr bg-he cs-he da-he de-he el-he en-he es-he et-he fi-he fr-he bg-hr cs-hr de-hr el-hr en-hr es-hr et-hr fi-hr fr-hr bg-hu cs-hu da-hu de-hu el-hu en-hu es-hu et-hu fi-hu fr-hu he-hu hr-hu cs-is de-is en-is es-is fi-is fr-is hu-is bg-it cs-it da-it de-it el-it en-it es-it fi-it fr-it he-it hu-it is-it bg-ja cs-ja de-ja el-ja en-ja es-ja fr-ja hu-ja bg-lt cs-lt el-lt en-lt es-lt et-lt fi-lt fr-lt he-lt hu-lt bg-lv es-lv hu-lv bg-nl cs-nl da-nl de-nl el-nl en-nl es-nl et-nl fi-nl fr-nl he-nl hr-nl hu-nl is-nl it-nl ja-nl lt-nl lv-nl bg-no cs-no da-no de-no el-no en-no es-no et-no fi-no fr-no hu-no is-no it-no ja-no lt-no nl-no bg-pl cs-pl de-pl el-pl en-pl es-pl et-pl fi-pl fr-pl he-pl hr-pl hu-pl is-pl nl-pl no-pl bg-pt cs-pt da-pt de-pt el-pt en-pt es-pt et-pt fi-pt fr-pt he-pt hr-pt hu-pt is-pt it-pt ja-pt lt-pt nl-pt no-pt pl-pt bg-pt_br cs-pt_br da-pt_br de-pt_br el-pt_br en-pt_br es-pt_br et-pt_br fi-pt_br fr-pt_br he-pt_br hr-pt_br hu-pt_br is-pt_br it-pt_br ja-pt_br lt-pt_br nl-pt_br no-pt_br pl-pt_br pt-pt_br bg-ro cs-ro da-ro de-ro el-ro en-ro es-ro et-ro fi-ro fr-ro he-ro hr-ro hu-ro is-ro it-ro ja-ro lt-ro lv-ro nl-ro no-ro pl-ro pt-ro pt_br-ro bg-ru cs-ru da-ru de-ru el-ru en-ru es-ru et-ru fi-ru fr-ru he-ru hu-ru lt-ru nl-ru no-ru pt-ru pt_br-ru ro-ru bg-sk cs-sk de-sk el-sk en-sk es-sk fi-sk he-sk hu-sk pl-sk pt-sk pt_br-sk ro-sk bg-sl cs-sl da-sl de-sl el-sl en-sl es-sl et-sl fi-sl fr-sl he-sl hr-sl hu-sl is-sl it-sl ja-sl lt-sl nl-sl no-sl pl-sl pt-sl pt_br-sl ro-sl ru-sl sk-sl bg-sv cs-sv da-sv de-sv el-sv en-sv es-sv et-sv fi-sv fr-sv he-sv hr-sv hu-sv is-sv it-sv lt-sv lv-sv nl-sv no-sv pl-sv pt-sv pt_br-sv ro-sv ru-sv sl-sv bg-tr cs-tr da-tr de-tr el-tr en-tr es-tr et-tr fi-tr fr-tr he-tr hr-tr hu-tr is-tr it-tr ja-tr lt-tr lv-tr nl-tr no-tr pl-tr pt-tr pt_br-tr ro-tr ru-tr sk-tr sl-tr sv-tr bg-zh cs-zh de-zh el-zh en-zh es-zh fi-zh fr-zh he-zh hu-zh lt-zh nl-zh pt-zh pt_br-zh ro-zh ru-zh sl-zh sv-zh tr-zh
OpenOffice_v3	OpenOffice/v3/moses/%s-%s.txt.zip	de-en_GB de-es en_GB-es de-fr en_GB-fr es-fr de-ja en_GB-ja es-ja fr-ja de-ru en_GB-ru es-ru fr-ru ja-ru de-sv en_GB-sv es-sv fr-sv ja-sv ru-sv de-zh_CN en_GB-zh_CN es-zh_CN fr-zh_CN ja-zh_CN ru-zh_CN sv-zh_CN
OpenOffice_v2	OpenOffice/v2/moses/%s-%s.txt.zip	de-en de-es en-es de-fr en-fr es-fr de-jp en-jp es-jp fr-jp de-sv en-sv es-sv fr-sv jp-sv
OfisPublik_v1	OfisPublik/v1/moses/%s-%s.txt.zip	br-fr
News_Commentary_v11	News-Commentary/v11/moses/%s-%s.txt.zip	ar-cs ar-de cs-de ar-en cs-en de-en ar-es cs-es de-es en-es ar-fr cs-fr de-fr en-fr es-fr ar-it cs-it de-it en-it es-it fr-it ar-ja cs-ja de-ja en-ja es-ja fr-ja ar-nl cs-nl de-nl en-nl es-nl fr-nl it-nl ar-pt cs-pt de-pt en-pt es-pt fr-pt it-pt nl-pt ar-ru cs-ru de-ru en-ru es-ru fr-ru it-ru ja-ru nl-ru pt-ru ar-zh cs-zh de-zh en-zh es-zh fr-zh it-zh ja-zh nl-zh pt-zh ru-zh
News_Commentary_v9.1	News-Commentary/v9.1/moses/%s-%s.txt.zip	ar-cs ar-de cs-de ar-en cs-en de-en ar-es cs-es de-es en-es ar-fr cs-fr de-fr en-fr es-fr ar-it cs-it de-it en-it es-it fr-it ar-ja cs-ja de-ja en-ja es-ja fr-ja ar-nl cs-nl de-nl en-nl es-nl fr-nl it-nl ar-pt cs-pt de-pt en-pt es-pt fr-pt it-pt nl-pt ar-ru cs-ru de-ru en-ru es-ru fr-ru it-ru ja-ru nl-ru pt-ru ar-zh cs-zh de-zh en-zh es-zh fr-zh it-zh ja-zh nl-zh pt-zh ru-zh
MultiParaCrawl_v5	MultiParaCrawl/v5/moses/%s-%s.txt.zip	bg-cs bg-da cs-da bg-de cs-de da-de bg-el cs-el da-el de-el bg-es cs-es da-es de-es el-es bg-et cs-et da-et de-et el-et es-et bg-fi cs-fi da-fi de-fi el-fi es-fi et-fi bg-fr cs-fr da-fr de-fr el-fr es-fr et-fr fi-fr bg-ga cs-ga da-ga de-ga el-ga es-ga et-ga fi-ga fr-ga bg-hr cs-hr da-hr de-hr el-hr es-hr et-hr fi-hr fr-hr ga-hr bg-hu cs-hu da-hu de-hu el-hu es-hu et-hu fi-hu fr-hu ga-hu hr-hu bg-it cs-it da-it de-it el-it es-it et-it fi-it fr-it ga-it hr-it hu-it bg-lt cs-lt da-lt de-lt el-lt es-lt et-lt fi-lt fr-lt ga-lt hr-lt hu-lt it-lt bg-lv cs-lv da-lv de-lv el-lv es-lv et-lv fi-lv fr-lv ga-lv hr-lv hu-lv it-lv lt-lv bg-mt cs-mt da-mt de-mt el-mt es-mt et-mt fi-mt fr-mt ga-mt hr-mt hu-mt it-mt lt-mt lv-mt bg-nl cs-nl da-nl de-nl el-nl es-nl et-nl fi-nl fr-nl ga-nl hr-nl hu-nl it-nl lt-nl lv-nl mt-nl bg-pl cs-pl da-pl de-pl el-pl es-pl et-pl fi-pl fr-pl ga-pl hr-pl hu-pl it-pl lt-pl lv-pl mt-pl nl-pl bg-pt cs-pt da-pt de-pt el-pt es-pt et-pt fi-pt fr-pt ga-pt hr-pt hu-pt it-pt lt-pt lv-pt mt-pt nl-pt pl-pt bg-ro cs-ro da-ro de-ro el-ro es-ro et-ro fi-ro fr-ro ga-ro hr-ro hu-ro it-ro lt-ro lv-ro mt-ro nl-ro pl-ro pt-ro bg-sk cs-sk da-sk de-sk el-sk es-sk et-sk fi-sk fr-sk ga-sk hr-sk hu-sk it-sk lt-sk lv-sk mt-sk nl-sk pl-sk pt-sk ro-sk bg-sl cs-sl da-sl de-sl el-sl es-sl et-sl fi-sl fr-sl ga-sl hr-sl hu-sl it-sl lt-sl lv-sl mt-sl nl-sl pl-sl pt-sl ro-sl sk-sl bg-sv cs-sv da-sv de-sv el-sv es-sv et-sv fi-sv fr-sv ga-sv hr-sv hu-sv it-sv lt-sv lv-sv mt-sv nl-sv pl-sv pt-sv ro-sv sk-sv sl-sv
MultiUN_v1	MultiUN/v1/moses/%s-%s.txt.zip	ar-de ar-en de-en ar-es de-es en-es ar-fr de-fr en-fr es-fr ar-ru de-ru en-ru es-ru fr-ru ar-zh de-zh en-zh es-zh fr-zh ru-zh
MontenegrinSubs_v1	MontenegrinSubs/v1/moses/%s-%s.txt.zip	en-me
memat_v1	memat/v1/moses/%s-%s.txt.zip	en-xh
MBS_v1	MBS/v1/moses/%s-%s.txt.zip	fr-nl
KDEdoc_v1	KDEdoc/v1/moses/%s-%s.txt.zip	de-en_GB de-es en_GB-es de-et en_GB-et es-et de-fr en_GB-fr es-fr et-fr de-hu en_GB-hu es-hu et-hu fr-hu de-it en_GB-it es-it fr-it hu-it de-ja en_GB-ja es-ja fr-ja hu-ja it-ja de-nl en_GB-nl es-nl et-nl fr-nl hu-nl it-nl ja-nl de-nn es-nn fr-nn hu-nn nl-nn de-pt en_GB-pt es-pt et-pt fr-pt hu-pt it-pt ja-pt nl-pt nn-pt de-pt_BR es-pt_BR fr-pt_BR hu-pt_BR it-pt_BR de-ro en_GB-ro es-ro fr-ro hu-ro it-ro ja-ro nl-ro pt-ro de-ru en_GB-ru es-ru et-ru fr-ru hu-ru it-ru ja-ru nl-ru pt-ru pt_BR-ru ro-ru de-sk en_GB-sk es-sk et-sk fr-sk hu-sk it-sk ja-sk nl-sk nn-sk pt-sk pt_BR-sk ro-sk ru-sk de-sl en_GB-sl es-sl et-sl fr-sl hu-sl it-sl ja-sl nl-sl nn-sl pt-sl pt_BR-sl ro-sl ru-sl sk-sl da-sr de-sr en_GB-sr es-sr fr-sr hu-sr it-sr ja-sr nl-sr pt-sr ro-sr ru-sr sk-sr sl-sr da-sv de-sv en_GB-sv es-sv fr-sv hu-sv it-sv ja-sv nl-sv nn-sv pt-sv pt_BR-sv ro-sv ru-sv sk-sv sl-sv sr-sv da-tr de-tr en_GB-tr es-tr fr-tr hu-tr it-tr ja-tr nl-tr pt-tr ro-tr ru-tr sk-tr sl-tr sr-tr sv-tr da-uk de-uk en_GB-uk es-uk fr-uk hu-uk it-uk ja-uk nl-uk nn-uk pt-uk ro-uk ru-uk sk-uk sl-uk sv-uk tr-uk da-wa de-wa en_GB-wa es-wa fr-wa hu-wa it-wa ja-wa nl-wa pt-wa ro-wa ru-wa sk-wa sl-wa sr-wa sv-wa tr-wa da-xh de-xh en_GB-xh es-xh fr-xh hu-xh it-xh ja-xh nl-xh nn-xh pt-xh pt_BR-xh ro-xh ru-xh sk-xh sl-xh sr-xh sv-xh tr-xh uk-xh wa-xh da-zh_TW de-zh_TW en_GB-zh_TW es-zh_TW fr-zh_TW hu-zh_TW it-zh_TW ja-zh_TW nl-zh_TW pt-zh_TW ro-zh_TW ru-zh_TW sk-zh_TW sl-zh_TW sr-zh_TW sv-zh_TW tr-zh_TW uk-zh_TW wa-zh_TW xh-zh_TW
KDE4_v2	KDE4/v2/moses/%s-%s.txt.zip	af-ar af-as ar-as af-ast ar-ast as-ast af-be ar-be as-be ast-be af-bg ar-bg as-bg ast-bg be-bg af-bn ar-bn as-bn ast-bn be-bn bg-bn af-bn_IN ar-bn_IN as-bn_IN ast-bn_IN be-bn_IN bg-bn_IN bn-bn_IN af-br ar-br as-br ast-br be-br bg-br bn-br bn_IN-br af-ca ar-ca as-ca ast-ca be-ca bg-ca bn-ca bn_IN-ca br-ca af-crh ar-crh as-crh ast-crh be-crh bg-crh bn-crh bn_IN-crh br-crh ca-crh af-cs ar-cs as-cs ast-cs be-cs bg-cs bn-cs bn_IN-cs br-cs ca-cs crh-cs af-csb ar-csb as-csb ast-csb be-csb bg-csb bn-csb bn_IN-csb br-csb ca-csb crh-csb cs-csb af-cy ar-cy as-cy ast-cy be-cy bg-cy bn-cy bn_IN-cy br-cy ca-cy crh-cy cs-cy csb-cy af-da ar-da as-da ast-da be-da bg-da bn-da bn_IN-da br-da ca-da crh-da cs-da csb-da cy-da af-de ar-de as-de ast-de be-de bg-de bn-de bn_IN-de br-de ca-de crh-de cs-de csb-de cy-de da-de af-el ar-el as-el ast-el be-el bg-el bn-el bn_IN-el br-el ca-el crh-el cs-el csb-el cy-el da-el de-el af-en ar-en as-en ast-en be-en bg-en bn-en bn_IN-en br-en ca-en crh-en cs-en csb-en cy-en da-en de-en el-en af-en_GB ar-en_GB as-en_GB ast-en_GB be-en_GB bg-en_GB bn-en_GB bn_IN-en_GB br-en_GB ca-en_GB crh-en_GB cs-en_GB csb-en_GB cy-en_GB da-en_GB de-en_GB el-en_GB en-en_GB af-eo ar-eo as-eo ast-eo be-eo bg-eo bn-eo bn_IN-eo br-eo ca-eo crh-eo cs-eo csb-eo cy-eo da-eo de-eo el-eo en-eo en_GB-eo af-es ar-es as-es ast-es be-es bg-es bn-es bn_IN-es br-es ca-es crh-es cs-es csb-es cy-es da-es de-es el-es en-es en_GB-es eo-es af-et ar-et as-et ast-et be-et bg-et bn-et bn_IN-et br-et ca-et crh-et cs-et csb-et cy-et da-et de-et el-et en-et en_GB-et eo-et es-et af-eu ar-eu as-eu ast-eu be-eu bg-eu bn-eu bn_IN-eu br-eu ca-eu crh-eu cs-eu csb-eu cy-eu da-eu de-eu el-eu en-eu en_GB-eu eo-eu es-eu et-eu af-fa ar-fa as-fa ast-fa be-fa bg-fa bn-fa bn_IN-fa br-fa ca-fa crh-fa cs-fa csb-fa cy-fa da-fa de-fa el-fa en-fa en_GB-fa eo-fa es-fa et-fa eu-fa af-fi ar-fi as-fi ast-fi be-fi bg-fi bn-fi bn_IN-fi br-fi ca-fi crh-fi cs-fi csb-fi cy-fi da-fi de-fi el-fi en-fi en_GB-fi eo-fi es-fi et-fi eu-fi fa-fi af-fr ar-fr as-fr ast-fr be-fr bg-fr bn-fr bn_IN-fr br-fr ca-fr crh-fr cs-fr csb-fr cy-fr da-fr de-fr el-fr en-fr en_GB-fr eo-fr es-fr et-fr eu-fr fa-fr fi-fr af-fy ar-fy as-fy ast-fy be-fy bg-fy bn-fy bn_IN-fy br-fy ca-fy crh-fy cs-fy csb-fy cy-fy da-fy de-fy el-fy en-fy en_GB-fy eo-fy es-fy et-fy eu-fy fa-fy fi-fy fr-fy af-ga ar-ga as-ga ast-ga be-ga bg-ga bn-ga bn_IN-ga br-ga ca-ga crh-ga cs-ga csb-ga cy-ga da-ga de-ga el-ga en-ga en_GB-ga eo-ga es-ga et-ga eu-ga fa-ga fi-ga fr-ga fy-ga af-gl ar-gl as-gl ast-gl be-gl bg-gl bn-gl bn_IN-gl br-gl ca-gl crh-gl cs-gl csb-gl cy-gl da-gl de-gl el-gl en-gl en_GB-gl eo-gl es-gl et-gl eu-gl fa-gl fi-gl fr-gl fy-gl ga-gl af-gu ar-gu as-gu ast-gu be-gu bg-gu bn-gu bn_IN-gu br-gu ca-gu crh-gu cs-gu csb-gu cy-gu da-gu de-gu el-gu en-gu en_GB-gu eo-gu es-gu et-gu eu-gu fa-gu fi-gu fr-gu fy-gu ga-gu gl-gu af-ha ar-ha as-ha ast-ha be-ha bg-ha bn-ha bn_IN-ha br-ha ca-ha crh-ha cs-ha csb-ha cy-ha da-ha de-ha el-ha en-ha en_GB-ha eo-ha es-ha et-ha eu-ha fa-ha fi-ha fr-ha fy-ha ga-ha gl-ha gu-ha af-he ar-he as-he ast-he be-he bg-he bn-he bn_IN-he br-he ca-he crh-he cs-he csb-he cy-he da-he de-he el-he en-he en_GB-he eo-he es-he et-he eu-he fa-he fi-he fr-he fy-he ga-he gl-he gu-he ha-he af-hi ar-hi as-hi ast-hi be-hi bg-hi bn-hi bn_IN-hi br-hi ca-hi crh-hi cs-hi csb-hi cy-hi da-hi de-hi el-hi en-hi en_GB-hi eo-hi es-hi et-hi eu-hi fa-hi fi-hi fr-hi fy-hi ga-hi gl-hi gu-hi ha-hi he-hi af-hne ar-hne as-hne ast-hne be-hne bg-hne bn-hne bn_IN-hne br-hne ca-hne crh-hne cs-hne csb-hne cy-hne da-hne de-hne el-hne en-hne en_GB-hne eo-hne es-hne et-hne eu-hne fa-hne fi-hne fr-hne fy-hne ga-hne gl-hne gu-hne ha-hne he-hne hi-hne af-hr ar-hr as-hr ast-hr be-hr bg-hr bn-hr bn_IN-hr br-hr ca-hr crh-hr cs-hr csb-hr cy-hr da-hr de-hr el-hr en-hr en_GB-hr eo-hr es-hr et-hr eu-hr fa-hr fi-hr fr-hr fy-hr ga-hr gl-hr gu-hr ha-hr he-hr hi-hr hne-hr af-hsb ar-hsb as-hsb ast-hsb be-hsb bg-hsb bn-hsb bn_IN-hsb br-hsb ca-hsb crh-hsb cs-hsb csb-hsb cy-hsb da-hsb de-hsb el-hsb en-hsb en_GB-hsb eo-hsb es-hsb et-hsb eu-hsb fa-hsb fi-hsb fr-hsb fy-hsb ga-hsb gl-hsb gu-hsb ha-hsb he-hsb hi-hsb hne-hsb hr-hsb af-hu ar-hu as-hu ast-hu be-hu bg-hu bn-hu bn_IN-hu br-hu ca-hu crh-hu cs-hu csb-hu cy-hu da-hu de-hu el-hu en-hu en_GB-hu eo-hu es-hu et-hu eu-hu fa-hu fi-hu fr-hu fy-hu ga-hu gl-hu gu-hu ha-hu he-hu hi-hu hne-hu hr-hu hsb-hu af-hy ar-hy as-hy ast-hy be-hy bg-hy bn-hy bn_IN-hy br-hy ca-hy crh-hy cs-hy csb-hy cy-hy da-hy de-hy el-hy en-hy en_GB-hy eo-hy es-hy et-hy eu-hy fa-hy fi-hy fr-hy fy-hy ga-hy gl-hy gu-hy ha-hy he-hy hi-hy hne-hy hr-hy hsb-hy hu-hy af-id ar-id as-id ast-id be-id bg-id bn-id bn_IN-id br-id ca-id crh-id cs-id csb-id cy-id da-id de-id el-id en-id en_GB-id eo-id es-id et-id eu-id fa-id fi-id fr-id fy-id ga-id gl-id gu-id ha-id he-id hi-id hne-id hr-id hsb-id hu-id hy-id af-is ar-is as-is ast-is be-is bg-is bn-is bn_IN-is br-is ca-is crh-is cs-is csb-is cy-is da-is de-is el-is en-is en_GB-is eo-is es-is et-is eu-is fa-is fi-is fr-is fy-is ga-is gl-is gu-is ha-is he-is hi-is hne-is hr-is hsb-is hu-is hy-is id-is af-it ar-it as-it ast-it be-it bg-it bn-it bn_IN-it br-it ca-it crh-it cs-it csb-it cy-it da-it de-it el-it en-it en_GB-it eo-it es-it et-it eu-it fa-it fi-it fr-it fy-it ga-it gl-it gu-it ha-it he-it hi-it hne-it hr-it hsb-it hu-it hy-it id-it is-it af-ja ar-ja as-ja ast-ja be-ja bg-ja bn-ja bn_IN-ja br-ja ca-ja crh-ja cs-ja csb-ja cy-ja da-ja de-ja el-ja en-ja en_GB-ja eo-ja es-ja et-ja eu-ja fa-ja fi-ja fr-ja fy-ja ga-ja gl-ja gu-ja ha-ja he-ja hi-ja hne-ja hr-ja hsb-ja hu-ja hy-ja id-ja is-ja it-ja af-ka ar-ka as-ka ast-ka be-ka bg-ka bn-ka bn_IN-ka br-ka ca-ka crh-ka cs-ka csb-ka cy-ka da-ka de-ka el-ka en-ka en_GB-ka eo-ka es-ka et-ka eu-ka fa-ka fi-ka fr-ka fy-ka ga-ka gl-ka gu-ka ha-ka he-ka hi-ka hne-ka hr-ka hsb-ka hu-ka hy-ka id-ka is-ka it-ka ja-ka af-kk ar-kk as-kk ast-kk be-kk bg-kk bn-kk bn_IN-kk br-kk ca-kk crh-kk cs-kk csb-kk cy-kk da-kk de-kk el-kk en-kk en_GB-kk eo-kk es-kk et-kk eu-kk fa-kk fi-kk fr-kk fy-kk ga-kk gl-kk gu-kk ha-kk he-kk hi-kk hne-kk hr-kk hsb-kk hu-kk hy-kk id-kk is-kk it-kk ja-kk ka-kk af-km ar-km as-km ast-km be-km bg-km bn-km bn_IN-km br-km ca-km crh-km cs-km csb-km cy-km da-km de-km el-km en-km en_GB-km eo-km es-km et-km eu-km fa-km fi-km fr-km fy-km ga-km gl-km gu-km ha-km he-km hi-km hne-km hr-km hsb-km hu-km hy-km id-km is-km it-km ja-km ka-km kk-km af-kn ar-kn as-kn ast-kn be-kn bg-kn bn-kn bn_IN-kn br-kn ca-kn crh-kn cs-kn csb-kn cy-kn da-kn de-kn el-kn en-kn en_GB-kn eo-kn es-kn et-kn eu-kn fa-kn fi-kn fr-kn fy-kn ga-kn gl-kn gu-kn ha-kn he-kn hi-kn hne-kn hr-kn hsb-kn hu-kn hy-kn id-kn is-kn it-kn ja-kn ka-kn kk-kn km-kn af-ko ar-ko as-ko ast-ko be-ko bg-ko bn-ko bn_IN-ko br-ko ca-ko crh-ko cs-ko csb-ko cy-ko da-ko de-ko el-ko en-ko en_GB-ko eo-ko es-ko et-ko eu-ko fa-ko fi-ko fr-ko fy-ko ga-ko gl-ko gu-ko ha-ko he-ko hi-ko hne-ko hr-ko hsb-ko hu-ko hy-ko id-ko is-ko it-ko ja-ko ka-ko kk-ko km-ko kn-ko af-ku ar-ku as-ku ast-ku be-ku bg-ku bn-ku bn_IN-ku br-ku ca-ku crh-ku cs-ku csb-ku cy-ku da-ku de-ku el-ku en-ku en_GB-ku eo-ku es-ku et-ku eu-ku fa-ku fi-ku fr-ku fy-ku ga-ku gl-ku gu-ku ha-ku he-ku hi-ku hne-ku hr-ku hsb-ku hu-ku hy-ku id-ku is-ku it-ku ja-ku ka-ku kk-ku km-ku kn-ku ko-ku af-lb ar-lb as-lb ast-lb be-lb bg-lb bn-lb bn_IN-lb br-lb ca-lb crh-lb cs-lb csb-lb cy-lb da-lb de-lb el-lb en-lb en_GB-lb eo-lb es-lb et-lb eu-lb fa-lb fi-lb fr-lb fy-lb ga-lb gl-lb gu-lb ha-lb he-lb hi-lb hne-lb hr-lb hsb-lb hu-lb hy-lb id-lb is-lb it-lb ja-lb ka-lb kk-lb km-lb kn-lb ko-lb ku-lb af-lt ar-lt as-lt ast-lt be-lt bg-lt bn-lt bn_IN-lt br-lt ca-lt crh-lt cs-lt csb-lt cy-lt da-lt de-lt el-lt en-lt en_GB-lt eo-lt es-lt et-lt eu-lt fa-lt fi-lt fr-lt fy-lt ga-lt gl-lt gu-lt ha-lt he-lt hi-lt hne-lt hr-lt hsb-lt hu-lt hy-lt id-lt is-lt it-lt ja-lt ka-lt kk-lt km-lt kn-lt ko-lt ku-lt lb-lt af-lv ar-lv as-lv ast-lv be-lv bg-lv bn-lv bn_IN-lv br-lv ca-lv crh-lv cs-lv csb-lv cy-lv da-lv de-lv el-lv en-lv en_GB-lv eo-lv es-lv et-lv eu-lv fa-lv fi-lv fr-lv fy-lv ga-lv gl-lv gu-lv ha-lv he-lv hi-lv hne-lv hr-lv hsb-lv hu-lv hy-lv id-lv is-lv it-lv ja-lv ka-lv kk-lv km-lv kn-lv ko-lv ku-lv lb-lv lt-lv af-mai ar-mai as-mai ast-mai be-mai bg-mai bn-mai bn_IN-mai br-mai ca-mai crh-mai cs-mai csb-mai cy-mai da-mai de-mai el-mai en-mai en_GB-mai eo-mai es-mai et-mai eu-mai fa-mai fi-mai fr-mai fy-mai ga-mai gl-mai gu-mai ha-mai he-mai hi-mai hne-mai hr-mai hsb-mai hu-mai hy-mai id-mai is-mai it-mai ja-mai ka-mai kk-mai km-mai kn-mai ko-mai ku-mai lb-mai lt-mai lv-mai af-mk ar-mk as-mk ast-mk be-mk bg-mk bn-mk bn_IN-mk br-mk ca-mk crh-mk cs-mk csb-mk cy-mk da-mk de-mk el-mk en-mk en_GB-mk eo-mk es-mk et-mk eu-mk fa-mk fi-mk fr-mk fy-mk ga-mk gl-mk gu-mk ha-mk he-mk hi-mk hne-mk hr-mk hsb-mk hu-mk hy-mk id-mk is-mk it-mk ja-mk ka-mk kk-mk km-mk kn-mk ko-mk ku-mk lb-mk lt-mk lv-mk mai-mk af-ml ar-ml as-ml ast-ml be-ml bg-ml bn-ml bn_IN-ml br-ml ca-ml crh-ml cs-ml csb-ml cy-ml da-ml de-ml el-ml en-ml en_GB-ml eo-ml es-ml et-ml eu-ml fa-ml fi-ml fr-ml fy-ml ga-ml gl-ml gu-ml ha-ml he-ml hi-ml hne-ml hr-ml hsb-ml hu-ml hy-ml id-ml is-ml it-ml ja-ml ka-ml kk-ml km-ml kn-ml ko-ml ku-ml lb-ml lt-ml lv-ml mai-ml mk-ml af-mr ar-mr as-mr ast-mr be-mr bg-mr bn-mr bn_IN-mr br-mr ca-mr crh-mr cs-mr csb-mr cy-mr da-mr de-mr el-mr en-mr en_GB-mr eo-mr es-mr et-mr eu-mr fa-mr fi-mr fr-mr fy-mr ga-mr gl-mr gu-mr ha-mr he-mr hi-mr hne-mr hr-mr hsb-mr hu-mr hy-mr id-mr is-mr it-mr ja-mr ka-mr kk-mr km-mr kn-mr ko-mr ku-mr lb-mr lt-mr lv-mr mai-mr mk-mr ml-mr af-ms ar-ms as-ms ast-ms be-ms bg-ms bn-ms bn_IN-ms br-ms ca-ms crh-ms cs-ms csb-ms cy-ms da-ms de-ms el-ms en-ms en_GB-ms eo-ms es-ms et-ms eu-ms fa-ms fi-ms fr-ms fy-ms ga-ms gl-ms gu-ms ha-ms he-ms hi-ms hne-ms hr-ms hsb-ms hu-ms hy-ms id-ms is-ms it-ms ja-ms ka-ms kk-ms km-ms kn-ms ko-ms ku-ms lb-ms lt-ms lv-ms mai-ms mk-ms ml-ms mr-ms ar-mt ast-mt be-mt bg-mt br-mt ca-mt cs-mt cy-mt da-mt de-mt el-mt en-mt en_GB-mt eo-mt es-mt et-mt eu-mt fi-mt fr-mt ga-mt gl-mt he-mt hi-mt hne-mt hr-mt hu-mt is-mt it-mt ja-mt ka-mt km-mt ko-mt lt-mt ms-mt af-nb ar-nb as-nb ast-nb be-nb bg-nb bn-nb bn_IN-nb br-nb ca-nb crh-nb cs-nb csb-nb cy-nb da-nb de-nb el-nb en-nb en_GB-nb eo-nb es-nb et-nb eu-nb fa-nb fi-nb fr-nb fy-nb ga-nb gl-nb gu-nb ha-nb he-nb hi-nb hne-nb hr-nb hsb-nb hu-nb hy-nb id-nb is-nb it-nb ja-nb ka-nb kk-nb km-nb kn-nb ko-nb ku-nb lb-nb lt-nb lv-nb mai-nb mk-nb ml-nb mr-nb ms-nb mt-nb af-nds ar-nds as-nds ast-nds be-nds bg-nds bn-nds bn_IN-nds br-nds ca-nds crh-nds cs-nds csb-nds cy-nds da-nds de-nds el-nds en-nds en_GB-nds eo-nds es-nds et-nds eu-nds fa-nds fi-nds fr-nds fy-nds ga-nds gl-nds gu-nds ha-nds he-nds hi-nds hne-nds hr-nds hsb-nds hu-nds hy-nds id-nds is-nds it-nds ja-nds ka-nds kk-nds km-nds kn-nds ko-nds ku-nds lb-nds lt-nds lv-nds mai-nds mk-nds ml-nds mr-nds ms-nds mt-nds nb-nds af-ne ar-ne as-ne ast-ne be-ne bg-ne bn-ne bn_IN-ne br-ne ca-ne crh-ne cs-ne csb-ne cy-ne da-ne de-ne el-ne en-ne en_GB-ne eo-ne es-ne et-ne eu-ne fa-ne fi-ne fr-ne fy-ne ga-ne gl-ne gu-ne ha-ne he-ne hi-ne hne-ne hr-ne hsb-ne hu-ne hy-ne id-ne is-ne it-ne ja-ne ka-ne kk-ne km-ne kn-ne ko-ne ku-ne lb-ne lt-ne lv-ne mai-ne mk-ne ml-ne mr-ne ms-ne nb-ne nds-ne af-nl ar-nl as-nl ast-nl be-nl bg-nl bn-nl bn_IN-nl br-nl ca-nl crh-nl cs-nl csb-nl cy-nl da-nl de-nl el-nl en-nl en_GB-nl eo-nl es-nl et-nl eu-nl fa-nl fi-nl fr-nl fy-nl ga-nl gl-nl gu-nl ha-nl he-nl hi-nl hne-nl hr-nl hsb-nl hu-nl hy-nl id-nl is-nl it-nl ja-nl ka-nl kk-nl km-nl kn-nl ko-nl ku-nl lb-nl lt-nl lv-nl mai-nl mk-nl ml-nl mr-nl ms-nl mt-nl nb-nl nds-nl ne-nl af-nn ar-nn as-nn ast-nn be-nn bg-nn bn-nn bn_IN-nn br-nn ca-nn crh-nn cs-nn csb-nn cy-nn da-nn de-nn el-nn en-nn en_GB-nn eo-nn es-nn et-nn eu-nn fa-nn fi-nn fr-nn fy-nn ga-nn gl-nn gu-nn ha-nn he-nn hi-nn hne-nn hr-nn hsb-nn hu-nn hy-nn id-nn is-nn it-nn ja-nn ka-nn kk-nn km-nn kn-nn ko-nn ku-nn lb-nn lt-nn lv-nn mai-nn mk-nn ml-nn mr-nn ms-nn mt-nn nb-nn nds-nn ne-nn nl-nn ar-nso ast-nso be-nso bg-nso br-nso ca-nso cs-nso cy-nso da-nso de-nso el-nso en-nso en_GB-nso eo-nso es-nso et-nso eu-nso fi-nso fr-nso ga-nso gl-nso he-nso hi-nso hne-nso hr-nso hu-nso is-nso it-nso ja-nso ka-nso km-nso lt-nso ms-nso mt-nso nb-nso nds-nso nl-nso nn-nso af-oc ar-oc as-oc ast-oc be-oc bg-oc bn-oc bn_IN-oc br-oc ca-oc crh-oc cs-oc csb-oc cy-oc da-oc de-oc el-oc en-oc en_GB-oc eo-oc es-oc et-oc eu-oc fa-oc fi-oc fr-oc fy-oc ga-oc gl-oc gu-oc ha-oc he-oc hi-oc hne-oc hr-oc hsb-oc hu-oc hy-oc id-oc is-oc it-oc ja-oc ka-oc kk-oc km-oc kn-oc ko-oc ku-oc lb-oc lt-oc lv-oc mai-oc mk-oc ml-oc mr-oc ms-oc mt-oc nb-oc nds-oc ne-oc nl-oc nn-oc nso-oc af-or ar-or as-or ast-or be-or bg-or bn-or bn_IN-or br-or ca-or crh-or cs-or csb-or cy-or da-or de-or el-or en-or en_GB-or eo-or es-or et-or eu-or fa-or fi-or fr-or fy-or ga-or gl-or gu-or ha-or he-or hi-or hne-or hr-or hsb-or hu-or hy-or id-or is-or it-or ja-or ka-or kk-or km-or kn-or ko-or ku-or lb-or lt-or lv-or mai-or mk-or ml-or mr-or ms-or nb-or nds-or ne-or nl-or nn-or oc-or af-pa ar-pa as-pa ast-pa be-pa bg-pa bn-pa bn_IN-pa br-pa ca-pa crh-pa cs-pa csb-pa cy-pa da-pa de-pa el-pa en-pa en_GB-pa eo-pa es-pa et-pa eu-pa fa-pa fi-pa fr-pa fy-pa ga-pa gl-pa gu-pa ha-pa he-pa hi-pa hne-pa hr-pa hsb-pa hu-pa hy-pa id-pa is-pa it-pa ja-pa ka-pa kk-pa km-pa kn-pa ko-pa ku-pa lb-pa lt-pa lv-pa mai-pa mk-pa ml-pa mr-pa ms-pa mt-pa nb-pa nds-pa ne-pa nl-pa nn-pa nso-pa oc-pa or-pa af-pl ar-pl as-pl ast-pl be-pl bg-pl bn-pl bn_IN-pl br-pl ca-pl crh-pl cs-pl csb-pl cy-pl da-pl de-pl el-pl en-pl en_GB-pl eo-pl es-pl et-pl eu-pl fa-pl fi-pl fr-pl fy-pl ga-pl gl-pl gu-pl ha-pl he-pl hi-pl hne-pl hr-pl hsb-pl hu-pl hy-pl id-pl is-pl it-pl ja-pl ka-pl kk-pl km-pl kn-pl ko-pl ku-pl lb-pl lt-pl lv-pl mai-pl mk-pl ml-pl mr-pl ms-pl mt-pl nb-pl nds-pl ne-pl nl-pl nn-pl nso-pl oc-pl or-pl pa-pl af-ps ar-ps as-ps ast-ps be-ps bg-ps bn-ps bn_IN-ps br-ps ca-ps crh-ps cs-ps csb-ps cy-ps da-ps de-ps el-ps en-ps en_GB-ps eo-ps es-ps et-ps eu-ps fa-ps fi-ps fr-ps fy-ps ga-ps gl-ps gu-ps ha-ps he-ps hi-ps hne-ps hr-ps hsb-ps hu-ps hy-ps id-ps is-ps it-ps ja-ps ka-ps kk-ps km-ps kn-ps ko-ps ku-ps lb-ps lt-ps lv-ps mai-ps mk-ps ml-ps mr-ps ms-ps nb-ps nds-ps ne-ps nl-ps nn-ps oc-ps or-ps pa-ps pl-ps af-pt ar-pt as-pt ast-pt be-pt bg-pt bn-pt bn_IN-pt br-pt ca-pt crh-pt cs-pt csb-pt cy-pt da-pt de-pt el-pt en-pt en_GB-pt eo-pt es-pt et-pt eu-pt fa-pt fi-pt fr-pt fy-pt ga-pt gl-pt gu-pt ha-pt he-pt hi-pt hne-pt hr-pt hsb-pt hu-pt hy-pt id-pt is-pt it-pt ja-pt ka-pt kk-pt km-pt kn-pt ko-pt ku-pt lb-pt lt-pt lv-pt mai-pt mk-pt ml-pt mr-pt ms-pt mt-pt nb-pt nds-pt ne-pt nl-pt nn-pt nso-pt oc-pt or-pt pa-pt pl-pt ps-pt af-pt_BR ar-pt_BR as-pt_BR ast-pt_BR be-pt_BR bg-pt_BR bn-pt_BR bn_IN-pt_BR br-pt_BR ca-pt_BR crh-pt_BR cs-pt_BR csb-pt_BR cy-pt_BR da-pt_BR de-pt_BR el-pt_BR en-pt_BR en_GB-pt_BR eo-pt_BR es-pt_BR et-pt_BR eu-pt_BR fa-pt_BR fi-pt_BR fr-pt_BR fy-pt_BR ga-pt_BR gl-pt_BR gu-pt_BR ha-pt_BR he-pt_BR hi-pt_BR hne-pt_BR hr-pt_BR hsb-pt_BR hu-pt_BR hy-pt_BR id-pt_BR is-pt_BR it-pt_BR ja-pt_BR ka-pt_BR kk-pt_BR km-pt_BR kn-pt_BR ko-pt_BR ku-pt_BR lb-pt_BR lt-pt_BR lv-pt_BR mai-pt_BR mk-pt_BR ml-pt_BR mr-pt_BR ms-pt_BR mt-pt_BR nb-pt_BR nds-pt_BR ne-pt_BR nl-pt_BR nn-pt_BR nso-pt_BR oc-pt_BR or-pt_BR pa-pt_BR pl-pt_BR ps-pt_BR pt-pt_BR af-ro ar-ro as-ro ast-ro be-ro bg-ro bn-ro bn_IN-ro br-ro ca-ro crh-ro cs-ro csb-ro cy-ro da-ro de-ro el-ro en-ro en_GB-ro eo-ro es-ro et-ro eu-ro fa-ro fi-ro fr-ro fy-ro ga-ro gl-ro gu-ro ha-ro he-ro hi-ro hne-ro hr-ro hsb-ro hu-ro hy-ro id-ro is-ro it-ro ja-ro ka-ro kk-ro km-ro kn-ro ko-ro ku-ro lb-ro lt-ro lv-ro mai-ro mk-ro ml-ro mr-ro ms-ro mt-ro nb-ro nds-ro ne-ro nl-ro nn-ro nso-ro oc-ro or-ro pa-ro pl-ro ps-ro pt-ro pt_BR-ro af-ru ar-ru as-ru ast-ru be-ru bg-ru bn-ru bn_IN-ru br-ru ca-ru crh-ru cs-ru csb-ru cy-ru da-ru de-ru el-ru en-ru en_GB-ru eo-ru es-ru et-ru eu-ru fa-ru fi-ru fr-ru fy-ru ga-ru gl-ru gu-ru ha-ru he-ru hi-ru hne-ru hr-ru hsb-ru hu-ru hy-ru id-ru is-ru it-ru ja-ru ka-ru kk-ru km-ru kn-ru ko-ru ku-ru lb-ru lt-ru lv-ru mai-ru mk-ru ml-ru mr-ru ms-ru mt-ru nb-ru nds-ru ne-ru nl-ru nn-ru nso-ru oc-ru or-ru pa-ru pl-ru ps-ru pt-ru pt_BR-ru ro-ru ar-rw ast-rw be-rw bg-rw br-rw ca-rw cs-rw cy-rw da-rw de-rw el-rw en-rw en_GB-rw eo-rw es-rw et-rw eu-rw fi-rw fr-rw ga-rw gl-rw he-rw hi-rw hne-rw hr-rw hu-rw is-rw it-rw ja-rw ka-rw km-rw ko-rw lt-rw lv-rw ml-rw ms-rw mt-rw nb-rw nds-rw nl-rw nn-rw nso-rw oc-rw pa-rw pl-rw pt-rw pt_BR-rw ro-rw ru-rw af-se ar-se as-se ast-se be-se bg-se bn-se bn_IN-se br-se ca-se crh-se cs-se csb-se cy-se da-se de-se el-se en-se en_GB-se eo-se es-se et-se eu-se fa-se fi-se fr-se fy-se ga-se gl-se gu-se ha-se he-se hi-se hne-se hr-se hsb-se hu-se hy-se id-se is-se it-se ja-se ka-se kk-se km-se kn-se ko-se ku-se lb-se lt-se lv-se mai-se mk-se ml-se mr-se ms-se mt-se nb-se nds-se ne-se nl-se nn-se nso-se oc-se or-se pa-se pl-se ps-se pt-se pt_BR-se ro-se ru-se rw-se af-si ar-si as-si ast-si be-si bg-si bn-si bn_IN-si br-si ca-si crh-si cs-si csb-si cy-si da-si de-si el-si en-si en_GB-si eo-si es-si et-si eu-si fa-si fi-si fr-si fy-si ga-si gl-si gu-si ha-si he-si hi-si hne-si hr-si hsb-si hu-si hy-si id-si is-si it-si ja-si ka-si kk-si km-si kn-si ko-si ku-si lb-si lt-si lv-si mai-si mk-si ml-si mr-si ms-si nb-si nds-si ne-si nl-si nn-si oc-si or-si pa-si pl-si ps-si pt-si pt_BR-si ro-si ru-si se-si af-sk ar-sk as-sk ast-sk be-sk bg-sk bn-sk bn_IN-sk br-sk ca-sk crh-sk cs-sk csb-sk cy-sk da-sk de-sk el-sk en-sk en_GB-sk eo-sk es-sk et-sk eu-sk fa-sk fi-sk fr-sk fy-sk ga-sk gl-sk gu-sk ha-sk he-sk hi-sk hne-sk hr-sk hsb-sk hu-sk hy-sk id-sk is-sk it-sk ja-sk ka-sk kk-sk km-sk kn-sk ko-sk ku-sk lb-sk lt-sk lv-sk mai-sk mk-sk ml-sk mr-sk ms-sk mt-sk nb-sk nds-sk ne-sk nl-sk nn-sk nso-sk oc-sk or-sk pa-sk pl-sk ps-sk pt-sk pt_BR-sk ro-sk ru-sk rw-sk se-sk si-sk af-sl ar-sl as-sl ast-sl be-sl bg-sl bn-sl bn_IN-sl br-sl ca-sl crh-sl cs-sl csb-sl cy-sl da-sl de-sl el-sl en-sl en_GB-sl eo-sl es-sl et-sl eu-sl fa-sl fi-sl fr-sl fy-sl ga-sl gl-sl gu-sl ha-sl he-sl hi-sl hne-sl hr-sl hsb-sl hu-sl hy-sl id-sl is-sl it-sl ja-sl ka-sl kk-sl km-sl kn-sl ko-sl ku-sl lb-sl lt-sl lv-sl mai-sl mk-sl ml-sl mr-sl ms-sl mt-sl nb-sl nds-sl ne-sl nl-sl nn-sl nso-sl oc-sl or-sl pa-sl pl-sl ps-sl pt-sl pt_BR-sl ro-sl ru-sl rw-sl se-sl si-sl sk-sl af-sr ar-sr as-sr ast-sr be-sr bg-sr bn-sr bn_IN-sr br-sr ca-sr crh-sr cs-sr csb-sr cy-sr da-sr de-sr el-sr en-sr en_GB-sr eo-sr es-sr et-sr eu-sr fa-sr fi-sr fr-sr fy-sr ga-sr gl-sr gu-sr ha-sr he-sr hi-sr hne-sr hr-sr hsb-sr hu-sr hy-sr id-sr is-sr it-sr ja-sr ka-sr kk-sr km-sr kn-sr ko-sr ku-sr lb-sr lt-sr lv-sr mai-sr mk-sr ml-sr mr-sr ms-sr mt-sr nb-sr nds-sr ne-sr nl-sr nn-sr nso-sr oc-sr or-sr pa-sr pl-sr ps-sr pt-sr pt_BR-sr ro-sr ru-sr rw-sr se-sr si-sr sk-sr sl-sr af-sv ar-sv as-sv ast-sv be-sv bg-sv bn-sv bn_IN-sv br-sv ca-sv crh-sv cs-sv csb-sv cy-sv da-sv de-sv el-sv en-sv en_GB-sv eo-sv es-sv et-sv eu-sv fa-sv fi-sv fr-sv fy-sv ga-sv gl-sv gu-sv ha-sv he-sv hi-sv hne-sv hr-sv hsb-sv hu-sv hy-sv id-sv is-sv it-sv ja-sv ka-sv kk-sv km-sv kn-sv ko-sv ku-sv lb-sv lt-sv lv-sv mai-sv mk-sv ml-sv mr-sv ms-sv mt-sv nb-sv nds-sv ne-sv nl-sv nn-sv nso-sv oc-sv or-sv pa-sv pl-sv ps-sv pt-sv pt_BR-sv ro-sv ru-sv rw-sv se-sv si-sv sk-sv sl-sv sr-sv af-ta ar-ta as-ta ast-ta be-ta bg-ta bn-ta bn_IN-ta br-ta ca-ta crh-ta cs-ta csb-ta cy-ta da-ta de-ta el-ta en-ta en_GB-ta eo-ta es-ta et-ta eu-ta fa-ta fi-ta fr-ta fy-ta ga-ta gl-ta gu-ta ha-ta he-ta hi-ta hne-ta hr-ta hsb-ta hu-ta hy-ta id-ta is-ta it-ta ja-ta ka-ta kk-ta km-ta kn-ta ko-ta ku-ta lb-ta lt-ta lv-ta mai-ta mk-ta ml-ta mr-ta ms-ta mt-ta nb-ta nds-ta ne-ta nl-ta nn-ta nso-ta oc-ta or-ta pa-ta pl-ta ps-ta pt-ta pt_BR-ta ro-ta ru-ta rw-ta se-ta si-ta sk-ta sl-ta sr-ta sv-ta af-te ar-te as-te ast-te be-te bg-te bn-te bn_IN-te br-te ca-te crh-te cs-te csb-te cy-te da-te de-te el-te en-te en_GB-te eo-te es-te et-te eu-te fa-te fi-te fr-te fy-te ga-te gl-te gu-te ha-te he-te hi-te hne-te hr-te hsb-te hu-te hy-te id-te is-te it-te ja-te ka-te kk-te km-te kn-te ko-te ku-te lb-te lt-te lv-te mai-te mk-te ml-te mr-te ms-te nb-te nds-te ne-te nl-te nn-te oc-te or-te pa-te pl-te ps-te pt-te pt_BR-te ro-te ru-te se-te si-te sk-te sl-te sr-te sv-te ta-te af-tg ar-tg as-tg ast-tg be-tg bg-tg bn-tg bn_IN-tg br-tg ca-tg crh-tg cs-tg csb-tg cy-tg da-tg de-tg el-tg en-tg en_GB-tg eo-tg es-tg et-tg eu-tg fa-tg fi-tg fr-tg fy-tg ga-tg gl-tg gu-tg ha-tg he-tg hi-tg hne-tg hr-tg hsb-tg hu-tg hy-tg id-tg is-tg it-tg ja-tg ka-tg kk-tg km-tg kn-tg ko-tg ku-tg lb-tg lt-tg lv-tg mai-tg mk-tg ml-tg mr-tg ms-tg mt-tg nb-tg nds-tg ne-tg nl-tg nn-tg nso-tg oc-tg or-tg pa-tg pl-tg ps-tg pt-tg pt_BR-tg ro-tg ru-tg rw-tg se-tg si-tg sk-tg sl-tg sr-tg sv-tg ta-tg te-tg af-th ar-th as-th ast-th be-th bg-th bn-th bn_IN-th br-th ca-th crh-th cs-th csb-th cy-th da-th de-th el-th en-th en_GB-th eo-th es-th et-th eu-th fa-th fi-th fr-th fy-th ga-th gl-th gu-th ha-th he-th hi-th hne-th hr-th hsb-th hu-th hy-th id-th is-th it-th ja-th ka-th kk-th km-th kn-th ko-th ku-th lb-th lt-th lv-th mai-th mk-th ml-th mr-th ms-th mt-th nb-th nds-th ne-th nl-th nn-th oc-th or-th pa-th pl-th ps-th pt-th pt_BR-th ro-th ru-th rw-th se-th si-th sk-th sl-th sr-th sv-th ta-th te-th tg-th af-tr ar-tr as-tr ast-tr be-tr bg-tr bn-tr bn_IN-tr br-tr ca-tr crh-tr cs-tr csb-tr cy-tr da-tr de-tr el-tr en-tr en_GB-tr eo-tr es-tr et-tr eu-tr fa-tr fi-tr fr-tr fy-tr ga-tr gl-tr gu-tr ha-tr he-tr hi-tr hne-tr hr-tr hsb-tr hu-tr hy-tr id-tr is-tr it-tr ja-tr ka-tr kk-tr km-tr kn-tr ko-tr ku-tr lb-tr lt-tr lv-tr mai-tr mk-tr ml-tr mr-tr ms-tr mt-tr nb-tr nds-tr ne-tr nl-tr nn-tr nso-tr oc-tr or-tr pa-tr pl-tr ps-tr pt-tr pt_BR-tr ro-tr ru-tr rw-tr se-tr si-tr sk-tr sl-tr sr-tr sv-tr ta-tr te-tr tg-tr th-tr af-uk ar-uk as-uk ast-uk be-uk bg-uk bn-uk bn_IN-uk br-uk ca-uk crh-uk cs-uk csb-uk cy-uk da-uk de-uk el-uk en-uk en_GB-uk eo-uk es-uk et-uk eu-uk fa-uk fi-uk fr-uk fy-uk ga-uk gl-uk gu-uk ha-uk he-uk hi-uk hne-uk hr-uk hsb-uk hu-uk hy-uk id-uk is-uk it-uk ja-uk ka-uk kk-uk km-uk kn-uk ko-uk ku-uk lb-uk lt-uk lv-uk mai-uk mk-uk ml-uk mr-uk ms-uk mt-uk nb-uk nds-uk ne-uk nl-uk nn-uk nso-uk oc-uk or-uk pa-uk pl-uk ps-uk pt-uk pt_BR-uk ro-uk ru-uk rw-uk se-uk si-uk sk-uk sl-uk sr-uk sv-uk ta-uk te-uk tg-uk th-uk tr-uk af-uz ar-uz as-uz ast-uz be-uz bg-uz bn-uz bn_IN-uz br-uz ca-uz crh-uz cs-uz csb-uz cy-uz da-uz de-uz el-uz en-uz en_GB-uz eo-uz es-uz et-uz eu-uz fa-uz fi-uz fr-uz fy-uz ga-uz gl-uz gu-uz ha-uz he-uz hi-uz hne-uz hr-uz hsb-uz hu-uz hy-uz id-uz is-uz it-uz ja-uz ka-uz kk-uz km-uz kn-uz ko-uz ku-uz lb-uz lt-uz lv-uz mai-uz mk-uz ml-uz mr-uz ms-uz mt-uz nb-uz nds-uz ne-uz nl-uz nn-uz nso-uz oc-uz or-uz pa-uz pl-uz ps-uz pt-uz pt_BR-uz ro-uz ru-uz rw-uz se-uz si-uz sk-uz sl-uz sr-uz sv-uz ta-uz te-uz tg-uz th-uz tr-uz uk-uz af-vi ar-vi as-vi ast-vi be-vi bg-vi bn-vi bn_IN-vi br-vi ca-vi crh-vi cs-vi csb-vi cy-vi da-vi de-vi el-vi en-vi en_GB-vi eo-vi es-vi et-vi eu-vi fa-vi fi-vi fr-vi fy-vi ga-vi gl-vi gu-vi ha-vi he-vi hi-vi hne-vi hr-vi hsb-vi hu-vi hy-vi id-vi is-vi it-vi ja-vi ka-vi kk-vi km-vi kn-vi ko-vi ku-vi lb-vi lt-vi lv-vi mai-vi mk-vi ml-vi mr-vi ms-vi nb-vi nds-vi ne-vi nl-vi nn-vi oc-vi or-vi pa-vi pl-vi ps-vi pt-vi pt_BR-vi ro-vi ru-vi se-vi si-vi sk-vi sl-vi sr-vi sv-vi ta-vi te-vi tg-vi th-vi tr-vi uk-vi uz-vi af-wa ar-wa as-wa ast-wa be-wa bg-wa bn-wa bn_IN-wa br-wa ca-wa crh-wa cs-wa csb-wa cy-wa da-wa de-wa el-wa en-wa en_GB-wa eo-wa es-wa et-wa eu-wa fa-wa fi-wa fr-wa fy-wa ga-wa gl-wa gu-wa ha-wa he-wa hi-wa hne-wa hr-wa hsb-wa hu-wa hy-wa id-wa is-wa it-wa ja-wa ka-wa kk-wa km-wa kn-wa ko-wa ku-wa lb-wa lt-wa lv-wa mai-wa mk-wa ml-wa mr-wa ms-wa mt-wa nb-wa nds-wa ne-wa nl-wa nn-wa nso-wa oc-wa or-wa pa-wa pl-wa ps-wa pt-wa pt_BR-wa ro-wa ru-wa rw-wa se-wa si-wa sk-wa sl-wa sr-wa sv-wa ta-wa te-wa tg-wa th-wa tr-wa uk-wa uz-wa vi-wa af-xh ar-xh as-xh ast-xh be-xh bg-xh bn-xh bn_IN-xh br-xh ca-xh crh-xh cs-xh csb-xh cy-xh da-xh de-xh el-xh en-xh en_GB-xh eo-xh es-xh et-xh eu-xh fa-xh fi-xh fr-xh fy-xh ga-xh gl-xh gu-xh ha-xh he-xh hi-xh hne-xh hr-xh hsb-xh hu-xh hy-xh id-xh is-xh it-xh ja-xh ka-xh kk-xh km-xh kn-xh ko-xh ku-xh lb-xh lt-xh lv-xh mai-xh mk-xh ml-xh mr-xh ms-xh mt-xh nb-xh nds-xh ne-xh nl-xh nn-xh nso-xh oc-xh or-xh pa-xh pl-xh ps-xh pt-xh pt_BR-xh ro-xh ru-xh rw-xh se-xh si-xh sk-xh sl-xh sr-xh sv-xh ta-xh te-xh tg-xh th-xh tr-xh uk-xh uz-xh vi-xh wa-xh af-zh_CN ar-zh_CN as-zh_CN ast-zh_CN be-zh_CN bg-zh_CN bn-zh_CN bn_IN-zh_CN br-zh_CN ca-zh_CN crh-zh_CN cs-zh_CN csb-zh_CN cy-zh_CN da-zh_CN de-zh_CN el-zh_CN en-zh_CN en_GB-zh_CN eo-zh_CN es-zh_CN et-zh_CN eu-zh_CN fa-zh_CN fi-zh_CN fr-zh_CN fy-zh_CN ga-zh_CN gl-zh_CN gu-zh_CN ha-zh_CN he-zh_CN hi-zh_CN hne-zh_CN hr-zh_CN hsb-zh_CN hu-zh_CN hy-zh_CN id-zh_CN is-zh_CN it-zh_CN ja-zh_CN ka-zh_CN kk-zh_CN km-zh_CN kn-zh_CN ko-zh_CN ku-zh_CN lb-zh_CN lt-zh_CN lv-zh_CN mai-zh_CN mk-zh_CN ml-zh_CN mr-zh_CN ms-zh_CN mt-zh_CN nb-zh_CN nds-zh_CN ne-zh_CN nl-zh_CN nn-zh_CN nso-zh_CN oc-zh_CN or-zh_CN pa-zh_CN pl-zh_CN ps-zh_CN pt-zh_CN pt_BR-zh_CN ro-zh_CN ru-zh_CN rw-zh_CN se-zh_CN si-zh_CN sk-zh_CN sl-zh_CN sr-zh_CN sv-zh_CN ta-zh_CN te-zh_CN tg-zh_CN th-zh_CN tr-zh_CN uk-zh_CN uz-zh_CN vi-zh_CN wa-zh_CN xh-zh_CN af-zh_HK ar-zh_HK as-zh_HK ast-zh_HK be-zh_HK bg-zh_HK bn-zh_HK bn_IN-zh_HK br-zh_HK ca-zh_HK crh-zh_HK cs-zh_HK csb-zh_HK cy-zh_HK da-zh_HK de-zh_HK el-zh_HK en-zh_HK en_GB-zh_HK eo-zh_HK es-zh_HK et-zh_HK eu-zh_HK fa-zh_HK fi-zh_HK fr-zh_HK fy-zh_HK ga-zh_HK gl-zh_HK gu-zh_HK ha-zh_HK he-zh_HK hi-zh_HK hne-zh_HK hr-zh_HK hsb-zh_HK hu-zh_HK hy-zh_HK id-zh_HK is-zh_HK it-zh_HK ja-zh_HK ka-zh_HK kk-zh_HK km-zh_HK kn-zh_HK ko-zh_HK ku-zh_HK lb-zh_HK lt-zh_HK lv-zh_HK mai-zh_HK mk-zh_HK ml-zh_HK mr-zh_HK ms-zh_HK nb-zh_HK nds-zh_HK ne-zh_HK nl-zh_HK nn-zh_HK oc-zh_HK or-zh_HK pa-zh_HK pl-zh_HK ps-zh_HK pt-zh_HK pt_BR-zh_HK ro-zh_HK ru-zh_HK se-zh_HK si-zh_HK sk-zh_HK sl-zh_HK sr-zh_HK sv-zh_HK ta-zh_HK te-zh_HK tg-zh_HK th-zh_HK tr-zh_HK uk-zh_HK uz-zh_HK vi-zh_HK wa-zh_HK xh-zh_HK zh_CN-zh_HK af-zh_TW ar-zh_TW as-zh_TW ast-zh_TW be-zh_TW bg-zh_TW bn-zh_TW bn_IN-zh_TW br-zh_TW ca-zh_TW crh-zh_TW cs-zh_TW csb-zh_TW cy-zh_TW da-zh_TW de-zh_TW el-zh_TW en-zh_TW en_GB-zh_TW eo-zh_TW es-zh_TW et-zh_TW eu-zh_TW fa-zh_TW fi-zh_TW fr-zh_TW fy-zh_TW ga-zh_TW gl-zh_TW gu-zh_TW ha-zh_TW he-zh_TW hi-zh_TW hne-zh_TW hr-zh_TW hsb-zh_TW hu-zh_TW hy-zh_TW id-zh_TW is-zh_TW it-zh_TW ja-zh_TW ka-zh_TW kk-zh_TW km-zh_TW kn-zh_TW ko-zh_TW ku-zh_TW lb-zh_TW lt-zh_TW lv-zh_TW mai-zh_TW mk-zh_TW ml-zh_TW mr-zh_TW ms-zh_TW mt-zh_TW nb-zh_TW nds-zh_TW ne-zh_TW nl-zh_TW nn-zh_TW nso-zh_TW oc-zh_TW or-zh_TW pa-zh_TW pl-zh_TW ps-zh_TW pt-zh_TW pt_BR-zh_TW ro-zh_TW ru-zh_TW rw-zh_TW se-zh_TW si-zh_TW sk-zh_TW sl-zh_TW sr-zh_TW sv-zh_TW ta-zh_TW te-zh_TW tg-zh_TW th-zh_TW tr-zh_TW uk-zh_TW uz-zh_TW vi-zh_TW wa-zh_TW xh-zh_TW zh_CN-zh_TW zh_HK-zh_TW
JRC-Acquis	JRC-Acquis/%s-%s.txt.zip	bg-cs bg-da cs-da bg-de cs-de da-de bg-el cs-el da-el de-el bg-en cs-en da-en de-en el-en bg-es cs-es da-es de-es el-es en-es bg-et cs-et da-et de-et el-et en-et es-et bg-fi cs-fi da-fi de-fi el-fi en-fi es-fi et-fi bg-fr cs-fr da-fr de-fr el-fr en-fr es-fr et-fr fi-fr bg-hu cs-hu da-hu de-hu el-hu en-hu es-hu et-hu fi-hu fr-hu bg-it cs-it da-it de-it el-it en-it es-it et-it fi-it fr-it hu-it bg-lt cs-lt da-lt de-lt el-lt en-lt es-lt et-lt fi-lt fr-lt hu-lt it-lt bg-lv cs-lv da-lv de-lv el-lv en-lv es-lv et-lv fi-lv fr-lv hu-lv it-lv lt-lv bg-mt cs-mt da-mt de-mt el-mt en-mt es-mt et-mt fi-mt fr-mt hu-mt it-mt lt-mt lv-mt bg-nl cs-nl da-nl de-nl el-nl en-nl es-nl et-nl fi-nl fr-nl hu-nl it-nl lt-nl lv-nl mt-nl bg-pl cs-pl da-pl de-pl el-pl en-pl es-pl et-pl fi-pl fr-pl hu-pl it-pl lt-pl lv-pl mt-pl nl-pl bg-pt cs-pt da-pt de-pt el-pt en-pt es-pt et-pt fi-pt fr-pt hu-pt it-pt lt-pt lv-pt mt-pt nl-pt pl-pt bg-ro cs-ro da-ro de-ro el-ro en-ro es-ro et-ro fi-ro fr-ro hu-ro it-ro lt-ro lv-ro mt-ro nl-ro pl-ro pt-ro bg-sk cs-sk da-sk de-sk el-sk en-sk es-sk et-sk fi-sk fr-sk hu-sk it-sk lt-sk lv-sk mt-sk nl-sk pl-sk pt-sk ro-sk bg-sl cs-sl da-sl de-sl el-sl en-sl es-sl et-sl fi-sl fr-sl hu-sl it-sl lt-sl lv-sl mt-sl nl-sl pl-sl pt-sl ro-sl sk-sl bg-sv cs-sv da-sv de-sv el-sv en-sv es-sv et-sv fi-sv fr-sv hu-sv it-sv lt-sv lv-sv mt-sv nl-sv pl-sv pt-sv ro-sv sk-sv sl-sv
infopankki_v1	infopankki/v1/moses/%s-%s.txt.zip	ar-en ar-es en-es ar-et en-et es-et ar-fa en-fa es-fa et-fa ar-fi en-fi es-fi et-fi fa-fi ar-fr en-fr es-fr et-fr fa-fr fi-fr ar-ru en-ru es-ru et-ru fa-ru fi-ru fr-ru ar-so en-so es-so et-so fa-so fi-so fr-so ru-so ar-sv en-sv es-sv et-sv fa-sv fi-sv fr-sv ru-sv so-sv ar-tr en-tr es-tr et-tr fa-tr fi-tr fr-tr ru-tr so-tr sv-tr ar-zh en-zh es-zh et-zh fa-zh fi-zh fr-zh ru-zh so-zh sv-zh tr-zh
hrenWaC_v1	hrenWaC/v1/moses/%s-%s.txt.zip	en-hr
GlobalVoices_v2017q3	GlobalVoices/v2017q3/moses/%s-%s.txt.zip	am-ar am-aym ar-aym ar-bg aym-bg am-bn ar-bn aym-bn bg-bn am-ca ar-ca aym-ca bg-ca bn-ca ar-cs aym-cs bg-cs bn-cs ca-cs am-da ar-da aym-da bg-da bn-da ca-da cs-da am-de ar-de aym-de bg-de bn-de ca-de cs-de da-de am-el ar-el aym-el bg-el bn-el ca-el cs-el da-el de-el am-en ar-en aym-en bg-en bn-en ca-en cs-en da-en de-en el-en ar-eo aym-eo bg-eo bn-eo ca-eo cs-eo da-eo de-eo el-eo en-eo am-es ar-es aym-es bg-es bn-es ca-es cs-es da-es de-es el-es en-es eo-es am-fa ar-fa aym-fa bg-fa bn-fa ca-fa cs-fa da-fa de-fa el-fa en-fa eo-fa es-fa ar-fil aym-fil bg-fil bn-fil ca-fil cs-fil da-fil de-fil el-fil en-fil eo-fil es-fil fa-fil am-fr ar-fr aym-fr bg-fr bn-fr ca-fr cs-fr da-fr de-fr el-fr en-fr eo-fr es-fr fa-fr fil-fr ar-he bn-he ca-he cs-he da-he de-he el-he en-he es-he fa-he fr-he am-hi ar-hi bg-hi bn-hi cs-hi de-hi el-hi en-hi eo-hi es-hi fa-hi fr-hi am-hu ar-hu aym-hu bg-hu bn-hu ca-hu cs-hu da-hu de-hu el-hu en-hu eo-hu es-hu fa-hu fil-hu fr-hu hi-hu am-id ar-id aym-id bg-id bn-id ca-id cs-id da-id de-id el-id en-id eo-id es-id fa-id fil-id fr-id hi-id hu-id am-it ar-it aym-it bg-it bn-it ca-it cs-it da-it de-it el-it en-it eo-it es-it fa-it fil-it fr-it he-it hi-it hu-it id-it am-jp ar-jp aym-jp bg-jp bn-jp ca-jp cs-jp da-jp de-jp el-jp en-jp eo-jp es-jp fa-jp fil-jp fr-jp he-jp hi-jp hu-jp id-jp it-jp ar-km aym-km bn-km ca-km da-km de-km el-km en-km es-km fa-km fil-km fr-km hu-km it-km jp-km am-ko ar-ko aym-ko bg-ko bn-ko ca-ko cs-ko da-ko de-ko el-ko en-ko eo-ko es-ko fa-ko fil-ko fr-ko hu-ko id-ko it-ko jp-ko am-mg ar-mg aym-mg bg-mg bn-mg ca-mg cs-mg da-mg de-mg el-mg en-mg eo-mg es-mg fa-mg fil-mg fr-mg he-mg hi-mg hu-mg id-mg it-mg jp-mg km-mg ko-mg am-mk ar-mk aym-mk bg-mk bn-mk ca-mk cs-mk da-mk de-mk el-mk en-mk eo-mk es-mk fa-mk fil-mk fr-mk he-mk hi-mk hu-mk id-mk it-mk jp-mk km-mk ko-mk mg-mk am-my ar-my aym-my bg-my bn-my ca-my cs-my da-my de-my el-my en-my es-my fa-my fil-my fr-my he-my hi-my hu-my id-my it-my jp-my ko-my mg-my mk-my am-nl ar-nl aym-nl bg-nl bn-nl ca-nl cs-nl da-nl de-nl el-nl en-nl eo-nl es-nl fa-nl fil-nl fr-nl he-nl hi-nl hu-nl id-nl it-nl jp-nl km-nl ko-nl mg-nl mk-nl my-nl ar-or aym-or bn-or ca-or cs-or de-or el-or en-or es-or fa-or fr-or hi-or it-or jp-or mg-or mk-or nl-or am-pl ar-pl aym-pl bg-pl bn-pl ca-pl cs-pl da-pl de-pl el-pl en-pl eo-pl es-pl fa-pl fil-pl fr-pl he-pl hi-pl hu-pl id-pl it-pl jp-pl ko-pl mg-pl mk-pl my-pl nl-pl or-pl am-pt ar-pt aym-pt bg-pt bn-pt ca-pt cs-pt da-pt de-pt el-pt en-pt eo-pt es-pt fa-pt fil-pt fr-pt he-pt hi-pt hu-pt id-pt it-pt jp-pt km-pt ko-pt mg-pt mk-pt my-pt nl-pt or-pt pl-pt ar-ro aym-ro bg-ro bn-ro ca-ro cs-ro de-ro el-ro en-ro es-ro fa-ro fr-ro hu-ro id-ro it-ro jp-ro ko-ro mg-ro mk-ro my-ro nl-ro pl-ro pt-ro am-ru ar-ru aym-ru bg-ru bn-ru ca-ru cs-ru da-ru de-ru el-ru en-ru eo-ru es-ru fa-ru fil-ru fr-ru he-ru hi-ru hu-ru id-ru it-ru jp-ru km-ru ko-ru mg-ru mk-ru my-ru nl-ru or-ru pl-ru pt-ru ro-ru ar-sq aym-sq bg-sq bn-sq ca-sq cs-sq da-sq de-sq el-sq en-sq eo-sq es-sq fa-sq fil-sq fr-sq hi-sq hu-sq id-sq it-sq jp-sq ko-sq mg-sq mk-sq my-sq nl-sq pl-sq pt-sq ru-sq am-sr ar-sr aym-sr bg-sr bn-sr ca-sr cs-sr da-sr de-sr el-sr en-sr eo-sr es-sr fa-sr fil-sr fr-sr hi-sr hu-sr id-sr it-sr jp-sr km-sr ko-sr mg-sr mk-sr my-sr nl-sr pl-sr pt-sr ro-sr ru-sr sq-sr ar-sv aym-sv bg-sv bn-sv ca-sv cs-sv da-sv de-sv el-sv en-sv eo-sv es-sv fa-sv fil-sv fr-sv he-sv hi-sv hu-sv id-sv it-sv jp-sv ko-sv mg-sv mk-sv my-sv nl-sv pl-sv pt-sv ro-sv ru-sv sq-sv sr-sv am-sw ar-sw aym-sw bg-sw bn-sw ca-sw cs-sw da-sw de-sw el-sw en-sw eo-sw es-sw fa-sw fil-sw fr-sw he-sw hi-sw hu-sw id-sw it-sw jp-sw km-sw ko-sw mg-sw mk-sw my-sw nl-sw pl-sw pt-sw ro-sw ru-sw sq-sw sr-sw sv-sw am-tr ar-tr aym-tr bg-tr bn-tr ca-tr cs-tr da-tr de-tr el-tr en-tr eo-tr es-tr fa-tr fil-tr fr-tr he-tr hi-tr hu-tr id-tr it-tr jp-tr ko-tr mg-tr mk-tr my-tr nl-tr pl-tr pt-tr ro-tr ru-tr sq-tr sr-tr sv-tr sw-tr am-ur ar-ur aym-ur bg-ur bn-ur ca-ur cs-ur da-ur de-ur el-ur en-ur eo-ur es-ur fa-ur fil-ur fr-ur he-ur hi-ur hu-ur id-ur it-ur jp-ur ko-ur mg-ur mk-ur my-ur nl-ur or-ur pl-ur pt-ur ro-ur ru-ur sq-ur sr-ur sv-ur sw-ur tr-ur am-zhs ar-zhs aym-zhs bg-zhs bn-zhs ca-zhs cs-zhs da-zhs de-zhs el-zhs en-zhs eo-zhs es-zhs fa-zhs fil-zhs fr-zhs he-zhs hi-zhs hu-zhs id-zhs it-zhs jp-zhs km-zhs ko-zhs mg-zhs mk-zhs my-zhs nl-zhs pl-zhs pt-zhs ro-zhs ru-zhs sq-zhs sr-zhs sv-zhs sw-zhs tr-zhs am-zht ar-zht aym-zht bg-zht bn-zht ca-zht cs-zht da-zht de-zht el-zht en-zht eo-zht es-zht fa-zht fil-zht fr-zht he-zht hi-zht hu-zht id-zht it-zht jp-zht km-zht ko-zht mg-zht mk-zht my-zht nl-zht pl-zht pt-zht ro-zht ru-zht sq-zht sr-zht sv-zht sw-zht tr-zht zhs-zht
GNOME_v1	GNOME/v1/moses/%s-%s.txt.zip	af-am af-an am-an af-ang am-ang an-ang af-ar am-ar an-ar ang-ar af-ar_TN am-ar_TN ar-ar_TN ar-ara af-as am-as an-as ang-as ar-as ara-as af-ast am-ast an-ast ang-ast ar-ast ar_TN-ast as-ast af-az am-az an-az ang-az ar-az ar_TN-az ara-az as-az ast-az af-az_IR am-az_IR an-az_IR ang-az_IR ar-az_IR as-az_IR ast-az_IR az-az_IR ar-bal as-bal ast-bal af-be am-be an-be ang-be ar-be as-be ast-be az-be az_IR-be bal-be af-bem an-bem ar-bem as-bem ast-bem be-bem af-bg am-bg an-bg ang-bg ar-bg ar_TN-bg ara-bg as-bg ast-bg az-bg az_IR-bg bal-bg be-bg bem-bg ar-bg_BG ara-bg_BG as-bg_BG az-bg_BG bg-bg_BG af-bn am-bn an-bn ang-bn ar-bn as-bn ast-bn az-bn az_IR-bn bal-bn be-bn bem-bn bg-bn af-bn_IN am-bn_IN an-bn_IN ang-bn_IN ar-bn_IN ara-bn_IN as-bn_IN ast-bn_IN az-bn_IN az_IR-bn_IN bal-bn_IN be-bn_IN bem-bn_IN bg-bn_IN bg_BG-bn_IN bn-bn_IN af-bo am-bo an-bo ar-bo as-bo ast-bo az-bo be-bo bg-bo bn-bo bn_IN-bo af-br am-br an-br ang-br ar-br ar_TN-br as-br ast-br az-br az_IR-br bal-br be-br bem-br bg-br bg_BG-br bn-br bn_IN-br bo-br af-brx an-brx ar-brx as-brx ast-brx be-brx bem-brx bg-brx bn-brx bn_IN-brx br-brx af-bs am-bs an-bs ang-bs ar-bs as-bs ast-bs az-bs az_IR-bs be-bs bg-bs bn-bs bn_IN-bs bo-bs br-bs af-ca am-ca an-ca ang-ca ar-ca ar_TN-ca ara-ca as-ca ast-ca az-ca az_IR-ca bal-ca be-ca bem-ca bg-ca bg_BG-ca bn-ca bn_IN-ca bo-ca br-ca brx-ca bs-ca ca-cat af-crh am-crh an-crh ang-crh ar-crh as-crh ast-crh az-crh az_IR-crh bal-crh be-crh bem-crh bg-crh bn-crh bn_IN-crh bo-crh br-crh brx-crh bs-crh ca-crh af-cs am-cs an-cs ang-cs ar-cs ar_TN-cs ara-cs as-cs ast-cs az-cs az_IR-cs bal-cs be-cs bem-cs bg-cs bg_BG-cs bn-cs bn_IN-cs bo-cs br-cs brx-cs bs-cs ca-cs cat-cs crh-cs af-csb am-csb an-csb ang-csb ar-csb as-csb ast-csb az-csb be-csb bg-csb bn-csb bn_IN-csb br-csb bs-csb ca-csb crh-csb cs-csb af-cy am-cy an-cy ang-cy ar-cy ara-cy as-cy ast-cy az-cy az_IR-cy bal-cy be-cy bem-cy bg-cy bg_BG-cy bn-cy bn_IN-cy bo-cy br-cy brx-cy bs-cy ca-cy crh-cy cs-cy csb-cy af-da am-da an-da ang-da ar-da ar_TN-da ara-da as-da ast-da az-da az_IR-da bal-da be-da bem-da bg-da bg_BG-da bn-da bn_IN-da bo-da br-da brx-da bs-da ca-da cat-da crh-da cs-da csb-da cy-da as-da_DK bg-da_DK bg_BG-da_DK bn_IN-da_DK ca-da_DK cs-da_DK da-da_DK af-de am-de an-de ang-de ar-de ar_TN-de ara-de as-de ast-de az-de az_IR-de bal-de be-de bem-de bg-de bg_BG-de bn-de bn_IN-de bo-de br-de brx-de bs-de ca-de cat-de crh-de cs-de csb-de cy-de da-de da_DK-de as-de_CH bn_IN-de_CH ca-de_CH cs-de_CH de-de_CH af-dv an-dv ar-dv as-dv ast-dv be-dv bg-dv bn-dv bn_IN-dv br-dv ca-dv crh-dv cs-dv csb-dv cy-dv da-dv de-dv af-dz am-dz an-dz ang-dz ar-dz ar_TN-dz as-dz ast-dz az-dz az_IR-dz bal-dz be-dz bem-dz bg-dz bn-dz bn_IN-dz bo-dz br-dz brx-dz bs-dz ca-dz crh-dz cs-dz csb-dz cy-dz da-dz de-dz dv-dz af-el am-el an-el ang-el ar-el ar_TN-el ara-el as-el ast-el az-el az_IR-el bal-el be-el bem-el bg-el bg_BG-el bn-el bn_IN-el bo-el br-el brx-el bs-el ca-el cat-el crh-el cs-el csb-el cy-el da-el da_DK-el de-el de_CH-el dv-el dz-el af-en am-en an-en ang-en ar-en ar_TN-en ara-en as-en ast-en az-en az_IR-en bal-en be-en bem-en bg-en bg_BG-en bn-en bn_IN-en bo-en br-en brx-en bs-en ca-en cat-en crh-en cs-en csb-en cy-en da-en da_DK-en de-en de_CH-en dv-en dz-en el-en af-en_AU am-en_AU an-en_AU ar-en_AU as-en_AU ast-en_AU az-en_AU be-en_AU bg-en_AU bn-en_AU bn_IN-en_AU br-en_AU bs-en_AU ca-en_AU cs-en_AU cy-en_AU da-en_AU de-en_AU dz-en_AU el-en_AU en-en_AU af-en_CA am-en_CA an-en_CA ang-en_CA ar-en_CA ar_TN-en_CA as-en_CA ast-en_CA az-en_CA az_IR-en_CA bal-en_CA be-en_CA bem-en_CA bg-en_CA bn-en_CA bn_IN-en_CA bo-en_CA br-en_CA brx-en_CA bs-en_CA ca-en_CA crh-en_CA cs-en_CA csb-en_CA cy-en_CA da-en_CA de-en_CA dv-en_CA dz-en_CA el-en_CA en-en_CA en_AU-en_CA af-en_GB am-en_GB an-en_GB ang-en_GB ar-en_GB ar_TN-en_GB ara-en_GB as-en_GB ast-en_GB az-en_GB az_IR-en_GB bal-en_GB be-en_GB bem-en_GB bg-en_GB bg_BG-en_GB bn-en_GB bn_IN-en_GB bo-en_GB br-en_GB brx-en_GB bs-en_GB ca-en_GB crh-en_GB cs-en_GB csb-en_GB cy-en_GB da-en_GB da_DK-en_GB de-en_GB dv-en_GB dz-en_GB el-en_GB en-en_GB en_AU-en_GB en_CA-en_GB bg-en_NZ ca-en_NZ cs-en_NZ da-en_NZ de-en_NZ el-en_NZ en-en_NZ en_AU-en_NZ en_CA-en_NZ en_GB-en_NZ af-en_US am-en_US ar-en_US as-en_US ast-en_US az-en_US be-en_US bg-en_US bn-en_US bn_IN-en_US br-en_US bs-en_US ca-en_US cs-en_US cy-en_US da-en_US de-en_US dz-en_US el-en_US en-en_US en_CA-en_US en_GB-en_US af-en_ZA ar-en_ZA az-en_ZA be-en_ZA bg-en_ZA bs-en_ZA ca-en_ZA cs-en_ZA cy-en_ZA da-en_ZA de-en_ZA dz-en_ZA el-en_ZA en-en_ZA en_CA-en_ZA en_GB-en_ZA af-eo am-eo an-eo ang-eo ar-eo ar_TN-eo ara-eo as-eo ast-eo az-eo az_IR-eo bal-eo be-eo bem-eo bg-eo bg_BG-eo bn-eo bn_IN-eo bo-eo br-eo brx-eo bs-eo ca-eo crh-eo cs-eo csb-eo cy-eo da-eo da_DK-eo de-eo dv-eo dz-eo el-eo en-eo en_AU-eo en_CA-eo en_GB-eo en_US-eo af-es am-es an-es ang-es ar-es ar_TN-es ara-es as-es ast-es az-es az_IR-es bal-es be-es bem-es bg-es bg_BG-es bn-es bn_IN-es bo-es br-es brx-es bs-es ca-es cat-es crh-es cs-es csb-es cy-es da-es da_DK-es de-es de_CH-es dv-es dz-es el-es en-es en_AU-es en_CA-es en_GB-es en_NZ-es en_US-es en_ZA-es eo-es af-es_AR am-es_AR ar-es_AR as-es_AR ast-es_AR az-es_AR be-es_AR bg-es_AR bn-es_AR bn_IN-es_AR br-es_AR bs-es_AR ca-es_AR crh-es_AR cs-es_AR csb-es_AR cy-es_AR da-es_AR de-es_AR dz-es_AR el-es_AR en-es_AR en_CA-es_AR en_GB-es_AR eo-es_AR es-es_AR af-es_CL am-es_CL ar-es_CL as-es_CL ast-es_CL az-es_CL be-es_CL bg-es_CL bn-es_CL bn_IN-es_CL br-es_CL bs-es_CL ca-es_CL crh-es_CL cs-es_CL csb-es_CL cy-es_CL da-es_CL de-es_CL dz-es_CL el-es_CL en-es_CL en_CA-es_CL en_GB-es_CL eo-es_CL es-es_CL es_AR-es_CL af-es_CO am-es_CO ar-es_CO as-es_CO ast-es_CO az-es_CO be-es_CO bg-es_CO bn-es_CO bn_IN-es_CO br-es_CO bs-es_CO ca-es_CO crh-es_CO cs-es_CO csb-es_CO cy-es_CO da-es_CO de-es_CO dz-es_CO el-es_CO en-es_CO en_CA-es_CO en_GB-es_CO eo-es_CO es-es_CO es_AR-es_CO es_CL-es_CO af-es_CR am-es_CR ar-es_CR as-es_CR ast-es_CR az-es_CR be-es_CR bg-es_CR bn-es_CR bn_IN-es_CR br-es_CR bs-es_CR ca-es_CR crh-es_CR cs-es_CR csb-es_CR cy-es_CR da-es_CR de-es_CR dz-es_CR el-es_CR en-es_CR en_CA-es_CR en_GB-es_CR eo-es_CR es-es_CR es_AR-es_CR es_CL-es_CR es_CO-es_CR af-es_DO am-es_DO ar-es_DO as-es_DO ast-es_DO az-es_DO be-es_DO bg-es_DO bn-es_DO bn_IN-es_DO br-es_DO bs-es_DO ca-es_DO crh-es_DO cs-es_DO csb-es_DO cy-es_DO da-es_DO de-es_DO dz-es_DO el-es_DO en-es_DO en_CA-es_DO en_GB-es_DO eo-es_DO es-es_DO es_AR-es_DO es_CL-es_DO es_CO-es_DO es_CR-es_DO af-es_EC am-es_EC ar-es_EC as-es_EC ast-es_EC az-es_EC be-es_EC bg-es_EC bn-es_EC bn_IN-es_EC br-es_EC bs-es_EC ca-es_EC crh-es_EC cs-es_EC csb-es_EC cy-es_EC da-es_EC de-es_EC dz-es_EC el-es_EC en-es_EC en_CA-es_EC en_GB-es_EC eo-es_EC es-es_EC es_AR-es_EC es_CL-es_EC es_CO-es_EC es_CR-es_EC es_DO-es_EC af-es_ES am-es_ES ar-es_ES as-es_ES ast-es_ES az-es_ES be-es_ES bg-es_ES bn-es_ES bn_IN-es_ES br-es_ES bs-es_ES ca-es_ES crh-es_ES cs-es_ES csb-es_ES cy-es_ES da-es_ES de-es_ES dz-es_ES el-es_ES en-es_ES en_CA-es_ES en_GB-es_ES eo-es_ES es-es_ES es_AR-es_ES es_CL-es_ES es_CO-es_ES es_CR-es_ES es_DO-es_ES es_EC-es_ES af-es_GT am-es_GT ar-es_GT as-es_GT ast-es_GT az-es_GT be-es_GT bg-es_GT bn-es_GT bn_IN-es_GT br-es_GT bs-es_GT ca-es_GT crh-es_GT cs-es_GT csb-es_GT cy-es_GT da-es_GT de-es_GT dz-es_GT el-es_GT en-es_GT en_CA-es_GT en_GB-es_GT eo-es_GT es-es_GT es_AR-es_GT es_CL-es_GT es_CO-es_GT es_CR-es_GT es_DO-es_GT es_EC-es_GT es_ES-es_GT af-es_HN am-es_HN ar-es_HN as-es_HN ast-es_HN az-es_HN be-es_HN bg-es_HN bn-es_HN bn_IN-es_HN br-es_HN bs-es_HN ca-es_HN crh-es_HN cs-es_HN csb-es_HN cy-es_HN da-es_HN de-es_HN dz-es_HN el-es_HN en-es_HN en_CA-es_HN en_GB-es_HN eo-es_HN es-es_HN es_AR-es_HN es_CL-es_HN es_CO-es_HN es_CR-es_HN es_DO-es_HN es_EC-es_HN es_ES-es_HN es_GT-es_HN af-es_MX am-es_MX ar-es_MX as-es_MX ast-es_MX az-es_MX be-es_MX bg-es_MX bn-es_MX bn_IN-es_MX br-es_MX bs-es_MX ca-es_MX crh-es_MX cs-es_MX csb-es_MX cy-es_MX da-es_MX de-es_MX dz-es_MX el-es_MX en-es_MX en_CA-es_MX en_GB-es_MX eo-es_MX es-es_MX es_AR-es_MX es_CL-es_MX es_CO-es_MX es_CR-es_MX es_DO-es_MX es_EC-es_MX es_ES-es_MX es_GT-es_MX es_HN-es_MX af-es_NI am-es_NI ar-es_NI as-es_NI ast-es_NI az-es_NI be-es_NI bg-es_NI bn-es_NI bn_IN-es_NI br-es_NI bs-es_NI ca-es_NI crh-es_NI cs-es_NI csb-es_NI cy-es_NI da-es_NI de-es_NI dz-es_NI el-es_NI en-es_NI en_CA-es_NI en_GB-es_NI eo-es_NI es-es_NI es_AR-es_NI es_CL-es_NI es_CO-es_NI es_CR-es_NI es_DO-es_NI es_EC-es_NI es_ES-es_NI es_GT-es_NI es_HN-es_NI es_MX-es_NI af-es_PA am-es_PA ar-es_PA as-es_PA ast-es_PA az-es_PA be-es_PA bg-es_PA bn-es_PA bn_IN-es_PA br-es_PA bs-es_PA ca-es_PA crh-es_PA cs-es_PA csb-es_PA cy-es_PA da-es_PA de-es_PA dz-es_PA el-es_PA en-es_PA en_CA-es_PA en_GB-es_PA eo-es_PA es-es_PA es_AR-es_PA es_CL-es_PA es_CO-es_PA es_CR-es_PA es_DO-es_PA es_EC-es_PA es_ES-es_PA es_GT-es_PA es_HN-es_PA es_MX-es_PA es_NI-es_PA af-es_PE am-es_PE ar-es_PE as-es_PE ast-es_PE az-es_PE be-es_PE bg-es_PE bn-es_PE bn_IN-es_PE br-es_PE bs-es_PE ca-es_PE crh-es_PE cs-es_PE csb-es_PE cy-es_PE da-es_PE de-es_PE dz-es_PE el-es_PE en-es_PE en_CA-es_PE en_GB-es_PE eo-es_PE es-es_PE es_AR-es_PE es_CL-es_PE es_CO-es_PE es_CR-es_PE es_DO-es_PE es_EC-es_PE es_ES-es_PE es_GT-es_PE es_HN-es_PE es_MX-es_PE es_NI-es_PE es_PA-es_PE af-es_PR am-es_PR ar-es_PR as-es_PR ast-es_PR az-es_PR be-es_PR bg-es_PR bn-es_PR bn_IN-es_PR br-es_PR bs-es_PR ca-es_PR crh-es_PR cs-es_PR csb-es_PR cy-es_PR da-es_PR de-es_PR dz-es_PR el-es_PR en-es_PR en_CA-es_PR en_GB-es_PR eo-es_PR es-es_PR es_AR-es_PR es_CL-es_PR es_CO-es_PR es_CR-es_PR es_DO-es_PR es_EC-es_PR es_ES-es_PR es_GT-es_PR es_HN-es_PR es_MX-es_PR es_NI-es_PR es_PA-es_PR es_PE-es_PR af-es_SV am-es_SV ar-es_SV as-es_SV ast-es_SV az-es_SV be-es_SV bg-es_SV bn-es_SV bn_IN-es_SV br-es_SV bs-es_SV ca-es_SV crh-es_SV cs-es_SV csb-es_SV cy-es_SV da-es_SV de-es_SV dz-es_SV el-es_SV en-es_SV en_CA-es_SV en_GB-es_SV eo-es_SV es-es_SV es_AR-es_SV es_CL-es_SV es_CO-es_SV es_CR-es_SV es_DO-es_SV es_EC-es_SV es_ES-es_SV es_GT-es_SV es_HN-es_SV es_MX-es_SV es_NI-es_SV es_PA-es_SV es_PE-es_SV es_PR-es_SV af-es_UY am-es_UY ar-es_UY as-es_UY ast-es_UY az-es_UY be-es_UY bg-es_UY bn-es_UY bn_IN-es_UY br-es_UY bs-es_UY ca-es_UY crh-es_UY cs-es_UY csb-es_UY cy-es_UY da-es_UY de-es_UY dz-es_UY el-es_UY en-es_UY en_CA-es_UY en_GB-es_UY eo-es_UY es-es_UY es_AR-es_UY es_CL-es_UY es_CO-es_UY es_CR-es_UY es_DO-es_UY es_EC-es_UY es_ES-es_UY es_GT-es_UY es_HN-es_UY es_MX-es_UY es_NI-es_UY es_PA-es_UY es_PE-es_UY es_PR-es_UY es_SV-es_UY af-es_VE am-es_VE ar-es_VE as-es_VE ast-es_VE az-es_VE be-es_VE bg-es_VE bn-es_VE bn_IN-es_VE br-es_VE bs-es_VE ca-es_VE crh-es_VE cs-es_VE csb-es_VE cy-es_VE da-es_VE de-es_VE dz-es_VE el-es_VE en-es_VE en_CA-es_VE en_GB-es_VE eo-es_VE es-es_VE es_AR-es_VE es_CL-es_VE es_CO-es_VE es_CR-es_VE es_DO-es_VE es_EC-es_VE es_ES-es_VE es_GT-es_VE es_HN-es_VE es_MX-es_VE es_NI-es_VE es_PA-es_VE es_PE-es_VE es_PR-es_VE es_SV-es_VE es_UY-es_VE af-et am-et an-et ang-et ar-et ar_TN-et as-et ast-et az-et az_IR-et bal-et be-et bem-et bg-et bn-et bn_IN-et bo-et br-et brx-et bs-et ca-et crh-et cs-et csb-et cy-et da-et de-et dv-et dz-et el-et en-et en_AU-et en_CA-et en_GB-et en_US-et en_ZA-et eo-et es-et es_AR-et es_CL-et es_CO-et es_CR-et es_DO-et es_EC-et es_ES-et es_GT-et es_HN-et es_MX-et es_NI-et es_PA-et es_PE-et es_PR-et es_SV-et es_UY-et es_VE-et af-eu am-eu an-eu ang-eu ar-eu ar_TN-eu ara-eu as-eu ast-eu az-eu az_IR-eu bal-eu be-eu bem-eu bg-eu bg_BG-eu bn-eu bn_IN-eu bo-eu br-eu brx-eu bs-eu ca-eu crh-eu cs-eu csb-eu cy-eu da-eu da_DK-eu de-eu dv-eu dz-eu el-eu en-eu en_AU-eu en_CA-eu en_GB-eu en_US-eu en_ZA-eu eo-eu es-eu es_AR-eu es_CL-eu es_CO-eu es_CR-eu es_DO-eu es_EC-eu es_ES-eu es_GT-eu es_HN-eu es_MX-eu es_NI-eu es_PA-eu es_PE-eu es_PR-eu es_SV-eu es_UY-eu es_VE-eu et-eu af-fa am-fa an-fa ang-fa ar-fa ar_TN-fa ara-fa as-fa ast-fa az-fa az_IR-fa bal-fa be-fa bem-fa bg-fa bg_BG-fa bn-fa bn_IN-fa bo-fa br-fa brx-fa bs-fa ca-fa crh-fa cs-fa csb-fa cy-fa da-fa da_DK-fa de-fa dv-fa dz-fa el-fa en-fa en_AU-fa en_CA-fa en_GB-fa en_US-fa eo-fa es-fa es_AR-fa es_CL-fa es_CO-fa es_CR-fa es_DO-fa es_EC-fa es_ES-fa es_GT-fa es_HN-fa es_MX-fa es_NI-fa es_PA-fa es_PE-fa es_PR-fa es_SV-fa es_UY-fa es_VE-fa et-fa eu-fa ar-fa_IR ara-fa_IR as-fa_IR az-fa_IR bg-fa_IR bg_BG-fa_IR bn_IN-fa_IR br-fa_IR ca-fa_IR cs-fa_IR cy-fa_IR da-fa_IR de-fa_IR el-fa_IR en-fa_IR en_GB-fa_IR eo-fa_IR es-fa_IR eu-fa_IR fa-fa_IR af-fi am-fi an-fi ang-fi ar-fi ar_TN-fi ara-fi as-fi ast-fi az-fi az_IR-fi bal-fi be-fi bem-fi bg-fi bg_BG-fi bn-fi bn_IN-fi bo-fi br-fi brx-fi bs-fi ca-fi crh-fi cs-fi csb-fi cy-fi da-fi da_DK-fi de-fi de_CH-fi dv-fi dz-fi el-fi en-fi en_AU-fi en_CA-fi en_GB-fi en_NZ-fi en_US-fi en_ZA-fi eo-fi es-fi es_AR-fi es_CL-fi es_CO-fi es_CR-fi es_DO-fi es_EC-fi es_ES-fi es_GT-fi es_HN-fi es_MX-fi es_NI-fi es_PA-fi es_PE-fi es_PR-fi es_SV-fi es_UY-fi es_VE-fi et-fi eu-fi fa-fi fa_IR-fi ar-fo ara-fo as-fo az-fo bg-fo bg_BG-fo bn_IN-fo br-fo ca-fo cs-fo cy-fo da-fo de-fo el-fo en-fo en_AU-fo en_CA-fo en_GB-fo en_NZ-fo eo-fo es-fo eu-fo fa-fo fa_IR-fo fi-fo ar-foo as-foo az-foo bg-foo bg_BG-foo bn_IN-foo br-foo ca-foo cs-foo cy-foo da-foo de-foo el-foo en-foo en_GB-foo eo-foo es-foo eu-foo fa-foo fa_IR-foo fi-foo fo-foo af-fr am-fr an-fr ang-fr ar-fr ara-fr as-fr ast-fr az-fr az_IR-fr bal-fr be-fr bem-fr bg-fr bg_BG-fr bn-fr bn_IN-fr bo-fr br-fr brx-fr bs-fr ca-fr cat-fr crh-fr cs-fr csb-fr cy-fr da-fr da_DK-fr de-fr de_CH-fr dv-fr dz-fr el-fr en-fr en_AU-fr en_CA-fr en_GB-fr en_NZ-fr en_US-fr en_ZA-fr eo-fr es-fr es_AR-fr es_CL-fr es_CO-fr es_CR-fr es_DO-fr es_EC-fr es_ES-fr es_GT-fr es_HN-fr es_MX-fr es_NI-fr es_PA-fr es_PE-fr es_PR-fr es_SV-fr es_UY-fr es_VE-fr et-fr eu-fr fa-fr fa_IR-fr fi-fr fo-fr foo-fr af-fur am-fur an-fur ang-fur ar-fur as-fur ast-fur az-fur be-fur bem-fur bg-fur bn-fur bn_IN-fur bo-fur br-fur brx-fur bs-fur ca-fur crh-fur cs-fur csb-fur cy-fur da-fur de-fur dv-fur dz-fur el-fur en-fur en_CA-fur en_GB-fur eo-fur es-fur et-fur eu-fur fa-fur fi-fur fr-fur af-fy am-fy an-fy ar-fy as-fy ast-fy az-fy be-fy bem-fy bg-fy bn-fy bn_IN-fy bo-fy br-fy brx-fy bs-fy ca-fy crh-fy cs-fy csb-fy cy-fy da-fy de-fy dv-fy dz-fy el-fy en-fy en_AU-fy en_CA-fy en_GB-fy eo-fy es-fy et-fy eu-fy fa-fy fi-fy fr-fy fur-fy af-ga am-ga an-ga ang-ga ar-ga ar_TN-ga ara-ga as-ga ast-ga az-ga az_IR-ga be-ga bem-ga bg-ga bg_BG-ga bn-ga bn_IN-ga bo-ga br-ga brx-ga bs-ga ca-ga crh-ga cs-ga csb-ga cy-ga da-ga da_DK-ga de-ga dv-ga dz-ga el-ga en-ga en_AU-ga en_CA-ga en_GB-ga en_US-ga en_ZA-ga eo-ga es-ga es_AR-ga es_CL-ga es_CO-ga es_CR-ga es_DO-ga es_EC-ga es_ES-ga es_GT-ga es_HN-ga es_MX-ga es_NI-ga es_PA-ga es_PE-ga es_PR-ga es_SV-ga es_UY-ga es_VE-ga et-ga eu-ga fa-ga fa_IR-ga fi-ga fo-ga foo-ga fr-ga fur-ga fy-ga af-gd am-gd an-gd ang-gd ar-gd ar_TN-gd as-gd ast-gd az-gd az_IR-gd be-gd bg-gd bn-gd bn_IN-gd bo-gd br-gd bs-gd ca-gd crh-gd cs-gd csb-gd cy-gd da-gd de-gd dv-gd dz-gd el-gd en-gd en_CA-gd en_GB-gd en_US-gd eo-gd es-gd es_AR-gd es_CL-gd es_CO-gd es_CR-gd es_DO-gd es_EC-gd es_ES-gd es_GT-gd es_HN-gd es_MX-gd es_NI-gd es_PA-gd es_PE-gd es_PR-gd es_SV-gd es_UY-gd es_VE-gd et-gd eu-gd fa-gd fi-gd fr-gd fur-gd fy-gd ga-gd af-gl am-gl an-gl ang-gl ar-gl ar_TN-gl ara-gl as-gl ast-gl az-gl az_IR-gl bal-gl be-gl bem-gl bg-gl bg_BG-gl bn-gl bn_IN-gl bo-gl br-gl brx-gl bs-gl ca-gl cat-gl crh-gl cs-gl csb-gl cy-gl da-gl da_DK-gl de-gl dv-gl dz-gl el-gl en-gl en_AU-gl en_CA-gl en_GB-gl en_NZ-gl en_US-gl en_ZA-gl eo-gl es-gl es_AR-gl es_CL-gl es_CO-gl es_CR-gl es_DO-gl es_EC-gl es_ES-gl es_GT-gl es_HN-gl es_MX-gl es_NI-gl es_PA-gl es_PE-gl es_PR-gl es_SV-gl es_UY-gl es_VE-gl et-gl eu-gl fa-gl fa_IR-gl fi-gl fo-gl foo-gl fr-gl fur-gl fy-gl ga-gl gd-gl af-gn an-gn ar-gn as-gn ast-gn be-gn bg-gn bn-gn bn_IN-gn br-gn ca-gn crh-gn cs-gn csb-gn cy-gn da-gn de-gn dv-gn dz-gn el-gn en-gn en_CA-gn en_GB-gn eo-gn es-gn et-gn eu-gn fa-gn fi-gn fr-gn fur-gn fy-gn ga-gn gd-gn gl-gn ar-gr as-gr bg-gr cs-gr de-gr el-gr en-gr en_CA-gr en_GB-gr eo-gr es-gr et-gr eu-gr fr-gr gl-gr af-gu am-gu an-gu ang-gu ar-gu ar_TN-gu ara-gu as-gu ast-gu az-gu az_IR-gu bal-gu be-gu bem-gu bg-gu bg_BG-gu bn-gu bn_IN-gu bo-gu br-gu brx-gu bs-gu ca-gu crh-gu cs-gu csb-gu cy-gu da-gu da_DK-gu de-gu de_CH-gu dv-gu dz-gu el-gu en-gu en_AU-gu en_CA-gu en_GB-gu en_US-gu en_ZA-gu eo-gu es-gu es_AR-gu es_CL-gu es_CO-gu es_CR-gu es_DO-gu es_EC-gu es_ES-gu es_GT-gu es_HN-gu es_MX-gu es_NI-gu es_PA-gu es_PE-gu es_PR-gu es_SV-gu es_UY-gu es_VE-gu et-gu eu-gu fa-gu fa_IR-gu fi-gu fo-gu foo-gu fr-gu fur-gu fy-gu ga-gu gd-gu gl-gu gn-gu gr-gu af-gv am-gv an-gv ar-gv as-gv ast-gv az-gv be-gv bg-gv bn-gv bn_IN-gv bo-gv br-gv bs-gv ca-gv crh-gv cs-gv csb-gv cy-gv da-gv de-gv dv-gv dz-gv el-gv en-gv en_CA-gv en_GB-gv eo-gv es-gv et-gv eu-gv fa-gv fi-gv fr-gv fur-gv fy-gv ga-gv gd-gv gl-gv gn-gv gu-gv af-ha am-ha an-ha ar-ha as-ha ast-ha az-ha be-ha bg-ha bn-ha bn_IN-ha bo-ha br-ha bs-ha ca-ha crh-ha cs-ha csb-ha cy-ha da-ha de-ha dv-ha dz-ha el-ha en-ha en_CA-ha en_GB-ha eo-ha es-ha et-ha eu-ha fa-ha fi-ha fr-ha fur-ha fy-ha ga-ha gd-ha gl-ha gn-ha gu-ha gv-ha af-he am-he an-he ang-he ar-he ar_TN-he ara-he as-he ast-he az-he az_IR-he bal-he be-he bem-he bg-he bg_BG-he bn-he bn_IN-he bo-he br-he brx-he bs-he ca-he cat-he crh-he cs-he csb-he cy-he da-he da_DK-he de-he de_CH-he dv-he dz-he el-he en-he en_AU-he en_CA-he en_GB-he en_NZ-he en_US-he en_ZA-he eo-he es-he es_AR-he es_CL-he es_CO-he es_CR-he es_DO-he es_EC-he es_ES-he es_GT-he es_HN-he es_MX-he es_NI-he es_PA-he es_PE-he es_PR-he es_SV-he es_UY-he es_VE-he et-he eu-he fa-he fa_IR-he fi-he fo-he foo-he fr-he fur-he fy-he ga-he gd-he gl-he gn-he gr-he gu-he gv-he ha-he af-hi am-hi an-hi ang-hi ar-hi ar_TN-hi ara-hi as-hi ast-hi az-hi az_IR-hi bal-hi be-hi bem-hi bg-hi bg_BG-hi bn-hi bn_IN-hi bo-hi br-hi brx-hi bs-hi ca-hi crh-hi cs-hi csb-hi cy-hi da-hi da_DK-hi de-hi de_CH-hi dv-hi dz-hi el-hi en-hi en_AU-hi en_CA-hi en_GB-hi en_US-hi en_ZA-hi eo-hi es-hi es_AR-hi es_CL-hi es_CO-hi es_CR-hi es_DO-hi es_EC-hi es_ES-hi es_GT-hi es_HN-hi es_MX-hi es_NI-hi es_PA-hi es_PE-hi es_PR-hi es_SV-hi es_UY-hi es_VE-hi et-hi eu-hi fa-hi fa_IR-hi fi-hi fo-hi foo-hi fr-hi fur-hi fy-hi ga-hi gd-hi gl-hi gn-hi gr-hi gu-hi gv-hi ha-hi he-hi af-hr am-hr an-hr ang-hr ar-hr ar_TN-hr ara-hr as-hr ast-hr az-hr az_IR-hr be-hr bem-hr bg-hr bg_BG-hr bn-hr bn_IN-hr bo-hr br-hr brx-hr bs-hr ca-hr crh-hr cs-hr csb-hr cy-hr da-hr da_DK-hr de-hr dv-hr dz-hr el-hr en-hr en_AU-hr en_CA-hr en_GB-hr en_US-hr en_ZA-hr eo-hr es-hr es_AR-hr es_CL-hr es_CO-hr es_CR-hr es_DO-hr es_EC-hr es_ES-hr es_GT-hr es_HN-hr es_MX-hr es_NI-hr es_PA-hr es_PE-hr es_PR-hr es_SV-hr es_UY-hr es_VE-hr et-hr eu-hr fa-hr fa_IR-hr fi-hr fo-hr foo-hr fr-hr fur-hr fy-hr ga-hr gd-hr gl-hr gn-hr gu-hr gv-hr ha-hr he-hr hi-hr af-hu am-hu an-hu ang-hu ar-hu ar_TN-hu ara-hu as-hu ast-hu az-hu az_IR-hu bal-hu be-hu bem-hu bg-hu bg_BG-hu bn-hu bn_IN-hu bo-hu br-hu brx-hu bs-hu ca-hu cat-hu crh-hu cs-hu csb-hu cy-hu da-hu da_DK-hu de-hu de_CH-hu dv-hu dz-hu el-hu en-hu en_AU-hu en_CA-hu en_GB-hu en_NZ-hu en_US-hu en_ZA-hu eo-hu es-hu es_AR-hu es_CL-hu es_CO-hu es_CR-hu es_DO-hu es_EC-hu es_ES-hu es_GT-hu es_HN-hu es_MX-hu es_NI-hu es_PA-hu es_PE-hu es_PR-hu es_SV-hu es_UY-hu es_VE-hu et-hu eu-hu fa-hu fa_IR-hu fi-hu fo-hu foo-hu fr-hu fur-hu fy-hu ga-hu gd-hu gl-hu gn-hu gr-hu gu-hu gv-hu ha-hu he-hu hi-hu hr-hu af-hy am-hy an-hy ang-hy ar-hy as-hy ast-hy az-hy az_IR-hy bal-hy be-hy bem-hy bg-hy bn-hy bn_IN-hy bo-hy br-hy brx-hy bs-hy ca-hy crh-hy cs-hy csb-hy cy-hy da-hy de-hy dv-hy dz-hy el-hy en-hy en_CA-hy en_GB-hy en_US-hy eo-hy es-hy es_AR-hy es_CL-hy es_CO-hy es_CR-hy es_DO-hy es_EC-hy es_ES-hy es_GT-hy es_HN-hy es_MX-hy es_NI-hy es_PA-hy es_PE-hy es_PR-hy es_SV-hy es_UY-hy es_VE-hy et-hy eu-hy fa-hy fi-hy fr-hy fur-hy fy-hy ga-hy gd-hy gl-hy gn-hy gu-hy gv-hy ha-hy he-hy hi-hy hr-hy hu-hy af-ia am-ia an-ia ang-ia ar-ia ara-ia as-ia ast-ia az-ia az_IR-ia be-ia bg-ia bg_BG-ia bn-ia bn_IN-ia br-ia bs-ia ca-ia crh-ia cs-ia csb-ia cy-ia da-ia da_DK-ia de-ia dv-ia dz-ia el-ia en-ia en_CA-ia en_GB-ia eo-ia es-ia et-ia eu-ia fa-ia fa_IR-ia fi-ia fo-ia foo-ia fr-ia fur-ia fy-ia ga-ia gd-ia gl-ia gn-ia gu-ia gv-ia ha-ia he-ia hi-ia hr-ia hu-ia hy-ia af-id am-id an-id ang-id ar-id ar_TN-id ara-id as-id ast-id az-id az_IR-id bal-id be-id bem-id bg-id bg_BG-id bn-id bn_IN-id bo-id br-id brx-id bs-id ca-id cat-id crh-id cs-id csb-id cy-id da-id da_DK-id de-id de_CH-id dv-id dz-id el-id en-id en_AU-id en_CA-id en_GB-id en_NZ-id en_US-id eo-id es-id es_AR-id es_CL-id es_CO-id es_CR-id es_DO-id es_EC-id es_ES-id es_GT-id es_HN-id es_MX-id es_NI-id es_PA-id es_PE-id es_PR-id es_SV-id es_UY-id es_VE-id et-id eu-id fa-id fa_IR-id fi-id fo-id foo-id fr-id fur-id fy-id ga-id gd-id gl-id gn-id gr-id gu-id gv-id ha-id he-id hi-id hr-id hu-id hy-id ia-id af-ig am-ig an-ig ar-ig as-ig ast-ig az-ig be-ig bg-ig bn-ig bn_IN-ig bo-ig br-ig bs-ig ca-ig crh-ig cs-ig csb-ig cy-ig da-ig de-ig dv-ig dz-ig el-ig en-ig en_CA-ig en_GB-ig eo-ig es-ig et-ig eu-ig fa-ig fi-ig fr-ig fur-ig fy-ig ga-ig gd-ig gl-ig gn-ig gu-ig gv-ig ha-ig he-ig hi-ig hr-ig hu-ig hy-ig ia-ig id-ig af-io am-io an-io ang-io ar-io as-io ast-io az-io az_IR-io be-io bem-io bg-io bn-io bn_IN-io bo-io br-io brx-io bs-io ca-io crh-io cs-io csb-io cy-io da-io de-io dv-io dz-io el-io en-io en_CA-io en_GB-io eo-io es-io et-io eu-io fa-io fi-io fr-io fur-io fy-io ga-io gd-io gl-io gn-io gu-io gv-io ha-io he-io hi-io hr-io hu-io hy-io ia-io id-io ig-io af-is am-is an-is ang-is ar-is as-is ast-is az-is az_IR-is be-is bg-is bn-is bn_IN-is bo-is br-is bs-is ca-is crh-is cs-is csb-is cy-is da-is de-is dv-is dz-is el-is en-is en_AU-is en_CA-is en_GB-is en_ZA-is eo-is es-is es_AR-is es_CL-is es_CO-is es_CR-is es_DO-is es_EC-is es_ES-is es_GT-is es_HN-is es_MX-is es_NI-is es_PA-is es_PE-is es_PR-is es_SV-is es_UY-is es_VE-is et-is eu-is fa-is fi-is fr-is fur-is fy-is ga-is gd-is gl-is gn-is gu-is gv-is ha-is he-is hi-is hr-is hu-is hy-is ia-is id-is ig-is io-is af-it am-it an-it ang-it ar-it ar_TN-it ara-it as-it ast-it az-it az_IR-it bal-it be-it bem-it bg-it bg_BG-it bn-it bn_IN-it bo-it br-it brx-it bs-it ca-it cat-it crh-it cs-it csb-it cy-it da-it da_DK-it de-it de_CH-it dv-it dz-it el-it en-it en_AU-it en_CA-it en_GB-it en_NZ-it en_US-it en_ZA-it eo-it es-it es_AR-it es_CL-it es_CO-it es_CR-it es_DO-it es_EC-it es_ES-it es_GT-it es_HN-it es_MX-it es_NI-it es_PA-it es_PE-it es_PR-it es_SV-it es_UY-it es_VE-it et-it eu-it fa-it fa_IR-it fi-it fo-it foo-it fr-it fur-it fy-it ga-it gd-it gl-it gn-it gr-it gu-it gv-it ha-it he-it hi-it hr-it hu-it hy-it ia-it id-it ig-it io-it is-it ar-it_IT as-it_IT az-it_IT bg-it_IT bg_BG-it_IT bn_IN-it_IT br-it_IT ca-it_IT cs-it_IT cy-it_IT da-it_IT da_DK-it_IT de-it_IT el-it_IT en-it_IT en_GB-it_IT eo-it_IT es-it_IT eu-it_IT fa-it_IT fa_IR-it_IT fi-it_IT fo-it_IT foo-it_IT fr-it_IT ga-it_IT gl-it_IT gu-it_IT he-it_IT hi-it_IT hr-it_IT hu-it_IT ia-it_IT id-it_IT it-it_IT af-ja am-ja an-ja ang-ja ar-ja ar_TN-ja ara-ja as-ja ast-ja az-ja az_IR-ja bal-ja be-ja bem-ja bg-ja bg_BG-ja bn-ja bn_IN-ja bo-ja br-ja brx-ja bs-ja ca-ja crh-ja cs-ja csb-ja cy-ja da-ja da_DK-ja de-ja de_CH-ja dv-ja dz-ja el-ja en-ja en_AU-ja en_CA-ja en_GB-ja en_NZ-ja en_US-ja en_ZA-ja eo-ja es-ja es_AR-ja es_CL-ja es_CO-ja es_CR-ja es_DO-ja es_EC-ja es_ES-ja es_GT-ja es_HN-ja es_MX-ja es_NI-ja es_PA-ja es_PE-ja es_PR-ja es_SV-ja es_UY-ja es_VE-ja et-ja eu-ja fa-ja fa_IR-ja fi-ja fo-ja foo-ja fr-ja fur-ja fy-ja ga-ja gd-ja gl-ja gn-ja gr-ja gu-ja gv-ja ha-ja he-ja hi-ja hr-ja hu-ja hy-ja ia-ja id-ja ig-ja io-ja is-ja it-ja it_IT-ja am-jbo ar-jbo az-jbo bg-jbo bn-jbo bn_IN-jbo ca-jbo cs-jbo da-jbo de-jbo dz-jbo el-jbo en-jbo en_AU-jbo en_GB-jbo eo-jbo es-jbo et-jbo eu-jbo fi-jbo fr-jbo gl-jbo gu-jbo he-jbo hi-jbo hr-jbo hu-jbo is-jbo it-jbo ja-jbo af-ka am-ka an-ka ang-ka ar-ka ar_TN-ka ara-ka as-ka ast-ka az-ka az_IR-ka bal-ka be-ka bem-ka bg-ka bg_BG-ka bn-ka bn_IN-ka bo-ka br-ka brx-ka bs-ka ca-ka crh-ka cs-ka csb-ka cy-ka da-ka da_DK-ka de-ka dv-ka dz-ka el-ka en-ka en_AU-ka en_CA-ka en_GB-ka en_US-ka en_ZA-ka eo-ka es-ka es_AR-ka es_CL-ka es_CO-ka es_CR-ka es_DO-ka es_EC-ka es_ES-ka es_GT-ka es_HN-ka es_MX-ka es_NI-ka es_PA-ka es_PE-ka es_PR-ka es_SV-ka es_UY-ka es_VE-ka et-ka eu-ka fa-ka fa_IR-ka fi-ka fo-ka foo-ka fr-ka fur-ka fy-ka ga-ka gd-ka gl-ka gn-ka gu-ka gv-ka ha-ka he-ka hi-ka hr-ka hu-ka hy-ka ia-ka id-ka ig-ka io-ka is-ka it-ka it_IT-ka ja-ka jbo-ka af-kg am-kg an-kg ang-kg ar-kg as-kg ast-kg az-kg az_IR-kg be-kg bem-kg bg-kg bn-kg bn_IN-kg br-kg brx-kg bs-kg ca-kg crh-kg cs-kg csb-kg cy-kg da-kg de-kg dv-kg dz-kg el-kg en-kg en_CA-kg en_GB-kg eo-kg es-kg et-kg eu-kg fa-kg fi-kg fr-kg fur-kg fy-kg ga-kg gd-kg gl-kg gn-kg gu-kg gv-kg ha-kg he-kg hi-kg hr-kg hu-kg hy-kg ia-kg id-kg ig-kg io-kg is-kg it-kg ja-kg ka-kg af-kk am-kk an-kk ang-kk ar-kk ara-kk as-kk ast-kk az-kk az_IR-kk be-kk bem-kk bg-kk bg_BG-kk bn-kk bn_IN-kk bo-kk br-kk brx-kk bs-kk ca-kk crh-kk cs-kk csb-kk cy-kk da-kk da_DK-kk de-kk dv-kk dz-kk el-kk en-kk en_CA-kk en_GB-kk en_US-kk eo-kk es-kk es_AR-kk es_CL-kk es_CO-kk es_CR-kk es_DO-kk es_EC-kk es_ES-kk es_GT-kk es_HN-kk es_MX-kk es_NI-kk es_PA-kk es_PE-kk es_PR-kk es_SV-kk es_UY-kk es_VE-kk et-kk eu-kk fa-kk fa_IR-kk fi-kk fo-kk foo-kk fr-kk fur-kk fy-kk ga-kk gd-kk gl-kk gn-kk gu-kk gv-kk ha-kk he-kk hi-kk hr-kk hu-kk hy-kk ia-kk id-kk ig-kk io-kk is-kk it-kk it_IT-kk ja-kk ka-kk kg-kk af-km am-km an-km ang-km ar-km as-km ast-km az-km az_IR-km be-km bem-km bg-km bn-km bn_IN-km bo-km br-km brx-km bs-km ca-km crh-km cs-km csb-km cy-km da-km de-km dv-km dz-km el-km en-km en_AU-km en_CA-km en_GB-km en_US-km en_ZA-km eo-km es-km et-km eu-km fa-km fi-km fr-km fur-km fy-km ga-km gd-km gl-km gn-km gu-km gv-km ha-km he-km hi-km hr-km hu-km hy-km ia-km id-km ig-km io-km is-km it-km ja-km ka-km kg-km kk-km af-kn am-kn an-kn ang-kn ar-kn ar_TN-kn ara-kn as-kn ast-kn az-kn az_IR-kn bal-kn be-kn bem-kn bg-kn bg_BG-kn bn-kn bn_IN-kn bo-kn br-kn brx-kn bs-kn ca-kn crh-kn cs-kn csb-kn cy-kn da-kn da_DK-kn de-kn de_CH-kn dv-kn dz-kn el-kn en-kn en_AU-kn en_CA-kn en_GB-kn en_US-kn eo-kn es-kn es_AR-kn es_CL-kn es_CO-kn es_CR-kn es_DO-kn es_EC-kn es_ES-kn es_GT-kn es_HN-kn es_MX-kn es_NI-kn es_PA-kn es_PE-kn es_PR-kn es_SV-kn es_UY-kn es_VE-kn et-kn eu-kn fa-kn fa_IR-kn fi-kn fo-kn foo-kn fr-kn fur-kn fy-kn ga-kn gd-kn gl-kn gn-kn gr-kn gu-kn gv-kn ha-kn he-kn hi-kn hr-kn hu-kn hy-kn ia-kn id-kn ig-kn io-kn is-kn it-kn it_IT-kn ja-kn jbo-kn ka-kn kg-kn kk-kn km-kn af-ko am-ko an-ko ang-ko ar-ko ar_TN-ko ara-ko as-ko ast-ko az-ko az_IR-ko bal-ko be-ko bem-ko bg-ko bg_BG-ko bn-ko bn_IN-ko bo-ko br-ko brx-ko bs-ko ca-ko crh-ko cs-ko csb-ko cy-ko da-ko da_DK-ko de-ko dv-ko dz-ko el-ko en-ko en_AU-ko en_CA-ko en_GB-ko en_US-ko en_ZA-ko eo-ko es-ko es_AR-ko es_CL-ko es_CO-ko es_CR-ko es_DO-ko es_EC-ko es_ES-ko es_GT-ko es_HN-ko es_MX-ko es_NI-ko es_PA-ko es_PE-ko es_PR-ko es_SV-ko es_UY-ko es_VE-ko et-ko eu-ko fa-ko fa_IR-ko fi-ko fo-ko foo-ko fr-ko fur-ko fy-ko ga-ko gd-ko gl-ko gn-ko gr-ko gu-ko gv-ko ha-ko he-ko hi-ko hr-ko hu-ko hy-ko ia-ko id-ko ig-ko io-ko is-ko it-ko it_IT-ko ja-ko jbo-ko ka-ko kg-ko kk-ko km-ko kn-ko ar-kr as-kr bg-kr cs-kr de-kr el-kr en-kr en_CA-kr en_GB-kr eo-kr es-kr et-kr eu-kr fr-kr gl-kr gr-kr gu-kr he-kr hi-kr hu-kr id-kr it-kr ja-kr kn-kr ko-kr af-ks am-ks an-ks ar-ks as-ks ast-ks az-ks be-ks bg-ks bn-ks bn_IN-ks br-ks bs-ks ca-ks crh-ks cs-ks cy-ks da-ks de-ks dz-ks el-ks en-ks en_CA-ks en_GB-ks eo-ks es-ks et-ks eu-ks fa-ks fi-ks fr-ks fur-ks fy-ks ga-ks gd-ks gl-ks gu-ks he-ks hi-ks hr-ks hu-ks id-ks is-ks it-ks ja-ks ka-ks kk-ks km-ks kn-ks ko-ks af-ku am-ku an-ku ang-ku ar-ku as-ku ast-ku az-ku az_IR-ku bal-ku be-ku bem-ku bg-ku bn-ku bn_IN-ku bo-ku br-ku brx-ku bs-ku ca-ku crh-ku cs-ku csb-ku cy-ku da-ku de-ku dv-ku dz-ku el-ku en-ku en_AU-ku en_CA-ku en_GB-ku en_US-ku eo-ku es-ku es_AR-ku es_CL-ku es_CO-ku es_CR-ku es_DO-ku es_EC-ku es_ES-ku es_GT-ku es_HN-ku es_MX-ku es_NI-ku es_PA-ku es_PE-ku es_PR-ku es_SV-ku es_UY-ku es_VE-ku et-ku eu-ku fa-ku fi-ku fr-ku fur-ku fy-ku ga-ku gd-ku gl-ku gn-ku gu-ku gv-ku ha-ku he-ku hi-ku hr-ku hu-ku hy-ku ia-ku id-ku ig-ku io-ku is-ku it-ku ja-ku jbo-ku ka-ku kg-ku kk-ku km-ku kn-ku ko-ku ks-ku af-ky am-ky an-ky ang-ky ar-ky as-ky ast-ky az-ky az_IR-ky be-ky bg-ky bn-ky bn_IN-ky bo-ky br-ky bs-ky ca-ky crh-ky cs-ky csb-ky cy-ky da-ky de-ky dv-ky dz-ky el-ky en-ky en_CA-ky en_GB-ky eo-ky es-ky es_AR-ky es_CL-ky es_CO-ky es_CR-ky es_DO-ky es_EC-ky es_ES-ky es_GT-ky es_HN-ky es_MX-ky es_NI-ky es_PA-ky es_PE-ky es_PR-ky es_SV-ky es_UY-ky es_VE-ky et-ky eu-ky fa-ky fi-ky fr-ky fur-ky fy-ky ga-ky gd-ky gl-ky gn-ky gu-ky gv-ky ha-ky he-ky hi-ky hr-ky hu-ky hy-ky ia-ky id-ky ig-ky io-ky is-ky it-ky ja-ky ka-ky kg-ky kk-ky km-ky kn-ky ko-ky ks-ky ku-ky af-la am-la an-la ar-la as-la ast-la az-la be-la bg-la bn-la bn_IN-la br-la bs-la ca-la crh-la cs-la csb-la cy-la da-la de-la dz-la el-la en-la en_CA-la en_GB-la eo-la es-la et-la eu-la fa-la fi-la fr-la fur-la fy-la ga-la gd-la gl-la gu-la gv-la ha-la he-la hi-la hr-la hu-la hy-la id-la ig-la is-la it-la ja-la ka-la kk-la km-la kn-la ko-la ks-la ku-la ky-la af-lg am-lg an-lg ang-lg ar-lg as-lg ast-lg az-lg az_IR-lg be-lg bg-lg bn-lg bn_IN-lg br-lg bs-lg ca-lg crh-lg cs-lg cy-lg da-lg de-lg dz-lg el-lg en-lg en_CA-lg en_GB-lg eo-lg es-lg et-lg eu-lg fa-lg fi-lg fr-lg fur-lg ga-lg gd-lg gl-lg gu-lg he-lg hi-lg hr-lg hu-lg hy-lg ia-lg id-lg io-lg is-lg it-lg ja-lg ka-lg kg-lg kk-lg km-lg kn-lg ko-lg ku-lg ky-lg la-lg af-li am-li an-li ang-li ar-li as-li ast-li az-li az_IR-li be-li bg-li bn-li bn_IN-li bo-li br-li bs-li ca-li crh-li cs-li csb-li cy-li da-li de-li dz-li el-li en-li en_CA-li en_GB-li eo-li es-li et-li eu-li fa-li fi-li fr-li fur-li fy-li ga-li gd-li gl-li gu-li gv-li ha-li he-li hi-li hr-li hu-li hy-li ia-li id-li ig-li io-li is-li it-li ja-li ka-li kg-li kk-li km-li kn-li ko-li ks-li ku-li ky-li la-li lg-li af-lo am-lo an-lo ar-lo as-lo ast-lo az-lo be-lo bg-lo bn-lo bn_IN-lo br-lo bs-lo ca-lo crh-lo cs-lo csb-lo cy-lo da-lo de-lo dv-lo dz-lo el-lo en-lo en_CA-lo en_GB-lo en_US-lo eo-lo es-lo et-lo eu-lo fa-lo fi-lo fr-lo fur-lo fy-lo ga-lo gd-lo gl-lo gn-lo gu-lo gv-lo ha-lo he-lo hi-lo hr-lo hu-lo hy-lo ia-lo id-lo ig-lo io-lo is-lo it-lo ja-lo ka-lo kg-lo kk-lo km-lo kn-lo ko-lo ku-lo ky-lo li-lo af-lt am-lt an-lt ang-lt ar-lt ar_TN-lt ara-lt as-lt ast-lt az-lt az_IR-lt bal-lt be-lt bem-lt bg-lt bg_BG-lt bn-lt bn_IN-lt bo-lt br-lt brx-lt bs-lt ca-lt crh-lt cs-lt csb-lt cy-lt da-lt da_DK-lt de-lt dv-lt dz-lt el-lt en-lt en_AU-lt en_CA-lt en_GB-lt en_US-lt en_ZA-lt eo-lt es-lt es_AR-lt es_CL-lt es_CO-lt es_CR-lt es_DO-lt es_EC-lt es_ES-lt es_GT-lt es_HN-lt es_MX-lt es_NI-lt es_PA-lt es_PE-lt es_PR-lt es_SV-lt es_UY-lt es_VE-lt et-lt eu-lt fa-lt fa_IR-lt fi-lt fo-lt foo-lt fr-lt fur-lt fy-lt ga-lt gd-lt gl-lt gn-lt gr-lt gu-lt gv-lt ha-lt he-lt hi-lt hr-lt hu-lt hy-lt ia-lt id-lt ig-lt io-lt is-lt it-lt it_IT-lt ja-lt jbo-lt ka-lt kg-lt kk-lt km-lt kn-lt ko-lt kr-lt ks-lt ku-lt ky-lt la-lt lg-lt li-lt lo-lt af-lv am-lv an-lv ang-lv ar-lv ar_TN-lv ara-lv as-lv ast-lv az-lv az_IR-lv bal-lv be-lv bem-lv bg-lv bg_BG-lv bn-lv bn_IN-lv bo-lv br-lv brx-lv bs-lv ca-lv cat-lv crh-lv cs-lv csb-lv cy-lv da-lv da_DK-lv de-lv dv-lv dz-lv el-lv en-lv en_AU-lv en_CA-lv en_GB-lv en_US-lv en_ZA-lv eo-lv es-lv es_AR-lv es_CL-lv es_CO-lv es_CR-lv es_DO-lv es_EC-lv es_ES-lv es_GT-lv es_HN-lv es_MX-lv es_NI-lv es_PA-lv es_PE-lv es_PR-lv es_SV-lv es_UY-lv es_VE-lv et-lv eu-lv fa-lv fa_IR-lv fi-lv fo-lv foo-lv fr-lv fur-lv fy-lv ga-lv gd-lv gl-lv gn-lv gr-lv gu-lv gv-lv ha-lv he-lv hi-lv hr-lv hu-lv hy-lv ia-lv id-lv ig-lv io-lv is-lv it-lv it_IT-lv ja-lv jbo-lv ka-lv kg-lv kk-lv km-lv kn-lv ko-lv kr-lv ks-lv ku-lv ky-lv la-lv lg-lv li-lv lo-lv lt-lv af-mai am-mai an-mai ang-mai ar-mai as-mai ast-mai az-mai az_IR-mai bal-mai be-mai bem-mai bg-mai bn-mai bn_IN-mai bo-mai br-mai brx-mai bs-mai ca-mai crh-mai cs-mai csb-mai cy-mai da-mai de-mai dv-mai dz-mai el-mai en-mai en_AU-mai en_CA-mai en_GB-mai en_US-mai eo-mai es-mai es_AR-mai es_CL-mai es_CO-mai es_CR-mai es_DO-mai es_EC-mai es_ES-mai es_GT-mai es_HN-mai es_MX-mai es_NI-mai es_PA-mai es_PE-mai es_PR-mai es_SV-mai es_UY-mai es_VE-mai et-mai eu-mai fa-mai fi-mai fr-mai fur-mai fy-mai ga-mai gd-mai gl-mai gn-mai gu-mai gv-mai ha-mai he-mai hi-mai hr-mai hu-mai hy-mai ia-mai id-mai ig-mai io-mai is-mai it-mai ja-mai ka-mai kg-mai kk-mai km-mai kn-mai ko-mai ks-mai ku-mai ky-mai la-mai lg-mai li-mai lo-mai lt-mai lv-mai af-mg am-mg an-mg ang-mg ar-mg as-mg ast-mg az-mg be-mg bem-mg bg-mg bn-mg bn_IN-mg bo-mg br-mg brx-mg bs-mg ca-mg crh-mg cs-mg csb-mg cy-mg da-mg de-mg dv-mg dz-mg el-mg en-mg en_CA-mg en_GB-mg en_US-mg eo-mg es-mg es_AR-mg es_CL-mg es_CO-mg es_CR-mg es_DO-mg es_EC-mg es_ES-mg es_GT-mg es_HN-mg es_MX-mg es_NI-mg es_PA-mg es_PE-mg es_PR-mg es_SV-mg es_UY-mg es_VE-mg et-mg eu-mg fa-mg fi-mg fr-mg fur-mg fy-mg ga-mg gd-mg gl-mg gn-mg gu-mg gv-mg ha-mg he-mg hi-mg hr-mg hu-mg hy-mg ia-mg id-mg ig-mg io-mg is-mg it-mg ja-mg ka-mg kg-mg kk-mg km-mg kn-mg ko-mg ks-mg ku-mg ky-mg la-mg lg-mg li-mg lo-mg lt-mg lv-mg mai-mg af-mi am-mi an-mi ang-mi ar-mi as-mi ast-mi az-mi az_IR-mi be-mi bg-mi bn-mi bn_IN-mi bo-mi br-mi bs-mi ca-mi crh-mi cs-mi csb-mi cy-mi da-mi de-mi dz-mi el-mi en-mi en_CA-mi en_GB-mi eo-mi es-mi et-mi eu-mi fa-mi fi-mi fr-mi fur-mi fy-mi ga-mi gd-mi gl-mi gu-mi gv-mi ha-mi he-mi hi-mi hr-mi hu-mi hy-mi ia-mi id-mi ig-mi io-mi is-mi it-mi ja-mi ka-mi kg-mi kk-mi km-mi kn-mi ko-mi ku-mi ky-mi la-mi lg-mi li-mi lo-mi lt-mi lv-mi mai-mi mg-mi af-mk am-mk an-mk ang-mk ar-mk ar_TN-mk as-mk ast-mk az-mk az_IR-mk bal-mk be-mk bem-mk bg-mk bn-mk bn_IN-mk bo-mk br-mk brx-mk bs-mk ca-mk crh-mk cs-mk csb-mk cy-mk da-mk de-mk dv-mk dz-mk el-mk en-mk en_AU-mk en_CA-mk en_GB-mk en_US-mk en_ZA-mk eo-mk es-mk es_AR-mk es_CL-mk es_CO-mk es_CR-mk es_DO-mk es_EC-mk es_ES-mk es_GT-mk es_HN-mk es_MX-mk es_NI-mk es_PA-mk es_PE-mk es_PR-mk es_SV-mk es_UY-mk es_VE-mk et-mk eu-mk fa-mk fi-mk fr-mk fur-mk fy-mk ga-mk gd-mk gl-mk gn-mk gu-mk gv-mk ha-mk he-mk hi-mk hr-mk hu-mk hy-mk ia-mk id-mk ig-mk io-mk is-mk it-mk ja-mk jbo-mk ka-mk kg-mk kk-mk km-mk kn-mk ko-mk ks-mk ku-mk ky-mk la-mk lg-mk li-mk lo-mk lt-mk lv-mk mai-mk mg-mk mi-mk af-ml am-ml an-ml ang-ml ar-ml ar_TN-ml ara-ml as-ml ast-ml az-ml az_IR-ml bal-ml be-ml bem-ml bg-ml bg_BG-ml bn-ml bn_IN-ml bo-ml br-ml brx-ml bs-ml ca-ml crh-ml cs-ml csb-ml cy-ml da-ml da_DK-ml de-ml de_CH-ml dv-ml dz-ml el-ml en-ml en_AU-ml en_CA-ml en_GB-ml en_US-ml eo-ml es-ml es_AR-ml es_CL-ml es_CO-ml es_CR-ml es_DO-ml es_EC-ml es_ES-ml es_GT-ml es_HN-ml es_MX-ml es_NI-ml es_PA-ml es_PE-ml es_PR-ml es_SV-ml es_UY-ml es_VE-ml et-ml eu-ml fa-ml fa_IR-ml fi-ml fo-ml foo-ml fr-ml fur-ml fy-ml ga-ml gd-ml gl-ml gn-ml gr-ml gu-ml gv-ml ha-ml he-ml hi-ml hr-ml hu-ml hy-ml ia-ml id-ml ig-ml io-ml is-ml it-ml it_IT-ml ja-ml ka-ml kg-ml kk-ml km-ml kn-ml ko-ml kr-ml ks-ml ku-ml ky-ml la-ml lg-ml li-ml lo-ml lt-ml lv-ml mai-ml mg-ml mi-ml mk-ml af-mn am-mn an-mn ang-mn ar-mn as-mn ast-mn az-mn az_IR-mn bal-mn be-mn bem-mn bg-mn bn-mn bn_IN-mn bo-mn br-mn brx-mn bs-mn ca-mn crh-mn cs-mn csb-mn cy-mn da-mn de-mn dv-mn dz-mn el-mn en-mn en_AU-mn en_CA-mn en_GB-mn en_US-mn eo-mn es-mn es_AR-mn es_CL-mn es_CO-mn es_CR-mn es_DO-mn es_EC-mn es_ES-mn es_GT-mn es_HN-mn es_MX-mn es_NI-mn es_PA-mn es_PE-mn es_PR-mn es_SV-mn es_UY-mn es_VE-mn et-mn eu-mn fa-mn fi-mn fr-mn fur-mn fy-mn ga-mn gd-mn gl-mn gn-mn gu-mn gv-mn ha-mn he-mn hi-mn hr-mn hu-mn hy-mn ia-mn id-mn ig-mn io-mn is-mn it-mn ja-mn ka-mn kg-mn kk-mn km-mn kn-mn ko-mn ks-mn ku-mn ky-mn la-mn lg-mn li-mn lo-mn lt-mn lv-mn mai-mn mg-mn mi-mn mk-mn ml-mn af-mr am-mr an-mr ang-mr ar-mr ar_TN-mr ara-mr as-mr ast-mr az-mr az_IR-mr bal-mr be-mr bem-mr bg-mr bg_BG-mr bn-mr bn_IN-mr bo-mr br-mr brx-mr bs-mr ca-mr crh-mr cs-mr csb-mr cy-mr da-mr da_DK-mr de-mr de_CH-mr dv-mr dz-mr el-mr en-mr en_AU-mr en_CA-mr en_GB-mr en_US-mr eo-mr es-mr es_AR-mr es_CL-mr es_CO-mr es_CR-mr es_DO-mr es_EC-mr es_ES-mr es_GT-mr es_HN-mr es_MX-mr es_NI-mr es_PA-mr es_PE-mr es_PR-mr es_SV-mr es_UY-mr es_VE-mr et-mr eu-mr fa-mr fa_IR-mr fi-mr fo-mr foo-mr fr-mr fur-mr fy-mr ga-mr gd-mr gl-mr gn-mr gr-mr gu-mr gv-mr ha-mr he-mr hi-mr hr-mr hu-mr hy-mr ia-mr id-mr ig-mr io-mr is-mr it-mr it_IT-mr ja-mr jbo-mr ka-mr kg-mr kk-mr km-mr kn-mr ko-mr kr-mr ks-mr ku-mr ky-mr la-mr lg-mr li-mr lo-mr lt-mr lv-mr mai-mr mg-mr mi-mr mk-mr ml-mr mn-mr af-ms am-ms an-ms ang-ms ar-ms ar_TN-ms ara-ms as-ms ast-ms az-ms az_IR-ms bal-ms be-ms bem-ms bg-ms bg_BG-ms bn-ms bn_IN-ms bo-ms br-ms brx-ms bs-ms ca-ms crh-ms cs-ms csb-ms cy-ms da-ms da_DK-ms de-ms dv-ms dz-ms el-ms en-ms en_AU-ms en_CA-ms en_GB-ms en_NZ-ms en_US-ms en_ZA-ms eo-ms es-ms es_AR-ms es_CL-ms es_CO-ms es_CR-ms es_DO-ms es_EC-ms es_ES-ms es_GT-ms es_HN-ms es_MX-ms es_NI-ms es_PA-ms es_PE-ms es_PR-ms es_SV-ms es_UY-ms es_VE-ms et-ms eu-ms fa-ms fa_IR-ms fi-ms fo-ms foo-ms fr-ms fur-ms fy-ms ga-ms gd-ms gl-ms gn-ms gu-ms gv-ms ha-ms he-ms hi-ms hr-ms hu-ms hy-ms ia-ms id-ms ig-ms io-ms is-ms it-ms it_IT-ms ja-ms jbo-ms ka-ms kg-ms kk-ms km-ms kn-ms ko-ms ks-ms ku-ms ky-ms la-ms lg-ms li-ms lo-ms lt-ms lv-ms mai-ms mg-ms mi-ms mk-ms ml-ms mn-ms mr-ms af-mt az-mt bg-mt ca-mt cs-mt da-mt de-mt el-mt en-mt en_GB-mt eo-mt es-mt eu-mt fi-mt fr-mt gl-mt hr-mt hu-mt id-mt it-mt ja-mt ky-mt lt-mt lv-mt ms-mt af-mus ar-mus as-mus bn-mus bn_IN-mus bs-mus da-mus el-mus en_AU-mus en_GB-mus es-mus fy-mus he-mus hr-mus ka-mus mai-mus ml-mus mn-mus mr-mus ms-mus af-my am-my an-my ang-my ar-my as-my ast-my az-my az_IR-my be-my bg-my bn-my bn_IN-my bo-my br-my bs-my ca-my crh-my cs-my csb-my cy-my da-my de-my dz-my el-my en-my en_CA-my en_GB-my en_US-my eo-my es-my et-my eu-my fa-my fi-my fr-my fur-my fy-my ga-my gd-my gl-my gu-my gv-my ha-my he-my hi-my hr-my hu-my hy-my ia-my id-my ig-my io-my is-my it-my ja-my ka-my kg-my kk-my km-my kn-my ko-my ks-my ku-my ky-my la-my lg-my li-my lt-my lv-my mai-my mg-my mi-my mk-my ml-my mn-my mr-my ms-my af-nb am-nb an-nb ang-nb ar-nb ar_TN-nb ara-nb as-nb ast-nb az-nb az_IR-nb bal-nb be-nb bem-nb bg-nb bg_BG-nb bn-nb bn_IN-nb bo-nb br-nb brx-nb bs-nb ca-nb cat-nb crh-nb cs-nb csb-nb cy-nb da-nb da_DK-nb de-nb dv-nb dz-nb el-nb en-nb en_AU-nb en_CA-nb en_GB-nb en_US-nb en_ZA-nb eo-nb es-nb es_AR-nb es_CL-nb es_CO-nb es_CR-nb es_DO-nb es_EC-nb es_ES-nb es_GT-nb es_HN-nb es_MX-nb es_NI-nb es_PA-nb es_PE-nb es_PR-nb es_SV-nb es_UY-nb es_VE-nb et-nb eu-nb fa-nb fa_IR-nb fi-nb fo-nb foo-nb fr-nb fur-nb fy-nb ga-nb gd-nb gl-nb gn-nb gr-nb gu-nb gv-nb ha-nb he-nb hi-nb hr-nb hu-nb hy-nb ia-nb id-nb ig-nb io-nb is-nb it-nb it_IT-nb ja-nb jbo-nb ka-nb kg-nb kk-nb km-nb kn-nb ko-nb kr-nb ks-nb ku-nb ky-nb la-nb lg-nb li-nb lo-nb lt-nb lv-nb mai-nb mg-nb mi-nb mk-nb ml-nb mn-nb mr-nb ms-nb mt-nb my-nb as-nb_NO bg-nb_NO bg_BG-nb_NO bn_IN-nb_NO ca-nb_NO cs-nb_NO da-nb_NO da_DK-nb_NO de-nb_NO el-nb_NO en-nb_NO en_GB-nb_NO eo-nb_NO es-nb_NO eu-nb_NO fa-nb_NO fi-nb_NO fr-nb_NO ga-nb_NO gl-nb_NO gu-nb_NO he-nb_NO hi-nb_NO hr-nb_NO hu-nb_NO ia-nb_NO id-nb_NO it-nb_NO it_IT-nb_NO ja-nb_NO ka-nb_NO kk-nb_NO kn-nb_NO ko-nb_NO lt-nb_NO lv-nb_NO ml-nb_NO mr-nb_NO ms-nb_NO nb-nb_NO af-nds am-nds an-nds ang-nds ar-nds as-nds ast-nds az-nds az_IR-nds bal-nds be-nds bem-nds bg-nds bn-nds bn_IN-nds bo-nds br-nds brx-nds bs-nds ca-nds crh-nds cs-nds csb-nds cy-nds da-nds de-nds dv-nds dz-nds el-nds en-nds en_AU-nds en_CA-nds en_GB-nds en_US-nds eo-nds es-nds es_AR-nds es_CL-nds es_CO-nds es_CR-nds es_DO-nds es_EC-nds es_ES-nds es_GT-nds es_HN-nds es_MX-nds es_NI-nds es_PA-nds es_PE-nds es_PR-nds es_SV-nds es_UY-nds es_VE-nds et-nds eu-nds fa-nds fi-nds fr-nds fur-nds fy-nds ga-nds gd-nds gl-nds gn-nds gu-nds gv-nds ha-nds he-nds hi-nds hr-nds hu-nds hy-nds ia-nds id-nds ig-nds io-nds is-nds it-nds ja-nds ka-nds kg-nds kk-nds km-nds kn-nds ko-nds ks-nds ku-nds ky-nds la-nds lg-nds li-nds lo-nds lt-nds lv-nds mai-nds mg-nds mi-nds mk-nds ml-nds mn-nds mr-nds ms-nds my-nds nb-nds af-ne am-ne an-ne ang-ne ar-ne ar_TN-ne as-ne ast-ne az-ne az_IR-ne bal-ne be-ne bg-ne bn-ne bn_IN-ne bo-ne br-ne bs-ne ca-ne crh-ne cs-ne csb-ne cy-ne da-ne de-ne dv-ne dz-ne el-ne en-ne en_AU-ne en_CA-ne en_GB-ne en_US-ne en_ZA-ne eo-ne es-ne es_AR-ne es_CL-ne es_CO-ne es_CR-ne es_DO-ne es_EC-ne es_ES-ne es_GT-ne es_HN-ne es_MX-ne es_NI-ne es_PA-ne es_PE-ne es_PR-ne es_SV-ne es_UY-ne es_VE-ne et-ne eu-ne fa-ne fi-ne fr-ne fur-ne fy-ne ga-ne gd-ne gl-ne gn-ne gu-ne gv-ne ha-ne he-ne hi-ne hr-ne hu-ne hy-ne ia-ne id-ne ig-ne io-ne is-ne it-ne ja-ne ka-ne kg-ne kk-ne km-ne kn-ne ko-ne ks-ne ku-ne ky-ne la-ne lg-ne li-ne lo-ne lt-ne lv-ne mai-ne mg-ne mi-ne mk-ne ml-ne mn-ne mr-ne ms-ne my-ne nb-ne nds-ne af-nhn am-nhn an-nhn ar-nhn as-nhn ast-nhn az-nhn be-nhn bg-nhn bn-nhn bn_IN-nhn br-nhn bs-nhn ca-nhn crh-nhn cs-nhn csb-nhn cy-nhn da-nhn de-nhn dz-nhn el-nhn en-nhn en_CA-nhn en_GB-nhn eo-nhn es-nhn et-nhn eu-nhn fa-nhn fi-nhn fr-nhn fur-nhn fy-nhn ga-nhn gd-nhn gl-nhn gu-nhn he-nhn hi-nhn hr-nhn hu-nhn id-nhn is-nhn it-nhn ja-nhn ka-nhn kk-nhn km-nhn kn-nhn ko-nhn ku-nhn li-nhn lt-nhn lv-nhn mai-nhn mg-nhn mk-nhn ml-nhn mn-nhn mr-nhn ms-nhn nb-nhn nds-nhn ne-nhn af-nl am-nl an-nl ang-nl ar-nl ar_TN-nl ara-nl as-nl ast-nl az-nl az_IR-nl bal-nl be-nl bem-nl bg-nl bg_BG-nl bn-nl bn_IN-nl bo-nl br-nl brx-nl bs-nl ca-nl crh-nl cs-nl csb-nl cy-nl da-nl da_DK-nl de-nl de_CH-nl dv-nl dz-nl el-nl en-nl en_AU-nl en_CA-nl en_GB-nl en_US-nl en_ZA-nl eo-nl es-nl es_AR-nl es_CL-nl es_CO-nl es_CR-nl es_DO-nl es_EC-nl es_ES-nl es_GT-nl es_HN-nl es_MX-nl es_NI-nl es_PA-nl es_PE-nl es_PR-nl es_SV-nl es_UY-nl es_VE-nl et-nl eu-nl fa-nl fa_IR-nl fi-nl fo-nl foo-nl fr-nl fur-nl fy-nl ga-nl gd-nl gl-nl gn-nl gr-nl gu-nl gv-nl ha-nl he-nl hi-nl hr-nl hu-nl hy-nl ia-nl id-nl ig-nl io-nl is-nl it-nl it_IT-nl ja-nl ka-nl kg-nl kk-nl km-nl kn-nl ko-nl kr-nl ks-nl ku-nl ky-nl la-nl lg-nl li-nl lo-nl lt-nl lv-nl mai-nl mg-nl mi-nl mk-nl ml-nl mn-nl mr-nl ms-nl mt-nl my-nl nb-nl nb_NO-nl nds-nl ne-nl nhn-nl af-nn am-nn an-nn ang-nn ar-nn ar_TN-nn ara-nn as-nn ast-nn az-nn az_IR-nn bal-nn be-nn bem-nn bg-nn bg_BG-nn bn-nn bn_IN-nn bo-nn br-nn brx-nn bs-nn ca-nn crh-nn cs-nn csb-nn cy-nn da-nn de-nn dv-nn dz-nn el-nn en-nn en_AU-nn en_CA-nn en_GB-nn en_US-nn en_ZA-nn eo-nn es-nn es_AR-nn es_CL-nn es_CO-nn es_CR-nn es_DO-nn es_EC-nn es_ES-nn es_GT-nn es_HN-nn es_MX-nn es_NI-nn es_PA-nn es_PE-nn es_PR-nn es_SV-nn es_UY-nn es_VE-nn et-nn eu-nn fa-nn fa_IR-nn fi-nn fo-nn foo-nn fr-nn fur-nn fy-nn ga-nn gd-nn gl-nn gn-nn gu-nn gv-nn ha-nn he-nn hi-nn hr-nn hu-nn hy-nn ia-nn id-nn ig-nn io-nn is-nn it-nn it_IT-nn ja-nn ka-nn kg-nn kk-nn km-nn kn-nn ko-nn ks-nn ku-nn ky-nn la-nn lg-nn li-nn lo-nn lt-nn lv-nn mai-nn mg-nn mi-nn mk-nn ml-nn mn-nn mr-nn ms-nn my-nn nb-nn nds-nn ne-nn nhn-nn nl-nn as-nn_NO bg-nn_NO bg_BG-nn_NO bn_IN-nn_NO ca-nn_NO cs-nn_NO da-nn_NO da_DK-nn_NO de-nn_NO el-nn_NO en-nn_NO en_GB-nn_NO eo-nn_NO es-nn_NO eu-nn_NO fa-nn_NO fi-nn_NO fr-nn_NO ga-nn_NO gl-nn_NO gu-nn_NO he-nn_NO hi-nn_NO hr-nn_NO hu-nn_NO ia-nn_NO id-nn_NO it-nn_NO it_IT-nn_NO ja-nn_NO ka-nn_NO kk-nn_NO kn-nn_NO ko-nn_NO lt-nn_NO lv-nn_NO ml-nn_NO mr-nn_NO ms-nn_NO nb-nn_NO nb_NO-nn_NO nl-nn_NO af-no am-no ang-no ar-no as-no ast-no az-no az_IR-no be-no bg-no bn-no bn_IN-no br-no bs-no ca-no crh-no cs-no cy-no da-no de-no dz-no el-no en-no en_CA-no en_GB-no eo-no es-no et-no eu-no fa-no fi-no fr-no ga-no gl-no gu-no he-no hi-no hr-no hu-no hy-no ia-no id-no is-no it-no ja-no ka-no km-no kn-no ko-no ku-no ky-no li-no lt-no lv-no mai-no mi-no mk-no ml-no mn-no mr-no ms-no my-no nb-no nds-no ne-no nl-no nn-no as-no_nb bg-no_nb bn_IN-no_nb ca-no_nb cs-no_nb da-no_nb de-no_nb el-no_nb en-no_nb en_GB-no_nb eo-no_nb es-no_nb eu-no_nb fi-no_nb fr-no_nb gl-no_nb gu-no_nb he-no_nb hi-no_nb hu-no_nb id-no_nb it-no_nb it_IT-no_nb ja-no_nb kn-no_nb ko-no_nb lt-no_nb lv-no_nb ml-no_nb mr-no_nb ms-no_nb nb-no_nb nl-no_nb af-nr ar-nr az-nr be-nr bg-nr bs-nr ca-nr cs-nr cy-nr da-nr de-nr dz-nr el-nr en-nr en_CA-nr en_GB-nr en_ZA-nr es-nr et-nr eu-nr fi-nr fr-nr ga-nr gl-nr gu-nr he-nr hi-nr hr-nr hu-nr is-nr it-nr ja-nr ka-nr km-nr ko-nr lt-nr lv-nr mk-nr ms-nr nb-nr ne-nr nl-nr nn-nr af-nso am-nso an-nso ang-nso ar-nso as-nso ast-nso az-nso az_IR-nso be-nso bg-nso bn-nso bn_IN-nso bo-nso br-nso bs-nso ca-nso crh-nso cs-nso csb-nso cy-nso da-nso de-nso dz-nso el-nso en-nso en_CA-nso en_GB-nso en_ZA-nso eo-nso es-nso et-nso eu-nso fa-nso fi-nso fr-nso fur-nso fy-nso ga-nso gd-nso gl-nso gu-nso gv-nso ha-nso he-nso hi-nso hr-nso hu-nso hy-nso ia-nso id-nso ig-nso io-nso is-nso it-nso ja-nso ka-nso kg-nso kk-nso km-nso kn-nso ko-nso ks-nso ku-nso ky-nso la-nso lg-nso li-nso lo-nso lt-nso lv-nso mai-nso mg-nso mi-nso mk-nso ml-nso mn-nso mr-nso ms-nso my-nso nb-nso nds-nso ne-nso nl-nso nn-nso no-nso nr-nso af-oc am-oc an-oc ang-oc ar-oc ar_TN-oc ara-oc as-oc ast-oc az-oc az_IR-oc bal-oc be-oc bem-oc bg-oc bg_BG-oc bn-oc bn_IN-oc bo-oc br-oc brx-oc bs-oc ca-oc crh-oc cs-oc csb-oc cy-oc da-oc de-oc dv-oc dz-oc el-oc en-oc en_AU-oc en_CA-oc en_GB-oc en_US-oc en_ZA-oc eo-oc es-oc es_AR-oc es_CL-oc es_CO-oc es_CR-oc es_DO-oc es_EC-oc es_ES-oc es_GT-oc es_HN-oc es_MX-oc es_NI-oc es_PA-oc es_PE-oc es_PR-oc es_SV-oc es_UY-oc es_VE-oc et-oc eu-oc fa-oc fa_IR-oc fi-oc fo-oc fr-oc fur-oc fy-oc ga-oc gd-oc gl-oc gn-oc gu-oc gv-oc ha-oc he-oc hi-oc hr-oc hu-oc hy-oc ia-oc id-oc ig-oc io-oc is-oc it-oc ja-oc jbo-oc ka-oc kg-oc kk-oc km-oc kn-oc ko-oc ks-oc ku-oc ky-oc la-oc lg-oc li-oc lo-oc lt-oc lv-oc mai-oc mg-oc mi-oc mk-oc ml-oc mn-oc mr-oc ms-oc mus-oc my-oc nb-oc nds-oc ne-oc nhn-oc nl-oc nn-oc no-oc nr-oc nso-oc af-or am-or an-or ang-or ar-or ara-or as-or ast-or az-or az_IR-or bal-or be-or bem-or bg-or bg_BG-or bn-or bn_IN-or bo-or br-or brx-or bs-or ca-or crh-or cs-or csb-or cy-or da-or da_DK-or de-or de_CH-or dv-or dz-or el-or en-or en_AU-or en_CA-or en_GB-or en_US-or eo-or es-or es_AR-or es_CL-or es_CO-or es_CR-or es_DO-or es_EC-or es_ES-or es_GT-or es_HN-or es_MX-or es_NI-or es_PA-or es_PE-or es_PR-or es_SV-or es_UY-or es_VE-or et-or eu-or fa-or fa_IR-or fi-or fo-or foo-or fr-or fur-or fy-or ga-or gd-or gl-or gn-or gr-or gu-or gv-or ha-or he-or hi-or hr-or hu-or hy-or ia-or id-or ig-or io-or is-or it-or it_IT-or ja-or jbo-or ka-or kg-or kk-or km-or kn-or ko-or kr-or ks-or ku-or ky-or la-or lg-or li-or lo-or lt-or lv-or mai-or mg-or mi-or mk-or ml-or mn-or mr-or ms-or mt-or mus-or my-or nb-or nb_NO-or nds-or ne-or nhn-or nl-or nn-or nn_NO-or no-or no_nb-or nso-or oc-or am-os ar-os az-os be-os bg-os ca-os cs-os da-os de-os dz-os el-os en-os en_CA-os en_GB-os eo-os es-os eu-os fi-os fr-os gl-os gu-os he-os hr-os hu-os id-os it-os ja-os ka-os lv-os mk-os ml-os mn-os ms-os nb-os nl-os nn-os oc-os af-pa am-pa an-pa ang-pa ar-pa ar_TN-pa ara-pa as-pa ast-pa az-pa az_IR-pa bal-pa be-pa bem-pa bg-pa bg_BG-pa bn-pa bn_IN-pa bo-pa br-pa brx-pa bs-pa ca-pa cat-pa crh-pa cs-pa csb-pa cy-pa da-pa da_DK-pa de-pa de_CH-pa dv-pa dz-pa el-pa en-pa en_AU-pa en_CA-pa en_GB-pa en_US-pa en_ZA-pa eo-pa es-pa es_AR-pa es_CL-pa es_CO-pa es_CR-pa es_DO-pa es_EC-pa es_ES-pa es_GT-pa es_HN-pa es_MX-pa es_NI-pa es_PA-pa es_PE-pa es_PR-pa es_SV-pa es_UY-pa es_VE-pa et-pa eu-pa fa-pa fa_IR-pa fi-pa fo-pa foo-pa fr-pa fur-pa fy-pa ga-pa gd-pa gl-pa gn-pa gr-pa gu-pa gv-pa ha-pa he-pa hi-pa hr-pa hu-pa hy-pa ia-pa id-pa ig-pa io-pa is-pa it-pa it_IT-pa ja-pa jbo-pa ka-pa kg-pa kk-pa km-pa kn-pa ko-pa kr-pa ks-pa ku-pa ky-pa la-pa lg-pa li-pa lo-pa lt-pa lv-pa mai-pa mg-pa mi-pa mk-pa ml-pa mn-pa mr-pa ms-pa mus-pa my-pa nb-pa nb_NO-pa nds-pa ne-pa nhn-pa nl-pa nn-pa nn_NO-pa no-pa no_nb-pa nr-pa nso-pa oc-pa or-pa os-pa af-pl am-pl an-pl ang-pl ar-pl ar_TN-pl ara-pl as-pl ast-pl az-pl az_IR-pl bal-pl be-pl bem-pl bg-pl bg_BG-pl bn-pl bn_IN-pl bo-pl br-pl brx-pl bs-pl ca-pl cat-pl crh-pl cs-pl csb-pl cy-pl da-pl da_DK-pl de-pl de_CH-pl dv-pl dz-pl el-pl en-pl en_AU-pl en_CA-pl en_GB-pl en_NZ-pl en_US-pl en_ZA-pl eo-pl es-pl es_AR-pl es_CL-pl es_CO-pl es_CR-pl es_DO-pl es_EC-pl es_ES-pl es_GT-pl es_HN-pl es_MX-pl es_NI-pl es_PA-pl es_PE-pl es_PR-pl es_SV-pl es_UY-pl es_VE-pl et-pl eu-pl fa-pl fa_IR-pl fi-pl fo-pl foo-pl fr-pl fur-pl fy-pl ga-pl gd-pl gl-pl gn-pl gr-pl gu-pl gv-pl ha-pl he-pl hi-pl hr-pl hu-pl hy-pl ia-pl id-pl ig-pl io-pl is-pl it-pl it_IT-pl ja-pl jbo-pl ka-pl kg-pl kk-pl km-pl kn-pl ko-pl kr-pl ks-pl ku-pl ky-pl la-pl lg-pl li-pl lo-pl lt-pl lv-pl mai-pl mg-pl mi-pl mk-pl ml-pl mn-pl mr-pl ms-pl mt-pl my-pl nb-pl nb_NO-pl nds-pl ne-pl nhn-pl nl-pl nn-pl nn_NO-pl no-pl no_nb-pl nr-pl nso-pl oc-pl or-pl os-pl pa-pl af-ps am-ps an-ps ang-ps ar-ps as-ps ast-ps az-ps az_IR-ps bal-ps be-ps bem-ps bg-ps bn-ps bn_IN-ps bo-ps br-ps brx-ps bs-ps ca-ps crh-ps cs-ps csb-ps cy-ps da-ps de-ps dv-ps dz-ps el-ps en-ps en_AU-ps en_CA-ps en_GB-ps en_US-ps en_ZA-ps eo-ps es-ps es_AR-ps es_CL-ps es_CO-ps es_CR-ps es_DO-ps es_EC-ps es_ES-ps es_GT-ps es_HN-ps es_MX-ps es_NI-ps es_PA-ps es_PE-ps es_PR-ps es_SV-ps es_UY-ps es_VE-ps et-ps eu-ps fa-ps fi-ps fr-ps fur-ps fy-ps ga-ps gd-ps gl-ps gn-ps gu-ps gv-ps ha-ps he-ps hi-ps hr-ps hu-ps hy-ps ia-ps id-ps ig-ps io-ps is-ps it-ps ja-ps ka-ps kg-ps kk-ps km-ps kn-ps ko-ps ks-ps ku-ps ky-ps la-ps lg-ps li-ps lo-ps lt-ps lv-ps mai-ps mg-ps mi-ps mk-ps ml-ps mn-ps mr-ps ms-ps my-ps nb-ps nds-ps ne-ps nhn-ps nl-ps nn-ps no-ps nr-ps nso-ps oc-ps or-ps pa-ps pl-ps af-pt am-pt an-pt ang-pt ar-pt ara-pt as-pt ast-pt az-pt az_IR-pt bal-pt be-pt bem-pt bg-pt bg_BG-pt bn-pt bn_IN-pt bo-pt br-pt brx-pt bs-pt ca-pt crh-pt cs-pt csb-pt cy-pt da-pt da_DK-pt de-pt de_CH-pt dv-pt dz-pt el-pt en-pt en_AU-pt en_CA-pt en_GB-pt en_US-pt en_ZA-pt eo-pt es-pt es_AR-pt es_CL-pt es_CO-pt es_CR-pt es_DO-pt es_EC-pt es_ES-pt es_GT-pt es_HN-pt es_MX-pt es_NI-pt es_PA-pt es_PE-pt es_PR-pt es_SV-pt es_UY-pt es_VE-pt et-pt eu-pt fa-pt fa_IR-pt fi-pt fo-pt foo-pt fr-pt fur-pt fy-pt ga-pt gd-pt gl-pt gn-pt gr-pt gu-pt gv-pt ha-pt he-pt hi-pt hr-pt hu-pt hy-pt ia-pt id-pt ig-pt io-pt is-pt it-pt it_IT-pt ja-pt jbo-pt ka-pt kg-pt kk-pt km-pt kn-pt ko-pt kr-pt ks-pt ku-pt ky-pt la-pt lg-pt li-pt lo-pt lt-pt lv-pt mai-pt mg-pt mi-pt mk-pt ml-pt mn-pt mr-pt ms-pt mus-pt my-pt nb-pt nb_NO-pt nds-pt ne-pt nhn-pt nl-pt nn-pt nn_NO-pt no-pt no_nb-pt nr-pt nso-pt oc-pt or-pt os-pt pa-pt pl-pt ps-pt af-pt_BR am-pt_BR an-pt_BR ang-pt_BR ar-pt_BR ar_TN-pt_BR ara-pt_BR as-pt_BR ast-pt_BR az-pt_BR az_IR-pt_BR bal-pt_BR be-pt_BR bem-pt_BR bg-pt_BR bg_BG-pt_BR bn-pt_BR bn_IN-pt_BR bo-pt_BR br-pt_BR brx-pt_BR bs-pt_BR ca-pt_BR cat-pt_BR crh-pt_BR cs-pt_BR csb-pt_BR cy-pt_BR da-pt_BR da_DK-pt_BR de-pt_BR de_CH-pt_BR dv-pt_BR dz-pt_BR el-pt_BR en-pt_BR en_AU-pt_BR en_CA-pt_BR en_GB-pt_BR en_NZ-pt_BR en_US-pt_BR en_ZA-pt_BR eo-pt_BR es-pt_BR es_AR-pt_BR es_CL-pt_BR es_CO-pt_BR es_CR-pt_BR es_DO-pt_BR es_EC-pt_BR es_ES-pt_BR es_GT-pt_BR es_HN-pt_BR es_MX-pt_BR es_NI-pt_BR es_PA-pt_BR es_PE-pt_BR es_PR-pt_BR es_SV-pt_BR es_UY-pt_BR es_VE-pt_BR et-pt_BR eu-pt_BR fa-pt_BR fa_IR-pt_BR fi-pt_BR fo-pt_BR foo-pt_BR fr-pt_BR fur-pt_BR fy-pt_BR ga-pt_BR gd-pt_BR gl-pt_BR gn-pt_BR gr-pt_BR gu-pt_BR gv-pt_BR ha-pt_BR he-pt_BR hi-pt_BR hr-pt_BR hu-pt_BR hy-pt_BR ia-pt_BR id-pt_BR ig-pt_BR io-pt_BR is-pt_BR it-pt_BR it_IT-pt_BR ja-pt_BR jbo-pt_BR ka-pt_BR kg-pt_BR kk-pt_BR km-pt_BR kn-pt_BR ko-pt_BR kr-pt_BR ks-pt_BR ku-pt_BR ky-pt_BR la-pt_BR lg-pt_BR li-pt_BR lo-pt_BR lt-pt_BR lv-pt_BR mai-pt_BR mg-pt_BR mi-pt_BR mk-pt_BR ml-pt_BR mn-pt_BR mr-pt_BR ms-pt_BR mt-pt_BR my-pt_BR nb-pt_BR nb_NO-pt_BR nds-pt_BR ne-pt_BR nhn-pt_BR nl-pt_BR nn-pt_BR nn_NO-pt_BR no-pt_BR no_nb-pt_BR nr-pt_BR nso-pt_BR oc-pt_BR or-pt_BR os-pt_BR pa-pt_BR pl-pt_BR ps-pt_BR pt-pt_BR as-pt_PT bg-pt_PT bg_BG-pt_PT bn_IN-pt_PT ca-pt_PT cs-pt_PT da-pt_PT da_DK-pt_PT de-pt_PT el-pt_PT en-pt_PT en_GB-pt_PT eo-pt_PT es-pt_PT eu-pt_PT fa-pt_PT fi-pt_PT fr-pt_PT ga-pt_PT gl-pt_PT gu-pt_PT he-pt_PT hi-pt_PT hr-pt_PT hu-pt_PT ia-pt_PT id-pt_PT it-pt_PT it_IT-pt_PT ja-pt_PT ka-pt_PT kk-pt_PT kn-pt_PT ko-pt_PT lt-pt_PT lv-pt_PT ml-pt_PT mr-pt_PT ms-pt_PT nb-pt_PT nb_NO-pt_PT nl-pt_PT nn_NO-pt_PT or-pt_PT pa-pt_PT pl-pt_PT pt-pt_PT pt_BR-pt_PT af-quz an-quz ar-quz as-quz ast-quz be-quz bg-quz bn-quz bn_IN-quz ca-quz cs-quz da-quz de-quz el-quz en-quz en_GB-quz eo-quz es-quz et-quz eu-quz fa-quz fi-quz fr-quz fur-quz gl-quz gu-quz he-quz hi-quz hu-quz id-quz it-quz ja-quz km-quz kn-quz ko-quz lt-quz lv-quz ml-quz mr-quz ms-quz nb-quz nl-quz nn-quz or-quz pa-quz pl-quz pt-quz pt_BR-quz af-ro am-ro an-ro ang-ro ar-ro ar_TN-ro ara-ro as-ro ast-ro az-ro az_IR-ro bal-ro be-ro bem-ro bg-ro bg_BG-ro bn-ro bn_IN-ro bo-ro br-ro brx-ro bs-ro ca-ro cat-ro crh-ro cs-ro csb-ro cy-ro da-ro da_DK-ro de-ro dv-ro dz-ro el-ro en-ro en_AU-ro en_CA-ro en_GB-ro en_NZ-ro en_US-ro en_ZA-ro eo-ro es-ro es_AR-ro es_CL-ro es_CO-ro es_CR-ro es_DO-ro es_EC-ro es_ES-ro es_GT-ro es_HN-ro es_MX-ro es_NI-ro es_PA-ro es_PE-ro es_PR-ro es_SV-ro es_UY-ro es_VE-ro et-ro eu-ro fa-ro fa_IR-ro fi-ro fo-ro foo-ro fr-ro fur-ro fy-ro ga-ro gd-ro gl-ro gn-ro gr-ro gu-ro gv-ro ha-ro he-ro hi-ro hr-ro hu-ro hy-ro ia-ro id-ro ig-ro io-ro is-ro it-ro it_IT-ro ja-ro jbo-ro ka-ro kg-ro kk-ro km-ro kn-ro ko-ro kr-ro ks-ro ku-ro ky-ro la-ro lg-ro li-ro lo-ro lt-ro lv-ro mai-ro mg-ro mi-ro mk-ro ml-ro mn-ro mr-ro ms-ro mt-ro mus-ro my-ro nb-ro nb_NO-ro nds-ro ne-ro nhn-ro nl-ro nn-ro nn_NO-ro no-ro no_nb-ro nr-ro nso-ro oc-ro or-ro os-ro pa-ro pl-ro ps-ro pt-ro pt_BR-ro pt_PT-ro quz-ro af-ru am-ru an-ru ang-ru ar-ru ar_TN-ru ara-ru as-ru ast-ru az-ru az_IR-ru bal-ru be-ru bem-ru bg-ru bg_BG-ru bn-ru bn_IN-ru bo-ru br-ru brx-ru bs-ru ca-ru cat-ru crh-ru cs-ru csb-ru cy-ru da-ru da_DK-ru de-ru de_CH-ru dv-ru dz-ru el-ru en-ru en_AU-ru en_CA-ru en_GB-ru en_NZ-ru en_US-ru en_ZA-ru eo-ru es-ru es_AR-ru es_CL-ru es_CO-ru es_CR-ru es_DO-ru es_EC-ru es_ES-ru es_GT-ru es_HN-ru es_MX-ru es_NI-ru es_PA-ru es_PE-ru es_PR-ru es_SV-ru es_UY-ru es_VE-ru et-ru eu-ru fa-ru fa_IR-ru fi-ru fo-ru foo-ru fr-ru fur-ru fy-ru ga-ru gd-ru gl-ru gn-ru gr-ru gu-ru gv-ru ha-ru he-ru hi-ru hr-ru hu-ru hy-ru ia-ru id-ru ig-ru io-ru is-ru it-ru it_IT-ru ja-ru jbo-ru ka-ru kg-ru kk-ru km-ru kn-ru ko-ru kr-ru ks-ru ku-ru ky-ru la-ru lg-ru li-ru lo-ru lt-ru lv-ru mai-ru mg-ru mi-ru mk-ru ml-ru mn-ru mr-ru ms-ru mt-ru my-ru nb-ru nb_NO-ru nds-ru ne-ru nhn-ru nl-ru nn-ru nn_NO-ru no-ru no_nb-ru nr-ru nso-ru oc-ru or-ru os-ru pa-ru pl-ru ps-ru pt-ru pt_BR-ru pt_PT-ru quz-ru ro-ru af-rw am-rw an-rw ang-rw ar-rw ar_TN-rw ara-rw as-rw ast-rw az-rw az_IR-rw be-rw bg-rw bg_BG-rw bn-rw bn_IN-rw bo-rw br-rw bs-rw ca-rw crh-rw cs-rw csb-rw cy-rw da-rw de-rw dv-rw dz-rw el-rw en-rw en_AU-rw en_CA-rw en_GB-rw en_US-rw en_ZA-rw eo-rw es-rw es_AR-rw es_CL-rw es_CO-rw es_CR-rw es_DO-rw es_EC-rw es_ES-rw es_GT-rw es_HN-rw es_MX-rw es_NI-rw es_PA-rw es_PE-rw es_PR-rw es_SV-rw es_UY-rw es_VE-rw et-rw eu-rw fa-rw fa_IR-rw fi-rw fo-rw fr-rw fur-rw fy-rw ga-rw gd-rw gl-rw gn-rw gu-rw gv-rw ha-rw he-rw hi-rw hr-rw hu-rw hy-rw ia-rw id-rw ig-rw io-rw is-rw it-rw ja-rw ka-rw kg-rw kk-rw km-rw kn-rw ko-rw ks-rw ku-rw ky-rw la-rw lg-rw li-rw lo-rw lt-rw lv-rw mai-rw mg-rw mi-rw mk-rw ml-rw mn-rw mr-rw ms-rw my-rw nb-rw nds-rw ne-rw nl-rw nn-rw no-rw nr-rw nso-rw oc-rw or-rw os-rw pa-rw pl-rw ps-rw pt-rw pt_BR-rw ro-rw ru-rw af-si am-si an-si ang-si ar-si as-si ast-si az-si az_IR-si bal-si be-si bem-si bg-si bn-si bn_IN-si bo-si br-si brx-si bs-si ca-si crh-si cs-si csb-si cy-si da-si de-si dv-si dz-si el-si en-si en_AU-si en_CA-si en_GB-si en_US-si eo-si es-si es_AR-si es_CL-si es_CO-si es_CR-si es_DO-si es_EC-si es_ES-si es_GT-si es_HN-si es_MX-si es_NI-si es_PA-si es_PE-si es_PR-si es_SV-si es_UY-si es_VE-si et-si eu-si fa-si fi-si fr-si fur-si fy-si ga-si gd-si gl-si gn-si gu-si gv-si ha-si he-si hi-si hr-si hu-si hy-si ia-si id-si ig-si io-si is-si it-si ja-si ka-si kg-si kk-si km-si kn-si ko-si ks-si ku-si ky-si la-si lg-si li-si lo-si lt-si lv-si mai-si mg-si mi-si mk-si ml-si mn-si mr-si ms-si my-si nb-si nds-si ne-si nhn-si nl-si nn-si no-si nso-si oc-si or-si pa-si pl-si ps-si pt-si pt_BR-si ro-si ru-si rw-si af-sk am-sk an-sk ang-sk ar-sk ar_TN-sk ara-sk as-sk ast-sk az-sk az_IR-sk bal-sk be-sk bem-sk bg-sk bg_BG-sk bn-sk bn_IN-sk bo-sk br-sk brx-sk bs-sk ca-sk crh-sk cs-sk csb-sk cy-sk da-sk da_DK-sk de-sk dv-sk dz-sk el-sk en-sk en_AU-sk en_CA-sk en_GB-sk en_US-sk en_ZA-sk eo-sk es-sk es_AR-sk es_CL-sk es_CO-sk es_CR-sk es_DO-sk es_EC-sk es_ES-sk es_GT-sk es_HN-sk es_MX-sk es_NI-sk es_PA-sk es_PE-sk es_PR-sk es_SV-sk es_UY-sk es_VE-sk et-sk eu-sk fa-sk fa_IR-sk fi-sk fo-sk foo-sk fr-sk fur-sk fy-sk ga-sk gd-sk gl-sk gn-sk gu-sk gv-sk ha-sk he-sk hi-sk hr-sk hu-sk hy-sk ia-sk id-sk ig-sk io-sk is-sk it-sk it_IT-sk ja-sk jbo-sk ka-sk kg-sk kk-sk km-sk kn-sk ko-sk ks-sk ku-sk ky-sk la-sk lg-sk li-sk lo-sk lt-sk lv-sk mai-sk mg-sk mi-sk mk-sk ml-sk mn-sk mr-sk ms-sk mt-sk my-sk nb-sk nb_NO-sk nds-sk ne-sk nhn-sk nl-sk nn-sk nn_NO-sk no-sk no_nb-sk nr-sk nso-sk oc-sk or-sk os-sk pa-sk pl-sk ps-sk pt-sk pt_BR-sk pt_PT-sk quz-sk ro-sk ru-sk rw-sk si-sk af-sl am-sl an-sl ang-sl ar-sl ar_TN-sl ara-sl as-sl ast-sl az-sl az_IR-sl bal-sl be-sl bem-sl bg-sl bg_BG-sl bn-sl bn_IN-sl bo-sl br-sl brx-sl bs-sl ca-sl cat-sl crh-sl cs-sl csb-sl cy-sl da-sl da_DK-sl de-sl dv-sl dz-sl el-sl en-sl en_AU-sl en_CA-sl en_GB-sl en_NZ-sl en_US-sl en_ZA-sl eo-sl es-sl es_AR-sl es_CL-sl es_CO-sl es_CR-sl es_DO-sl es_EC-sl es_ES-sl es_GT-sl es_HN-sl es_MX-sl es_NI-sl es_PA-sl es_PE-sl es_PR-sl es_SV-sl es_UY-sl es_VE-sl et-sl eu-sl fa-sl fa_IR-sl fi-sl fo-sl foo-sl fr-sl fur-sl fy-sl ga-sl gd-sl gl-sl gn-sl gr-sl gu-sl gv-sl ha-sl he-sl hi-sl hr-sl hu-sl hy-sl ia-sl id-sl ig-sl io-sl is-sl it-sl it_IT-sl ja-sl jbo-sl ka-sl kg-sl kk-sl km-sl kn-sl ko-sl kr-sl ks-sl ku-sl ky-sl la-sl lg-sl li-sl lo-sl lt-sl lv-sl mai-sl mg-sl mi-sl mk-sl ml-sl mn-sl mr-sl ms-sl mt-sl my-sl nb-sl nb_NO-sl nds-sl ne-sl nhn-sl nl-sl nn-sl nn_NO-sl no-sl no_nb-sl nr-sl nso-sl oc-sl or-sl os-sl pa-sl pl-sl ps-sl pt-sl pt_BR-sl pt_PT-sl quz-sl ro-sl ru-sl rw-sl si-sl sk-sl af-so am-so ar-so ar_TN-so ast-so az-so bg-so br-so ca-so cs-so da-so de-so dz-so el-so en-so en_CA-so en_GB-so eo-so es-so et-so eu-so fa-so fi-so fr-so ga-so gd-so gl-so gu-so he-so hi-so hr-so hu-so id-so it-so ja-so ka-so kn-so ko-so lt-so lv-so mk-so ml-so mr-so ms-so nb-so ne-so nl-so nn-so oc-so pa-so pl-so pt-so pt_BR-so ro-so ru-so rw-so sk-so sl-so af-sq am-sq an-sq ang-sq ar-sq ar_TN-sq ara-sq as-sq ast-sq az-sq az_IR-sq bal-sq be-sq bem-sq bg-sq bg_BG-sq bn-sq bn_IN-sq bo-sq br-sq brx-sq bs-sq ca-sq crh-sq cs-sq csb-sq cy-sq da-sq da_DK-sq de-sq dv-sq dz-sq el-sq en-sq en_AU-sq en_CA-sq en_GB-sq en_US-sq en_ZA-sq eo-sq es-sq es_AR-sq es_CL-sq es_CO-sq es_CR-sq es_DO-sq es_EC-sq es_ES-sq es_GT-sq es_HN-sq es_MX-sq es_NI-sq es_PA-sq es_PE-sq es_PR-sq es_SV-sq es_UY-sq es_VE-sq et-sq eu-sq fa-sq fa_IR-sq fi-sq fo-sq foo-sq fr-sq fur-sq fy-sq ga-sq gd-sq gl-sq gn-sq gu-sq gv-sq ha-sq he-sq hi-sq hr-sq hu-sq hy-sq ia-sq id-sq ig-sq io-sq is-sq it-sq it_IT-sq ja-sq jbo-sq ka-sq kg-sq kk-sq km-sq kn-sq ko-sq ks-sq ku-sq ky-sq la-sq lg-sq li-sq lo-sq lt-sq lv-sq mai-sq mg-sq mi-sq mk-sq ml-sq mn-sq mr-sq ms-sq mt-sq my-sq nb-sq nb_NO-sq nds-sq ne-sq nhn-sq nl-sq nn-sq nn_NO-sq no-sq nr-sq nso-sq oc-sq or-sq pa-sq pl-sq ps-sq pt-sq pt_BR-sq pt_PT-sq ro-sq ru-sq rw-sq si-sq sk-sq sl-sq so-sq af-sr am-sr an-sr ang-sr ar-sr ar_TN-sr ara-sr as-sr ast-sr az-sr az_IR-sr bal-sr be-sr bem-sr bg-sr bg_BG-sr bn-sr bn_IN-sr bo-sr br-sr brx-sr bs-sr ca-sr cat-sr crh-sr cs-sr csb-sr cy-sr da-sr da_DK-sr de-sr de_CH-sr dv-sr dz-sr el-sr en-sr en_AU-sr en_CA-sr en_GB-sr en_NZ-sr en_US-sr en_ZA-sr eo-sr es-sr es_AR-sr es_CL-sr es_CO-sr es_CR-sr es_DO-sr es_EC-sr es_ES-sr es_GT-sr es_HN-sr es_MX-sr es_NI-sr es_PA-sr es_PE-sr es_PR-sr es_SV-sr es_UY-sr es_VE-sr et-sr eu-sr fa-sr fa_IR-sr fi-sr fo-sr foo-sr fr-sr fur-sr fy-sr ga-sr gd-sr gl-sr gn-sr gr-sr gu-sr gv-sr ha-sr he-sr hi-sr hr-sr hu-sr hy-sr ia-sr id-sr ig-sr io-sr is-sr it-sr it_IT-sr ja-sr jbo-sr ka-sr kg-sr kk-sr km-sr kn-sr ko-sr kr-sr ks-sr ku-sr ky-sr la-sr lg-sr li-sr lo-sr lt-sr lv-sr mai-sr mg-sr mi-sr mk-sr ml-sr mn-sr mr-sr ms-sr mt-sr my-sr nb-sr nb_NO-sr nds-sr ne-sr nhn-sr nl-sr nn-sr nn_NO-sr no-sr no_nb-sr nr-sr nso-sr oc-sr or-sr os-sr pa-sr pl-sr ps-sr pt-sr pt_BR-sr pt_PT-sr quz-sr ro-sr ru-sr rw-sr si-sr sk-sr sl-sr so-sr sq-sr af-sr_ME am-sr_ME ar-sr_ME ar_TN-sr_ME ast-sr_ME az-sr_ME bg-sr_ME br-sr_ME ca-sr_ME cs-sr_ME da-sr_ME de-sr_ME dz-sr_ME el-sr_ME en-sr_ME en_CA-sr_ME en_GB-sr_ME eo-sr_ME es-sr_ME et-sr_ME eu-sr_ME fa-sr_ME fi-sr_ME fr-sr_ME ga-sr_ME gd-sr_ME gl-sr_ME gu-sr_ME he-sr_ME hi-sr_ME hr-sr_ME hu-sr_ME id-sr_ME it-sr_ME ja-sr_ME ka-sr_ME kn-sr_ME ko-sr_ME lt-sr_ME lv-sr_ME mk-sr_ME ml-sr_ME mr-sr_ME ms-sr_ME nb-sr_ME ne-sr_ME nl-sr_ME nn-sr_ME oc-sr_ME pa-sr_ME pl-sr_ME pt-sr_ME pt_BR-sr_ME ro-sr_ME ru-sr_ME rw-sr_ME sk-sr_ME sl-sr_ME so-sr_ME sq-sr_ME sr-sr_ME af-st ar-st az-st be-st bg-st bs-st ca-st cs-st cy-st da-st de-st dz-st el-st en-st en_CA-st en_GB-st en_ZA-st es-st et-st eu-st fi-st fr-st ga-st gl-st gu-st he-st hi-st hr-st hu-st is-st it-st ja-st ka-st km-st ko-st lt-st lv-st mk-st ms-st nb-st ne-st nl-st nn-st nr-st nso-st oc-st pa-st pl-st ps-st pt-st pt_BR-st ro-st ru-st rw-st sk-st sl-st sq-st sr-st af-sv am-sv an-sv ang-sv ar-sv ar_TN-sv ara-sv as-sv ast-sv az-sv az_IR-sv bal-sv be-sv bem-sv bg-sv bg_BG-sv bn-sv bn_IN-sv bo-sv br-sv brx-sv bs-sv ca-sv cat-sv crh-sv cs-sv csb-sv cy-sv da-sv da_DK-sv de-sv de_CH-sv dv-sv dz-sv el-sv en-sv en_AU-sv en_CA-sv en_GB-sv en_NZ-sv en_US-sv en_ZA-sv eo-sv es-sv es_AR-sv es_CL-sv es_CO-sv es_CR-sv es_DO-sv es_EC-sv es_ES-sv es_GT-sv es_HN-sv es_MX-sv es_NI-sv es_PA-sv es_PE-sv es_PR-sv es_SV-sv es_UY-sv es_VE-sv et-sv eu-sv fa-sv fa_IR-sv fi-sv fo-sv foo-sv fr-sv fur-sv fy-sv ga-sv gd-sv gl-sv gn-sv gr-sv gu-sv gv-sv ha-sv he-sv hi-sv hr-sv hu-sv hy-sv ia-sv id-sv ig-sv io-sv is-sv it-sv it_IT-sv ja-sv jbo-sv ka-sv kg-sv kk-sv km-sv kn-sv ko-sv kr-sv ks-sv ku-sv ky-sv la-sv lg-sv li-sv lo-sv lt-sv lv-sv mai-sv mg-sv mi-sv mk-sv ml-sv mn-sv mr-sv ms-sv mt-sv my-sv nb-sv nb_NO-sv nds-sv ne-sv nhn-sv nl-sv nn-sv nn_NO-sv no-sv no_nb-sv nr-sv nso-sv oc-sv or-sv os-sv pa-sv pl-sv ps-sv pt-sv pt_BR-sv pt_PT-sv quz-sv ro-sv ru-sv rw-sv si-sv sk-sv sl-sv so-sv sq-sv sr-sv sr_ME-sv st-sv af-sw an-sw ar-sw as-sw ast-sw be-sw bem-sw bg-sw bn-sw bn_IN-sw br-sw brx-sw bs-sw ca-sw crh-sw cs-sw cy-sw da-sw de-sw dz-sw el-sw en-sw en_CA-sw en_GB-sw en_ZA-sw eo-sw es-sw et-sw eu-sw fa-sw fi-sw fr-sw fur-sw fy-sw ga-sw gl-sw gu-sw he-sw hi-sw hr-sw hu-sw hy-sw id-sw io-sw is-sw it-sw ja-sw ka-sw kg-sw kk-sw km-sw kn-sw ko-sw ku-sw lt-sw lv-sw mai-sw mg-sw mk-sw ml-sw mn-sw mr-sw ms-sw nb-sw nds-sw ne-sw nl-sw nn-sw nr-sw nso-sw oc-sw or-sw pa-sw pl-sw ps-sw pt-sw pt_BR-sw ro-sw ru-sw rw-sw si-sw sk-sw sl-sw sq-sw sr-sw st-sw sv-sw af-szl an-szl ar-szl as-szl ast-szl be-szl bg-szl bn-szl bn_IN-szl br-szl ca-szl crh-szl cs-szl csb-szl cy-szl da-szl de-szl dv-szl dz-szl el-szl en-szl en_CA-szl en_GB-szl eo-szl es-szl et-szl eu-szl fa-szl fi-szl fr-szl fur-szl fy-szl ga-szl gd-szl gl-szl gn-szl gu-szl gv-szl ha-szl he-szl hi-szl hr-szl hu-szl hy-szl ia-szl id-szl ig-szl io-szl is-szl it-szl ja-szl ka-szl kg-szl kk-szl km-szl kn-szl ko-szl ku-szl ky-szl lo-szl lt-szl lv-szl mai-szl mg-szl mk-szl ml-szl mn-szl mr-szl ms-szl nb-szl nds-szl ne-szl nl-szl nn-szl oc-szl or-szl pa-szl pl-szl ps-szl pt-szl pt_BR-szl ro-szl ru-szl rw-szl si-szl sk-szl sl-szl sq-szl sr-szl sv-szl af-ta am-ta an-ta ang-ta ar-ta ar_TN-ta ara-ta as-ta ast-ta az-ta az_IR-ta bal-ta be-ta bem-ta bg-ta bg_BG-ta bn-ta bn_IN-ta bo-ta br-ta brx-ta bs-ta ca-ta crh-ta cs-ta csb-ta cy-ta da-ta da_DK-ta de-ta de_CH-ta dv-ta dz-ta el-ta en-ta en_AU-ta en_CA-ta en_GB-ta en_US-ta eo-ta es-ta es_AR-ta es_CL-ta es_CO-ta es_CR-ta es_DO-ta es_EC-ta es_ES-ta es_GT-ta es_HN-ta es_MX-ta es_NI-ta es_PA-ta es_PE-ta es_PR-ta es_SV-ta es_UY-ta es_VE-ta et-ta eu-ta fa-ta fa_IR-ta fi-ta fo-ta foo-ta fr-ta fur-ta fy-ta ga-ta gd-ta gl-ta gn-ta gr-ta gu-ta gv-ta ha-ta he-ta hi-ta hr-ta hu-ta hy-ta ia-ta id-ta ig-ta io-ta is-ta it-ta it_IT-ta ja-ta jbo-ta ka-ta kg-ta kk-ta km-ta kn-ta ko-ta kr-ta ks-ta ku-ta ky-ta la-ta lg-ta li-ta lo-ta lt-ta lv-ta mai-ta mg-ta mi-ta mk-ta ml-ta mn-ta mr-ta ms-ta mus-ta my-ta nb-ta nb_NO-ta nds-ta ne-ta nhn-ta nl-ta nn-ta nn_NO-ta no-ta no_nb-ta nso-ta oc-ta or-ta pa-ta pl-ta ps-ta pt-ta pt_BR-ta pt_PT-ta quz-ta ro-ta ru-ta rw-ta si-ta sk-ta sl-ta so-ta sq-ta sr-ta sr_ME-ta sv-ta sw-ta szl-ta af-te am-te an-te ang-te ar-te ar_TN-te ara-te as-te ast-te az-te az_IR-te bal-te be-te bem-te bg-te bg_BG-te bn-te bn_IN-te bo-te br-te brx-te bs-te ca-te crh-te cs-te csb-te cy-te da-te da_DK-te de-te de_CH-te dv-te dz-te el-te en-te en_AU-te en_CA-te en_GB-te en_US-te eo-te es-te es_AR-te es_CL-te es_CO-te es_CR-te es_DO-te es_EC-te es_ES-te es_GT-te es_HN-te es_MX-te es_NI-te es_PA-te es_PE-te es_PR-te es_SV-te es_UY-te es_VE-te et-te eu-te fa-te fa_IR-te fi-te fo-te foo-te fr-te fur-te fy-te ga-te gd-te gl-te gn-te gr-te gu-te gv-te ha-te he-te hi-te hr-te hu-te hy-te ia-te id-te ig-te io-te is-te it-te it_IT-te ja-te jbo-te ka-te kg-te kk-te km-te kn-te ko-te kr-te ks-te ku-te ky-te la-te lg-te li-te lo-te lt-te lv-te mai-te mg-te mi-te mk-te ml-te mn-te mr-te ms-te my-te nb-te nb_NO-te nds-te ne-te nhn-te nl-te nn-te nn_NO-te no-te no_nb-te nso-te oc-te or-te pa-te pl-te ps-te pt-te pt_BR-te pt_PT-te quz-te ro-te ru-te rw-te si-te sk-te sl-te so-te sq-te sr-te sr_ME-te sv-te sw-te szl-te ta-te af-tg am-tg an-tg ang-tg ar-tg as-tg ast-tg az-tg az_IR-tg be-tg bg-tg bn-tg bn_IN-tg bo-tg br-tg bs-tg ca-tg crh-tg cs-tg csb-tg cy-tg da-tg de-tg dv-tg dz-tg el-tg en-tg en_AU-tg en_CA-tg en_GB-tg en_US-tg eo-tg es-tg et-tg eu-tg fa-tg fi-tg fr-tg fur-tg fy-tg ga-tg gd-tg gl-tg gn-tg gu-tg gv-tg ha-tg he-tg hi-tg hr-tg hu-tg hy-tg ia-tg id-tg ig-tg io-tg is-tg it-tg ja-tg ka-tg kg-tg kk-tg km-tg kn-tg ko-tg ks-tg ku-tg ky-tg la-tg lg-tg li-tg lo-tg lt-tg lv-tg mai-tg mg-tg mi-tg mk-tg ml-tg mn-tg mr-tg ms-tg my-tg nb-tg nds-tg ne-tg nhn-tg nl-tg nn-tg nso-tg oc-tg or-tg pa-tg pl-tg ps-tg pt-tg pt_BR-tg ro-tg ru-tg rw-tg si-tg sk-tg sl-tg sq-tg sr-tg sv-tg szl-tg ta-tg te-tg af-th am-th an-th ang-th ar-th ar_TN-th ara-th as-th ast-th az-th az_IR-th bal-th be-th bem-th bg-th bg_BG-th bn-th bn_IN-th bo-th br-th brx-th bs-th ca-th crh-th cs-th csb-th cy-th da-th da_DK-th de-th dv-th dz-th el-th en-th en_AU-th en_CA-th en_GB-th en_US-th en_ZA-th eo-th es-th es_AR-th es_CL-th es_CO-th es_CR-th es_DO-th es_EC-th es_ES-th es_GT-th es_HN-th es_MX-th es_NI-th es_PA-th es_PE-th es_PR-th es_SV-th es_UY-th es_VE-th et-th eu-th fa-th fa_IR-th fi-th fo-th foo-th fr-th fur-th fy-th ga-th gd-th gl-th gn-th gu-th gv-th ha-th he-th hi-th hr-th hu-th hy-th ia-th id-th ig-th io-th is-th it-th it_IT-th ja-th jbo-th ka-th kg-th kk-th km-th kn-th ko-th ks-th ku-th ky-th la-th lg-th li-th lo-th lt-th lv-th mai-th mg-th mi-th mk-th ml-th mn-th mr-th ms-th mus-th my-th nb-th nb_NO-th nds-th ne-th nhn-th nl-th nn-th nn_NO-th no-th no_nb-th nr-th nso-th oc-th or-th pa-th pl-th ps-th pt-th pt_BR-th pt_PT-th quz-th ro-th ru-th rw-th si-th sk-th sl-th so-th sq-th sr-th sr_ME-th st-th sv-th sw-th szl-th ta-th te-th tg-th af-tk am-tk an-tk ang-tk ar-tk as-tk ast-tk az-tk az_IR-tk be-tk bg-tk bn-tk bn_IN-tk bo-tk br-tk bs-tk ca-tk crh-tk cs-tk csb-tk cy-tk da-tk de-tk dz-tk el-tk en-tk en_CA-tk en_GB-tk en_US-tk eo-tk es-tk et-tk eu-tk fa-tk fi-tk fr-tk fur-tk fy-tk ga-tk gd-tk gl-tk gu-tk gv-tk ha-tk he-tk hi-tk hr-tk hu-tk hy-tk ia-tk id-tk ig-tk io-tk is-tk it-tk ja-tk ka-tk kg-tk kk-tk km-tk kn-tk ko-tk ks-tk ku-tk ky-tk la-tk lg-tk li-tk lo-tk lt-tk lv-tk mai-tk mg-tk mi-tk mk-tk ml-tk mn-tk mr-tk ms-tk my-tk nb-tk nds-tk ne-tk nhn-tk nl-tk nn-tk no-tk nso-tk oc-tk or-tk pa-tk pl-tk ps-tk pt-tk pt_BR-tk ro-tk ru-tk rw-tk si-tk sk-tk sl-tk sq-tk sr-tk sv-tk ta-tk te-tk tg-tk th-tk af-tl am-tl an-tl ar-tl as-tl ast-tl az-tl be-tl bg-tl bn-tl bn_IN-tl bs-tl ca-tl cs-tl cy-tl da-tl de-tl dz-tl el-tl en-tl en_AU-tl en_CA-tl en_GB-tl eo-tl es-tl et-tl eu-tl fa-tl fi-tl fr-tl ga-tl gl-tl gu-tl he-tl hi-tl hr-tl hu-tl hy-tl id-tl is-tl it-tl ja-tl jbo-tl ka-tl kk-tl kn-tl ko-tl ku-tl lt-tl lv-tl mai-tl mg-tl mk-tl ml-tl mn-tl mr-tl ms-tl nb-tl nds-tl ne-tl nl-tl nn-tl oc-tl or-tl pa-tl pl-tl ps-tl pt-tl pt_BR-tl ro-tl ru-tl rw-tl si-tl sk-tl sl-tl sq-tl sr-tl sv-tl ta-tl te-tl tg-tl th-tl af-tmp am-tmp ar-tmp as-tmp ast-tmp az-tmp be-tmp bg-tmp bn-tmp bn_IN-tmp br-tmp bs-tmp ca-tmp crh-tmp cs-tmp cy-tmp da-tmp de-tmp dz-tmp el-tmp en-tmp en_CA-tmp en_GB-tmp eo-tmp es-tmp et-tmp eu-tmp fa-tmp fi-tmp fr-tmp ga-tmp gl-tmp gu-tmp he-tmp hi-tmp hr-tmp hu-tmp hy-tmp id-tmp is-tmp it-tmp ja-tmp ka-tmp kk-tmp kn-tmp ko-tmp ku-tmp lt-tmp lv-tmp mai-tmp mg-tmp mk-tmp ml-tmp mn-tmp mr-tmp ms-tmp nb-tmp nds-tmp ne-tmp nl-tmp nn-tmp nso-tmp oc-tmp or-tmp pa-tmp pl-tmp pt-tmp pt_BR-tmp ro-tmp ru-tmp rw-tmp si-tmp sk-tmp sl-tmp sq-tmp sr-tmp sv-tmp ta-tmp te-tmp th-tmp af-tr am-tr an-tr ang-tr ar-tr ar_TN-tr ara-tr as-tr ast-tr az-tr az_IR-tr bal-tr be-tr bem-tr bg-tr bg_BG-tr bn-tr bn_IN-tr bo-tr br-tr brx-tr bs-tr ca-tr crh-tr cs-tr csb-tr cy-tr da-tr da_DK-tr de-tr dv-tr dz-tr el-tr en-tr en_AU-tr en_CA-tr en_GB-tr en_US-tr en_ZA-tr eo-tr es-tr es_AR-tr es_CL-tr es_CO-tr es_CR-tr es_DO-tr es_EC-tr es_ES-tr es_GT-tr es_HN-tr es_MX-tr es_NI-tr es_PA-tr es_PE-tr es_PR-tr es_SV-tr es_UY-tr es_VE-tr et-tr eu-tr fa-tr fa_IR-tr fi-tr fo-tr foo-tr fr-tr fur-tr fy-tr ga-tr gd-tr gl-tr gn-tr gu-tr gv-tr ha-tr he-tr hi-tr hr-tr hu-tr hy-tr ia-tr id-tr ig-tr io-tr is-tr it-tr it_IT-tr ja-tr jbo-tr ka-tr kg-tr kk-tr km-tr kn-tr ko-tr ks-tr ku-tr ky-tr la-tr lg-tr li-tr lo-tr lt-tr lv-tr mai-tr mg-tr mi-tr mk-tr ml-tr mn-tr mr-tr ms-tr mt-tr my-tr nb-tr nb_NO-tr nds-tr ne-tr nhn-tr nl-tr nn-tr nn_NO-tr no-tr no_nb-tr nr-tr nso-tr oc-tr or-tr os-tr pa-tr pl-tr ps-tr pt-tr pt_BR-tr pt_PT-tr quz-tr ro-tr ru-tr rw-tr si-tr sk-tr sl-tr so-tr sq-tr sr-tr sr_ME-tr st-tr sv-tr sw-tr szl-tr ta-tr te-tr tg-tr th-tr tk-tr tl-tr tmp-tr ca-tr_TR cs-tr_TR da-tr_TR de-tr_TR el-tr_TR en-tr_TR en_GB-tr_TR eo-tr_TR es-tr_TR et-tr_TR fi-tr_TR fr-tr_TR gl-tr_TR hu-tr_TR id-tr_TR it-tr_TR ja-tr_TR lv-tr_TR nb-tr_TR nds-tr_TR nl-tr_TR pl-tr_TR pt-tr_TR pt_BR-tr_TR ro-tr_TR ru-tr_TR sl-tr_TR sr-tr_TR sv-tr_TR th-tr_TR tr-tr_TR af-ts am-ts ar-ts as-ts ast-ts az-ts be-ts bg-ts bn-ts bn_IN-ts br-ts bs-ts ca-ts cs-ts cy-ts da-ts de-ts dz-ts el-ts en-ts en_CA-ts en_GB-ts en_ZA-ts eo-ts es-ts et-ts eu-ts fa-ts fi-ts fr-ts fur-ts fy-ts ga-ts gd-ts gl-ts gu-ts he-ts hi-ts hr-ts hu-ts id-ts is-ts it-ts ja-ts ka-ts kk-ts km-ts kn-ts ko-ts ks-ts ku-ts lt-ts lv-ts mai-ts mg-ts mk-ts ml-ts mn-ts mr-ts ms-ts my-ts nb-ts nds-ts ne-ts nl-ts nn-ts nr-ts nso-ts oc-ts or-ts pa-ts pl-ts ps-ts pt-ts pt_BR-ts ro-ts ru-ts rw-ts si-ts sk-ts sl-ts sq-ts sr-ts st-ts sv-ts sw-ts ta-ts te-ts tg-ts th-ts tk-ts tr-ts af-tt am-tt an-tt ang-tt ar-tt as-tt ast-tt az-tt az_IR-tt be-tt bg-tt bn-tt bn_IN-tt br-tt bs-tt ca-tt crh-tt cs-tt csb-tt cy-tt da-tt de-tt dz-tt el-tt en-tt en_CA-tt en_GB-tt eo-tt es-tt et-tt eu-tt fa-tt fi-tt fr-tt fur-tt ga-tt gd-tt gl-tt gu-tt he-tt hi-tt hr-tt hu-tt hy-tt ia-tt id-tt io-tt is-tt it-tt ja-tt ka-tt kg-tt kk-tt km-tt kn-tt ko-tt ku-tt ky-tt la-tt lg-tt li-tt lt-tt lv-tt mai-tt mg-tt mi-tt mk-tt ml-tt mn-tt mr-tt ms-tt my-tt nb-tt nds-tt ne-tt nl-tt nn-tt no-tt nso-tt oc-tt or-tt pa-tt pl-tt ps-tt pt-tt pt_BR-tt ro-tt ru-tt rw-tt si-tt sk-tt sl-tt sq-tt sr-tt sv-tt ta-tt te-tt tg-tt th-tt tk-tt tl-tt tr-tt af-ug am-ug an-ug ang-ug ar-ug as-ug ast-ug az-ug az_IR-ug bal-ug be-ug bem-ug bg-ug bn-ug bn_IN-ug bo-ug br-ug brx-ug bs-ug ca-ug crh-ug cs-ug csb-ug cy-ug da-ug de-ug dv-ug dz-ug el-ug en-ug en_AU-ug en_CA-ug en_GB-ug en_US-ug eo-ug es-ug es_AR-ug es_CL-ug es_CO-ug es_CR-ug es_DO-ug es_EC-ug es_ES-ug es_GT-ug es_HN-ug es_MX-ug es_NI-ug es_PA-ug es_PE-ug es_PR-ug es_SV-ug es_UY-ug es_VE-ug et-ug eu-ug fa-ug fi-ug fr-ug fur-ug fy-ug ga-ug gd-ug gl-ug gn-ug gu-ug gv-ug ha-ug he-ug hi-ug hr-ug hu-ug hy-ug ia-ug id-ug ig-ug io-ug is-ug it-ug ja-ug ka-ug kg-ug kk-ug km-ug kn-ug ko-ug ks-ug ku-ug ky-ug la-ug lg-ug li-ug lo-ug lt-ug lv-ug mai-ug mg-ug mi-ug mk-ug ml-ug mn-ug mr-ug ms-ug my-ug nb-ug nds-ug ne-ug nhn-ug nl-ug nn-ug nso-ug oc-ug or-ug pa-ug pl-ug ps-ug pt-ug pt_BR-ug quz-ug ro-ug ru-ug rw-ug si-ug sk-ug sl-ug sq-ug sr-ug sv-ug sw-ug szl-ug ta-ug te-ug tg-ug th-ug tk-ug tl-ug tmp-ug tr-ug ts-ug tt-ug af-uk am-uk an-uk ang-uk ar-uk ar_TN-uk ara-uk as-uk ast-uk az-uk az_IR-uk bal-uk be-uk bem-uk bg-uk bg_BG-uk bn-uk bn_IN-uk bo-uk br-uk brx-uk bs-uk ca-uk crh-uk cs-uk csb-uk cy-uk da-uk da_DK-uk de-uk de_CH-uk dv-uk dz-uk el-uk en-uk en_AU-uk en_CA-uk en_GB-uk en_NZ-uk en_US-uk en_ZA-uk eo-uk es-uk es_AR-uk es_CL-uk es_CO-uk es_CR-uk es_DO-uk es_EC-uk es_ES-uk es_GT-uk es_HN-uk es_MX-uk es_NI-uk es_PA-uk es_PE-uk es_PR-uk es_SV-uk es_UY-uk es_VE-uk et-uk eu-uk fa-uk fa_IR-uk fi-uk fo-uk foo-uk fr-uk fur-uk fy-uk ga-uk gd-uk gl-uk gn-uk gr-uk gu-uk gv-uk ha-uk he-uk hi-uk hr-uk hu-uk hy-uk ia-uk id-uk ig-uk io-uk is-uk it-uk it_IT-uk ja-uk jbo-uk ka-uk kg-uk kk-uk km-uk kn-uk ko-uk kr-uk ks-uk ku-uk ky-uk la-uk lg-uk li-uk lo-uk lt-uk lv-uk mai-uk mg-uk mi-uk mk-uk ml-uk mn-uk mr-uk ms-uk mt-uk my-uk nb-uk nb_NO-uk nds-uk ne-uk nhn-uk nl-uk nn-uk nn_NO-uk no-uk no_nb-uk nr-uk nso-uk oc-uk or-uk os-uk pa-uk pl-uk ps-uk pt-uk pt_BR-uk pt_PT-uk quz-uk ro-uk ru-uk rw-uk si-uk sk-uk sl-uk so-uk sq-uk sr-uk sr_ME-uk st-uk sv-uk sw-uk szl-uk ta-uk te-uk tg-uk th-uk tk-uk tl-uk tmp-uk tr-uk ts-uk tt-uk ug-uk af-ur am-ur an-ur ang-ur ar-ur ar_TN-ur as-ur ast-ur az-ur az_IR-ur be-ur bg-ur bn-ur bn_IN-ur br-ur bs-ur ca-ur crh-ur cs-ur csb-ur cy-ur da-ur de-ur dz-ur el-ur en-ur en_CA-ur en_GB-ur eo-ur es-ur et-ur eu-ur fa-ur fi-ur fr-ur fur-ur fy-ur ga-ur gd-ur gl-ur gu-ur ha-ur he-ur hi-ur hr-ur hu-ur hy-ur ia-ur id-ur ig-ur io-ur is-ur it-ur ja-ur ka-ur kg-ur kk-ur km-ur kn-ur ko-ur ku-ur ky-ur lg-ur li-ur lo-ur lt-ur lv-ur mai-ur mg-ur mi-ur mk-ur ml-ur mn-ur mr-ur ms-ur my-ur nb-ur nds-ur ne-ur nl-ur nn-ur no-ur nso-ur oc-ur or-ur pa-ur pl-ur ps-ur pt-ur pt_BR-ur ro-ur ru-ur rw-ur si-ur sk-ur sl-ur so-ur sq-ur sr-ur sr_ME-ur sv-ur ta-ur te-ur tg-ur th-ur tk-ur tr-ur tt-ur ug-ur uk-ur af-ur_PK am-ur_PK an-ur_PK ar-ur_PK as-ur_PK ast-ur_PK az-ur_PK be-ur_PK bg-ur_PK bn-ur_PK bn_IN-ur_PK br-ur_PK bs-ur_PK ca-ur_PK cs-ur_PK csb-ur_PK cy-ur_PK da-ur_PK de-ur_PK dz-ur_PK el-ur_PK en-ur_PK en_CA-ur_PK en_GB-ur_PK eo-ur_PK es-ur_PK et-ur_PK eu-ur_PK fa-ur_PK fi-ur_PK fr-ur_PK fur-ur_PK fy-ur_PK ga-ur_PK gd-ur_PK gl-ur_PK gu-ur_PK he-ur_PK hi-ur_PK hr-ur_PK hu-ur_PK hy-ur_PK id-ur_PK is-ur_PK it-ur_PK ja-ur_PK ka-ur_PK kk-ur_PK km-ur_PK kn-ur_PK ko-ur_PK ku-ur_PK lt-ur_PK lv-ur_PK mai-ur_PK mg-ur_PK mk-ur_PK ml-ur_PK mn-ur_PK mr-ur_PK ms-ur_PK my-ur_PK nb-ur_PK nds-ur_PK ne-ur_PK nl-ur_PK nn-ur_PK oc-ur_PK or-ur_PK pa-ur_PK pl-ur_PK ps-ur_PK pt-ur_PK pt_BR-ur_PK ro-ur_PK ru-ur_PK rw-ur_PK si-ur_PK sk-ur_PK sl-ur_PK sq-ur_PK sr-ur_PK sv-ur_PK ta-ur_PK te-ur_PK tg-ur_PK th-ur_PK tk-ur_PK tr-ur_PK ug-ur_PK uk-ur_PK ur-ur_PK af-uz am-uz an-uz ang-uz ar-uz as-uz ast-uz az-uz az_IR-uz be-uz bg-uz bn-uz bn_IN-uz bo-uz br-uz bs-uz ca-uz crh-uz cs-uz csb-uz cy-uz da-uz de-uz dz-uz el-uz en-uz en_CA-uz en_GB-uz eo-uz es-uz et-uz eu-uz fa-uz fi-uz fr-uz fur-uz fy-uz ga-uz gd-uz gl-uz gu-uz gv-uz ha-uz he-uz hi-uz hr-uz hu-uz hy-uz ia-uz id-uz ig-uz io-uz is-uz it-uz ja-uz ka-uz kg-uz kk-uz km-uz kn-uz ko-uz ks-uz ku-uz ky-uz la-uz lg-uz li-uz lo-uz lt-uz lv-uz mai-uz mg-uz mi-uz mk-uz ml-uz mn-uz mr-uz ms-uz my-uz nb-uz nds-uz ne-uz nhn-uz nl-uz nn-uz no-uz nso-uz oc-uz or-uz pa-uz pl-uz ps-uz pt-uz pt_BR-uz ro-uz ru-uz rw-uz si-uz sk-uz sl-uz sq-uz sr-uz sv-uz ta-uz te-uz tg-uz th-uz tk-uz tmp-uz tr-uz ts-uz tt-uz ug-uz uk-uz ur-uz af-vi am-vi an-vi ang-vi ar-vi ar_TN-vi ara-vi as-vi ast-vi az-vi az_IR-vi bal-vi be-vi bem-vi bg-vi bg_BG-vi bn-vi bn_IN-vi bo-vi br-vi brx-vi bs-vi ca-vi crh-vi cs-vi csb-vi cy-vi da-vi de-vi dv-vi dz-vi el-vi en-vi en_AU-vi en_CA-vi en_GB-vi en_US-vi en_ZA-vi eo-vi es-vi es_AR-vi es_CL-vi es_CO-vi es_CR-vi es_DO-vi es_EC-vi es_ES-vi es_GT-vi es_HN-vi es_MX-vi es_NI-vi es_PA-vi es_PE-vi es_PR-vi es_SV-vi es_UY-vi es_VE-vi et-vi eu-vi fa-vi fa_IR-vi fi-vi fo-vi foo-vi fr-vi fur-vi fy-vi ga-vi gd-vi gl-vi gn-vi gr-vi gu-vi gv-vi ha-vi he-vi hi-vi hr-vi hu-vi hy-vi ia-vi id-vi ig-vi io-vi is-vi it-vi it_IT-vi ja-vi jbo-vi ka-vi kg-vi kk-vi km-vi kn-vi ko-vi kr-vi ks-vi ku-vi ky-vi la-vi lg-vi li-vi lo-vi lt-vi lv-vi mai-vi mg-vi mi-vi mk-vi ml-vi mn-vi mr-vi ms-vi mt-vi my-vi nb-vi nds-vi ne-vi nhn-vi nl-vi nn-vi no-vi nr-vi nso-vi oc-vi or-vi os-vi pa-vi pl-vi ps-vi pt-vi pt_BR-vi quz-vi ro-vi ru-vi rw-vi si-vi sk-vi sl-vi so-vi sq-vi sr-vi sr_ME-vi st-vi sv-vi sw-vi szl-vi ta-vi te-vi tg-vi th-vi tk-vi tl-vi tmp-vi tr-vi ts-vi tt-vi ug-vi uk-vi ur-vi ur_PK-vi uz-vi af-wa am-wa an-wa ang-wa ar-wa ar_TN-wa ara-wa as-wa ast-wa az-wa az_IR-wa be-wa bg-wa bg_BG-wa bn-wa bn_IN-wa bo-wa br-wa bs-wa ca-wa crh-wa cs-wa csb-wa cy-wa da-wa de-wa dz-wa el-wa en-wa en_AU-wa en_CA-wa en_GB-wa en_US-wa en_ZA-wa eo-wa es-wa es_AR-wa es_CL-wa es_CO-wa es_CR-wa es_DO-wa es_EC-wa es_ES-wa es_GT-wa es_HN-wa es_MX-wa es_NI-wa es_PA-wa es_PE-wa es_PR-wa es_SV-wa es_UY-wa es_VE-wa et-wa eu-wa fa-wa fa_IR-wa fi-wa fo-wa foo-wa fr-wa fur-wa fy-wa ga-wa gd-wa gl-wa gu-wa gv-wa ha-wa he-wa hi-wa hr-wa hu-wa hy-wa ia-wa id-wa ig-wa io-wa is-wa it-wa it_IT-wa ja-wa jbo-wa ka-wa kg-wa kk-wa km-wa kn-wa ko-wa ks-wa ku-wa ky-wa la-wa lg-wa li-wa lo-wa lt-wa lv-wa mai-wa mg-wa mi-wa mk-wa ml-wa mn-wa mr-wa ms-wa my-wa nb-wa nds-wa ne-wa nhn-wa nl-wa nn-wa no-wa nr-wa nso-wa oc-wa or-wa os-wa pa-wa pl-wa ps-wa pt-wa pt_BR-wa ro-wa ru-wa rw-wa si-wa sk-wa sl-wa so-wa sq-wa sr-wa sr_ME-wa st-wa sv-wa ta-wa te-wa tg-wa th-wa tk-wa tl-wa tmp-wa tr-wa ts-wa tt-wa ug-wa uk-wa ur-wa uz-wa vi-wa af-xh am-xh an-xh ang-xh ar-xh as-xh ast-xh az-xh az_IR-xh be-xh bg-xh bn-xh bn_IN-xh bo-xh br-xh bs-xh ca-xh crh-xh cs-xh csb-xh cy-xh da-xh de-xh dv-xh dz-xh el-xh en-xh en_AU-xh en_CA-xh en_GB-xh en_US-xh en_ZA-xh eo-xh es-xh es_AR-xh es_CL-xh es_CO-xh es_CR-xh es_DO-xh es_EC-xh es_ES-xh es_GT-xh es_HN-xh es_MX-xh es_NI-xh es_PA-xh es_PE-xh es_PR-xh es_SV-xh es_UY-xh es_VE-xh et-xh eu-xh fa-xh fi-xh fr-xh fur-xh fy-xh ga-xh gd-xh gl-xh gn-xh gu-xh gv-xh ha-xh he-xh hi-xh hr-xh hu-xh hy-xh ia-xh id-xh ig-xh io-xh is-xh it-xh ja-xh ka-xh kg-xh kk-xh km-xh kn-xh ko-xh ks-xh ku-xh ky-xh la-xh lg-xh li-xh lo-xh lt-xh lv-xh mai-xh mg-xh mi-xh mk-xh ml-xh mn-xh mr-xh ms-xh my-xh nb-xh nds-xh ne-xh nhn-xh nl-xh nn-xh no-xh nr-xh nso-xh oc-xh or-xh pa-xh pl-xh ps-xh pt-xh pt_BR-xh ro-xh ru-xh rw-xh si-xh sk-xh sl-xh sq-xh sr-xh st-xh sv-xh sw-xh szl-xh ta-xh te-xh tg-xh th-xh tk-xh tl-xh tmp-xh tr-xh ts-xh tt-xh ug-xh uk-xh ur-xh ur_PK-xh uz-xh vi-xh wa-xh af-yi am-yi an-yi ang-yi ar-yi as-yi ast-yi az-yi az_IR-yi be-yi bg-yi bn-yi bn_IN-yi bo-yi br-yi bs-yi ca-yi crh-yi cs-yi csb-yi cy-yi da-yi de-yi dz-yi el-yi en-yi en_CA-yi en_GB-yi eo-yi es-yi et-yi eu-yi fa-yi fi-yi fr-yi fur-yi fy-yi ga-yi gd-yi gl-yi gu-yi gv-yi ha-yi he-yi hi-yi hr-yi hu-yi hy-yi ia-yi id-yi ig-yi io-yi is-yi it-yi ja-yi ka-yi kg-yi kk-yi km-yi kn-yi ko-yi ku-yi ky-yi la-yi lg-yi li-yi lo-yi lt-yi lv-yi mai-yi mg-yi mi-yi mk-yi ml-yi mn-yi mr-yi ms-yi my-yi nb-yi nds-yi ne-yi nl-yi nn-yi no-yi nso-yi oc-yi or-yi pa-yi pl-yi ps-yi pt-yi pt_BR-yi ro-yi ru-yi rw-yi si-yi sk-yi sl-yi sq-yi sr-yi sv-yi ta-yi te-yi tg-yi th-yi tk-yi tl-yi tr-yi tt-yi ug-yi uk-yi ur-yi uz-yi vi-yi wa-yi xh-yi af-yo am-yo an-yo ar-yo as-yo ast-yo az-yo be-yo bg-yo bn-yo bn_IN-yo bo-yo br-yo bs-yo ca-yo crh-yo cs-yo csb-yo cy-yo da-yo de-yo dv-yo dz-yo el-yo en-yo en_CA-yo en_GB-yo eo-yo es-yo et-yo eu-yo fa-yo fi-yo fr-yo fur-yo fy-yo ga-yo gd-yo gl-yo gn-yo gu-yo gv-yo ha-yo he-yo hi-yo hr-yo hu-yo hy-yo ia-yo id-yo ig-yo io-yo is-yo it-yo ja-yo ka-yo kg-yo kk-yo km-yo kn-yo ko-yo ku-yo ky-yo la-yo li-yo lo-yo lt-yo lv-yo mai-yo mg-yo mi-yo mk-yo ml-yo mn-yo mr-yo ms-yo my-yo nb-yo nds-yo ne-yo nl-yo nn-yo nso-yo oc-yo or-yo pa-yo pl-yo ps-yo pt-yo pt_BR-yo ro-yo ru-yo rw-yo si-yo sk-yo sl-yo sq-yo sr-yo sv-yo szl-yo ta-yo te-yo tg-yo th-yo tk-yo tr-yo ug-yo uk-yo ur-yo uz-yo vi-yo wa-yo xh-yo yi-yo af-zh_CN am-zh_CN an-zh_CN ang-zh_CN ar-zh_CN ar_TN-zh_CN ara-zh_CN as-zh_CN ast-zh_CN az-zh_CN az_IR-zh_CN bal-zh_CN be-zh_CN bem-zh_CN bg-zh_CN bg_BG-zh_CN bn-zh_CN bn_IN-zh_CN bo-zh_CN br-zh_CN brx-zh_CN bs-zh_CN ca-zh_CN cat-zh_CN crh-zh_CN cs-zh_CN csb-zh_CN cy-zh_CN da-zh_CN da_DK-zh_CN de-zh_CN de_CH-zh_CN dv-zh_CN dz-zh_CN el-zh_CN en-zh_CN en_AU-zh_CN en_CA-zh_CN en_GB-zh_CN en_NZ-zh_CN en_US-zh_CN en_ZA-zh_CN eo-zh_CN es-zh_CN es_AR-zh_CN es_CL-zh_CN es_CO-zh_CN es_CR-zh_CN es_DO-zh_CN es_EC-zh_CN es_ES-zh_CN es_GT-zh_CN es_HN-zh_CN es_MX-zh_CN es_NI-zh_CN es_PA-zh_CN es_PE-zh_CN es_PR-zh_CN es_SV-zh_CN es_UY-zh_CN es_VE-zh_CN et-zh_CN eu-zh_CN fa-zh_CN fa_IR-zh_CN fi-zh_CN fo-zh_CN foo-zh_CN fr-zh_CN fur-zh_CN fy-zh_CN ga-zh_CN gd-zh_CN gl-zh_CN gn-zh_CN gr-zh_CN gu-zh_CN gv-zh_CN ha-zh_CN he-zh_CN hi-zh_CN hr-zh_CN hu-zh_CN hy-zh_CN ia-zh_CN id-zh_CN ig-zh_CN io-zh_CN is-zh_CN it-zh_CN it_IT-zh_CN ja-zh_CN jbo-zh_CN ka-zh_CN kg-zh_CN kk-zh_CN km-zh_CN kn-zh_CN ko-zh_CN kr-zh_CN ks-zh_CN ku-zh_CN ky-zh_CN la-zh_CN lg-zh_CN li-zh_CN lo-zh_CN lt-zh_CN lv-zh_CN mai-zh_CN mg-zh_CN mi-zh_CN mk-zh_CN ml-zh_CN mn-zh_CN mr-zh_CN ms-zh_CN mt-zh_CN mus-zh_CN my-zh_CN nb-zh_CN nb_NO-zh_CN nds-zh_CN ne-zh_CN nhn-zh_CN nl-zh_CN nn-zh_CN nn_NO-zh_CN no-zh_CN no_nb-zh_CN nr-zh_CN nso-zh_CN oc-zh_CN or-zh_CN os-zh_CN pa-zh_CN pl-zh_CN ps-zh_CN pt-zh_CN pt_BR-zh_CN pt_PT-zh_CN quz-zh_CN ro-zh_CN ru-zh_CN rw-zh_CN si-zh_CN sk-zh_CN sl-zh_CN so-zh_CN sq-zh_CN sr-zh_CN sr_ME-zh_CN st-zh_CN sv-zh_CN sw-zh_CN szl-zh_CN ta-zh_CN te-zh_CN tg-zh_CN th-zh_CN tk-zh_CN tl-zh_CN tmp-zh_CN tr-zh_CN tr_TR-zh_CN ts-zh_CN tt-zh_CN ug-zh_CN uk-zh_CN ur-zh_CN ur_PK-zh_CN uz-zh_CN vi-zh_CN wa-zh_CN xh-zh_CN yi-zh_CN yo-zh_CN af-zh_HK am-zh_HK an-zh_HK ang-zh_HK ar-zh_HK ar_TN-zh_HK ara-zh_HK as-zh_HK ast-zh_HK az-zh_HK az_IR-zh_HK bal-zh_HK be-zh_HK bem-zh_HK bg-zh_HK bg_BG-zh_HK bn-zh_HK bn_IN-zh_HK bo-zh_HK br-zh_HK brx-zh_HK bs-zh_HK ca-zh_HK crh-zh_HK cs-zh_HK csb-zh_HK cy-zh_HK da-zh_HK da_DK-zh_HK de-zh_HK dv-zh_HK dz-zh_HK el-zh_HK en-zh_HK en_AU-zh_HK en_CA-zh_HK en_GB-zh_HK en_US-zh_HK eo-zh_HK es-zh_HK es_AR-zh_HK es_CL-zh_HK es_CO-zh_HK es_CR-zh_HK es_DO-zh_HK es_EC-zh_HK es_ES-zh_HK es_GT-zh_HK es_HN-zh_HK es_MX-zh_HK es_NI-zh_HK es_PA-zh_HK es_PE-zh_HK es_PR-zh_HK es_SV-zh_HK es_UY-zh_HK es_VE-zh_HK et-zh_HK eu-zh_HK fa-zh_HK fa_IR-zh_HK fi-zh_HK fo-zh_HK foo-zh_HK fr-zh_HK fur-zh_HK fy-zh_HK ga-zh_HK gd-zh_HK gl-zh_HK gn-zh_HK gu-zh_HK gv-zh_HK ha-zh_HK he-zh_HK hi-zh_HK hr-zh_HK hu-zh_HK hy-zh_HK ia-zh_HK id-zh_HK ig-zh_HK io-zh_HK is-zh_HK it-zh_HK it_IT-zh_HK ja-zh_HK jbo-zh_HK ka-zh_HK kg-zh_HK kk-zh_HK km-zh_HK kn-zh_HK ko-zh_HK ks-zh_HK ku-zh_HK ky-zh_HK la-zh_HK lg-zh_HK li-zh_HK lo-zh_HK lt-zh_HK lv-zh_HK mai-zh_HK mg-zh_HK mi-zh_HK mk-zh_HK ml-zh_HK mn-zh_HK mr-zh_HK ms-zh_HK mt-zh_HK mus-zh_HK my-zh_HK nb-zh_HK nb_NO-zh_HK nds-zh_HK ne-zh_HK nhn-zh_HK nl-zh_HK nn-zh_HK nn_NO-zh_HK no-zh_HK nso-zh_HK oc-zh_HK or-zh_HK os-zh_HK pa-zh_HK pl-zh_HK ps-zh_HK pt-zh_HK pt_BR-zh_HK pt_PT-zh_HK quz-zh_HK ro-zh_HK ru-zh_HK rw-zh_HK si-zh_HK sk-zh_HK sl-zh_HK so-zh_HK sq-zh_HK sr-zh_HK sr_ME-zh_HK sv-zh_HK sw-zh_HK szl-zh_HK ta-zh_HK te-zh_HK tg-zh_HK th-zh_HK tk-zh_HK tl-zh_HK tmp-zh_HK tr-zh_HK ts-zh_HK tt-zh_HK ug-zh_HK uk-zh_HK ur-zh_HK ur_PK-zh_HK uz-zh_HK vi-zh_HK wa-zh_HK xh-zh_HK yi-zh_HK yo-zh_HK zh_CN-zh_HK af-zh_TW am-zh_TW an-zh_TW ang-zh_TW ar-zh_TW ar_TN-zh_TW ara-zh_TW as-zh_TW ast-zh_TW az-zh_TW az_IR-zh_TW bal-zh_TW be-zh_TW bem-zh_TW bg-zh_TW bg_BG-zh_TW bn-zh_TW bn_IN-zh_TW bo-zh_TW br-zh_TW brx-zh_TW bs-zh_TW ca-zh_TW crh-zh_TW cs-zh_TW csb-zh_TW cy-zh_TW da-zh_TW da_DK-zh_TW de-zh_TW de_CH-zh_TW dv-zh_TW dz-zh_TW el-zh_TW en-zh_TW en_AU-zh_TW en_CA-zh_TW en_GB-zh_TW en_NZ-zh_TW en_US-zh_TW en_ZA-zh_TW eo-zh_TW es-zh_TW es_AR-zh_TW es_CL-zh_TW es_CO-zh_TW es_CR-zh_TW es_DO-zh_TW es_EC-zh_TW es_ES-zh_TW es_GT-zh_TW es_HN-zh_TW es_MX-zh_TW es_NI-zh_TW es_PA-zh_TW es_PE-zh_TW es_PR-zh_TW es_SV-zh_TW es_UY-zh_TW es_VE-zh_TW et-zh_TW eu-zh_TW fa-zh_TW fa_IR-zh_TW fi-zh_TW fo-zh_TW foo-zh_TW fr-zh_TW fur-zh_TW fy-zh_TW ga-zh_TW gd-zh_TW gl-zh_TW gn-zh_TW gu-zh_TW gv-zh_TW ha-zh_TW he-zh_TW hi-zh_TW hr-zh_TW hu-zh_TW hy-zh_TW ia-zh_TW id-zh_TW ig-zh_TW io-zh_TW is-zh_TW it-zh_TW it_IT-zh_TW ja-zh_TW jbo-zh_TW ka-zh_TW kg-zh_TW kk-zh_TW km-zh_TW kn-zh_TW ko-zh_TW ks-zh_TW ku-zh_TW ky-zh_TW la-zh_TW lg-zh_TW li-zh_TW lo-zh_TW lt-zh_TW lv-zh_TW mai-zh_TW mg-zh_TW mi-zh_TW mk-zh_TW ml-zh_TW mn-zh_TW mr-zh_TW ms-zh_TW mt-zh_TW mus-zh_TW my-zh_TW nb-zh_TW nb_NO-zh_TW nds-zh_TW ne-zh_TW nhn-zh_TW nl-zh_TW nn-zh_TW nn_NO-zh_TW no-zh_TW no_nb-zh_TW nr-zh_TW nso-zh_TW oc-zh_TW or-zh_TW os-zh_TW pa-zh_TW pl-zh_TW ps-zh_TW pt-zh_TW pt_BR-zh_TW pt_PT-zh_TW quz-zh_TW ro-zh_TW ru-zh_TW rw-zh_TW si-zh_TW sk-zh_TW sl-zh_TW so-zh_TW sq-zh_TW sr-zh_TW sr_ME-zh_TW st-zh_TW sv-zh_TW sw-zh_TW szl-zh_TW ta-zh_TW te-zh_TW tg-zh_TW th-zh_TW tk-zh_TW tl-zh_TW tmp-zh_TW tr-zh_TW tr_TR-zh_TW ts-zh_TW tt-zh_TW ug-zh_TW uk-zh_TW ur-zh_TW ur_PK-zh_TW uz-zh_TW vi-zh_TW wa-zh_TW xh-zh_TW yi-zh_TW yo-zh_TW zh_CN-zh_TW zh_HK-zh_TW af-zu am-zu an-zu ar-zu ar_TN-zu as-zu ast-zu az-zu be-zu bem-zu bg-zu bn-zu bn_IN-zu bo-zu br-zu brx-zu bs-zu ca-zu crh-zu cs-zu csb-zu cy-zu da-zu de-zu dv-zu dz-zu el-zu en-zu en_CA-zu en_GB-zu en_US-zu en_ZA-zu eo-zu es-zu et-zu eu-zu fa-zu fi-zu fr-zu fur-zu fy-zu ga-zu gd-zu gl-zu gn-zu gu-zu gv-zu ha-zu he-zu hi-zu hr-zu hu-zu hy-zu ia-zu id-zu ig-zu io-zu is-zu it-zu ja-zu ka-zu kg-zu kk-zu km-zu kn-zu ko-zu ks-zu ku-zu ky-zu la-zu lg-zu li-zu lo-zu lt-zu lv-zu mai-zu mg-zu mi-zu mk-zu ml-zu mn-zu mr-zu ms-zu my-zu nb-zu nds-zu ne-zu nl-zu nn-zu nr-zu nso-zu oc-zu or-zu pa-zu pl-zu ps-zu pt-zu pt_BR-zu quz-zu ro-zu ru-zu rw-zu si-zu sk-zu sl-zu so-zu sq-zu sr-zu sr_ME-zu st-zu sv-zu sw-zu szl-zu ta-zu te-zu tg-zu th-zu tk-zu tmp-zu tr-zu ts-zu tt-zu ug-zu uk-zu ur-zu ur_PK-zu uz-zu vi-zu wa-zu xh-zu yi-zu yo-zu zh_CN-zu zh_HK-zu zh_TW-zu
giga_fren_v2	giga-fren/v2/moses/%s-%s.txt.zip	en-fr
fiskmo_v2	fiskmo/v2/moses/%s-%s.txt.zip	fi-sv
Finlex_v2018	Finlex/v2018/moses/%s-%s.txt.zip	fi-sv
Europarl_v8	Europarl/v8/moses/%s-%s.txt.zip	bg-cs da-cs bg-da cs-da bg-de cs-de da-de bg-el cs-el da-el de-el bg-en cs-en da-en de-en el-en bg-es cs-es da-es de-es el-es en-es bg-et cs-et da-et de-et el-et en-et es-et bg-fi cs-fi da-fi de-fi el-fi en-fi es-fi et-fi bg-fr cs-fr da-fr de-fr el-fr en-fr es-fr et-fr fi-fr bg-hu cs-hu da-hu de-hu el-hu en-hu es-hu et-hu fi-hu fr-hu bg-it cs-it da-it de-it el-it en-it es-it et-it fi-it fr-it hu-it bg-lt cs-lt da-lt de-lt el-lt en-lt es-lt et-lt fi-lt fr-lt hu-lt it-lt bg-lv cs-lv da-lv de-lv el-lv en-lv es-lv et-lv fi-lv fr-lv hu-lv it-lv lt-lv bg-nl cs-nl da-nl de-nl el-nl en-nl es-nl et-nl fi-nl fr-nl hu-nl it-nl lt-nl lv-nl bg-pl cs-pl da-pl de-pl el-pl en-pl es-pl et-pl fi-pl fr-pl hu-pl it-pl lt-pl lv-pl nl-pl bg-pt cs-pt da-pt de-pt el-pt en-pt es-pt et-pt fi-pt fr-pt hu-pt it-pt lt-pt lv-pt nl-pt pl-pt bg-ro cs-ro da-ro de-ro el-ro en-ro es-ro et-ro fi-ro fr-ro hu-ro it-ro lt-ro lv-ro nl-ro pl-ro pt-ro bg-sk cs-sk da-sk de-sk el-sk en-sk es-sk et-sk fi-sk fr-sk hu-sk it-sk lt-sk lv-sk nl-sk pl-sk pt-sk ro-sk bg-sl cs-sl da-sl de-sl el-sl en-sl es-sl et-sl fi-sl fr-sl hu-sl it-sl lt-sl lv-sl nl-sl pl-sl pt-sl ro-sl sk-sl bg-sv cs-sv da-sv de-sv el-sv en-sv es-sv et-sv fi-sv fr-sv hu-sv it-sv lt-sv lv-sv nl-sv pl-sv pt-sv ro-sv sk-sv sl-sv"""

from mtdata import log
from mtdata.index import Index, Entry
from collections import defaultdict


def load_all(index: Index):
    from mtdata.iso import iso3_code
    citation = """@inproceedings{tiedemann2012parallel,
  title={Parallel Data, Tools and Interfaces in OPUS.},
  author={Tiedemann, J{\"o}rg},
  booktitle={Lrec},
  volume={2012},
  pages={2214--2218},
  year={2012}
}"""
    skip_langs = set()
    skip_counts = defaultdict(int)
    dupes = defaultdict(set)
    for line in data.split('\n'):
        assert len(line.split('\t')) == 3 , line
        name, url_pat, pairs = line.split('\t')
        name = 'OPUS_' + name.replace('.', '_').replace('-', '_')
        url_pat = f'http://opus.nlpl.eu/download.php?f={url_pat}'
        assert url_pat.endswith('.txt.zip')
        in_ext = 'txt'

        for pair in pairs.split(" "):
            l1, l2 = pair.split('-')
            url = url_pat % (l1, l2)
            iso_l1, iso_l2 = iso3_code(l1), iso3_code(l2)
            langs = (iso_l1, iso_l2)
            if not iso_l1 or not iso_l2 or index.contains_entry(name, langs):
                skip_counts[l1] += 1
                skip_counts[l2] += 1
                if not iso_l1:
                    skip_langs.add(l1)
                if not iso_l2:
                    skip_langs.add(l2)
                if index.contains_entry(name, langs):
                    dupes[name].add(langs)
                continue
            entry = Entry(langs=langs, name=name, url=url, cite=citation,
                          in_paths=[f'*.{l1}', f'*.{l2}'], in_ext=in_ext)
            index.add_entry(entry)
    log.debug(f"Skipped langs: {skip_langs}")
    log.debug(f"Duplicates langs: {dupes}")
